# We have to override the new %%install behavior because, well... the kernel is special.
%global __spec_install_pre %{___build_pre}

Summary: The Linux kernel

# % define buildid .local

# For a kernel released for public testing, released_kernel should be 1.
# For internal testing builds during development, it should be 0.
%global released_kernel 1

%global distro_build 327

%define rpmversion 3.10.0
%define pkgrelease 327.3.1.el7

%define pkg_release %{pkgrelease}%{?buildid}

# The kernel tarball/base version
%define rheltarball %{rpmversion}-%{pkgrelease}

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# kernel
%define with_default   %{?_without_default:   0} %{?!_without_default:   1}
# kernel-debug
%define with_debug     %{?_without_debug:     0} %{?!_without_debug:     1}
# kernel-doc
%define with_doc       %{?_without_doc:       0} %{?!_without_doc:       1}
# kernel-headers
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
# perf
%define with_perf      %{?_without_perf:      0} %{?!_without_perf:      1}
# tools
%define with_tools     %{?_without_tools:     0} %{?!_without_tools:     1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# kernel-kdump (only for s390x)
%define with_kdump     %{?_without_kdump:     0} %{?!_without_kdump:     0}
# kernel-bootwrapper (for creating zImages from kernel + initrd)
%define with_bootwrapper %{?_without_bootwrapper: 0} %{?!_without_bootwrapper: 0}
# kernel-abi-whitelists
%define with_kernel_abi_whitelists %{?_with_kernel_abi_whitelists: 0} %{?!_with_kernel_abi_whitelists: 1}

# In RHEL, we always want the doc build failing to build to be a failure,
# which means settings this to false.
%define doc_build_fail false

# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the debug kernel (--with dbgonly):
%define with_dbgonly   %{?_with_dbgonly:      1} %{?!_with_dbgonly:      0}

# Control whether we perform a compat. check against published ABI.
%define with_kabichk   %{?_without_kabichk:   0} %{?!_without_kabichk:   1}

# should we do C=1 builds with sparse
%define with_sparse    %{?_with_sparse:       1} %{?!_with_sparse:       0}

# Cross compile requested?
%define with_cross    %{?_with_cross:         1} %{?!_with_cross:        0}

# Set debugbuildsenabled to 1 for production (build separate debug kernels)
#  and 0 for rawhide (all kernels are debug kernels).
# See also 'make debug' and 'make release'. RHEL only ever does 1.
%define debugbuildsenabled 1

%define with_gcov %{?_with_gcov: 1} %{?!_with_gcov: 0}

# turn off debug kernel and kabichk for gcov builds
%if %{with_gcov}
%define with_debug 0
%define with_kabichk 0
%endif

%define make_target bzImage

# Kernel Version Release + Arch -> KVRA
%define KVRA %{version}-%{release}.%{_target_cpu}
%define hdrarch %{_target_cpu}
%define asmarch %{_target_cpu}
%define cross_target %{_target_cpu}

%if !%{debugbuildsenabled}
%define with_debug 0
%endif

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug

# if requested, only build base kernel
%if %{with_baseonly}
%define with_debug 0
%define with_kdump 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%define with_default 0
%define with_kdump 0
%define with_tools 0
%define with_perf 0
%endif

# These arches install vdso/ directories.
%define vdso_arches %{all_x86} x86_64 ppc ppc64 ppc64le s390 s390x

# Overrides for generic default options

# only build kernel-debug on x86_64, s390x, ppc64 ppc64le
%ifnarch x86_64 s390x ppc64 ppc64le
%define with_debug 0
%endif

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%define with_kernel_abi_whitelists 0
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_default 0
%define with_headers 0
%define with_tools 0
%define with_perf 0
%define all_arch_configs kernel-%{version}-*.config
%endif

# sparse blows up on ppc64
%ifarch ppc64 ppc64le ppc
%define with_sparse 0
%endif

# Per-arch tweaks

%ifarch i686
%define asmarch x86
%define hdrarch i386
%endif

%ifarch x86_64
%define asmarch x86
%define all_arch_configs kernel-%{version}-x86_64*.config
%define image_install_path boot
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc
%define asmarch powerpc
%define hdrarch powerpc
%endif

%ifarch ppc64 ppc64le
%define asmarch powerpc
%define hdrarch powerpc
%define all_arch_configs kernel-%{version}-ppc64*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define with_bootwrapper 1
%define cross_target powerpc64
%define kcflags -O3
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs kernel-%{version}-s390x*.config
%define image_install_path boot
%define kernel_image arch/s390/boot/bzImage
%define with_tools 0
%define with_kdump 1
%endif

#cross compile make
%if %{with_cross}
%define cross_opts CROSS_COMPILE=%{cross_target}-linux-gnu-
%define with_perf 0
%define with_tools 0
%endif

# Should make listnewconfig fail if there's config options
# printed out?
%define listnewconfig_fail 1

# To temporarily exclude an architecture from being built, add it to
# %%nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We only build kernel-headers on the following...
%define nobuildarches i686 s390 ppc

%ifarch %nobuildarches
%define with_default 0
%define with_debuginfo 0
%define with_kdump 0
%define with_tools 0
%define with_perf 0
%define _enable_debug_packages 0
%endif

# Architectures we build tools/cpupower on
%define cpupowerarchs x86_64 ppc64 ppc64le

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2, device-mapper-libs < 1.02.63-2, mdadm < 3.2.1-5

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%define package_conflicts initscripts < 7.23, udev < 063-6, iptables < 1.3.2-1, ipw2200-firmware < 2.4, iwl4965-firmware < 228.57.2, selinux-policy-targeted < 1.25.3-14, squashfs-tools < 4.0, wireless-tools < 29-3

# We moved the drm include files into kernel-headers, make sure there's
# a recent enough libdrm-devel on the system that doesn't have those.
%define kernel_headers_conflicts libdrm-devel < 2.4.0-0.15

#
# Packages that need to be installed before the kernel is, because the %%post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools >= 3.16-2, initscripts >= 8.11.1-1, grubby >= 8.28-2
%define initrd_prereq  dracut >= 033-283

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: kernel = %{rpmversion}-%{pkg_release}\
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:.%{1}}\
Provides: kernel-drm = 4.3.0\
Provides: kernel-drm-nouveau = 16\
Provides: kernel-modeset = 1\
Provides: kernel-uname-r = %{KVRA}%{?1:.%{1}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): linux-firmware >= 20150904-43\
Requires(post): %{_sbindir}/new-kernel-pkg\
Requires(preun): %{_sbindir}/new-kernel-pkg\
Conflicts: %{kernel_dot_org_conflicts}\
Conflicts: %{package_conflicts}\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}

Name: kernel%{?variant}
Group: System Environment/Kernel
License: GPLv2
URL: http://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch i686 x86_64 ppc ppc64 ppc64le s390 s390x
ExclusiveOS: Linux

%kernel_reqprovconf

#
# List the packages used during the kernel build
#
BuildRequires: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildRequires: xz, findutils, gzip, m4, perl, make >= 3.78, diffutils, gawk
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config >= 9.1.0-55
BuildRequires: hostname, net-tools, bc
BuildRequires: xmlto, asciidoc
BuildRequires: openssl
BuildRequires: hmaccalc
BuildRequires: python-devel, newt-devel, perl(ExtUtils::Embed)
%ifarch x86_64
BuildRequires: pesign >= 0.109-4
%endif
%if %{with_sparse}
BuildRequires: sparse >= 0.4.1
%endif
%if %{with_perf}
BuildRequires: elfutils-devel zlib-devel binutils-devel bison
BuildRequires: audit-libs-devel
%ifnarch s390 s390x
BuildRequires: numactl-devel
%endif
%endif
%if %{with_tools}
BuildRequires: pciutils-devel gettext ncurses-devel
%endif
%if %{with_debuginfo}
# Fancy new debuginfo generation introduced in Fedora 8/RHEL 6.
# The -r flag to find-debuginfo.sh invokes eu-strip --reloc-debug-sections
# which reduces the number of relocations in kernel module .ko.debug files and
# was introduced with rpm 4.9 and elfutils 0.153.
BuildRequires: rpm-build >= 4.9.0-1, elfutils >= 0.153-1
%define debuginfo_args --strict-build-id -r
%endif
%ifarch s390x
# required for zfcpdump
BuildRequires: glibc-static
%endif

Source0: linux-%{rpmversion}-%{pkgrelease}.tar.xz

Source1: Makefile.common

Source10: sign-modules
%define modsign_cmd %{SOURCE10}
Source11: x509.genkey
Source12: extra_certificates
%if %{?released_kernel}
Source13: centos.cer
Source14: secureboot.cer
%define pesign_name redhatsecureboot301
%else
Source13: centos.cer
Source14: secureboot.cer
%define pesign_name redhatsecureboot003
%endif
Source15: centos-ldup.x509
Source16: centos-kpatch.x509

Source18: check-kabi

Source20: Module.kabi_x86_64
Source21: Module.kabi_ppc64
Source22: Module.kabi_ppc64le
Source23: Module.kabi_s390x

Source25: kernel-abi-whitelists-%{distro_build}.tar.bz2

Source50: kernel-%{version}-x86_64.config
Source51: kernel-%{version}-x86_64-debug.config

Source60: kernel-%{version}-ppc64.config
Source61: kernel-%{version}-ppc64-debug.config
Source62: kernel-%{version}-ppc64le.config
Source63: kernel-%{version}-ppc64le-debug.config

Source70: kernel-%{version}-s390x.config
Source71: kernel-%{version}-s390x-debug.config
Source72: kernel-%{version}-s390x-kdump.config

# Sources for kernel-tools
Source2000: cpupower.service
Source2001: cpupower.config

# empty final patch to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch
Patch1000: debrand-single-cpu.patch
Patch1001: debrand-rh_taint.patch
Patch1002: debrand-rh-i686-cpu.patch

BuildRoot: %{_tmppath}/kernel-%{KVRA}-root

%description
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
AutoReqProv: no
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders < 3.0-46
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package bootwrapper
Summary: Boot wrapper files for generating combined kernel + initrd images
Group: Development/System
Requires: gzip binutils
%description bootwrapper
Kernel-bootwrapper contains the wrapper code which makes bootable "zImage"
files combining both kernel and initial ramdisk.

%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{with_perf}
%package -n perf
Summary: Performance monitoring for the Linux kernel
Group: Development/System
License: GPLv2
%description -n perf
This package contains the perf tool, which enables performance monitoring
of the Linux kernel.

%package -n perf-debuginfo
Summary: Debug information for package perf
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n perf-debuginfo
This package provides debug information for the perf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '.*%%{_bindir}/perf(\.debug)?|.*%%{_libexecdir}/perf-core/.*|XXX' -o perf-debuginfo.list}

%package -n python-perf
Summary: Python bindings for apps which will manipulate perf events
Group: Development/Libraries
%description -n python-perf
The python-perf package contains a module that permits applications
written in the Python programming language to use the interface
to manipulate perf events.

%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%package -n python-perf-debuginfo
Summary: Debug information for package perf python bindings
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n python-perf-debuginfo
This package provides debug information for the perf python bindings.

# the python_sitearch macro should already be defined from above
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '.*%%{python_sitearch}/perf.so(\.debug)?|XXX' -o python-perf-debuginfo.list}


%endif # with_perf

%if %{with_tools}

%package -n kernel-tools
Summary: Assortment of tools for the Linux kernel
Group: Development/System
License: GPLv2
Provides:  cpupowerutils = 1:009-0.6.p1
Obsoletes: cpupowerutils < 1:009-0.6.p1
Provides:  cpufreq-utils = 1:009-0.6.p1
Provides:  cpufrequtils = 1:009-0.6.p1
Obsoletes: cpufreq-utils < 1:009-0.6.p1
Obsoletes: cpufrequtils < 1:009-0.6.p1
Obsoletes: cpuspeed < 1:2.0
Requires: kernel-tools-libs = %{version}-%{release}
%description -n kernel-tools
This package contains the tools/ directory from the kernel source
and the supporting documentation.

%package -n kernel-tools-libs
Summary: Libraries for the kernels-tools
Group: Development/System
License: GPLv2
%description -n kernel-tools-libs
This package contains the libraries built from the tools/ directory
from the kernel source.

%package -n kernel-tools-libs-devel
Summary: Assortment of tools for the Linux kernel
Group: Development/System
License: GPLv2
Requires: kernel-tools = %{version}-%{release}
Provides:  cpupowerutils-devel = 1:009-0.6.p1
Obsoletes: cpupowerutils-devel < 1:009-0.6.p1
Requires: kernel-tools-libs = %{version}-%{release}
Provides: kernel-tools-devel
%description -n kernel-tools-libs-devel
This package contains the development files for the tools/ directory from
the kernel source.

%package -n kernel-tools-debuginfo
Summary: Debug information for package kernel-tools
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n kernel-tools-debuginfo
This package provides debug information for package kernel-tools.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '.*%%{_bindir}/centrino-decode(\.debug)?|.*%%{_bindir}/powernow-k8-decode(\.debug)?|.*%%{_bindir}/cpupower(\.debug)?|.*%%{_libdir}/libcpupower.*|.*%%{_libdir}/libcpupower.*|.*%%{_bindir}/turbostat(\.debug)?|.*%%{_bindir}/x86_energy_perf_policy(\.debug)?|.*%%{_bindir}/tmon(\.debug)?|XXX' -o kernel-tools-debuginfo.list}

%endif # with_tools

%if %{with_gcov}
%package gcov
Summary: gcov graph and source files for coverage data collection.
Group: Development/System
%description gcov
kernel-gcov includes the gcov graph and source files for gcov coverage collection.
%endif

%package -n kernel-abi-whitelists
Summary: The CentOS Linux kernel ABI symbol whitelists
Group: System Environment/Kernel
AutoReqProv: no
%description -n kernel-abi-whitelists
The kABI package contains information pertaining to the CentOS
Linux kernel ABI, including lists of kernel symbols that are needed by
external Linux kernel modules, and a yum plugin to aid enforcement.

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
AutoReqProv: no\
%description -n %{name}%{?1:-%{1}}-debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVRA}.\
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '/.*/%%{KVRA}%{?1:\.%{1}}/.*|/.*%%{KVRA}%{?1:\.%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel-devel-uname-r = %{KVRA}%{?1:.%{1}}\
AutoReqProv: no\
Requires(pre): /usr/bin/find\
Requires: perl\
%description -n kernel%{?variant}%{?1:-%{1}}-devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package %1\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
%kernel_reqprovconf\
%{expand:%%kernel_devel_package %1 %{!?-n:%1}%{?-n:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %1}\
%{nil}


# First the auxiliary packages of the main kernel package.
%kernel_devel_package
%kernel_debuginfo_package


# Now, each variant package.

%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

%define variant_summary A minimal Linux kernel compiled for crash dumps
%kernel_variant_package kdump
%description kdump
This package includes a kdump version of the Linux kernel. It is
required only on machines which will use the kexec-based kernel crash dump
mechanism.

%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_default}
echo "Cannot build --with baseonly, default kernel build is disabled"
exit 1
%endif
%endif

# more sanity checking; do it quietly
if [ "%{patches}" != "%%{patches}" ] ; then
  for patch in %{patches} ; do
    if [ ! -f $patch ] ; then
      echo "ERROR: Patch  ${patch##/*/}  listed in specfile but is missing"
      exit 1
    fi
  done
fi 2>/dev/null

patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  if ! grep -E "^Patch[0-9]+: $patch\$" %{_specdir}/${RPM_PACKAGE_NAME%%%%%{?variant}}.spec ; then
    if [ "${patch:0:8}" != "patch-3." ] ; then
      echo "ERROR: Patch  $patch  not listed as a source patch in specfile"
      exit 1
    fi
  fi 2>/dev/null
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz) gunzip < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# don't apply patch if it's empty
ApplyOptionalPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  local C=$(wc -l $RPM_SOURCE_DIR/$patch | awk '{print $1}')
  if [ "$C" -gt 9 ]; then
    ApplyPatch $patch ${1+"$@"}
  fi
}

%setup -q -n kernel-%{rheltarball} -c
mv linux-%{rheltarball} linux-%{KVRA}
cd linux-%{KVRA}

# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/kernel-%{version}-*.config .

ApplyOptionalPatch linux-kernel-test.patch
ApplyOptionalPatch debrand-single-cpu.patch
ApplyOptionalPatch debrand-rh_taint.patch
ApplyOptionalPatch debrand-rh-i686-cpu.patch

# Any further pre-build tree manipulations happen here.

chmod +x scripts/checkpatch.pl

# This Prevents scripts/setlocalversion from mucking with our version numbers.
touch .scmversion

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

if [ -L configs ]; then
	rm -f configs
	mkdir configs
fi

# Remove configs not for the buildarch
for cfg in kernel-%{version}-*.config; do
  if [ `echo %{all_arch_configs} | grep -c $cfg` -eq 0 ]; then
    rm -f $cfg
  fi
done

%if !%{debugbuildsenabled}
rm -f kernel-%{version}-*debug.config
%endif

# enable GCOV kernel config options if gcov is on
%if %{with_gcov}
for i in *.config
do
  sed -i 's/# CONFIG_GCOV_KERNEL is not set/CONFIG_GCOV_KERNEL=y\nCONFIG_GCOV_PROFILE_ALL=y\n/' $i
done
%endif

# now run oldconfig over all the config files
for i in *.config
do
  mv $i .config
  Arch=`head -1 .config | cut -b 3-`
  make %{?cross_opts} ARCH=$Arch listnewconfig | grep -E '^CONFIG_' >.newoptions || true
%if %{listnewconfig_fail}
  if [ -s .newoptions ]; then
    cat .newoptions
    exit 1
  fi
%endif
  rm -f .newoptions
  make %{?cross_opts} ARCH=$Arch oldnoconfig
  echo "# $Arch" > configs/$i
  cat .config >> configs/$i
done
# end of kernel config
%endif

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

# remove unnecessary SCM files
find . -name .gitignore -exec rm -f {} \; >/dev/null

cd ..

###
### build
###
%build

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

%if %{with_debuginfo}
# This override tweaks the kernel makefiles so that we run debugedit on an
# object before embedding it.  When we later run find-debuginfo.sh, it will
# run debugedit again.  The edits it does change the build ID bits embedded
# in the stripped object, but repeating debugedit is a no-op.  We do it
# beforehand to get the proper final build ID bits into the embedded image.
# This affects the vDSO images in vmlinux, and the vmlinux image in bzImage.
export AFTER_LINK='sh -xc "/usr/lib/rpm/debugedit -b $$RPM_BUILD_DIR -d /usr/src/debug -i $@ > $@.id"'
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3
    InstallName=${4:-vmlinuz}

    # Pick the right config file for the kernel we're building
    Config=kernel-%{version}-%{_target_cpu}${Flavour:+-${Flavour}}.config
    DevelDir=/usr/src/kernels/%{KVRA}${Flavour:+.${Flavour}}

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    KernelVer=%{KVRA}${Flavour:+.${Flavour}}
    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}.%{_target_cpu}${Flavour:+.${Flavour}}/" Makefile

    # and now to start the build process

    make %{?cross_opts} -s mrproper

    cp %{SOURCE11} .	# x509.genkey
    cp %{SOURCE12} .	# extra_certificates
    cp %{SOURCE15} .	# rheldup3.x509
    cp %{SOURCE16} .	# rhelkpatch1.x509

    cp configs/$Config .config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

%ifarch s390x
    if [ "$Flavour" == "kdump" ]; then
        pushd arch/s390/boot
        gcc -static -o zfcpdump zfcpdump.c
        popd
    fi
%endif

    make -s %{?cross_opts} ARCH=$Arch oldnoconfig >/dev/null
    make -s %{?cross_opts} ARCH=$Arch V=1 %{?_smp_mflags} KCFLAGS="%{?kcflags}" WITH_GCOV="%{?with_gcov}" $MakeTarget %{?sparse_mflags}

    if [ "$Flavour" != "kdump" ]; then
        make -s %{?cross_opts} ARCH=$Arch V=1 %{?_smp_mflags} KCFLAGS="%{?kcflags}" WITH_GCOV="%{?with_gcov}" modules %{?sparse_mflags} || exit 1
    fi

    # Start installing the results
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/boot
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer

    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20

    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi
# EFI SecureBoot signing, x86_64-only
%ifarch x86_64
    %pesign -s -i $KernelImage -o $KernelImage.signed -a %{SOURCE13} -c %{SOURCE13}
    mv $KernelImage.signed $KernelImage
%endif
    $CopyKernel $KernelImage $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer

    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    sha512hmac $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer | sed -e "s,$RPM_BUILD_ROOT,," > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/kernel
    if [ "$Flavour" != "kdump" ]; then
        # Override $(mod-fw) because we don't want it to install any firmware
        # we'll get it from the linux-firmware package and we don't want conflicts
        make -s %{?cross_opts} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=
%if %{with_gcov}
	# install gcov-needed files to $BUILDROOT/$BUILD/...:
	#   gcov_info->filename is absolute path
	#   gcno references to sources can use absolute paths (e.g. in out-of-tree builds)
	#   sysfs symlink targets (set up at compile time) use absolute paths to BUILD dir
	find . \( -name '*.gcno' -o -name '*.[chS]' \) -exec install -D '{}' "$RPM_BUILD_ROOT/$(pwd)/{}" \;
%endif
    fi
%ifarch %{vdso_arches}
    make -s %{?cross_opts} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
    if [ ! -s ldconfig-kernel.conf ]; then
      echo > ldconfig-kernel.conf "\
# Placeholder file, no vDSO hwcap entries used in this kernel."
    fi
    %{__install} -D -m 444 ldconfig-kernel.conf $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-$KernelVer.conf
%endif

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    # NOTENOTE: the name symvers is used by the rpm backend
    # NOTENOTE: to discover and run the /usr/lib/rpm/fileattrs/kabi.attr
    # NOTENOTE: script which dynamically adds exported kernel symbol
    # NOTENOTE: checksums to the rpm metadata provides list.
    # NOTENOTE: if you change the symvers name, update the backend too
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz

%if %{with_kabichk}
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        rm $RPM_BUILD_ROOT/Module.kabi # for now, don't keep it around.
    else
        echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi
%endif

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
%ifarch ppc64 ppc64le
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include

    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/autoconf.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

%if %{with_debuginfo}
    if test -s vmlinux.id; then
      cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id
    else
      echo >&2 "*** ERROR *** no vmlinux build ID! ***"
      exit 1
    fi

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    grep -F /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
      LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking 'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|rt2x00(pci|usb)_probe|register_netdevice'
    collect_modules_list block 'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm 'drm_open|drm_init'
    collect_modules_list modesetting 'drm_crtc_init'

    # detect missing or incorrect license tags
    rm -f modinfo
    while read i
    do
      echo -n "${i#$RPM_BUILD_ROOT/lib/modules/$KernelVer/} " >> modinfo
      /sbin/modinfo -l $i >> modinfo
    done < modnames

    grep -E -v 'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' modinfo && exit 1

    rm -f modinfo modnames

    # Save off the .tmp_versions/ directory.  We'll use it in the
    # __debug_install_post macro below to sign the right things
    # Also save the signing keys so we actually sign the modules with the
    # right key.
    cp -r .tmp_versions .tmp_versions.sign${Flavour:+.${Flavour}}
    cp signing_key.priv signing_key.priv.sign${Flavour:+.${Flavour}}
    cp signing_key.x509 signing_key.x509.sign${Flavour:+.${Flavour}}

    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias alias.bin builtin.bin ccwmap dep dep.bin ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols symbols.bin usbmap softdep devname
    do
      rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    # prune junk from kernel-devel
    find $RPM_BUILD_ROOT/usr/src/kernels -name ".*.cmd" -exec rm -f {} \;
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot
mkdir -p $RPM_BUILD_ROOT%{_libexecdir}

cd linux-%{KVRA}

%if %{with_default}
BuildKernel %make_target %kernel_image
%endif

%if %{with_debug}
BuildKernel %make_target %kernel_image debug
%endif

%if %{with_kdump}
BuildKernel %make_target %kernel_image kdump
%endif

%global perf_make make %{?_smp_mflags} -C tools/perf -s V=1 WERROR=0 NO_LIBUNWIND=1 HAVE_CPLUS_DEMANGLE=1 NO_GTK2=1 NO_STRLCPY=1 NO_PERF_READ_VDSO32=1 NO_PERF_READ_VDSOX32=1 prefix=%{_prefix} lib=%{_lib}
%if %{with_perf}
# perf
%{perf_make} all
%{perf_make} man || %{doc_build_fail}
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
# cpupower
# make sure version-gen.sh is executable.
chmod +x tools/power/cpupower/utils/version-gen.sh
make %{?cross_opts} %{?_smp_mflags} -C tools/power/cpupower CPUFREQ_BENCH=false
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    make %{?_smp_mflags} centrino-decode powernow-k8-decode
    popd
%endif
%ifarch x86_64
   pushd tools/power/x86/x86_energy_perf_policy/
   make
   popd
   pushd tools/power/x86/turbostat
   make
   popd
%endif #turbostat/x86_energy_perf_policy
%endif
pushd tools
make tmon
popd
%endif

%if %{with_doc}
# Make the HTML and man pages.
make htmldocs mandocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

# In the modsign case, we do 3 things.  1) We check the "flavour" and hard
# code the value in the following invocations.  This is somewhat sub-optimal
# but we're doing this inside of an RPM macro and it isn't as easy as it
# could be because of that.  2) We restore the .tmp_versions/ directory from
# the one we saved off in BuildKernel above.  This is to make sure we're
# signing the modules we actually built/installed in that flavour.  3) We
# grab the arch and invoke 'make modules_sign' and the mod-extra-sign.sh
# commands to actually sign the modules.
#
# We have to do all of those things _after_ find-debuginfo runs, otherwise
# that will strip the signature off of the modules.
#
# Finally, pick a module at random and check that it's signed and fail the build
# if it isn't.

%define __modsign_install_post \
  if [ "%{with_debug}" -ne "0" ]; then \
    Arch=`head -1 configs/kernel-%{version}-%{_target_cpu}-debug.config | cut -b 3-` \
    rm -rf .tmp_versions \
    mv .tmp_versions.sign.debug .tmp_versions \
    mv signing_key.priv.sign.debug signing_key.priv \
    mv signing_key.x509.sign.debug signing_key.x509 \
    %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVRA}.debug || exit 1 \
  fi \
    if [ "%{with_default}" -ne "0" ]; then \
    Arch=`head -1 configs/kernel-%{version}-%{_target_cpu}.config | cut -b 3-` \
    rm -rf .tmp_versions \
    mv .tmp_versions.sign .tmp_versions \
    mv signing_key.priv.sign signing_key.priv \
    mv signing_key.x509.sign signing_key.x509 \
    %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVRA} || exit 1 \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{with_debuginfo}

%define __debug_install_post \
  /usr/lib/rpm/find-debuginfo.sh %{debuginfo_args} %{_builddir}/%{?buildsubdir}\
%{nil}

%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%defattr(-,root,root)
%endif

%endif

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__modsign_install_post}

###
### install
###

%install

cd linux-%{KVRA}

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{rpmversion}
man9dir=$RPM_BUILD_ROOT%{_datadir}/man/man9

# copy the source over
mkdir -p $docdir
tar -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir

# Install man pages for the kernel API.
mkdir -p $man9dir
find Documentation/DocBook/man -name '*.9.gz' -print0 |
xargs -0 --no-run-if-empty %{__install} -m 444 -t $man9dir $m
ls $man9dir | grep -q '' || > $man9dir/BROKEN
%endif # with_doc

# We have to do the headers install before the tools install because the
# kernel headers_install will remove any header files in /usr/include that
# it doesn't install itself.

%if %{with_headers}
# Install kernel headers
make %{?cross_opts} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Do headers_check but don't die if it fails.
make %{?cross_opts} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_check > hdrwarnings.txt || :
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

find $RPM_BUILD_ROOT/usr/include \( -name .install -o -name .check -o -name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

%endif

%if %{with_kernel_abi_whitelists}
# kabi directory
INSTALL_KABI_PATH=$RPM_BUILD_ROOT/lib/modules/
mkdir -p $INSTALL_KABI_PATH

# install kabi releases directories
tar xjvf %{SOURCE25} -C $INSTALL_KABI_PATH
%endif  # with_kernel_abi_whitelists

%if %{with_perf}
# perf tool binary and supporting scripts/binaries
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install
# remove the 'trace' symlink.
rm -f $RPM_BUILD_ROOT/%{_bindir}/trace

# perf-python extension
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-python_ext

# perf man pages (note: implicit rpm magic compresses them later)
%{perf_make} DESTDIR=$RPM_BUILD_ROOT try-install-man || %{doc_build_fail}
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
make -C tools/power/cpupower DESTDIR=$RPM_BUILD_ROOT libdir=%{_libdir} mandir=%{_mandir} CPUFREQ_BENCH=false install
rm -f %{buildroot}%{_libdir}/*.{a,la}
%find_lang cpupower
mv cpupower.lang ../
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    install -m755 centrino-decode %{buildroot}%{_bindir}/centrino-decode
    install -m755 powernow-k8-decode %{buildroot}%{_bindir}/powernow-k8-decode
    popd
%endif
chmod 0755 %{buildroot}%{_libdir}/libcpupower.so*
mkdir -p %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/sysconfig
install -m644 %{SOURCE2000} %{buildroot}%{_unitdir}/cpupower.service
install -m644 %{SOURCE2001} %{buildroot}%{_sysconfdir}/sysconfig/cpupower
%ifarch %{ix86} x86_64
   mkdir -p %{buildroot}%{_mandir}/man8
   pushd tools/power/x86/x86_energy_perf_policy
   make DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/turbostat
   make DESTDIR=%{buildroot} install
   popd
%endif #turbostat/x86_energy_perf_policy
pushd tools/thermal/tmon
make INSTALL_ROOT=%{buildroot} install
popd
%endif

%endif

%if %{with_bootwrapper}
make %{?cross_opts} DESTDIR=$RPM_BUILD_ROOT bootwrapper_install WRAPPER_OBJDIR=%{_libdir}/kernel-wrapper WRAPPER_DTSDIR=%{_libdir}/kernel-wrapper/dts
%endif

%if %{with_doc}
# Red Hat UEFI Secure Boot CA cert, which can be used to authenticate the kernel
mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/%{rpmversion}-%{pkgrelease}
install -m 0644 %{SOURCE13} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/%{rpmversion}-%{pkgrelease}/kernel-signing-ca.cer
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

%if %{with_tools}
%post -n kernel-tools
/sbin/ldconfig

%postun -n kernel-tools
/sbin/ldconfig
%endif

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{KVRA}%{?1:.%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*.%{?dist}.*/$f $f\
     done)\
fi\
%{nil}


# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1}}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --add-kernel %{KVRA}%{?1:.%{1}} || exit $?\
fi\
%{_sbindir}/new-kernel-pkg --package kernel%{?-v:-%{-v*}} --mkinitrd --dracut --depmod --update %{KVRA}%{?-v:.%{-v*}} || exit $?\
%{_sbindir}/new-kernel-pkg --package kernel%{?1:-%{1}} --rpmposttrans %{KVRA}%{?1:.%{1}} || exit $?\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post %{?-v*}}\
%{-r:\
if [ `uname -i` == "x86_64" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
%{expand:\
%{_sbindir}/new-kernel-pkg --package kernel%{?-v:-%{-v*}} --install %{KVRA}%{?-v:.%{-v*}} || exit $?\
}\
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1}}\
%{_sbindir}/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVRA}%{?1:.%{1}} || exit $?\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --remove-kernel %{KVRA}%{?1:.%{1}} || exit $?\
fi\
%{nil}

%kernel_variant_preun
%kernel_variant_post 

%kernel_variant_preun debug
%kernel_variant_post -v debug

%ifarch s390x
%postun kdump
    # Create softlink to latest remaining kdump kernel.
    # If no more kdump kernel is available, remove softlink.
    if [ "$(readlink /boot/zfcpdump)" == "/boot/vmlinuz-%{KVRA}.kdump" ]
    then
        vmlinuz_next=$(ls /boot/vmlinuz-*.kdump 2> /dev/null | sort | tail -n1)
        if [ $vmlinuz_next ]
        then
            ln -sf $vmlinuz_next /boot/zfcpdump
        else
            rm -f /boot/zfcpdump
        fi
    fi

%post kdump
    ln -sf /boot/vmlinuz-%{KVRA}.kdump /boot/zfcpdump
%endif # s390x

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{with_bootwrapper}
%files bootwrapper
%defattr(-,root,root)
/usr/sbin/*
%{_libdir}/kernel-wrapper
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}
%{_datadir}/man/man9/*
%{_datadir}/doc/kernel-keys/%{rpmversion}-%{pkgrelease}/kernel-signing-ca.cer
%dir %{_datadir}/doc/kernel-keys/%{rpmversion}-%{pkgrelease}
%dir %{_datadir}/doc/kernel-keys
%endif

%if %{with_kernel_abi_whitelists}
%files -n kernel-abi-whitelists
%defattr(-,root,root,-)
/lib/modules/kabi-*
%endif

%if %{with_perf}
%files -n perf
%defattr(-,root,root)
%{_bindir}/perf
%dir %{_libexecdir}/perf-core
%{_libexecdir}/perf-core/*
%{_libdir}/traceevent
%{_mandir}/man[1-8]/perf*
%{_sysconfdir}/bash_completion.d/perf

%files -n python-perf
%defattr(-,root,root)
%{python_sitearch}

%if %{with_debuginfo}
%files -f perf-debuginfo.list -n perf-debuginfo
%defattr(-,root,root)

%files -f python-perf-debuginfo.list -n python-perf-debuginfo
%defattr(-,root,root)
%endif
%endif

%if %{with_tools}
%files -n kernel-tools -f cpupower.lang
%defattr(-,root,root)
%ifarch %{cpupowerarchs}
%{_bindir}/cpupower
%ifarch x86_64
%{_bindir}/centrino-decode
%{_bindir}/powernow-k8-decode
%endif
%{_unitdir}/cpupower.service
%{_mandir}/man[1-8]/cpupower*
%config(noreplace) %{_sysconfdir}/sysconfig/cpupower
%ifarch %{ix86} x86_64
%{_bindir}/x86_energy_perf_policy
%{_mandir}/man8/x86_energy_perf_policy*
%{_bindir}/turbostat
%{_mandir}/man8/turbostat*
%endif
%endif
%{_bindir}/tmon
%if %{with_debuginfo}
%files -f kernel-tools-debuginfo.list -n kernel-tools-debuginfo
%defattr(-,root,root)
%endif

%ifarch %{cpupowerarchs}
%files -n kernel-tools-libs
%defattr(-,root,root)
%{_libdir}/libcpupower.so.0
%{_libdir}/libcpupower.so.0.0.0

%files -n kernel-tools-libs-devel
%defattr(-,root,root)
%{_libdir}/libcpupower.so
%{_includedir}/cpufreq.h
%endif

%endif # with_tools

%if %{with_gcov}
%ifarch x86_64 s390x ppc64 ppc64le
%files gcov
%defattr(-,root,root)
%{_builddir}
%endif
%endif

# This is %%{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{1}\
%{expand:%%files %{?2}}\
%defattr(-,root,root)\
/%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVRA}%{?2:.%{2}}\
/%{image_install_path}/.vmlinuz-%{KVRA}%{?2:.%{2}}.hmac \
%attr(600,root,root) /boot/System.map-%{KVRA}%{?2:.%{2}}\
/boot/symvers-%{KVRA}%{?2:.%{2}}.gz\
/boot/config-%{KVRA}%{?2:.%{2}}\
%dir /lib/modules/%{KVRA}%{?2:.%{2}}\
/lib/modules/%{KVRA}%{?2:.%{2}}/kernel\
/lib/modules/%{KVRA}%{?2:.%{2}}/build\
/lib/modules/%{KVRA}%{?2:.%{2}}/source\
/lib/modules/%{KVRA}%{?2:.%{2}}/extra\
/lib/modules/%{KVRA}%{?2:.%{2}}/updates\
/lib/modules/%{KVRA}%{?2:.%{2}}/weak-updates\
%ifarch %{vdso_arches}\
/lib/modules/%{KVRA}%{?2:.%{2}}/vdso\
/etc/ld.so.conf.d/kernel-%{KVRA}%{?2:.%{2}}.conf\
%endif\
/lib/modules/%{KVRA}%{?2:.%{2}}/modules.*\
%ghost /boot/initramfs-%{KVRA}%{?2:.%{2}}.img\
%{expand:%%files %{?2:%{2}-}devel}\
%defattr(-,root,root)\
/usr/src/kernels/%{KVRA}%{?2:.%{2}}\
%if %{with_debuginfo}\
%ifnarch noarch\
%{expand:%%files -f debuginfo%{?2}.list %{?2:%{2}-}debuginfo}\
%defattr(-,root,root)\
%endif\
%endif\
%endif\
%{nil}

%kernel_variant_files %{with_default}
%kernel_variant_files %{with_debug} debug
%kernel_variant_files %{with_kdump} kdump

%changelog
* Tue Dec 08 2015 CentOS Sources <bugs@centos.org> - 3.10.0-327.3.1.el7
- Apply debranding changes

* Fri Nov 20 2015 Alexander Gordeev <agordeev@redhat.com> [3.10.0-327.3.1.el7]
- rebuild

* Fri Nov 13 2015 Alexander Gordeev <agordeev@redhat.com> [3.10.0-327.2.1.el7]
- [netdrv] macvtap: unbreak receiving of gro skb with frag list (Jason Wang) [1279794 1273737]
- [net] ipv6: drop frames with attached skb->sk in forwarding (Hannes Frederic Sowa) [1281701 1243966]
- [net] ipv6: ip6_forward: perform skb->pkt_type check at the beginning (Hannes Frederic Sowa) [1281701 1243966]
- [net] sctp: Fix race between OOTB responce and route removal (Jamie Bainbridge) [1281426 1277309]
- [x86] mm: fix VM_FAULT_RETRY handling (Andrea Arcangeli) [1281427 1277226]
- [x86] mm: consolidate VM_FAULT_RETRY handling (Andrea Arcangeli) [1281427 1277226]
- [x86] mm: move mmap_sem unlock from mm_fault_error() to caller (Andrea Arcangeli) [1281427 1277226]
- [mm] let mm_find_pmd fix buggy race with THP fault (Larry Woodman) [1281424 1273993]
- [mm] ksm: unstable_tree_search_insert error checking cleanup (Andrea Arcangeli) [1281422 1274871]
- [mm] ksm: use find_mergeable_vma in try_to_merge_with_ksm_page (Andrea Arcangeli) [1281422 1274871]
- [mm] ksm: use the helper method to do the hlist_empty check (Andrea Arcangeli) [1281422 1274871]
- [mm] ksm: don't fail stable tree lookups if walking over stale stable_nodes (Andrea Arcangeli) [1281422 1274871]
- [mm] ksm: add cond_resched() to the rmap_walks (Andrea Arcangeli) [1281422 1274871]
- [powerpc] kvm: book3s_hv: Synthesize segment fault if SLB lookup fails (Thomas Huth) [1281423 1269467]
- [powerpc] kvm: book3s_hv: Create debugfs file for each guest's HPT (David Gibson) [1281420 1273692]
- [powerpc] kvm: book3s_hv: Add helpers for lock/unlock hpte (David Gibson) [1281420 1273692]
- [powerpc] pci: initialize hybrid_dma_data before use (Laurent Vivier) [1279793 1270717]
- [md] raid10: don't clear bitmap bit when bad-block-list write fails (Jes Sorensen) [1279796 1267652]
- [md] raid1: don't clear bitmap bit when bad-block-list write fails (Jes Sorensen) [1279796 1267652]
- [md] raid10: submit_bio_wait() returns 0 on success (Jes Sorensen) [1279796 1267652]
- [md] raid1: submit_bio_wait() returns 0 on success (Jes Sorensen) [1279796 1267652]
- [md] crash in md-raid1 and md-raid10 due to incorrect list manipulation (Jes Sorensen) [1279796 1267652]
- [md] raid10: ensure device failure recorded before write request returns (Jes Sorensen) [1279796 1267652]
- [md] raid1: ensure device failure recorded before write request returns (Jes Sorensen) [1279796 1267652]
- [block] nvme: Fix memory leak on retried commands (David Milburn) [1279792 1271860]
- [cpufreq] intel_pstate: fix rounding error in max_freq_pct (Prarit Bhargava) [1281491 1263866]
- [cpufreq] intel_pstate: fix PCT_TO_HWP macro (Prarit Bhargava) [1273926 1264990]
- [cpufreq] revert "intel_pstate: add quirk to disable HWP on Skylake-S processors" (Prarit Bhargava) [1273926 1264990]
- [cpufreq] revert "intel_pstate: disable Skylake processors" (Prarit Bhargava) [1273926 1264990]
- [x86] kvm: svm: unconditionally intercept #DB (Paolo Bonzini) [1279469 1279470] {CVE-2015-8104}
- [x86] virt: guest to host DoS by triggering an infinite loop in microcode (Paolo Bonzini) [1277560 1277561] {CVE-2015-5307}

* Tue Nov 03 2015 Alexander Gordeev <agordeev@redhat.com> [3.10.0-327.1.1.el7]
- [x86] kvm: mmu: fix validation of mmio page fault (Bandan Das) [1275150 1267128]

* Thu Oct 29 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-327.el7]
- [mm] free compound page with correct order (Andrea Arcangeli) [1274867]
- [netdrv] revert "ixgbe: Refactor busy poll socket code to address multiple issues" (John Greene) [1261275]
- [powerpc] dma: dma_set_coherent_mask() should not be GPL only (Gustavo Duarte) [1275976]

* Fri Oct 23 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-326.el7]
- [md] dm-cache: the CLEAN_SHUTDOWN flag was not being set (Mike Snitzer) [1274450]
- [md] dm-btree: fix leak of bufio-backed block in btree_split_beneath error path (Mike Snitzer) [1274393]
- [md] dm-btree-remove: fix a bug when rebalancing nodes after removal (Mike Snitzer) [1274396]
- [fs] nfsd: fix duplicated destroy_delegation code introduced by backport ("J. Bruce Fields") [1273228]
- [fs] xfs: validate transaction header length on log recovery (Brian Foster) [1164135]
- [net] ipv6: don't use CHECKSUM_PARTIAL on MSG_MORE/UDP_CORK sockets (Hannes Frederic Sowa) [1271759]
- [net] add length argument to skb_copy_and_csum_datagram_iovec (Sabrina Dubroca) [1269228]
- [x86] kvm: fix edge EOI and IOAPIC reconfig race (Radim Krcmar) [1271333]
- [x86] kvm: set KVM_REQ_EVENT when updating IRR (Radim Krcmar) [1271333]
- [kernel] Initialize msg/shm IPC objects before doing ipc_addid() (Lennert Buytenhek) [1271507] {CVE-2015-7613}

* Fri Oct 16 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-325.el7]
- [fs] nfsd: ensure that delegation stateid hash references are only put once ("J. Bruce Fields") [1233284]
- [fs] nfsd: ensure that the ol stateid hash reference is only put once ("J. Bruce Fields") [1233284]
- [fs] nfsv4: Fix a nograce recovery hang (Benjamin Coddington) [1264478]
- [fs] vfs: Test for and handle paths that are unreachable from their mnt_root ("Eric W. Biederman") [1209371] {CVE-2015-2925}
- [fs] dcache: Handle escaped paths in prepend_path ("Eric W. Biederman") [1209371] {CVE-2015-2925}
- [fs] xfs: add an xfs_zero_eof() tracepoint (Brian Foster) [1260383]
- [fs] xfs: always drain dio before extending aio write submission (Brian Foster) [1260383]
- [md] dm-cache: fix NULL pointer when switching from cleaner policy (Mike Snitzer) [1269959]
- [mm] Temporary fix for BUG_ON() triggered by THP vs. gup() race (David Gibson) [1268999]
- [hid] usbhid: improve handling of Clear-Halt and reset (Don Zickus) [1260123]
- [drm] qxl: fix framebuffer dirty rectangle tracking (Gerd Hoffmann) [1268293]
- [s390] hmcdrv: fix interrupt registration (Hendrik Brueckner) [1262735]
- [block] blk-mq: fix deadlock when reading cpu_list (Jeff Moyer) [1260615]
- [block] blk-mq: avoid inserting requests before establishing new mapping (Jeff Moyer) [1260615]
- [block] blk-mq: fix q->mq_usage_counter access race (Jeff Moyer) [1260615]
- [block] blk-mq: Fix use after of free q->mq_map (Jeff Moyer) [1260615]
- [block] blk-mq: fix sysfs registration/unregistration race (Jeff Moyer) [1260615]
- [block] blk-mq: avoid setting hctx->tags->cpumask before allocation (Jeff Moyer) [1260615]
- [netdrv] cxgb4: Enhance driver to update FW, when FW is too old (Sai Vemuri) [1077966]
- [netdrv] cxgb4: Force uninitialized state if FW in adapter is unsupported (Sai Vemuri) [1077966]
- [powerpc] revert "Use the POWER8 Micro Partition Prefetch Engine in KVM HV on POWER8" (Thomas Huth) [1269653]

* Tue Oct 13 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-324.el7]
- [netdrv] i40e/i40evf: set AQ count after memory allocation (Neil Horman) [1267663]
- [netdrv] i40e: fix offload of GRE tunnels (Neil Horman) [1267663]
- [netdrv] i40evf: don't blow away MAC address (Neil Horman) [1267663]
- [netdrv] i40e/i40evf: grab the AQ spinlocks before clearing registers (Neil Horman) [1267663]
- [netdrv] i40e: Fix a memory leak in X722 rss config path (Neil Horman) [1267663]
- [netdrv] i40evf: Use numa_mem_id() to better support memoryless node (Neil Horman) [1267663]
- [netdrv] i40e: Use numa_mem_id() to better support memoryless node (Neil Horman) [1267663]
- [netdrv] i40e: fix 32 bit build warnings (Neil Horman) [1267663]
- [netdrv] i40e: fix kbuild warnings (Neil Horman) [1267663]
- [netdrv] i40evf: tweak init timing (Neil Horman) [1267663]
- [netdrv] i40e: warn on double free (Neil Horman) [1267663]
- [netdrv] i40e: refactor interrupt enable (Neil Horman) [1267663]
- [netdrv] i40e: Strip VEB stats if they are disabled in HW (Neil Horman) [1267663]
- [netdrv] i40e/i40evf: add new device id 1588 (Neil Horman) [1267663]
- [netdrv] i40e: Remove useless message (Neil Horman) [1267663]
- [netdrv] i40e: limit debugfs io ops (Neil Horman) [1267663]
- [netdrv] i40e: use QOS field consistently (Neil Horman) [1267663]
- [netdrv] i40e: count drops in netstat interface (Neil Horman) [1267663]
- [netdrv] i40e/i40evf: fix Tx hang workaround code (Neil Horman) [1267663]
- [netdrv] i40e: fixup padding issue in get_cee_dcb_cfg_v1_resp (Neil Horman) [1267663]
- [netdrv] i40e: Fix a port VLAN configuration bug (Neil Horman) [1267663]
- [netdrv] i40e/i40evf: fix up type clash in i40e_aq_rc_to_posix conversion (Neil Horman) [1267663]
- [netdrv] i40e: rtnl_lock called twice in i40e_pci_error_resume() (Neil Horman) [1267663]
- [netdrv] i40evf: missing rtnl_unlock in i40evf_resume() (Neil Horman) [1267663]

* Mon Oct 12 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-323.el7]
- [scsi] report 'INQUIRY result too short' once (Vitaly Kuznetsov) [1254049]
- [scsi] scsi_scan: don't dump trace when scsi_prep_async_scan() is called twice (Vitaly Kuznetsov) [1254049]
- [fs] userfaultfd: add missing mmput() in error path (Andrea Arcangeli) [1263480]
- [mm] check if section present during memory block registering (Jan Stancek) [1256723]
- [mm] avoid setting up anonymous pages into file mapping (Larry Woodman) [1261582]
- [mm] add p[te|md] revert "protnone helpers for use by NUMA balancing" (Thomas Huth) [1256718]
- [powerpc] revert "mm: convert p[te|md]_numa users to p[te|md]_protnone_numa" (Thomas Huth) [1256718]
- [powerpc] revert "mm: add paranoid warnings for unexpected DSISR_PROTFAULT" (Thomas Huth) [1256718]
- [mm] revert "convert p[te|md]_mknonnuma and remaining page table manipulations" (Thomas Huth) [1256718]
- [mm] revert "numa: Do not mark PTEs pte_numa when splitting huge pages" (Thomas Huth) [1256718]
- [mm] revert "remove remaining references to NUMA hinting bits and helpers" (Thomas Huth) [1256718]
- [mm] revert "numa: do not trap faults on the huge zero page" (Thomas Huth) [1256718]
- [mm] revert "numa: add paranoid check around pte_protnone_numa" (Thomas Huth) [1256718]
- [mm] revert "numa: avoid unnecessary TLB flushes when setting NUMA hinting entries" (Thomas Huth) [1256718]
- [powerpc] mm: Change the swap encoding in pte (Thomas Huth) [1256718]
- [x86] perf: Fix multi-segment problem of perf_event_intel_uncore (Jiri Olsa) [1257825]
- [lib] partially revert "[lib] vsprintf: implement bitmap printing through '*pb[l]'" (Maurizio Lombardi) [1260118]
- [drm] radeon: update no_64bit_msi flag for certain ASICs (Oded Gabbay) [1262429]
- [drm] nouveau: fbcon: take runpm reference when userspace has an open fd (Ben Skeggs) [1176163]
- [drm] qxl: validate monitors config modes (Dave Airlie) [1242847]
- [drm] radeon: don't attempt WC mappings on powerpc (Dave Airlie) [1262429]
- [drm] drm/qxl: recreate the primary surface when the bo is not primary (Dave Airlie) [1258301]
- [drm] qxl: only report first monitor as connected if we have no state (Dave Airlie) [1258301]
- [drm] dp_mst: drop cancel work sync in the mstb destroy path (Dave Airlie) [1251331]
- [drm] dp_mst: split connector registration into two parts (Dave Airlie) [1251331]
- [drm] dp_mst: update the link_address_sent before sending the link address (Dave Airlie) [1251331]
- [drm] dp_mst: fixup handling hotplug on port removal (Dave Airlie) [1251331]
- [drm] dp_mst: don't pass port into the path builder function (Dave Airlie) [1251331]
- [drm] dp_mst: make functions that always return 0 return void (Dave Airlie) [1251331]
- [kernel] uprobes: fix kABI broken by the exported return_instance (Oleg Nesterov) [1207373]
- [kernel] uprobes: Make arch_uretprobe_is_alive(RP_CHECK_CALL) more clever (Oleg Nesterov) [1207373]
- [kernel] uprobes: Add the "enum rp_check ctx" arg to arch_uretprobe_is_alive() (Oleg Nesterov) [1207373]
- [kernel] uprobes: Change prepare_uretprobe() to (try to) flush the dead frames (Oleg Nesterov) [1207373]
- [kernel] uprobes: Change handle_trampoline() to flush the frames invalidated by longjmp() (Oleg Nesterov) [1207373]
- [kernel] uprobes: Reimplement arch_uretprobe_is_alive() (Oleg Nesterov) [1207373]
- [kernel] uprobes: Export 'struct return_instance', introduce arch_uretprobe_is_alive() (Oleg Nesterov) [1207373]
- [kernel] uprobes: Change handle_trampoline() to find the next chain beforehand (Oleg Nesterov) [1207373]
- [kernel] uprobes: Change prepare_uretprobe() to use uprobe_warn() (Oleg Nesterov) [1207373]
- [kernel] uprobes: Send SIGILL if handle_trampoline() fails (Oleg Nesterov) [1207373]
- [kernel] uprobes: Introduce free_ret_instance() (Oleg Nesterov) [1207373]
- [kernel] uprobes: Introduce get_uprobe() (Oleg Nesterov) [1207373]
- [kernel] lockdep: Fix a race between /proc/lock_stat and module unload (Jerome Marchand) [1183891]
- [kernel] lockdep: Fix the module unload key range freeing logic (Jerome Marchand) [1183891]
- [kernel] module: Free lock-classes if parse_args failed (Jerome Marchand) [1183891]
- [cpufreq] revert "intel_pstate: honor user space min_perf_pct override on resume" (Prarit Bhargava) [1269518]

* Mon Oct 05 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-322.el7]
- [fs] nfs: fix v4.2 SEEK on files over 2 gigs ("J. Bruce Fields") [1262181]
- [fs] nfs: verify open flags before allowing open (Benjamin Coddington) [1164431]
- [fs] nfsv4.1: Fix pnfs_put_lseg races (Benjamin Coddington) [1263155]
- [fs] nfsv4.1: pnfs_send_layoutreturn should use GFP_NOFS (Benjamin Coddington) [1263155]
- [fs] nfsv4.1: Pin the inode and super block in asynchronous layoutreturns (Benjamin Coddington) [1263155]
- [fs] nfsv4.1: Pin the inode and super block in asynchronous layoutcommit (Benjamin Coddington) [1263155]
- [md] raid0: apply base queue limits *before* disk_stack_limits (Jes Sorensen) [1265182]
- [net] revert "ipv6: Don't reduce hop limit for an interface" (Sabrina Dubroca) [1258324]
- [x86] kvmclock: abolish PVCLOCK_COUNTS_FROM_ZERO (Radim Krcmar) [1263030]
- [x86] revert "kvm: x86: zero kvmclock_offset when vcpu0 initializes kvmclock system MSR" (Radim Krcmar) [1263030]
- [x86] kvm: svm: reset mmu on VCPU reset (Igor Mammedov) [1255217]
- [edac] sb_edac: correctly fetch DIMM width on Ivy Bridge and Haswell (Aristeu Rozanski) [1112413]
- [edac] sb_edac: look harder for DDRIO on Haswell systems (Aristeu Rozanski) [1112413]
- [tools] perf-trace: Fix race condition at the end of started workloads (Jiri Olsa) [1250068]
- [netdrv] cxgb4: Fix tx flit calculation (Sai Vemuri) [1266248]
- [netdrv] igb: assume MSI-X interrupts during initialization (Stefan Assmann) [1263625]
- [cpufreq] intel_pstate: disable Skylake processors (Prarit Bhargava) [1267343]
- [infiniband] mlx4: Report checksum offload cap for RAW QP when query device (Doug Ledford) [1265795]
- [infiniband] core: Add support of checksum capability reporting for RC and RAW (Doug Ledford) [1265795]

* Wed Sep 30 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-321.el7]
- [netdrv] i40e/i40evf: check for stopped admin queue (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: refactor tx timeout logic (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Bump i40e to 1.3.21 and i40evf to 1.3.13 (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: add get AQ result command to nvmupdate utility (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: add exec_aq command to nvmupdate utility (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: add wait states to NVM state machine (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: add GetStatus command for nvmupdate (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: add handling of writeback descriptor (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: save aq writeback for future inspection (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Bump i40e to 1.3.9 and i40evf to 1.3.5 (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Cache the CEE TLV status returned from firmware (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: add VIRTCHNL_VF_OFFLOAD flag (Stefan Assmann) [1267255]
- [netdrv] i40evf: Remove PF specific register definitions from the VF (Stefan Assmann) [1267255]
- [netdrv] i40evf: Use the correct defines to match the VF registers (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Add capability to gather VEB per TC stats (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Add TX/RX outer UDP checksum support for X722 (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Add support for writeback on ITR feature for X722 (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: RSS changes for X722 (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Update register.h file for X722 (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Update FW API with X722 support (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Add flags for X722 capabilities (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Add device ids for X722 (Stefan Assmann) [1267255]
- [netdrv] i40e: use BIT and BIT_ULL macros (Stefan Assmann) [1267255]
- [netdrv] i40e: clean up error status messages (Stefan Assmann) [1267255]
- [netdrv] i40evf: support virtual channel API version 1.1 (Stefan Assmann) [1267255]
- [netdrv] i40evf: handle big resets (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: add macros for virtual channel API version and device capability (Stefan Assmann) [1267255]
- [netdrv] i40e: add VF capabilities to virtual channel interface (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Fix and refactor dynamic ITR code (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Bump version to 1.3.6 for i40e and 1.3.2 for i40evf (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Add support for pre-allocated pages for PD (Stefan Assmann) [1267255]
- [netdrv] i40evf: add MAC address filter in open, not init (Stefan Assmann) [1267255]
- [netdrv] i40evf: don't delete all the filters (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Update the admin queue command header (Stefan Assmann) [1267255]
- [netdrv] i40evf: Allow for an abundance of vectors (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: improve Tx performance with a small tweak (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Update Flex-10 related device/function capabilities (Stefan Assmann) [1267255]
- [netdrv] i40e/i40evf: Add stats to track FD ATR and SB dynamic enable state (Stefan Assmann) [1267255]
- [netdrv] i40e: Fix for recursive RTNL lock during PROMISC change (Stefan Assmann) [1267254]
- [netdrv] i40e: Fix RS bit update in Tx path and disable force WB workaround (Stefan Assmann) [1267254]
- [netdrv] i40e: add GRE tunnel type to csum encoding (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: refactor tx timeout logic (Stefan Assmann) [1267254]
- [netdrv] i40e: Move i40e_get_head into header file (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: check for stopped admin queue (Stefan Assmann) [1267254]
- [netdrv] i40e: fix VLAN inside VXLAN (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Bump i40e to 1.3.21 and i40evf to 1.3.13 (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: add get AQ result command to nvmupdate utility (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: add exec_aq command to nvmupdate utility (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: add wait states to NVM state machine (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: add GetStatus command for nvmupdate (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: add handling of writeback descriptor (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: save aq writeback for future inspection (Stefan Assmann) [1267254]
- [netdrv] i40e: rename variable to prevent clash of understanding (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Bump i40e to 1.3.9 and i40evf to 1.3.5 (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Cache the CEE TLV status returned from firmware (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: add VIRTCHNL_VF_OFFLOAD flag (Stefan Assmann) [1267254]
- [netdrv] i40e: Remove redundant and unneeded messages (Stefan Assmann) [1267254]
- [netdrv] i40e: correct spelling error (Stefan Assmann) [1267254]
- [netdrv] i40e: Fix comment for ethtool diagnostic link test (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Add capability to gather VEB per TC stats (Stefan Assmann) [1267254]
- [netdrv] i40e: Fix ethtool offline diagnostic with netqueues (Stefan Assmann) [1267254]
- [netdrv] i40e: Fix legacy interrupt mode in the driver (Stefan Assmann) [1267254]
- [netdrv] i40e: Move function calls to i40e_shutdown instead of i40e_suspend (Stefan Assmann) [1267254]
- [netdrv] i40e: add RX to port CRC errors label (Stefan Assmann) [1267254]
- [netdrv] i40e: don't degrade __le16 (Stefan Assmann) [1267254]
- [netdrv] i40e: Add AQ commands for NVM Update for X722 (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Add ATR HW eviction support for X722 (Stefan Assmann) [1267254]
- [netdrv] i40e: Add IWARP support for X722 (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Add TX/RX outer UDP checksum support for X722 (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Add support for writeback on ITR feature for X722 (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: RSS changes for X722 (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Update register.h file for X722 (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Update FW API with X722 support (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Add flags for X722 capabilities (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Add device ids for X722 (Stefan Assmann) [1267254]
- [netdrv] i40e: use BIT and BIT_ULL macros (Stefan Assmann) [1267254]
- [netdrv] i40e: provide correct API version to older VF drivers (Stefan Assmann) [1267254]
- [netdrv] i40e: support virtual channel API 1.1 (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: add macros for virtual channel API version and device capability (Stefan Assmann) [1267254]
- [netdrv] i40e: add VF capabilities to virtual channel interface (Stefan Assmann) [1267254]
- [netdrv] i40e: clean up unneeded gotos (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Fix and refactor dynamic ITR code (Stefan Assmann) [1267254]
- [netdrv] i40e: only report generic filters in get_ts_info (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Bump version to 1.3.6 for i40e and 1.3.2 for i40evf (Stefan Assmann) [1267254]
- [netdrv] i40e: Refine an error message to avoid confusion (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Add support for pre-allocated pages for PD (Stefan Assmann) [1267254]
- [netdrv] i40e: un-disable VF after reset (Stefan Assmann) [1267254]
- [netdrv] i40e: do a proper reset when disabling a VF (Stefan Assmann) [1267254]
- [netdrv] i40e: correctly program filters for VFs (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Update the admin queue command header (Stefan Assmann) [1267254]
- [netdrv] i40e: Remove incorrect #ifdef's (Stefan Assmann) [1267254]
- [netdrv] i40e: ignore duplicate port VLAN requests (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: improve Tx performance with a small tweak (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Update Flex-10 related device/function capabilities (Stefan Assmann) [1267254]
- [netdrv] i40e/i40evf: Add stats to track FD ATR and SB dynamic enable state (Stefan Assmann) [1267254]
- [netdrv] i40e: Implement ndo_features_check() (Stefan Assmann) [1267254]

* Mon Sep 28 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-320.el7]
- [md] raid1: Avoid raid1 resync getting stuck (Jes Sorensen) [1256954]
- [fs] gfs2: fallocate: do not rely on file_update_time to mark the inode dirty (Andrew Price) [1264521]
- [fs] gfs2: Update timestamps on fallocate (Andrew Price) [1264521]
- [fs] gfs2: Update i_size properly on fallocate (Andrew Price) [1264521]
- [fs] gfs2: Use inode_newsize_ok and get_write_access in fallocate (Andrew Price) [1264521]
- [fs] revert "nfs: Make close(2) asynchronous when closing NFS O_DIRECT files" (Benjamin Coddington) [1263385]
- [fs] gfs2: Average in only non-zero round-trip times for congestion stats (Robert S Peterson) [1162821]
- [fs] lockd: fix rpcbind crash on lockd startup failure ("J. Bruce Fields") [1253782]
- [fs] Failing to send a CLOSE if file is opened WRONLY and server reboots on a 4.x mount (Benjamin Coddington) [1263376]
- [fs] fsnotify: fix oops in fsnotify_clear_marks_by_group_flags() (Lukas Czerner) [1247436]
- [net] sctp: fix race on protocol/netns initialization (Marcelo Leitner) [1251807] {CVE-2015-5283}
- [x86] Mark Broadwell-DE SoC Supported (Prarit Bhargava) [1131685]
- [kernel] sched,numa: limit amount of virtual memory scanned in task_numa_work (Rik van Riel) [1261722]
- [drivers] base: show nohz_full cpus in sysfs (Rik van Riel) [1212618]
- [drivers] base: show isolated cpus in sysfs (Rik van Riel) [1212618]
- [cpufreq] intel_pstate: add quirk to disable HWP on Skylake-S processors (Jerry Snitselaar) [1263069]
- [drivers] core: Add symlink to device-tree from devices with an OF node (Gustavo Duarte) [1258828]
- [powerpc] device: Add dev_of_node() accessor (Gustavo Duarte) [1258828]
- [powerpc] iommu: Support "hybrid" iommu/direct DMA ops for coherent_mask < dma_mask (Gustavo Duarte) [1246880]
- [powerpc] iommu: Cleanup setting of DMA base/offset (Gustavo Duarte) [1246880]
- [powerpc] iommu: Remove dma_data union (Gustavo Duarte) [1246880]
- [powerpc] kvm: book3s-hv: Fix handling of interrupted VCPUs (Thomas Huth) [1263568]
- [powerpc] kvm: Take the kvm->srcu lock in kvmppc_h_logical_ci_load/store() (Thomas Huth) [1263577]

* Tue Sep 22 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-319.el7]
- [netdrv] cxgb4: Make necessary changes after reverting FCoE (Sai Vemuri) [1258657]
- [netdrv] revert "cxgb4: add cxgb4_fcoe.c for FCoE" (Sai Vemuri) [1258657]
- [infiniband] iw_cxgb4: Cleanup register defines/MACROS (Sai Vemuri) [1251611]
- [infiniband] iw_cxgb4: 32b platform fixes (Sai Vemuri) [1251611]
- [infiniband] iw_cxgb4: use BAR2 GTS register for T5 kernel mode CQs (Sai Vemuri) [1251611]
- [infiniband] iw_cxgb4: enforce qp/cq id requirements (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fix incorrect sequence numbers shown in devlog (Sai Vemuri) [1251611]
- [netdrv] cxgb4: remove unused fn to enable/disable db coalescing (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxgb4vf: function and argument name cleanup (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add debugfs facility to inject FL starvation (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add PHY firmware support for T420-BT cards (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Update T4/T5 adapter register ranges (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Optimize and cleanup setup memory window code (Sai Vemuri) [1251611]
- [netdrv] cxgb4: replace ntoh{s, l} and hton{s, l} calls with the generic byteorder (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Remove dead function t4_read_edc and t4_read_mc (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxgb4vf: Cleanup macros, add comments and add new MACROS (Sai Vemuri) [1251611]
- [netdrv] cxgb3/4/4vf: Update drivers to use dma_rmb/wmb where appropriate (Sai Vemuri) [1251611]
- [netdrv] cxgb4: add cxgb4_fcoe.c for FCoE (Sai Vemuri) [1251611]
- [infiniband] iw_cxgb4: Remove negative advice dmesg warnings (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Initialize RSS mode for all Ports (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Discard the packet if the length is greater than mtu (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Move SGE Ingress DMA state monitor code to a new routine (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add device node to ULD info (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Pass in a Congestion Channel Map to t4_sge_alloc_rxq() (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Enable congestion notification from SGE for IQs and FLs (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Make sure that Freelist size is larger than Egress Congestion Threshold (Sai Vemuri) [1251611]
- [netdrv] cxgb4: drop __GFP_NOFAIL allocation (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fix MC1 memory offset calculation (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Don't call t4_slow_intr_handler when we're not the Master PF (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add comment for calculate tx flits and sge length code (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Use device node in page allocation (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Freelist starving threshold varies from adapter to adapter (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Increased the value of MAX_IMM_TX_PKT_LEN from 128 to 256 bytes (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Move ethtool related code to a separate file (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fix to dump devlog, even if FW is crashed (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Firmware macro changes for fw verison 1.13.32.0 (Sai Vemuri) [1251611]
- [infiniband] cxgb4: Serialize CQ event upcalls with CQ destruction (Sai Vemuri) [1251611]
- [infiniband] cxgb4: Don't hang threads forever waiting on WR replies (Sai Vemuri) [1251611]
- [netdrv] cxgb4vf: Fix sparse warnings (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Disable interrupts and napi before unregistering netdev (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Allocate dynamic mem. for egress and ingress queue maps (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fix frame size warning for 32 bit arch (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxgb4vf/csiostor: Make PCI Device ID Tables be "const" (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add device ID for new adapter (Sai Vemuri) [1251611]
- [netdrv] cxgb4: fix coccinelle warnings (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Try and provide an RDMA CIQ per cpu (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Use pci_enable_msix_range() instead of pci_enable_msix() (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Move offload Rx queue allocation to separate function (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fix PCI-E Memory window interface for big-endian systems (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add support in cxgb4 to get expansion rom version via ethtool (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fix trace observed while dumping clip_tbl (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add support in debugfs to dump the congestion control table (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add support to dump mailbox content in debugfs (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add support for ULP RX logic analyzer output in debugfs (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Added support in debugfs to display TP logic analyzer output (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add support in debugfs to display sensor information (Sai Vemuri) [1251611]
- [netdrv] chelsio: cxgb4: fix sparse warning (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Delete an unnecessary check before the function call "release_firmware" (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add low latency socket busy_poll support (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Improve IEEE DCBx support, other minor open-lldp fixes (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Remove preprocessor check for CONFIG_CXGB4_DCB (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Move firmware version MACRO to t4fw_version.h (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Added support in debugfs to dump different timer and clock values of the adapter (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Added support in debugfs to dump PM module stats (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Addded support in debugfs to dump CIM outbound queue content (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Added support in debugfs to dump cim ingress bound queue contents (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Added support in debugfs to dump sge_qinfo (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fixes cxgb4_inet6addr_notifier unregister call (Sai Vemuri) [1251611]
- [netdrv] mode_t whack-a-mole: chelsio (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add debugfs options to dump the rss key, config for PF, VF, etc (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add debugfs entry to dump the contents of the flash (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Update ipv6 address handling api (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Ripping out old hard-wired initialization code in driver (Sai Vemuri) [1251611]
- [netdrv] iw_cxgb4/cxgb4/cxgb4vf/cxgb4i/csiostor: Cleanup register defines/macros related to all other cpl messages (Sai Vemuri) [1251611]
- [netdrv] iw_cxgb4/cxgb4/cxgb4i: Cleanup register defines/MACROS related to CM CPL messages (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add support for mps_tcam debugfs (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add support for cim_qcfg entry in debugfs (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add support for cim_la entry in debugfs (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add support for devlog (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add PCI device ID for new T5 adapter (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxgb4vf/csiostor: Cleanup PL, XGMAC, SF and MC related register defines (Sai Vemuri) [1251611]
- [netdrv] cxgb4/csiostor: Cleanup TP, MPS and TCAM related register defines (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxg4vf/csiostor: Cleanup MC, MA and CIM related register defines (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxgb4vf/csiostor: Cleanup SGE and PCI related register defines (Sai Vemuri) [1251611]
- [infiniband] cxgb4/cxgb4vf/csiostor: Cleanup SGE register defines (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fix decoding QSA module for ethtool get settings (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add support for QSA modules (Sai Vemuri) [1251611]
- [netdrv] cxgb4/csiostor: Don't use MASTER_MUST for fw_hello call (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxgb4vf: global named must be unique (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Update firmware version after flashing it via ethtool (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxgb4vf: Use new interfaces to calculate BAR2 SGE Queue Register addresses (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxgb4vf: Add code to calculate T5 BAR2 Offsets for SGE Queue Registers (Sai Vemuri) [1251611]
- [netdrv] cxgb4vf: Add and initialize some sge params for VF driver (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Update FW version string to match FW binary version 1.12.25.0 (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add a check for flashing FW using ethtool (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fill in supported link mode for SFP modules (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxgb4vf/csiostor: Add T4/T5 PCI ID Table (Sai Vemuri) [1251611]
- [infiniband] cxgb4/cxgb4vf/csiostor: Cleanup macros/register defines related to PCIE, RSS and FW (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxgb4vf/csiostor: Cleanup macros/register defines related to port and VI (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Disable recursive mailbox commands when enabling vi (Sai Vemuri) [1251611]
- [netdrv] cxgb4/cxgb4vf/csiostor: Cleanup macros/register defines related to queues (Sai Vemuri) [1251611]
- [infiniband] cxgb4/csiostor: Cleansup FW related macros/register defines for PF/VF and LDST (Sai Vemuri) [1251611]
- [infiniband] cxgb4: Cleanup Filter related macros/register defines (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fix DCB priority groups being returned in wrong order (Sai Vemuri) [1251611]
- [netdrv] cxgb4i/cxgb4: Refactor macros to conform to uniform standards (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fix static checker warning (Sai Vemuri) [1251611]
- [netdrv] cxgb4: dcb open-lldp interop fixes (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fix bug in DCB app deletion (Sai Vemuri) [1251611]
- [scsi] cxgb4: Cleanup macros so they follow the same style and look consistent, part 2 (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Cleanup macros so they follow the same style and look consistent (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add cxgb4_debugfs.c, move all debugfs code to new file (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Handle dcb enable correctly (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Improve handling of DCB negotiation or loss thereof (Sai Vemuri) [1251611]
- [netdrv] cxgb4: IEEE fixes for DCBx state machine (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Fix endian bug introduced in cxgb4 dcb patchset (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Update copyright year on all cxgb4 files (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Makefile & Kconfig changes for DCBx support (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Integrate DCBx support into cxgb4 module. Register dbcnl_ops to give access to DCBx functions (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Add DCBx support codebase and dcbnl_ops (Sai Vemuri) [1251611]
- [netdrv] cxgb4: Update fw interface file for DCBx support. Adds all the required fields to fw interface to communicate DCBx info (Sai Vemuri) [1251611]

* Mon Sep 21 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-318.el7]
- [net] vlan: Add GRO support for non hardware accelerated vlan (Ivan Vecera) [1235229]
- [net] Add priority to packet_offload objects (Ivan Vecera) [1235229]
- [net] sctp: add routing output fallback (Marcelo Leitner) [1258494]
- [net] sctp: fix dst leak (Marcelo Leitner) [1258494]
- [scsi] hpsa: move lockup_detected attribute to host attr (Joseph Szczypek) [1259673]
- [sound] alsa: hda - Fix subsystem ID read regression (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - Set patch_ops before calling auto-parser (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - Disable widget power-save for VIA codecs (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - Fix Dock Headphone on Thinkpad X250 seen as a Line Out (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - Fix link power unbalance at device removal (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - Re-add the lost fake mute support (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - Don't actually write registers for caps overwrites (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - set GET bit when adding a vendor verb to the codec regmap (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - Always allow access for POWER_STATE verbs via regmap (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - Set use_single_rw flag for regmap (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - Handle a few verbs as read-only (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - Add cache support for COEF read/write (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - Handle get/set power verb symmetrically via regmap (Jaroslav Kysela) [1256578]
- [sound] alsa: hda - fix i915 probe for HSW/BDW (Jaroslav Kysela) [1253837]
- [sound] alsa: hda - Fix NULL dereference from CA0132 DSP loader (Jaroslav Kysela) [1251483]
- [tools] cpupower: Do not change the frequency of offline cpu (Gustavo Duarte) [1260293]
- [crypto] nx - add LE support to pSeries platform driver (Gustavo Duarte) [1261375]
- [netdrv] ibmveth: Don't receive packets when the napi budget == 0 (Gustavo Duarte) [1264158]
- [netdrv] iwlwifi: pcie: fix prepare card flow (Stanislaw Gruszka) [1256419]
- [netdrv] rtlwifi: Fix NULL dereference when PCI driver used as an AP (Stanislaw Gruszka) [1256419]
- [net] mac80211: fix invalid read in minstrel_sort_best_tp_rates() (Stanislaw Gruszka) [1256419]
- [netdrv] iwlwifi: pcie: prepare the device before accessing it (Stanislaw Gruszka) [1256419]
- [netdrv] iwlwifi: nvm: remove mac address byte swapping in 8000 family (Stanislaw Gruszka) [1256419]
- [netdrv] iwlwifi: mvm: fix antenna selection when BT is active (Stanislaw Gruszka) [1256419]
- [net] mac80211: clear subdir_stations when removing debugfs (Stanislaw Gruszka) [1256419]
- [net] mac80211: prevent possible crypto tx tailroom corruption (Stanislaw Gruszka) [1256419]
- [wireless] cfg80211: ignore netif running state when changing iftype (Stanislaw Gruszka) [1256419]
- [netdrv] iwlwifi: mvm: fix ROC reference accounting (Stanislaw Gruszka) [1256419]
- [net] mac80211: fix the beacon csa counter for mesh and ibss (Stanislaw Gruszka) [1256419]
- [netdrv] rtlwifi: Remove the clear interrupt routine from all drivers (Stanislaw Gruszka) [1256419]
- [netdrv] ath9k_htc: memory corruption calling set_bit() (Stanislaw Gruszka) [1256419]
- [netdrv] ath9k: fix DMA stop sequence for AR9003+ (Stanislaw Gruszka) [1256419]
- [net] mac80211: fix locking in update_vlan_tailroom_need_count() (Stanislaw Gruszka) [1256419]
- [wireless] cfg80211: wext: clear sinfo struct before calling driver (Stanislaw Gruszka) [1256419]
- [netdrv] ssb: Fix handling of ssb_pmu_get_alp_clock() (Stanislaw Gruszka) [1256419]
- [infiniband] hfi: Properly set permissions for user device files (Don Dutile) [1255736]

* Fri Sep 18 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-317.el7]
- [fs] nfs: Don't attempt to decode missing directory entries (Benjamin Coddington) [1261725]
- [fs] xfs: flush entire file on dio read/write to cached file (Brian Foster) [1229074]
- [fs] gfs2: Don't support fallocate on jdata files (Abhijith Das) [1221331]
- [fs] xfs: checksum log record ext headers based on record size (Brian Foster) [1256593]
- [md] dm-crypt: constrain crypt device's max_segment_size to PAGE_SIZE (Mike Snitzer) [1252726]
- [md] dm-thin: disable discard support for thin devices if pool's is disabled (Mike Snitzer) [1260135]
- [md] dm-cache: small cleanups related to deferred prison cell cleanup (Mike Snitzer) [1250832]
- [md] dm-cache: fix leaking of deferred bio prison cells (Mike Snitzer) [1250832]
- [md] dm-cache: fix use after freeing migrations (Mike Snitzer) [1250832]
- [md] dm-cache: move wake_waker() from free_migrations() to where it is needed (Mike Snitzer) [1250832]
- [md] raid1: count resync requests in nr_pending (Jes Sorensen) [1261114]
- [md] raid1: update next_resync under resync_lock (Jes Sorensen) [1261114]
- [md] raid1: Don't use next_resync to determine how far resync has progressed (Jes Sorensen) [1261114]
- [md] raid1: make sure resync waits for conflicting writes to complete (Jes Sorensen) [1261114]
- [md] raid1: clean up request counts properly in close_sync() (Jes Sorensen) [1261114]
- [md] raid1: be more cautious where we read-balance during resync (Jes Sorensen) [1261114]
- [md] raid1: intialise start_next_window for READ case to avoid hang (Jes Sorensen) [1261114]
- [md] raid0: update queue parameter in a safer location (Jes Sorensen) [1247854]
- [x86] perf/uncore: Use Sandy Bridge client PMU on Haswell/Broadwell (Jiri Olsa) [1250642]
- [x86] perf/uncore: Add support for ARB uncore PMU on Sandy/IvyBridge (Jiri Olsa) [1250642]
- [x86] perf/uncore: Add Broadwell-U uncore IMC PMU support (Jiri Olsa) [1250642]
- [x86] perf: Disable fixup_ht_bug function (Jiri Olsa) [1246669]
- [base] pm: add Red Hat dev_pm_info_rh struct (Prarit Bhargava) [1261130]
- [base] device: allocate/free Red Hat only struct device_rh (Prarit Bhargava) [1261130]
- [idle] intel_idle: Add CPU model 54 (Atom N2000 series) (Prarit Bhargava) [1230936]
- [block] blk-mq: don't lose requests if a stopped queue restarts (Jeff Moyer) [1251417]
- [block] blk-mq: fix FUA request hang (Jeff Moyer) [1251417]
- [block] blk-mq: fix CPU hotplug handling (Jeff Moyer) [1251417]
- [block] blk-mq: fix race between timeout and CPU hotplug (Jeff Moyer) [1251417]
- [block] blk-mq: initialize 'struct request' and associated data to zero (Jeff Moyer) [1251417]
- [netdrv] be2net: Revert "make the RX_FILTER command asynchronous" commit (Ivan Vecera) [1253268]
- [netdrv] mlx4_core: Capping number of requested MSIXs to MAX_MSIX (Amir Vadai) [1260507]
- [scripts] modpost: Keep hfi1 driver in staging from tainting kernel (Don Dutile) [1257994]
- [powerpc] kdump: Increase the amount of memory reserved for crashkernel=auto (Dave Young) [1222059]

* Tue Sep 15 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-316.el7]
- [fs] Set UID in sess_auth_rawntlmssp_authenticate too (Sachin Prabhu) [1258490]
- [drm] radeon: fix hotplug race at startup (Dave Airlie) [1262218]
- [net] fix NULL pointer dereference in skb_copy_and_csum_datagram_iovec when using NFS (Sabrina Dubroca) [1258907]
- [net] ipv4: suppress NETDEV_UP notification on address lifetime update (Aaron Conole) [1250705]
- [lib] radix-tree: handle allocation failure in radix_tree_insert() (Seth Jennings) [1260613]
- [x86] efi: Use all 64 bit of efi_memmap in setup_e820() (Larry Woodman) [1248452]
- [x86] Fix misapplied XSTATE_LAZY patch (Prarit Bhargava) [1258840]
- [netdrv] r8169: Fix sleeping function called during get_stats64 (Corinna Vinschen) [1261973]
- [netdrv] ixgbe: Remove bimodal SR-IOV disabling (Alex Williamson) [1243821]
- [powerpc] kvm: book3s-hv: Exit on H_DOORBELL if HOST_IPI is set (David Gibson) [1259571]
- [powerpc] kvm: book3s-hv: Fix race in starting secondary threads (David Gibson) [1259571]
- [powerpc] powernv/pci-ioda: fix kdump with non-power-of-2 crashkernel= (Gustavo Duarte) [1258491]
- [powerpc] powernv/pci-ioda: fix 32-bit TCE table init in kdump kernel (Gustavo Duarte) [1258491]

* Tue Sep 08 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-315.el7]
- [unisys] Add modalias files to visorbus devices (Erik Arfvidson) [1259509]
- [net] tcp: use dctcp if enabled on the route to the initiator (Florian Westphal) [1254839]
- [net] fib, fib6: reject invalid feature bits (Florian Westphal) [1254839]
- [net] fib6: reduce identation in ip6_convert_metrics (Florian Westphal) [1254839]
- [net] fib: move metrics parsing to a helper (Florian Westphal) [1254839]
- [net] tunnels: enable module autoloading (Phil Sutter) [1258861]
- [net] ip6_gre: release cached dst on tunnel removal (Sabrina Dubroca) [1210346]
- [scsi] qla2xxx: Fix backporting error in "Fix virtual port configuration, when switch port is disabled/enabled" (Chad Dupuis) [1240912]
- [scsi] megaraid_sas: Code refactor for use of requestorId (Tomas Henzl) [1257604]
- [scsi] megaraid_sas: Fix validHandles check in io path (Tomas Henzl) [1257604]
- [scsi] megaraid_sas: Chip reset if driver fail to bring ioc ready (Tomas Henzl) [1257604]
- [scsi] megaraid_sas: init tasklet earlier (Tomas Henzl) [1252127]
- [misc] enclosure: handle non-unique element descriptors (Jose Castillo) [1188248]
- [edac] ie31200_edac: Allocate mci and map mchbar first (Seth Jennings) [1241708]
- [edac] ie31200_edac: Introduce the driver (Seth Jennings) [1241708]
- [kernel] readq/writeq: Add explicit lo_hi_[read|write]_q and hi_lo_[read|write]_q (Seth Jennings) [1241708]
- [infiniband] mlx4: Fix use of flow-counters for process_mad (Amir Vadai) [1251740]
- [netdrv] mlx4_core: Use sink counter for the VF default as fallback (Amir Vadai) [1251740]
- [netdrv] i40e: Set defport behavior for the Main VSI when in promiscuous mode (Stefan Assmann) [1190049 1226826]
- [netdrv] i40e: clean up error status messages (Stefan Assmann) [1190049 1226826]
- [pci] Add ACS quirks for Intel I219-LM/V (Alex Williamson) [1252128]
- [ipc] sem: fix use after free on IPC_RMID after a task using same semaphore set exits ("Herton R. Krzesinski") [1254322]
- [x86] mce: Do not panic when single core has reached a timeout (Prarit Bhargava) [1195534]
- [x86] fpu: Fix double-increment in setup_xstate_features() (Herbert Xu) [1232494]
- [x86] fpu/xstate: Don't assume the first zero xfeatures zero bit means the end (Herbert Xu) [1232494]
- [fs] cifs: Terminate cifs_smb_version_tokens with NULL (Sachin Prabhu) [1247446]
- [mm] numa: disable change protection for vma(VM_HUGETLB) (Larry Woodman) [1251007]
- [kenrel] trace: Check permission only for parent tracepoint event (Jiri Olsa) [1253487]

* Thu Sep 03 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-314.el7]
- [drm] nouveau/pmu/gk104: implement a hackish workaround for a hw bug (Rob Clark) [1249805]
- [drm] nouveau/disp/dp: gm1xx appears to have same dp lane ordering as gm2xx (Rob Clark) [1249805]
- [drm] nouveau/disp/dp: fix some tx_pu mishandling (Rob Clark) [1249805]
- [drm] nouveau/bios/dp: use alternate set of drvctl values where necessary (Rob Clark) [1249805]
- [drm] nouveau/bios/dcb: accept "maxwell" lane count values for dcb 4.0 (Rob Clark) [1249805]
- [drm] dp/mst: dump branch OUI in debugfs (v2) (Rob Clark) [1249805]
- [drm] dp-mst: Remove debug WARN_ON (Rob Clark) [1249805]
- [drm] radeon: Don't link train DisplayPort on HPD until we get the dpcd (Rob Clark) [1249805]
- [drm] dp/mst: Remove port after removing connector (Rob Clark) [1249805]
- [drm] nouveau/drm/nv04-nv40/instmem: protect access to priv->heap by mutex (Rob Clark) [1249805]
- [drm] nouveau: hold mutex when calling nouveau_abi16_fini() (Rob Clark) [1249805]
- [drm] nouveau/kms/nv50-: guard against enabling cursor on disabled heads (Rob Clark) [1249805]
- [drm] nouveau/fbcon/nv11-: correctly account for ring space usage (Rob Clark) [1249805]
- [drm] Stop resetting connector state to unknown (Rob Clark) [1249805]
- [drm] Provide compat ioctl for addfb2.1 (Rob Clark) [1249805]
- [drm] add a check for x/y in drm_mode_setcrtc (Rob Clark) [1249805]
- [drm] radeon/ci: silence a harmless PCC warning (Rob Clark) [1249805]
- [drm] radeon: fix user ptr race condition (Rob Clark) [1249805]
- [drm] radeon: add a dpm quirk for Sapphire Radeon R9 270X 2GB GDDR5 (Rob Clark) [1249805]
- [drm] radeon: Don't flush the GART TLB if rdev->gart.ptr == NULL (Rob Clark) [1249805]
- [drm] radeon: unpin cursor BOs on suspend and pin them again on resume (v2) (Rob Clark) [1249805]
- [drm] radeon: Clean up reference counting and pinning of the cursor BOs (Rob Clark) [1249805]
- [drm] radeon: Handle irqs only based on irq ring, not irq status regs (Rob Clark) [1249805]
- [drm] radeon: fix HDP flushing (Rob Clark) [1249805]
- [drm] radeon: only check the sink type on DP connectors (Rob Clark) [1249805]
- [drm] revert "drm/radeon: dont switch vt on suspend" (Rob Clark) [1249805]
- [drm] radeon: SDMA fix hibernation (CI GPU family) (Rob Clark) [1249805]
- [drm] radeon: compute ring fix hibernation (CI GPU family) v2 (Rob Clark) [1249805]
- [drm] i915: Use two 32bit reads for select 64bit REG_READ ioctls (Rob Clark) [1249805]
- [drm] i915: Forward all core DRM ioctls to core compat handling (Rob Clark) [1249805]
- [drm] i915: Snapshot seqno of most recently submitted request (Rob Clark) [1249805]
- [drm] i915: fix backlight after resume on 855gm (Rob Clark) [1249805]
- [drm] i915: Fix IPS related flicker (Rob Clark) [1249805]
- [drm] i915/ppgtt: Break loop in gen8_ppgtt_clear_range failure path (Rob Clark) [1249805]
- [drm] radeon: clean up radeon_audio_enable (Rob Clark) [1249805]
- [drm] radeon: take the mode_config mutex when dealing with hpds (v2) (Rob Clark) [1249805]
- [drm] atomic: fix out of bounds read in for_each_*_in_state helpers (Rob Clark) [1249805]
- [drm] bridge: ptn3460: Include linux/gpio/consumer.h (Rob Clark) [1249805]
- [drm] qxl: Do not leak memory if qxl_release_list_add fails (Rob Clark) [1249805]
- [drm] qxl: Do not cause spice-server to clean our objects (Rob Clark) [1249805]
- [drm] dp/mst: make sure mst_primary mstb is valid in work function (Rob Clark) [1249805]
- [drm] dp/mst: take lock around looking up the branch device on hpd irq (Rob Clark) [1249805]
- [drm] dp/mst: close deadlock in connector destruction (Rob Clark) [1249805]
- [drm] radeon: don't probe MST on hw we don't support it on (Rob Clark) [1249805]
- [drm] radeon: Add RADEON_INFO_VA_UNMAP_WORKING query (Rob Clark) [1249805]
- [drm] mgag200: Reject non-character-cell-aligned mode widths (Rob Clark) [1249805]
- [drm] revert "drm/i915: Don't skip request retirement if the active list is empty" (Rob Clark) [1249805]
- [drm] i915: Always reset vma->ggtt_view.pages cache on unbinding (Rob Clark) [1249805]
- [drm] radeon: Make sure radeon_vm_bo_set_addr always unreserves the BO (Rob Clark) [1249805]
- [drm] revert "drm/radeon: adjust pll when audio is not enabled" (Rob Clark) [1249805]
- [drm] revert "drm/radeon: don't share plls if monitors differ in audio support" (Rob Clark) [1249805]
- [drm] radeon: fix freeze for laptop with Turks/Thames GPU (Rob Clark) [1249805]
- [mm] hugetlb: fix race in region tracking (Aristeu Rozanski) [1252129]
- [mm] hugetlb: improve, cleanup resv_map parameters (Aristeu Rozanski) [1252129]
- [mm] hugetlb: unify region structure handling (Aristeu Rozanski) [1252129]
- [hv] mshyperv: fix recognition of Hyper-V guest crash MSR's (Vitaly Kuznetsov) [1235998]
- [hv] vmbus: prefer 'die' notification chain to 'panic' (Vitaly Kuznetsov) [1235998]
- [usb] Delete XHCI command timer if necessary (Dave Young) [1242851]
- [x86] perf: cqm: Do not access cpu_data() from CPU_UP_PREPARE handler (Yasuaki Ishimatsu) [1257502]
- [x86] kprobes: Fix conflict between jprobes and function graph tracing (Jiri Olsa) [1242825]
- [netdrv] sfc: only use vadaptor stats if firmware is capable (Jarod Wilson) [1248331]
- [netdrv] r8169: Add software counter for multicast packages (Corinna Vinschen) [1253102]
- [powerpc] powernv: Invoke opal_cec_reboot2() on unrecoverable HMI (Gustavo Duarte) [1253477]
- [powerpc] powernv: Invoke opal_cec_reboot2() on unrecoverable machine check errors (Gustavo Duarte) [1253477]
- [powerpc] powernv: Pull all HMI events before panic (Gustavo Duarte) [1253477]
- [powerpc] powernv: display reason for Malfunction Alert HMI (Gustavo Duarte) [1253477]
- [powerpc] powernv: Add poweroff (EPOW, DPO) events support for PowerNV platform (Gustavo Duarte) [1257315]
- [powerpc] pseries: Cleanup on pci_dn_reconfig_notifier() (Laurent Vivier) [1254200]
- [powerpc] pseries: Fix corrupted pdn list (Laurent Vivier) [1254200]
- [powercap] rapl: change domain detection message (Prarit Bhargava) [1238347]
- [powercap] rapl: further relax energy counter checks (Prarit Bhargava) [1238347]

* Mon Aug 31 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-313.el7]
- [fs] locks: remove i_have_this_lease check from __break_lease (Steve Dickson) [1258337]
- [fs] locks: set fl_owner for leases to filp instead of current->files (Steve Dickson) [1258337]
- [fs] locks: fix NULL-deref in generic_delete_lease (Steve Dickson) [1258337]
- [fs] ext4: fix potential use after free in __ext4_journal_stop (Lukas Czerner) [1210588]
- [fs] ext4: fix NULL pointer dereference when journal restart fails (Lukas Czerner) [1210588]
- [fs] cifs: fix use-after-free bug in find_writable_file (Sachin Prabhu) [1186260]
- [fs] ext4: check for zero length extent explicitly (Eryu Guan) [1221905]
- [fs] ioctx_alloc(): fix vma (and file) leak on failure (Jarod Wilson) [1209536]
- [fs] ext4: reject journal options for ext2 mounts (Carlos Maiolino) [839466]
- [fs] fanotify: fix -EOVERFLOW with large files on 64-bit (Carlos Maiolino) [981181]
- [fs] xfs: close xc_cil list_empty() races with cil commit sequence (Brian Foster) [1028505]
- [fs] xfs: fix quota block reservation leak when tp allocates and frees blocks (Brian Foster) [1068915]
- [fs] xfs: always log the inode on unwritten extent conversion (Brian Foster) [1053384]
- [fs] xfs: direct IO EOF zeroing needs to drain AIO (Brian Foster) [1213370]
- [fs] xfs: DIO write completion size updates race (Brian Foster) [1213370]
- [fs] nfsv4.2: handle NFS-specific llseek errors ("J. Bruce Fields") [1079385]
- [fs] nfsd4: disallow SEEK with special stateids ("J. Bruce Fields") [1079385]
- [fs] nfsd4: disallow ALLOCATE with special stateids ("J. Bruce Fields") [1079385]
- [fs] nfs: Reduce time spent holding the i_mutex during fallocate() ("J. Bruce Fields") [1079385]
- [fs] nfs: Don't zap caches on fallocate() ("J. Bruce Fields") [1079385]
- [fs] nfs: Add DEALLOCATE support ("J. Bruce Fields") [1079385]
- [fs] nfs: Add ALLOCATE support ("J. Bruce Fields") [1079385]
- [fs] nfs: Use nfs_server_capable() for checknig NFS_CAP_SEEK ("J. Bruce Fields") [1079385]
- [fs] nfsd: correctly define v4.2 support attributes ("J. Bruce Fields") [1079385]
- [fs] nfsd: Add DEALLOCATE support ("J. Bruce Fields") [1079385]
- [fs] nfsd: Add ALLOCATE support (Steve Dickson) [1079385]
- [fs] vfs: Rename do_fallocate() to vfs_fallocate() ("J. Bruce Fields") [1079385]
- [fs] nfs: Implement SEEK ("J. Bruce Fields") [1079385]
- [fs] nfsd: Implement SEEK (Steve Dickson) [1079385]
- [fs] nfsd: Add generic v4.2 infrastructure ("J. Bruce Fields") [1079385]
- [fs] vfs: export lseek_execute() to modules ("J. Bruce Fields") [1079385]
- [fs] lseek_execute() doesn't need an inode passed to it ("J. Bruce Fields") [1079385]
- [fs] flexfilelayout: Mark the Flexfile layout driver as a tech preview (Steve Dickson) [1246230]
- [fs] blocklayout: Mark the NFSv4 Block Layout Driver layout driver as a tech preview (Steve Dickson) [1246237]
- [fs] nfs4layouts: Remove unnecessary BUG_ON in nfsd4_layout_setlease() (Steve Dickson) [1195496]
- [fs] nfsd: restore trace event lost in mismerge (Steve Dickson) [1195496]
- [fs] nfsd: don't recursively call nfsd4_cb_layout_fail (Steve Dickson) [1195496]
- [fs] nfsd/blocklayout: pretend we can send deviceid notifications (Steve Dickson) [1195496]
- [fs] nfsd: add NFSEXP_PNFS to the exflags array (Steve Dickson) [1195496]
- [fs] nfsd: require an explicit option to enable pNFS (Steve Dickson) [1195496]
- [fs] nfsd: pNFS block layout driver (Steve Dickson) [1195496]
- [fs] nfsd: add trace events (Steve Dickson) [1195496]
- [fs] nfsd: update documentation for pNFS support (Steve Dickson) [1195496]
- [fs] nfsd: implement pNFS layout recalls (Steve Dickson) [1195496]
- [fs] nfsd: implement pNFS operations (Steve Dickson) [1195496]
- [fs] nfsd: factor out a helper to decode nfstime4 values (Steve Dickson) [1195496]
- [fs] nfsd: make find_any_file available outside nfs4state.c (Steve Dickson) [1195496]
- [fs] nfsd: make find/get/put file available outside nfs4state.c (Steve Dickson) [1195496]
- [fs] nfsd: make lookup/alloc/unhash_stid available outside nfs4state.c (Steve Dickson) [1195496]
- [fs] nfsd: add fh_fsid_match helper (Steve Dickson) [1195496]
- [fs] nfsd: move nfsd_fh_match to nfsfh.h (Steve Dickson) [1195496]
- [fs] nfs: add LAYOUT_TYPE_MAX enum value (Steve Dickson) [1195496]
- [fs] exportfs: add methods for block layout exports (Steve Dickson) [1195496]
- [fs] fs: track fl_owner for leases (Steve Dickson) [1195496]
- [fs] locks: plumb a "priv" pointer into the setlease routines (Steve Dickson) [1195496]
- [fs] locks: generic_delete_lease doesn't need a file_lock at all (Steve Dickson) [1195496]
- [fs] locks: add some tracepoints in the lease handling code (Steve Dickson) [1195496]
- [fs] fs: add FL_LAYOUT lease type (Steve Dickson) [1195496]
- [fs] locks: close potential race between setlease and open (Steve Dickson) [1195496]
- [fs] nfs: Fetch MOUNTED_ON_FILEID when updating an inode (Steve Dickson) [1225090]
- [fs] nfsv3: Use the readdir fileid as the mounted-on-fileid (Steve Dickson) [1225090]
- [fs] nfs: Fix use of nfs_attr_use_mounted_on_fileid() (Steve Dickson) [1225090]
- [x86] kernel: microcode, amd, avoid allocating with vmalloc & GFP_KERNEL when IRQs are disabled (Prarit Bhargava) [1080951]

* Fri Aug 28 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-312.el7]
- [target] iscsi: Fix np_ip bracket issue by removing np_ip (Andy Grover) [1249107]
- [scsi] libiscsi: Fix host busy blocking during connection teardown (Chris Leech) [1253032]
- [md] raid1: extend spinlock to protect raid1_end_read_request against inconsistencies (Jes Sorensen) [1255758]
- [md] raid1: fix test for 'was read error from last working device' (Jes Sorensen) [1255758]
- [net] pktgen: fix race between pktgen_thread_worker() and kthread_stop() (Oleg Nesterov) [1054125]
- [net] vxlan: re-ignore EADDRINUSE from igmp_join (Marcelo Leitner) [1256976]
- [net] netfilter: nf_ct_sctp: minimal multihoming support (Marcelo Leitner) [1256795]
- [net] Fix skb_set_peeked use-after-free bug (Sabrina Dubroca) [1243993]
- [net] Fix skb csum races when peeking (Sabrina Dubroca) [1243993]
- [net] Clone skb before setting peeked flag (Sabrina Dubroca) [1243993]
- [net] sock: fix SO_MAX_PACING_RATE (Sabrina Dubroca) [1235100]
- [net] netfilter: conntrack: don't reject clashing expectation if its in another ct zone (Florian Westphal) [1253847]
- [net] flowcache: Fix kernel panic in flow_cache_flush_task (Phil Sutter) [1243591]
- [net] flowcache: Fix resource leaks on namespace exit (Phil Sutter) [1243591]
- [net] xfrm: Fix refcount imbalance in xfrm_lookup (Phil Sutter) [1243591]
- [net] flowcache: restore a single flow_cache kmem_cache (Phil Sutter) [1243591]
- [net] xfrm: release dst_orig in case of error in xfrm_lookup() (Phil Sutter) [1243591]
- [net] xfrm: remove irrelevant comment in xfrm_input(). (Phil Sutter) [1243591]
- [net] xfrm: Generate queueing routes only from route lookup functions (Phil Sutter) [1243591]
- [net] xfrm: Remove caching of xfrm_policy_sk_bundles (Phil Sutter) [1243591]
- [net] flowcache: Make flow cache name space aware (Phil Sutter) [1243591]
- [net] xfrm: Fix null pointer dereference when decoding sessions (Phil Sutter) [1243591]
- [net] ipv6: update flowi6_oif in ip6_dst_lookup_flow if not set (Phil Sutter) [1243591]
- [net] Remove FLOWI_FLAG_CAN_SLEEP (Phil Sutter) [1243591]
- [net] xfrm: Remove ancient sleeping when the SA is in acquire state (Phil Sutter) [1243591]
- [net] xfrm: Fix NULL pointer dereference on sub policy usage (Phil Sutter) [1243591]
- [net] xfrm: Namespacify xfrm state/policy locks (Phil Sutter) [1243591]
- [net] xfrm: Using the right namespace to migrate key info (Phil Sutter) [1243591]
- [net] xfrm: Remove extern from function prototypes (Phil Sutter) [1243591]
- [net] xfrm: constify mark argument of xfrm_find_acq() (Phil Sutter) [1243591]
- [net] ip: Remove extern from function prototypes (Phil Sutter) [1243591]
- [net] ipv6: prevent fib6_run_gc() contention (Phil Sutter) [1243591]
- [net] ipv4: remove fib_update_nh_saddrs() declaration (Phil Sutter) [1243591]
- [net] xfrm: Generate blackhole routes only from route lookup functions (Phil Sutter) [1243591]
- [net] xfrm: check for a vaild skb in xfrm_policy_queue_process (Phil Sutter) [1243591]
- [net] xfrm: Add refcount handling to queued policies (Phil Sutter) [1243591]
- [net] xfrm: Decode sessions with output interface (Phil Sutter) [1243591]
- [drm] qxl: rewrite framebuffer support (Gerd Hoffmann) [1072350]
- [x86] hyperv: Mark the Hyper-V TSC as unstable (Vitaly Kuznetsov) [1235523]

* Fri Aug 28 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-311.el7]
- [hv] vmbus: don't send CHANNELMSG_UNLOAD on pre-Win2012R2 hosts (Vitaly Kuznetsov) [1248352]
- [hv] vmbus: add special crash handler (Vitaly Kuznetsov) [1248352]
- [hv] don't do hypercalls when hypercall_page is NULL (Vitaly Kuznetsov) [1248352]
- [hv] vmbus: add special kexec handler (Vitaly Kuznetsov) [1248352]
- [hv] vmbus: remove hv_synic_free_cpu() call from hv_synic_cleanup() (Vitaly Kuznetsov) [1248352]
- [hv] vmbus: kill tasklets on module unload (Vitaly Kuznetsov) [1248352]
- [hv] vmbus: Implement the protocol for tearing down vmbus state (Vitaly Kuznetsov) [1248352]
- [hv] vmbus: Get rid of some unused definitions (Vitaly Kuznetsov) [1248352]
- [hid] usbhid: Fix the check for HID_RESET_PENDING in hid_io_error (Don Zickus) [1167266]
- [x86] documentation: add kernel-parameters.txt entry for dis_ucode_ldr (Prarit Bhargava) [1256913]
- [x86] microcode: Add a disable chicken bit (Prarit Bhargava) [1256913]
- [x86] boot: Carve out early cmdline parsing function (Prarit Bhargava) [1256913]
- [block] mtip32x: fix regression introduced by blk-mq per-hctx flush (Jeff Moyer) [1228812]
- [hwmon] coretemp: Atom CPUs don't support TjMax; no warning needed (Prarit Bhargava) [1253935]
- [crypto] nx - Removing CTR mode from NX driver (Herbert Xu) [1241751]
- [unisys] add visorhid driver (Erik Arfvidson) [1232017]
- [unisys] add MODULE_DEVICE_TABLE and temporary MODULE_ALIAS lines to visornic (Erik Arfvidson) [1232014]
- [unisys] Add s-Par visorhba (Erik Arfvidson) [1232014]
- [netdrv] r8169: Add values missing in @get_stats64 from HW counters (Corinna Vinschen) [1253102]
- [netdrv] enic: fix work done in tx napi_poll (Stefan Assmann) [1247856]
- [netdrv] enic: update desc properly in rx_copybreak (Stefan Assmann) [1247856]
- [netdrv] enic: handle error condition properly in enic_rq_indicate_buf (Stefan Assmann) [1247856]
- [netdrv] enic: implement rx_copybreak (Stefan Assmann) [1247856]
- [thermal] powerclamp: support Knights Landing (Steve Best) [1158597]
- [thermal] powerclamp: add cpu id for Skylake u/y (Steve Best) [1179991]
- [thermal] powerclamp: add cpu id for skylake h/s (Steve Best) [1179991]
- [thermal] powerclamp: Remove tick_nohz_idle abuse (Steve Best) [1255864]
- [thermal] powerclamp: Clean up preempt_enable_no_resched() abuse (Steve Best) [1255864]

* Thu Aug 27 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-310.el7]
- [infiniband] Move hfi1 to staging (David Sowa) [1173291]
- [infiniband] core: Add opa driver to kbuild (David Sowa) [1173291]
- [infiniband] revert "ib/hfi1: Switch to topology_sibling_mask()" (David Sowa) [1173291]
- [infiniband] revert "ib/hfi1: Switch to the ->write_iter() API" (David Sowa) [1173291]
- [infiniband] hfi1: Remove inline from trace functions (David Sowa) [1173291]
- [infiniband] hfi1: Add Infiniband dependency to Kconfig (David Sowa) [1173291]
- [infiniband] hfi1: add driver make/config files (David Sowa) [1173291]
- [infiniband] hfi1: add multicast routines (David Sowa) [1173291]
- [infiniband] hfi1: add general verbs handling (David Sowa) [1173291]
- [infiniband] hfi1: add PSM sdma hooks (David Sowa) [1173291]
- [infiniband] hfi1: add low level page locking (David Sowa) [1173291]
- [infiniband] hfi1: add UD QP handling (David Sowa) [1173291]
- [infiniband] hfi1: add UC QP handling (David Sowa) [1173291]
- [infiniband] hfi1: add QSFP twsi routines (David Sowa) [1173291]
- [infiniband] hfi1: add tracepoint debug routines (David Sowa) [1173291]
- [infiniband] hfi1: add sysfs routines and documentation (David Sowa) [1173291]
- [infiniband] hfi1: add SRQ handling (David Sowa) [1173291]
- [infiniband] hfi1: add sdma header file (David Sowa) [1173291]
- [infiniband] hfi1: add sdma routines (David Sowa) [1173291]
- [infiniband] hfi1: add common routines for RC/UC (David Sowa) [1173291]
- [infiniband] hfi1: add RC QP handling (David Sowa) [1173291]
- [infiniband] hfi1: add qsfp handling (David Sowa) [1173291]
- [infiniband] hfi1: add qp handling (David Sowa) [1173291]
- [infiniband] hfi1: add platform config definitions (David Sowa) [1173291]
- [infiniband] hfi1: add pio handling (David Sowa) [1173291]
- [infiniband] hfi1: add pcie routines (David Sowa) [1173291]
- [infiniband] hfi1: add misc OPA defines (David Sowa) [1173291]
- [infiniband] hfi1: add memory region handling (David Sowa) [1173291]
- [infiniband] hfi1: add user/kernel memory sharing hooks (David Sowa) [1173291]
- [infiniband] hfi1: add local mad header (David Sowa) [1173291]
- [infiniband] hfi1: add OPA mad handling part2 (David Sowa) [1173291]
- [infiniband] hfi1: add OPA mad handling part1 (David Sowa) [1173291]
- [infiniband] hfi1: add rkey/lkey validation (David Sowa) [1173291]
- [infiniband] hfi1: add progress delay/restart hooks (David Sowa) [1173291]
- [infiniband] hfi1: add interrupt hooks (David Sowa) [1173291]
- [infiniband] hfi1: add module init hooks (David Sowa) [1173291]
- [infiniband] hfi1: add general hfi header file (David Sowa) [1173291]
- [infiniband] hfi1: add firmware hooks (David Sowa) [1173291]
- [infiniband] hfi1: add PSM driver control/data path (David Sowa) [1173291]
- [infiniband] hfi1: add eeprom hooks (David Sowa) [1173291]
- [infiniband] hfi1: add low level receive functions (David Sowa) [1173291]
- [infiniband] hfi1: add dma operation hooks (David Sowa) [1173291]
- [infiniband] hfi1: add diagnostic hooks (David Sowa) [1173291]
- [infiniband] hfi1: add char device instantiation code (David Sowa) [1173291]
- [infiniband] hfi1: add debugfs handling (David Sowa) [1173291]
- [infiniband] hfi1: add completion queue processing (David Sowa) [1173291]
- [infiniband] hfi1: add common header file definitions (David Sowa) [1173291]
- [infiniband] hfi1: add chip specific headers (David Sowa) [1173291]
- [infiniband] hfi1: add chip register definitions (David Sowa) [1173291]
- [infiniband] hfi1: add chip specific support part4 (David Sowa) [1173291]
- [infiniband] hfi1: add chip specific support part3 (David Sowa) [1173291]
- [infiniband] hfi1: add chip specific support part2 (David Sowa) [1173291]
- [infiniband] hfi1: add chip specific support part1 (David Sowa) [1173291]
- [infiniband] core: Add header definitions (David Sowa) [1173291]
- [infiniband] core: Add CNP opcode enumeration (David Sowa) [1173291]

* Mon Aug 24 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-309.el7]
- [netdrv] ixgbevf: Driver version update to indicate RHEL 7.2 (John Greene) [1173787]
- [netdrv] ixgbevf: add support for reporting RSS key and hash table for X550 (John Greene) [1173787]
- [netdrv] ixgbevf: Set Rx hash type for ingress packets (John Greene) [1173787]
- [netdrv] ixgbevf: fold ixgbevf_pull_tail into ixgbevf_add_rx_frag (John Greene) [1173787]
- [netdrv] ixgbevf: Use dev_kfree_skb_any in xmit path, not dev_kfree_skb (John Greene) [1173787]
- [netdrv] ixgbevf: Add the appropriate ethtool ops to query RSS indirection table and key (John Greene) [1173787]
- [netdrv] ixgbevf: Add RSS Key query code (John Greene) [1173787]
- [netdrv] ixgbevf: Add a RETA query code (John Greene) [1173787]
- [netdrv] ixgbevf: Use ether_addr_copy() instead of memcpy() (John Greene) [1173787]
- [netdrv] ixgbevf: Fix code comments and whitespace (John Greene) [1173787]
- [netdrv] ixgbevf: codespell comment spelling fixes (John Greene) [1173787]
- [netdrv] ixgbevf: combine all of the tasks into a single service task (John Greene) [1173787]
- [netdrv] ixgbevf: rewrite watchdog task to function similar to igbvf (John Greene) [1173787]
- [netdrv] ixgbevf: Add code to check for Tx hang (John Greene) [1173787]
- [netdrv] ixgbevf: Fix ordering of shutdown to correctly disable Rx and Tx (John Greene) [1173787]
- [netdrv] ixgbevf: set vlan_features in a single write instead of several ORs (John Greene) [1173787]
- [netdrv] ixgbevf: add RSS support for X550 (John Greene) [1173787]
- [netdrv] ixgbevf: enable multiple queue support (John Greene) [1173787]
- [netdrv] ixgbevf: Fix checksum error when using stacked vlan (John Greene) [1173787]
- [netdrv] ixgbevf: Use eth_skb_pad and skb_put_padto helpers (John Greene) [1173787]
- [netdrv] ixgbevf: fix possible crashes in probe and remove (John Greene) [1173787]
- [netdrv] ixgbevf: add support for X550 VFs (John Greene) [1173787 1187248]
- [netdrv] ixgbevf: add netpoll support (John Greene) [1173787]
- [netdrv] ixgbevf: compare total_rx_packets and budget in ixgbevf_clean_rx_irq (John Greene) [1173787]
- [netdrv] ixgbevf: Change receive model to use double buffered page based receives (John Greene) [1173787]
- [netdrv] ixgbevf: Update Rx next to clean in real time (John Greene) [1173787]
- [netdrv] ixgbevf: reorder main loop in ixgbe_clean_rx_irq to allow for do/while/continue (John Greene) [1173787]
- [netdrv] ixgbevf: Cleanup variable usage, improve stack performance (John Greene) [1173787]
- [netdrv] ixgbevf: Combine the logic for post Rx processing into single function (John Greene) [1173787]
- [netdrv] ixgbevf: Test Rx status bits directly out of the descriptor (John Greene) [1173787]
- [netdrv] ixgbevf: Update ixgbevf_alloc_rx_buffers to handle clearing of status bits (John Greene) [1173787]
- [netdrv] ixgbevf: remove useless bd_number from struct ixgbevf_adapter (John Greene) [1173787 1187248]
- [netdrv] ixgbevf: Resolve missing-field-initializers warnings (John Greene) [1173787]
- [netdrv] ixgbevf: introduce delay for checking VFLINKS on 82599 (John Greene) [1173787]
- [netdrv] ixgbevf: implement ethtool get/set coalesce (John Greene) [1173787]
- [netdrv] ixgbe: update driver version to indicate RHEL7.2 (John Greene) [1173786]
- [netdrv] ixgbe: Don't report flow director filter's status (John Greene) [1173786]
- [netdrv] ixgbe: Specify Rx hash type WRT Rx desc RSS type (John Greene) [1173786]
- [netdrv] ixgbe: only report generic filters in get_ts_info (John Greene) [1173786]
- [netdrv] ixgbe: Remember to write ixfi changes after modifying (John Greene) [1173786]
- [netdrv] ixgbe: fix X550 default set_phy_power method (John Greene) [1173786]
- [netdrv] ixgbe: Set lan_id before using I2C (John Greene) [1173786]
- [netdrv] ixgbe: add link check for X550 copper (John Greene) [1173786]
- [netdrv] ixgbe: Add support for another X550 device (John Greene) [1173786]
- [netdrv] ixgbe: fix X550 PHY function pointers (John Greene) [1173786]
- [netdrv] ixgbe: fix X550 devices init flow (John Greene) [1173786]
- [netdrv] ixgbe: fix bug in not clearing counters for X550 devices (John Greene) [1173786]
- [netdrv] ixgbe: fix issue with sfp events with new X550 devices (John Greene) [1173786]
- [netdrv] ixgbe: add support for interrupts from X550 external PHY (John Greene) [1173786]
- [netdrv] ixgbe: Add const string for overheat message (John Greene) [1173786]
- [netdrv] ixgbe: Add reset for X550 device (John Greene) [1173786]
- [netdrv] ixgbe: add X550 support for external PHY and forced 1G/10G support (John Greene) [1173786]
- [netdrv] ixgbe: Restore ESDP settings after MAC reset (John Greene) [1173786]
- [netdrv] ixgbe: Add a PHY power state method (John Greene) [1173786]
- [netdrv] ixgbe: add define for X557 PHY ID (John Greene) [1173786]
- [netdrv] ixgbe: add support for WoL and autoneg FC for some X550 devices (John Greene) [1173786]
- [netdrv] ixgbe: add array of MAC type dependent values (John Greene) [1173786]
- [netdrv] ixgbe: Use a signed type to hold error codes (John Greene) [1173786]
- [netdrv] ixgbe: Release semaphore bits in the right order (John Greene) [1173786]
- [netdrv] ixgbe: Fix IOSF SB access issues (John Greene) [1173786]
- [netdrv] ixgbe: Add GET_RSS_KEY command to VF-PF channel commands set (John Greene) [1173786]
- [netdrv] ixgbe: Add a RETA query command to VF-PF channel API (John Greene) [1173786]
- [netdrv] ixgbe: Add a new netdev op to allow/prevent a VF from querying an RSS info (John Greene) [1173786]
- [netdrv] ixgbe: Add the appropriate ethtool ops to query RSS indirection table and key (John Greene) [1173786]
- [netdrv] ixgbe: Refactor the RSS configuration code (John Greene) [1173786]
- [netdrv] ixgbe: Drop unnecessary call to rcu_barrier (John Greene) [1173786]
- [netdrv] ixgbe: Remove NETIF_F_HW_VLAN_CTAG_FILTER from hw_features (John Greene) [1173786]
- [netdrv] ixgbe: adds x550 specific FCoE offloads (John Greene) [1173786]
- [netdrv] ixgbe: add support for X550 source_address_prunning (John Greene) [1173786]
- [netdrv] ixgbe: add new bridge mode support function (John Greene) [1173786]
- [netdrv] ixgbe: Move bridge mode from flag to variable (John Greene) [1173786]
- [netdrv] ixgbe: use helpers for converting ns to timespec (John Greene) [1173786]
- [netdrv] ixgbe: Use bool function returns of true/false instead of 1/0 (John Greene) [1173786]
- [netdrv] ixgbe: Remove IXGBE_FLAG_IN_NETPOLL since it doesn't do anything (John Greene) [1173786]
- [netdrv] ixgbe: enable relaxed ordering for SPARC (John Greene) [1173786]
- [netdrv] ixgbe: cleanup make ixgbe_set_ethertype_anti_spoofing_X550 static (John Greene) [1173786]
- [netdrv] ixgbe: Clean up type inconsistency (John Greene) [1173786]
- [netdrv] ixgbe: add new wrapper for X550 support (John Greene) [1173786]
- [netdrv] ixgbe: codespell comment spelling fixes (John Greene) [1173786]
- [netdrv] ixgbe: Use eth_<foo>_addr instead of memset (John Greene) [1173786]
- [netdrv] ixgbe: add Tx anti spoofing support (John Greene) [1173786]
- [netdrv] ixgbe: cleanup redundant default method set_rxpba (John Greene) [1173786]
- [netdrv] ixgbe: fix setting port VLAN (John Greene) [1173786]
- [netdrv] ixgbe: allow multiple queues in SRIOV mode (John Greene) [1173786]
- [netdrv] ixgbe: cleanup sparse errors in new ixgbe_x550.c file (John Greene) [1173786]
- [netdrv] ixgbe: Fix checksum error when using stacked vlan (John Greene) [1173786]
- [netdrv] ixgbe: convert to CYCLECOUNTER_MASK macro (John Greene) [1173786]
- [netdrv] ixgbe: convert to timecounter adjtime (John Greene) [1173786]
- [netdrv] ixgbe: Use dma_rmb on Rx descriptor reads (John Greene) [1173786]
- [netdrv] ixgbe: Use napi_alloc_skb (John Greene) [1173786]
- [netdrv] ixgbe: Use eth_skb_pad and skb_put_padto helpers (John Greene) [1173786]
- [netdrv] ixgbe: fix crash on rmmod after probe fail (John Greene) [1173786]
- [netdrv] ixgbe: add support for X550 extended RSS support (John Greene) [1173786]
- [netdrv] ixgbe: Remove tail write abstraction and add missing barrier (John Greene) [1173786]
- [netdrv] ixgbe: Clean-up page reuse code (John Greene) [1173786]
- [netdrv] ixgbe: Check for presence of IFLA_AF_SPEC (John Greene) [1173786]
- [netdrv] ixgbe: Validate IFLA_BRIDGE_MODE attribute length (John Greene) [1173786]
- [netdrv] ixgbe: fix use after free adapter->state test in ixgbe_remove/ixgbe_probe (John Greene) [1173786]
- [netdrv] ixgbe: Correctly disable VLAN filter in promiscuous mode (John Greene) [1173786]
- [netdrv] ixgbe: use netdev_rss_key_fill() helper (John Greene) [1173786]
- [netdrv] ixgbe: Replace __skb_alloc_page with dev_alloc_page (John Greene) [1173786]
- [netdrv] ixgbe: phy: fix uninitialized status in ixgbe_setup_phy_link_tnx (John Greene) [1173786]
- [netdrv] ixgbe: cleanup move setting PFQDE.HIDE_VLAN to support function (John Greene) [1173786]
- [netdrv] ixgbe: cleanup ixgbe_ndo_set_vf_vlan (John Greene) [1173786]
- [netdrv] ixgbe: fix X540 Completion timeout (John Greene) [1173786]
- [netdrv] ixgbe: fix race when setting advertised speed (John Greene) [1173786]
- [netdrv] ixgbe: need not repeat init skb with NULL (John Greene) [1173786]
- [netdrv] ixgbe: check for vfs outside of sriov_num_vfs before dereference (John Greene) [1173786]
- [netdrv] ixgbe: fix race accessing page->_count (John Greene) [1173786]
- [netdrv] ixgbe: fix setting of TXDCTL.WTRHESH when ITR is set to 0 and no BQL (John Greene) [1173786]
- [netdrv] ixgbe: remove wait loop on autoneg for copper devices (John Greene) [1173786]
- [netdrv] ixgbe: Convert the normal transmit complete path to dev_consume_skb_any() (John Greene) [1173786]
- [netdrv] ixgbe: remove IXGBE_FLAG_MSI(X)_CAPABLE flags (John Greene) [1173786]
- [netdrv] ixgbe: add warnings for other disabled features without MSI-X support (John Greene) [1173786]
- [netdrv] ixgbe: use e_dev_warn instead of netif_printk (John Greene) [1173786]
- [netdrv] ixgbe: use e_dev_warn instead of e_err for displaying warning (John Greene) [1173786]
- [netdrv] ixgbe: determine vector count inside ixgbe_acquire_msix_vectors (John Greene) [1173786]
- [netdrv] ixgbe: move msix_entries allocation into ixgbe_acquire_msix_vectors (John Greene) [1173786]
- [netdrv] ixgbe: return integer from ixgbe_acquire_msix_vectors (John Greene) [1173786]
- [netdrv] ixgbe: use e_dev_warn instead of netif_printk (John Greene) [1173786]
- [netdrv] ixgbe: Do not schedule an uninitialized workqueue entry (John Greene) [1173786]
- [netdrv] ixgbe: remove useless bd_number from adapter struct (John Greene) [1173786]
- [netdrv] ixgbe: Refactor busy poll socket code to address multiple issues (John Greene) [1173786]
- [netdrv] ixgbe: Drop Rx alloc at end of Rx cleanup (John Greene) [1173786]
- [netdrv] ixgbe: use new eth_get_headlen interface (John Greene) [1173786]
- [netdrv] ixgbe: Resolve warnings produced in W=2 builds (John Greene) [1173786]
- [netdrv] ixgbe: add comment noting recalculation of queues (John Greene) [1173786]
- [netdrv] ixgbe: reset interface on link loss with pending Tx work from the VF (John Greene) [1173786]
- [netdrv] ixgbe: Cleanup FDB handling code (John Greene) [1173786]
- [netdrv] ixgbe: Make return values more direct (John Greene) [1173786]
- [netdrv] ixgbe: Delete a bunch of dead code (John Greene) [1173786]
- [netdrv] ixgbe: Fix ixgbe_write_mbx error result (John Greene) [1173786]
- [netdrv] ixgbe: Correct X540 semaphore error (John Greene) [1173786]
- [netdrv] ixgbe: Fix spurious release of semaphore in EEPROM access REDUX (John Greene) [1173786]
- [netdrv] ixgbe: Convert some udelays to usleep_range (John Greene) [1173786]
- [netdrv] ixgbe: don't check minimum link when direct assigned to virtual machine (John Greene) [1173786]
- [netdrv] ixgbe: fix use of list_for_each in ixgbe_enumerate_functions (John Greene) [1173786]
- [netdrv] ixgbe: Change some uses of strncpy to strlcpy (John Greene) [1173786]
- [netdrv] ixgbe: Fix possible null-dereference in error path (John Greene) [1173786]
- [netdrv] ixgbe: remove unnecessary break after return (John Greene) [1173786]
- [netdrv] ixgbe: remove unnecessary break after goto (John Greene) [1173786]
- [netdrv] ixgbe: change PTP NSECS_PER_SEC to IXGBE_PTP_PPS_HALF_SECOND (John Greene) [1173786]
- [netdrv] ixgbe: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (John Greene) [1173786]
- [netdrv] ixgbe: remove linux/export.h header from ixgbe_ptp.c (John Greene) [1173786]
- [netdrv] ixgbe: fix detection of SFP+ capable interfaces (John Greene) [1173786]
- [netdrv] ixgbe: avoid duplicate code in suspend and stop paths (John Greene) [1173786]
- [netdrv] ixgbe: separate the PTP suspend and stop actions (John Greene) [1173786]
- [netdrv] ixgbe: extract PTP clock device from ptp_init (John Greene) [1173786]
- [netdrv] ixgbe: allow ixgbe_ptp_reset to maintain current hwtstamp config (John Greene) [1173786]
- [netdrv] ixgbe: extract the hardware setup from the ixgbe_ptp_set_ts_config (John Greene) [1173786]
- [netdrv] ixgbe: rename ixgbe_ptp_enable to ixgbe_ptp_feature_enable (John Greene) [1173786]
- [netdrv] ixgbe: fix linking at 100Mbps on copper devices with MNG FW enabled (John Greene) [1173786]
- [netdrv] ixgbe: remove return statements for void functions (John Greene) [1173786]
- [netdrv] ixgbe: add /* fallthrough */ comment to case statements (John Greene) [1173786]
- [netdrv] ixgbe: add space between operands to & (John Greene) [1173786]
- [netdrv] ixgbe: don't check NULL for debugfs_remove_recursive (John Greene) [1173786]
- [netdrv] ixgbe: add braces around else block (John Greene) [1173786]
- [netdrv] ixgbe: fix several concatenated strings to single line (John Greene) [1173786]
- [netdrv] ixgbe: fix checkpatch style of blank line after declaration (John Greene) [1173786]
- [netdrv] ixgbe: fix function-like macro, remove semicolon (John Greene) [1173786]
- [netdrv] ixgbe: clean up checkpatch warnings about CODE_INDENT and LEADING_SPACE (John Greene) [1173786]
- [netdrv] ixgbe: remove unnecessary duplication of PCIe bandwidth display (John Greene) [1173786]
- [netdrv] ixgbe: get rid of SET_ETHTOOL_OPS (John Greene) [1173786]
- [netdrv] ixgbe: improve mac filter handling (John Greene) [1173786]
- [netdrv] ixgbe: change handling of multicast filters (John Greene) [1173786]
- [netdrv] ixgbe: remove vlan_filter_disable and enable functions (John Greene) [1173786]
- [netdrv] ixgbe: Use out-of-line function for register reads (John Greene) [1173786]
- [netdrv] ixgbe: convert low_water into an array (John Greene) [1173786]
- [netdrv] ixgbe: remove CIAA/D register reads from bad VF check (John Greene) [1173786 1205903]
- [netdrv] ixgbe: add helper function for setting RSS key in preparation of X550 (John Greene) [1173786]
- [netdrv] ixgbe: Mass conversion of smp_mb__*() (John Greene) [1173786]
- [netdrv] ixgbe: Clear head write-back registers on VF reset (John Greene) [1173786]
- [netdrv] ixgbe: Force QDE via PFQDE for VFs during reset (John Greene) [1173786]
- [netdrv] ixgbe: cleanup ixgbe_enumerate_functions (John Greene) [1173786]
- [netdrv] ixgbe: remove marketing names from busy poll code (John Greene) [1173786]
- [netdrv] ixgbe: reinit_locked() should be called with rtnl_lock (John Greene) [1173786]
- [netdrv] ixgbe: fix rx-usecs range checks for BQL (John Greene) [1173786]
- [netdrv] ixgbe: ethtool DCB registers dump for 82599 and x540 (John Greene) [1173786]
- [netdrv] ixgbe: fix 32-bit DMA mask handling (John Greene) [1173786]
- [netdrv] ixgbe: limit setting speed to only one at a time for QSFP modules (John Greene) [1173786]
- [net] if_link: Add an additional parameter to ifla_vf_info for RSS querying (John Greene) [1173786]
- [net] rtnetlink: ifla_vf_policy: fix misuses of NLA_BINARY (John Greene) [1173786]
- [net] core: Add VF link state control policy (John Greene) [1173786]
- [netdrv] igb: make sure SR-IOV init uses the right number of queues (Stefan Assmann) [1229219]
- [netdrv] igb: do not re-init SR-IOV during probe (Stefan Assmann) [1229219]
- [netdrv] be2net: avoid vxlan offloading on multichannel configs (Ivan Vecera) [1232327]
- [thermal] powerclamp: fix missing newer package c-states (Steve Best) [1255413]

* Fri Aug 21 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-308.el7]
- [fs] inotify: don't add consecutive overflow events to the queue (Eric Sandeen) [1168465]
- [md] dm-stats: report precise_timestamps and histogram in @stats_list output (Mike Snitzer) [1254801]
- [md] dm-stats: add support for request-based DM devices (Mike Snitzer) [1254801]
- [md] dm-stats: collect and report histogram of IO latencies (Mike Snitzer) [1254801]
- [md] dm-stats: support precise timestamps (Mike Snitzer) [1254801]
- [md] dm-stats: fix divide by zero if 'number_of_areas' arg is zero (Mike Snitzer) [1254801]
- [md] dm-stats: Use kvfree() in dm_kvfree() (Mike Snitzer) [1254801]
- [net] bridge: mdb: fix double add notification (Xin Long) [1245012]
- [net] ipt_ulog: do not fail init after creating socket (Thadeu Lima de Souza Cascardo) [1235978]
- [net] ipv4: off-by-one in continuation handling in /proc/net/route (Alexander Duyck) [1253783]
- [x86] kernel: Allocate enough low memory when crashkernel=high (Baoquan He) [1123039]
- [vfio] Fix lockdep issue (Alex Williamson) [1250237]
- [idle] intel_idle: Skylake Client Support (Steve Best) [1189910]
- [netdrv] mlx5_core: Set log_uar_page_sz for non 4K page size architecture (Honggang Li) [1248676]
- [netdrv] igbvf: clear buffer_info->dma after dma_unmap_single() (Stefan Assmann) [1248335]
- [netdrv] ibmveth: add support for TSO6 (Gustavo Duarte) [1251393]

* Thu Aug 20 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-307.el7]
- [firmware] dmi_scan: Coding style cleanups (Jarod Wilson) [853192]
- [firmware] dmi_scan: Trim DMI table length before exporting it (Jarod Wilson) [853192]
- [firmware] dmi_scan: Rename dmi_table to dmi_decode_table (Jarod Wilson) [853192]
- [firmware] dmi_scan: Only honor end-of-table for 64-bit tables (Jarod Wilson) [853192]
- [firmware] dmi_scan: Fix ordering of product_uuid (Jarod Wilson) [853192]
- [firmware] dmi_scan: Simplified displayed version (Jarod Wilson) [853192]
- [firmware] dmi_scan: Use direct access to static vars (Jarod Wilson) [853192]
- [firmware] dmi_scan: Use full dmi version for SMBIOS3 (Jarod Wilson) [853192]
- [powerpc] mm: Change the swap encoding in pte (Gustavo Duarte) [1217743]
- [mm] numa: avoid unnecessary TLB flushes when setting NUMA hinting entries (Gustavo Duarte) [1217743]
- [mm] numa: add paranoid check around pte_protnone_numa (Gustavo Duarte) [1217743]
- [mm] numa: do not trap faults on the huge zero page (Gustavo Duarte) [1217743]
- [mm] remove remaining references to NUMA hinting bits and helpers (Gustavo Duarte) [1217743]
- [mm] numa: Do not mark PTEs pte_numa when splitting huge pages (Gustavo Duarte) [1217743]
- [mm] convert p[te|md]_mknonnuma and remaining page table manipulations (Gustavo Duarte) [1217743]
- [powerpc] mm: add paranoid warnings for unexpected DSISR_PROTFAULT (Gustavo Duarte) [1217743]
- [powerpc] mm: convert p[te|md]_numa users to p[te|md]_protnone_numa (Gustavo Duarte) [1217743]
- [mm] add p[te|md] protnone helpers for use by NUMA balancing (Gustavo Duarte) [1217743]
- [mm] numa: do not dereference pmd outside of the lock during NUMA hinting fault (Gustavo Duarte) [1217743]
- [md] dm-btree-remove: fix bug in remove_one() (Mike Snitzer) [1250905]
- [md] dm-cache-policy-smq: move 'dm-cache-default' module alias to SMQ (Mike Snitzer) [1253505]
- [md] dm-btree: add ref counting ops for the leaves of top level btrees (Mike Snitzer) [1253505]
- [md] dm-thin-metadata: delete btrees when releasing metadata snapshot (Mike Snitzer) [1253505]
- [x86] kvm: vmx: fix vmwrite to invalid VMCS (Radim Krcmar) [1238320 1251552]
- [x86] kvm: add missed use_eager_fpu() (Radim Krcmar) [1251552]
- [iommu] amd: Fix bug in put_pasid_state_wait (Jerome Glisse) [1210495]
- [iommu] amd: Use wait_event in put_pasid_state_wait (Jerome Glisse) [1210495]
- [iommu] amd: Fix amd_iommu_free_device() (Jerome Glisse) [1210495]
- [iommu] amd: use handle_mm_fault directly (Jerome Glisse) [1210495]
- [iommu] amd: fix accounting of device_state (Jerome Glisse) [1210495]
- [iommu] amd: use new invalidate_range mmu-notifier (Jerome Glisse) [1210495]
- [unisys] visornic: Convert to using napi (Erik Arfvidson) [1232018]
- [unisys] visorchannel: Add peek function (Erik Arfvidson) [1232018]
- [unisys] visornic - consolidate+simplify xmit watermark checks (Erik Arfvidson) [1232018]
- [unisys] visornic: enable skb->len error-check, remove DEBUG blocks (Erik Arfvidson) [1232018]
- [unisys] visornic_resume needs to mirror _serverdown_complete (Erik Arfvidson) [1232018]
- [unisys] visornic - correctly reset flag prior to send_enbdis() (Erik Arfvidson) [1232018]
- [unisys] visornic - prevent lock recursion after IO recovery (Erik Arfvidson) [1232018]
- [unisys] avoid format string parsing (Erik Arfvidson) [1232018]
- [unisys] visornic - prevent NETDEV WATCHDOG timeouts after IO recovery (Erik Arfvidson) [1232018]
- [unisys] visornic - check visorchannel_signalinsert/remove failures (Erik Arfvidson) [1232018]
- [unisys] visornic - ensure proper net locking in tx reset logic (Erik Arfvidson) [1232018]
- [unisys] Process more than one response per check (Erik Arfvidson) [1232018]
- [unisys] remove bogus error checking (Erik Arfvidson) [1232018]
- [unisys] remove visornic_ioctl (Erik Arfvidson) [1232018]
- [unisys] Remove trans_start (Erik Arfvidson) [1232018]
- [unisys] Fix improper use of NETDEV_TX_BUSY (Erik Arfvidson) [1232018]
- [unisys] Remove some extraneous start/stop queue operations (Erik Arfvidson) [1232018]
- [unisys] Change enable/disable to wait forever (Erik Arfvidson) [1232018]
- [unisys] Make serverdown synchronous (Erik Arfvidson) [1232018]
- [unisys] simplify visornic_serverdown_complete (Erik Arfvidson) [1232018]
- [unisys] Guard against task leakage (Erik Arfvidson) [1232018]
- [unisys] Clean up kthread usage (Erik Arfvidson) [1232018]
- [unisys] Linarize skbs (Erik Arfvidson) [1232018]
- [unisys] BUG halt on error in I/O channel (Erik Arfvidson) [1232018]
- [unisys] Check return code properly on visor_copy_fragsinfo_from_skb (Erik Arfvidson) [1232018]
- [unisys] Remove num_visornic_open array (Erik Arfvidson) [1232018]
- [unisys] fix copyright statements (Erik Arfvidson) [1232018]
- [unisys] visornic: prevent erroneous kfree of devdata pointer (Erik Arfvidson) [1232018]
- [unisys] visornic: use preferred interface for setting netdev's parent (Erik Arfvidson) [1232018]
- [unisys] visornic: delay start of worker thread until netdev created (Erik Arfvidson) [1232018]
- [unisys] visornic: don't destroy global workqueues until devs destroyed (Erik Arfvidson) [1232018]
- [unisys] visornic: correctly clean up device on removal (Erik Arfvidson) [1232018]
- [unisys] visornic: correct obvious double-allocation of workqueues (Erik Arfvidson) [1232018]
- [unisys] add error messages to visornic (Erik Arfvidson) [1232018]
- [unisys] neglect to NULL rcvbuf pointer (Erik Arfvidson) [1232018]
- [unisys] prevent faults in visornic_pause (Erik Arfvidson) [1232018]
- [unisys] visornic: correct visornic_pause (Erik Arfvidson) [1232018]
- [unisys] Add s-Par visornic ethernet driver (Erik Arfvidson) [1232018]

* Wed Aug 19 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-306.0.1.el7]
- [misc] redhat: roll back to pre-release secureboot keys [1254992]

* Mon Aug 17 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-306.el7]
- [net] ipv6: don't reject link-local nexthop on other interface (Florian Westphal) [1228700]
- [net] vlan: Correctly propagate promisc|allmulti flags in notifier (Alexander Duyck) [1166516]
- [net] chunk lost from bd9b51 (Oleg Nesterov) [1246968]
- [net] openvswitch: Fix L4 checksum handling when dealing with IP fragments (Flavio Leitner) [1249863]
- [net] tcp: fix recv with flags MSG_WAITALL | MSG_PEEK (Sabrina Dubroca) [1205258]
- [net] netfilter: synproxy: fix sending window update to client (Phil Sutter) [1242094 1251031]
- [net] netfilter: ip6t_synproxy: fix NULL pointer dereference (Phil Sutter) [1242094 1251031]
- [net] sctp: fix src address selection if using secondary addresses (Xin Long) [1245205]
- [net] sctp: reduce indent level on sctp_v4_get_dst (Xin Long) [1245205]
- [net] sctp: reset flowi4_oif parameter on route lookup (Xin Long) [1245205]
- [scsi] hpsa: update driver version (Joseph Szczypek) [1227171]
- [scsi] hpsa: fix rmmod issues (Joseph Szczypek) [1227171]
- [scsi] hpsa: add in new controller id (Joseph Szczypek) [1227171]
- [scsi] hpsa: cleanup reset (Joseph Szczypek) [1227171]
- [scsi] hpsa: propagate the error code in hpsa_kdump_soft_reset (Joseph Szczypek) [1227171]
- [scsi] hpsa: add support for tagged queueing (Joseph Szczypek) [1227171]
- [scsi] hpsa: use scsi host_no as hpsa controller number (Joseph Szczypek) [1227171]
- [scsi] hpsa: use block layer tag for command allocation (Joseph Szczypek) [1227171]
- [scsi] hpsa: add interrupt number to /proc/interrupts interrupt name (Joseph Szczypek) [1227171]
- [scsi] hpsa: create workqueue after the driver is ready for use (Joseph Szczypek) [1227171]
- [scsi] hpsa: fix try_soft_reset error handling (Joseph Szczypek) [1227171]
- [scsi] hpsa: cleanup for init_one step 2 in kdump (Joseph Szczypek) [1227171]
- [scsi] hpsa: skip free_irq calls if irqs are not allocated (Joseph Szczypek) [1227171]
- [scsi] hpsa: call pci_release_regions after pci_disable_device (Joseph Szczypek) [1227171]
- [scsi] hpsa: performance tweak for hpsa_scatter_gather() (Joseph Szczypek) [1227171]
- [scsi] hpsa: refactor and rework support for sending TEST_UNIT_READY (Joseph Szczypek) [1227171]
- [scsi] hpsa: don't return abort request until target is complete (Joseph Szczypek) [1227171]
- [scsi] hpsa: use helper routines for finishing commands (Joseph Szczypek) [1227171]
- [scsi] hpsa: add support sending aborts to physical devices via the ioaccel2 path (Joseph Szczypek) [1227171]
- [scsi] hpsa: do not print ioaccel2 warning messages about unusual completions (Joseph Szczypek) [1227171]
- [scsi] hpsa: clean up some error reporting output in abort handler (Joseph Szczypek) [1227171]
- [scsi] hpsa: clean up driver init (Joseph Szczypek) [1227171]
- [scsi] hpsa: correct return values from driver functions (Joseph Szczypek) [1227171]
- [scsi] hpsa: do not check cmd_alloc return value - it cannnot return NULL (Joseph Szczypek) [1227171]
- [scsi] hpsa: add more ioaccel2 error handling, including underrun statuses (Joseph Szczypek) [1227171]
- [scsi] hpsa: add ioaccel sg chaining for the ioaccel2 path (Joseph Szczypek) [1227171]
- [scsi] hpsa: refactor freeing of resources into more logical functions (Joseph Szczypek) [1227171]
- [scsi] hpsa: clean up error handling (Joseph Szczypek) [1227171]
- [scsi] hpsa: break hpsa_free_irqs_and_disable_msix into two functions (Joseph Szczypek) [1227171]
- [scsi] hpsa: Get queue depth from identify physical bmic for physical disks (Joseph Szczypek) [1227171]
- [scsi] hpsa: use ioaccel2 path to submit IOs to physical drives in HBA mode (Joseph Szczypek) [1227171]
- [scsi] hpsa: print accurate SSD Smart Path Enabled status (Joseph Szczypek) [1227171]
- [scsi] hpsa: factor out hpsa_ioaccel_submit function (Joseph Szczypek) [1227171]
- [scsi] hpsa: try resubmitting down raid path on task set full (Joseph Szczypek) [1227171]
- [scsi] hpsa: do not ignore return value of hpsa_register_scsi (Joseph Szczypek) [1227171]
- [scsi] hpsa: factor out hpsa_init_cmd function (Joseph Szczypek) [1227171]
- [scsi] hpsa: make function names consistent (Joseph Szczypek) [1227171]
- [scsi] hpsa: allow lockup detected to be viewed via sysfs (Joseph Szczypek) [1227171]
- [scsi] hpsa: hpsa decode sense data for io and tmf (Joseph Szczypek) [1227171]
- [scsi] hpsa: decrement h->commands_outstanding in fail_all_outstanding_cmds (Joseph Szczypek) [1227171]
- [scsi] hpsa: clean up aborts (Joseph Szczypek) [1227171]
- [scsi] hpsa: rework controller command submission (Joseph Szczypek) [1227171]
- [scsi] hpsa: clean up host, channel, target, lun prints (Joseph Szczypek) [1227171]
- [scsi] hpsa: add masked physical devices into h->dev array (Joseph Szczypek) [1227171]
- [scsi] hpsa: dont meddle with hw which isn't ours (cciss) (Joseph Szczypek) [1227171]
- [scsi] hpsa: Fix weird uses of num_online_cpus() (Joseph Szczypek) [1227171]
- [kernel] livepatch: kernel: add TAINT_LIVEPATCH (Josh Poimboeuf) [1090549]
- [kernel] fix TAINT_SOFTLOCKUP printable character (Josh Poimboeuf) [1090549]
- [cpufreq] intel_pstate: Add SKY-S support (Steve Best) [1199346]
- [powerpc] kvm: book3s: correct width in XER handling (David Gibson) [1178502]

* Fri Aug 14 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-305.el7]
- [kernel] Call mark_tech_preview() for user namespace (Adrian Reber) [1243523]
- [kernel] ntp: Do leapsecond adjustment in adjtimex read path (Prarit Bhargava) [1250754]
- [kernel] time: Prevent early expiry of hrtimers[CLOCK_REALTIME] at the leap second edge (Prarit Bhargava) [1250754]
- [kernel] ntp: Introduce and use SECS_PER_DAY macro instead of 86400 (Prarit Bhargava) [1250754]
- [kernel] hrtimer: Make offset update smarter (Prarit Bhargava) [1250754]
- [kernel] timekeeping: Use ktime_t data for ktime_get_update_offsets_now() (Prarit Bhargava) [1250754]
- [netdrv] macvtap: fix network header pointer for VLAN tagged pkts (Ivan Vecera) [1251987]
- [net] core: Fix vlan_get_protocol for stacked vlan (Ivan Vecera) [1251987]
- [netdrv] r8169: enforce RX_MULTI_EN on rtl8168ep/8111ep chips (Ivan Vecera) [1218279]
- [netdrv] virtio-net: drop NETIF_F_FRAGLIST (Jason Wang) [1247840] {CVE-2015-5156}
- [netdrv] usbnet: remove generic hard_header_len check (Don Zickus) [1164735]
- [usb] usb: io_ti: Add heartbeat to keep idle EP/416 ports from disconnecting (Don Zickus) [1207487 1208644]
- [usb] usb: io_ti: Add firmware image sanity checks (Don Zickus) [1208644]
- [usb] usb: io_ti: Increase insufficient timeout for firmware downloads (Don Zickus) [1208644]
- [usb] usb: io_ti: Fix firmware version handling (Don Zickus) [1208644]
- [x86] perf: Tweak broken BIOS rules during check_hw_exists() (Don Zickus) [1082511]
- [x86] uefi: copy secure_boot flag in boot params across kexec (Dave Young) [1243998]
- [mm] vm_is_stack: use for_each_thread() rather then buggy while_each_thread() (Jerry Snitselaar) [1252188]
- [fs] dcache: d_walk() might skip too much (Denys Vlasenko) [1173813] {CVE-2014-8559}
- [fs] dcache: deal with deadlock in d_walk() (Denys Vlasenko) [1173813] {CVE-2014-8559}
- [fs] dcache: move d_rcu from overlapping d_child to overlapping d_alias (Denys Vlasenko) [1173813] {CVE-2014-8559}
- [fs] dcache: fold try_to_ascend() into the sole remaining caller (Denys Vlasenko) [1173813] {CVE-2014-8559}
- [fs] pipe: fix offset and len mismatch on pipe_iov_copy_to_user() failure (Seth Jennings) [1239006]
- [fs] overlayfs: Warn on copy up if a process has a R/O fd open to the lower file V2 (David Howells) [1226346]
- [md] dm: revert dm_merge_bvec changes (Mike Snitzer) [1250148]
- [pci] pciehp: Handle invalid data when reading from non-existent devices (Jarod Wilson) [1108793 1172014]
- [edac] sb_edac: fix TAD presence check for sbridge_mci_bind_devs() (Seth Jennings) [1250709]
- [perf] bench-numa: Fix to show proper convergence stats (Petr Holasek) [1222518]
- [scsi] ipr: Driver version 2.6.2 (Gustavo Duarte) [1251842]
- [scsi] ipr: Endian / sparse fixes (Gustavo Duarte) [1251842]
- [scsi] ipr: Fix locking for unit attention handling (Gustavo Duarte) [1251842]
- [scsi] ipr: Re-enable write same (Gustavo Duarte) [1251842]
- [scsi] ipr: Fix invalid array indexing for HRRQ (Gustavo Duarte) [1251184]
- [scsi] ipr: Fix incorrect trace indexing (Gustavo Duarte) [1251184]
- [scsi] ipr: Byte swapping for device_id attribute in sysfs (Gustavo Duarte) [1214645]
- [crypto] nx - respect sg limit bounds when building sg lists for SHA (Herbert Xu) [1250733]
- [crypto] nx - Fix reentrancy bugs (Herbert Xu) [1250733]
- [crypto] nx - Fixing SHA update bug (Herbert Xu) [1250733]
- [crypto] nx - Fixing NX data alignment with nx_sg list (Herbert Xu) [1250733]
- [crypto] nx - make platform drivers directly register with crypto (Gustavo Duarte) [1238571 1245132]
- [crypto] nx - rename nx-842-crypto.c to nx-842.c (Gustavo Duarte) [1238571 1245132]
- [crypto] nx - merge nx-compress and nx-compress-crypto (Gustavo Duarte) [1238571 1245132]
- [crypto] nx - use common code for both NX decompress success cases (Gustavo Duarte) [1238571 1245132]
- [crypto] nx - don't register pSeries driver if ENODEV (Gustavo Duarte) [1238571 1245132]
- [crypto] nx - move kzalloc() out of spinlock (Gustavo Duarte) [1238571 1245132]
- [crypto] nx - remove pSeries NX 'status' field (Gustavo Duarte) [1238571 1245132]
- [crypto] nx - remove __init/__exit from VIO functions (Gustavo Duarte) [1238571 1245132]
- [crypto] nx/842 - Fix context corruption (Gustavo Duarte) [1238571 1245132]
- [crypto] nx - reduce chattiness of platform drivers (Gustavo Duarte) [1238571 1245132]
- [crypto] nx - do not emit extra output if status is disabled (Gustavo Duarte) [1238571 1245132]
- [crypto] nx - rename nx842_{init, exit} to nx842_pseries_{init, exit} (Gustavo Duarte) [1238571 1245132]
- [crypto] nx - nx842_OF_upd_status should return ENODEV if device is not 'okay' (Gustavo Duarte) [1238571 1245132]
- [cpufreq] powernv: Restore cpu frequency to policy->cur on unthrottling (Gustavo Duarte) [1249561]
- [cpufreq] powernv: Report Psafe only if PMSR.psafe_mode_active bit is set (Gustavo Duarte) [1249561]
- [cpufreq] powernv: Call throttle_check() on receiving OCC_THROTTLE (Gustavo Duarte) [1249561]
- [cpufreq] powernv: Register for OCC related opal_message notification (Gustavo Duarte) [1249561]
- [powerpc] powernv: Add definition of OPAL_MSG_OCC message type (Gustavo Duarte) [1249561]
- [cpufreq] powernv: Handle throttling due to Pmax capping at chip level (Gustavo Duarte) [1249561]
- [cpuidle] menu: Return (-1) if there are no suitable states (Gustavo Duarte) [1226250]
- [powerpc] eeh: Fix trivial error in eeh_restore_dev_state() (David Gibson) [1227573]
- [powercap] rapl: Add support for Broadwell-H (Steve Best) [1249855]

* Fri Aug 07 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-304.el7]
- [md] dm-cache: fix device destroy hang due to improper prealloc_used accounting (Mike Snitzer) [1247192]
- [md] revert "dm-cache: do not wake_worker() in free_migration()" (Mike Snitzer) [1247192]
- [ipc] mqueue: remove limits for the amount of system-wide queues (Milos Vyletel) [1247632]
- [scsi] fix memory leak with scsi-mq (Ewan Milne) [1248739]
- [scsi] qla2xxx: do not clear slot in outstanding cmd array (Chad Dupuis) [1188168]
- [scsi] qla2xxx: Remove decrement of sp reference count in abort handler (Chad Dupuis) [1188168]
- [scsi] qla2xxx: Do not reset adapter if SRB handle is in range (Chad Dupuis) [1188168]
- [scsi] qla2xxx: Do not crash system for sp ref count zero (Chad Dupuis) [1188168]
- [tools] power turbostat: enable turbostat to support Knights Landing (KNL) (Steve Best) [1214141]
- [vhost] fix error handling for memory region alloc (Igor Mammedov) [1152962]
- [vhost] add max_mem_regions module parameter (Igor Mammedov) [1152962]
- [vhost] extend memory regions allocation to vmalloc (Igor Mammedov) [1152962]
- [vhost] use binary search instead of linear in find_region() (Igor Mammedov) [1152962]
- [vhost] Make vhost a separate module (Igor Mammedov) [1152962]
- [vhost] move memory pointer to VQs (Igor Mammedov) [1152962]
- [vhost] move acked_features to VQs (Igor Mammedov) [1152962]
- [vhost] replace rcu with mutex (Igor Mammedov) [1152962]
- [vhost] Remove custom vhost rcu usage (Igor Mammedov) [1152962]
- [vhost] scsi: Always access vq->private_data under vq mutex (Igor Mammedov) [1152962]
- [vhost] net: Always access vq->private_data under vq mutex (Igor Mammedov) [1152962]
- [powercap] rapl: Add support for Skylake H/S (Steve Best) [1249848]
- [wireless] Backport rtlwifi driver family from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport mwl8k driver from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport brcm80211 common code from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport brcmsmac driver from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport brcmfmac driver from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport BCMA bus driver from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport SSB bus driver from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport mwifiex driver from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport rt2x00 driver from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport wil6210 driver from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport carl9170 from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport ath common code from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport ath9k driver from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport iwlegacy driver from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport iwlwifi driver from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport mac80211 from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] Backport wireless core from linux-4.1-rc6 (Stanislaw Gruszka) [1169606 1229225]
- [wireless] debugfs: add helper function to create device related seq_file (Stanislaw Gruszka) [1169606 1229225]
- [wireless] net: Add EXPORT_SYMBOL_GPL(get_net_ns_by_fd) (Stanislaw Gruszka) [1169606 1229225]
- [security] keys: Ensure we free the assoc array edit if edit is valid (David Howells) [1244171] {CVE-2015-1333}

* Wed Aug 05 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-303.el7]
- [powerpc] powernv: Fix vma page prot flags in opal-prd driver (Gustavo Duarte) [1241177]
- [powerpc] rtas: Introduce rtas_get_sensor_fast() for IRQ handlers (Thomas Huth) [1243779]
- [thermal] powerclamp: add cpu id for denlow platform (Steve Best) [1177872]
- [powercap] rapl: Support Knights Landing (Steve Best) [1145372]
- [s390] nmi: fix vector register corruption (Hendrik Brueckner) [1247500]
- [s390] ctl_reg: add union type for control register 0 (Hendrik Brueckner) [1247500]
- [s390] revert "dasd: add support for control unit initiated reconfiguration" (Hendrik Brueckner) [1243498]
- [mm] tmpfs: ZERO_RANGE and COLLAPSE_RANGE not currently supported (Eric Sandeen) [1237080]
- [md] dm-cache-policy-smq: fix alloc_bitset check that always evaluates as false (Mike Snitzer) [1247192]
- [md] dm-thin: return -ENOSPC when erroring retry list due to out of data space (Mike Snitzer) [1247192]
- [md] clear Blocked flag on failed devices when array is read-only (Xiao Ni) [1177912]
- [acpi] ghes: Make NMI handler have a single reader (Jiri Olsa) [1230934]
- [iommu] vt-d: Fix VM domain ID leak (Alex Williamson) [1242331]
- [video] hyperv_fb: match wait_for_completion_timeout return type (Vitaly Kuznetsov) [1247678]
- [video] hyperv_fb: refresh the VM screen by force on VM panic (Vitaly Kuznetsov) [1247678]
- [video] hyperv-fb: add blanking support (Vitaly Kuznetsov) [1247678]
- [block] nvme: Failed controller initialization fixes (David Milburn) [1223515]
- [block] nvme: Unify controller probe and resume (David Milburn) [1223515]
- [block] nvme: Automatic namespace rescan (David Milburn) [1223515]
- [block] nvme: add sysfs and ioctl controller reset (David Milburn) [1223515]
- [block] nvme: Remove hctx reliance for multi-namespace (David Milburn) [1223515]
- [block] blk-mq: Shared tag enhancements (David Milburn) [1223515]
- [block] add blk_set_queue_dying() to blkdev.h (David Milburn) [1223515]
- [block] nvme: disable irqs in nvme_freeze_queues (David Milburn) [1223515]
- [block] nvme: Meta data handling through submit io ioctl (David Milburn) [1223515]
- [block] nvme: Fix for BLK_DEV_INTEGRITY not set (David Milburn) [1223515]
- [block] nvme: Metadata format support (David Milburn) [1223515]
- [netdrv] bonding: fix destruction of bond with devices different from arphrd_ether (Gustavo Duarte) [1061028]
- [netdrv] fix copyright statements (Erik Arfvidson) [1245362]
- [unisys] Lock visorchannels associated with devices (Erik Arfvidson) [1245362]
- [unisys] fix random hangs with network stress in visornic (Erik Arfvidson) [1245362]
- [unisys] Reduce indent (Erik Arfvidson) [1245362]
- [unisys] Use kzalloc instead of kmalloc/memset (Erik Arfvidson) [1245362]
- [unisys] correctly NULL-terminate visorbus sysfs attribute array (Erik Arfvidson) [1245362]
- [unisys] fix random memory corruption in visorchannel_write() (Erik Arfvidson) [1245362]
- [unisys] Fix broken build when ARCH=um (Erik Arfvidson) [1245362]
- [unisys] Allow visorbus to autoload (Erik Arfvidson) [1245362]
- [unisys] prevent faults processing messages (Erik Arfvidson) [1245362]
- [unisys] respond to msgs post device_create (Erik Arfvidson) [1245362]

* Fri Jul 31 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-302.el7]
- [fs] nfs: objectlayout: Mark the object layout driver as a tech preview (Steve Dickson) [1248070]
- [x86] Tell irq work about self IPI support (Rafael Aquini) [1240799]
- [acpi] scan: reduce log level of "acpi: \_pr_.cpu4: failed to get CPU APIC ID" (Lenny Szubowicz) [1246077]
- [netdrv] mlx4: restore conditional call to napi_complete_done() (Honggang Li) [1248338]
- [cpufreq] intel_pstate: Add get_scaling cpu_defaults param to Knights Landing (Steve Best) [1145366]
- [cpufreq] intel_pstate: Knights Landing support (Steve Best) [1145366]
- [powerpc] add running_clock for powerpc to prevent spurious softlockup warnings (Gustavo Duarte) [1197000]
- [kernel] sched/clock: add another clock for use with the soft lockup watchdog (Gustavo Duarte) [1197000]
- [kernel] fork: Allow CLONE_PARENT after setns(CLONE_NEWPID) (Adrian Reber) [1241560]
- [kernel] fork: unify and tighten up CLONE_NEWUSER/CLONE_NEWPID checks (Adrian Reber) [1241560]
- [kernel] pidns: kill the unnecessary CLONE_NEWPID in copy_process() (Adrian Reber) [1241560]
- [kernel] workqueue: Allow modifying low level unbound workqueue cpumask (Daniel Bristot de Oliveira) [1176155]
- [kernel] workqueue: Create low-level unbound workqueues cpumask (Daniel Bristot de Oliveira) [1176155]
- [kernel] workqueue: split apply_workqueue_attrs() into 3 stages (Daniel Bristot de Oliveira) [1176155]
- [kernel] cpumask, nodemask: implement cpumask/nodemask_pr_args() (Daniel Bristot de Oliveira) [1176155]
- [documentation] add print bitmap description (Daniel Bristot de Oliveira) [1176155]
- [lib] vsprintf: implement bitmap printing through '*pb[l]' (Daniel Bristot de Oliveira) [1176155]
- [fs] userfaultfd: call mark_tech_preview (Andrea Arcangeli) [965657]
- [fs] userfaultfd: avoid missing wakeups during refile in userfaultfd_read (Andrea Arcangeli) [965657]
- [mm] userfaultfd: propagate the full address in THP faults (Andrea Arcangeli) [965657]
- [fs] userfaultfd: allow signals to interrupt a userfault (Andrea Arcangeli) [965657]
- [fs] userfaultfd: require UFFDIO_API before other ioctls (Andrea Arcangeli) [965657]
- [mm] userfaultfd: switch to exclusive wakeup for blocking reads (Andrea Arcangeli) [965657]
- [fs] userfaultfd: fs/userfaultfd.c add more comments (Andrea Arcangeli) [965657]
- [mm] userfaultfd: documentation update (Andrea Arcangeli) [965657]
- [mm] userfaultfd: UFFDIO_COPY and UFFDIO_ZEROPAGE (Andrea Arcangeli) [965657]
- [mm] userfaultfd: avoid mmap_sem read recursion in mcopy_atomic (Andrea Arcangeli) [965657]
- [mm] userfaultfd: mcopy_atomic|mfill_zeropage: UFFDIO_COPY|UFFDIO_ZEROPAGE preparation (Andrea Arcangeli) [965657]
- [mm] userfaultfd: UFFDIO_COPY|UFFDIO_ZEROPAGE uAPI (Andrea Arcangeli) [965657]
- [x86] userfaultfd: activate syscall (Andrea Arcangeli) [965657]
- [mm] userfaultfd: buildsystem activation (Andrea Arcangeli) [965657]
- [mm] userfaultfd: solve the race between UFFDIO_COPY|ZEROPAGE and read (Andrea Arcangeli) [965657]
- [mm] userfaultfd: allocate the userfaultfd_ctx cacheline aligned (Andrea Arcangeli) [965657]
- [mm] userfaultfd: optimize read() and poll() to be O(1) (Andrea Arcangeli) [965657]
- [mm] userfaultfd: wake pending userfaults (Andrea Arcangeli) [965657]
- [mm] userfaultfd: update the uffd_msg structure to be the same on 32/64bit (Andrea Arcangeli) [965657]
- [mm] userfaultfd: change the read API to return a uffd_msg (Andrea Arcangeli) [965657]
- [mm] userfaultfd: Rename uffd_api.bits into .features fixup (Andrea Arcangeli) [965657]
- [mm] userfaultfd: Rename uffd_api.bits into .features (Andrea Arcangeli) [965657]
- [mm] userfaultfd: waitqueue_active() race fix (Andrea Arcangeli) [965657]
- [mm] userfaultfd: cleanup superfluous _irq locking (Andrea Arcangeli) [965657]
- [mm] userfaultfd: add new syscall to provide memory externalization (Andrea Arcangeli) [965657]
- [mm] userfaultfd: prevent khugepaged to merge if userfaultfd is armed (Andrea Arcangeli) [965657]
- [mm] userfaultfd: teach vma_merge to merge across vma->vm_userfaultfd_ctx (Andrea Arcangeli) [965657]
- [mm] userfaultfd: call handle_userfault() for userfaultfd_missing() faults (Andrea Arcangeli) [965657]
- [mm] userfaultfd: add VM_UFFD_MISSING and VM_UFFD_WP (Andrea Arcangeli) [965657]
- [mm] userfaultfd: add vm_userfaultfd_ctx to the vm_area_struct (Andrea Arcangeli) [965657]
- [mm] userfaultfd: linux/userfaultfd_k.h (Andrea Arcangeli) [965657]
- [mm] userfaultfd: uapi: add missing include/types.h (Andrea Arcangeli) [965657]
- [mm] userfaultfd: uAPI (Andrea Arcangeli) [965657]
- [mm] userfaultfd: linux/Documentation/vm/userfaultfd.txt (Andrea Arcangeli) [965657]
- [fs] nfs: use get_user_pages_unlocked (Andrea Arcangeli) [965657]
- [mm] gup: kvm use get_user_pages_unlocked (Andrea Arcangeli) [965657]
- [mm] gup: use get_user_pages_unlocked within get_user_pages_fast (Andrea Arcangeli) [965657]
- [mm] gup: add __get_user_pages_unlocked to customize gup_flags (Andrea Arcangeli) [965657]
- [mm] gup: add get_user_pages_locked and get_user_pages_unlocked (Andrea Arcangeli) [965657]
- [net] bridge: vlan: fix usage of vlan 0 and 4095 again (John Greene) [1236709]
- [net] bridge: new mode flag to indicate mode 'undefined' (John Greene) [1236709]
- [net] bridge: simplify br_getlink() a bit (John Greene) [1236709]
- [net] bridge: remove oflags from setlink/dellink (John Greene) [1236709]
- [net] bridge: fix setlink/dellink notifications (John Greene) [1236709]
- [net] bridge: fix uninitialized variable warning (John Greene) [1236709]
- [net] bridge: new function to pack vlans into ranges during gets (John Greene) [1236709]
- [net] rtnetlink: new filter RTEXT_FILTER_BRVLAN_COMPRESSED (John Greene) [1236709]
- [net] bridge: support for multiple vlans and vlan ranges in setlink and dellink requests (John Greene) [1236709]
- [net] bridge: add brport flags to dflt bridge_getlink (John Greene) [1236709]
- [net] bridge: add new brport flag LEARNING_SYNC (John Greene) [1236709]
- [net] bridge: move private brport flags to if_bridge.h so port drivers can use flags (John Greene) [1236709]
- [net] bridge: add export of multicast database adjacent to net_dev (John Greene) [1236709]
- [net] fib_trie: Drop unnecessary calls to leaf_pull_suffix (Alexander Duyck) [1247411]
- [net] inet_diag: always export IPV6_V6ONLY sockopt for listening sockets (Phil Sutter) [1247309]
- [net] inet_diag: export IPV6_V6ONLY sockopt (Phil Sutter) [1247309]

* Wed Jul 29 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-301.el7]
- [powerpc] kvm: book3s_hv: Fix preempted vcore stolen time calculation (Laurent Vivier) [1242757]
- [powerpc] kvm: book3s_hv: Fix preempted vcore list locking (Laurent Vivier) [1242757]
- [netdrv] be2net: support ndo_get_phys_port_id() (Ivan Vecera) [1138670]
- [fs] ovl: Enable copy-up fd checking by default (David Howells) [1246555]
- [fs] nfs: increase size of EXCHANGE_ID name string buffer (Benjamin Coddington) [1243961]
- [fs] vfs: avoid creation of inode number 0 in get_next_ino (Carlos Maiolino) [1241665]
- [fs] dlm: adopt orphan locks (David Teigland) [1208288]
- [tools] turbostat: Revert to old -v/-V options (Prarit Bhargava) [1245299]
- [perf] x86: Add more Broadwell model numbers (Jiri Olsa) [1242695]
- [scsi] save command pool address of Scsi_Host (Vitaly Kuznetsov) [1245857]
- [iser-target] Fix possible use-after-free (Andy Grover) [1136558 1185396]
- [iser-target] release stale iser connections (Andy Grover) [1136558 1185396]
- [iser-target] Fix variable-length response error completion (Andy Grover) [1136558 1185396]
- [iser-target] Bump version to 1.0 (Andy Grover) [1136558 1185396]
- [iser-target] Remove conn_ prefix from struct isert_conn members (Andy Grover) [1136558 1185396]
- [iser-target] Remove un-needed rdma_listen backlog (Andy Grover) [1136558 1185396]
- [iser-target] Remove redundant check on the device (Andy Grover) [1136558 1185396]
- [iser-target] Get rid of redundant max_accept (Andy Grover) [1136558 1185396]
- [iser-target] Split some logic in isert_connect_request to routines (Andy Grover) [1136558 1185396]
- [iser-target] Rename device find/release routines (Andy Grover) [1136558 1185396]
- [iser-target] Rename rend/recv completion routines (Andy Grover) [1136558 1185396]
- [iser-target] Remove redundant assignment to local variable (Andy Grover) [1136558 1185396]
- [iser-target] Introduce isert_alloc|free_comps (Andy Grover) [1136558 1185396]
- [iser-target] Split isert_setup_qp (Andy Grover) [1136558 1185396]
- [iser-target] Remove redundant casting on void pointers (Andy Grover) [1136558 1185396]
- [iser-target] Remove redundant local variable (Andy Grover) [1136558 1185396]
- [iser-target] Remove dead code (Andy Grover) [1136558 1185396]
- [iser-target] Remove redundant check on recv completion (Andy Grover) [1136558 1185396]
- [iser-target] Use a single DMA MR and PD per device (Andy Grover) [1136558 1185396]
- [iser-target] Rebase to v4.0.5 (Andy Grover) [1136558 1185396]
- [infiniband] mlx5: iser,isert: Add Signature API additions (Andy Grover) [1136558 1185396]
- [scsi] add SPC-3 command definitions (Andy Grover) [1136558 1185396]
- [scsi] rename SERVICE_ACTION_IN to SERVICE_ACTION_IN_16 (Andy Grover) [1136558 1185396]
- [scsi] st: null pointer dereference panic caused by use after kref_put by st_open (Maurizio Lombardi) [1239060]

* Sat Jul 25 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-300.el7]
- [watchdog] hpwdt: Fix initialization message in hpwdt.c (Nigel Croxon) [1204514]
- [fs] autofs: fix the return value of autofs4_fill_super (Ian Kent) [1207319]
- [fs] autofs4: translate pids to the right namespace for the daemon (Ian Kent) [1207319]
- [fs] autofs4: allow autofs to work outside the initial PID namespace (Ian Kent) [1207319]
- [fs] autofs4: make freeing sbi rcu-delayed (Ian Kent) [1207319]
- [net] call rcu_read_lock early in process_backlog (Jiri Benc) [1243980]
- [net] do not process device backlog during unregistration (Jiri Benc) [1243980]
- [net] graceful exit from netif_alloc_netdev_queues() (Jiri Benc) [1245278]
- [net] extend net_device allocation to vmalloc() (Jiri Benc) [1245278]
- [net] rtnetlink: remove ndo_get_slave (Jarod Wilson) [1210322]
- [net] rtnetlink: remove IFLA_BOND_SLAVE definition (Jarod Wilson) [1210322]
- [net] rtnetlink: fix oops in rtnl_link_get_slave_info_data_size (Jarod Wilson) [1210322]
- [net] rtnetlink: remove check for fill_slave_info in rtnl_have_link_slave_info (Jarod Wilson) [1210322]
- [net] bonding: convert netlink to use slave data info api (Jarod Wilson) [1210322]
- [net] rtnetlink: add missing IFLA_BOND_AD_INFO_UNSPEC (Jarod Wilson) [1210322]
- [net] rtnetlink: provide api for getting and setting slave info (Jarod Wilson) [1210322]
- [net] rtnetlink: put "BOND" into nl attribute names which are related to bonding (Jarod Wilson) [1210322]
- [net] bonding: add netlink attributes to slave link dev (Jarod Wilson) [1210322]
- [net] ipv4: take rtnl_lock and mark mrt table as freed on namespace cleanup (Phil Sutter) [1240747]
- [bluetooth] Fix RFCOMM parent device for reused dlc (Lubomir Rintel) [1241844]
- [bluetooth] Fix unsafe RFCOMM device parenting (Lubomir Rintel) [1241844]
- [bluetooth] Directly close dlc for not yet started RFCOMM session (Lubomir Rintel) [1241844]
- [bluetooth] Refactor dlc disconnect logic in rfcomm_dlc_close() (Lubomir Rintel) [1241844]
- [bluetooth] Refactor deferred setup test in rfcomm_dlc_close() (Lubomir Rintel) [1241844]
- [bluetooth] Simplify RFCOMM session state eval (Lubomir Rintel) [1241844]
- [bluetooth] Verify dlci not in use before rfcomm_dev create (Lubomir Rintel) [1241844]
- [bluetooth] Fix RFCOMM tty teardown race (Lubomir Rintel) [1241844]
- [bluetooth] Fix unreleased rfcomm_dev reference (Lubomir Rintel) [1241844]
- [bluetooth] Release rfcomm_dev only once (Lubomir Rintel) [1241844]
- [bluetooth] Exclude released devices from RFCOMMGETDEVLIST ioctl (Lubomir Rintel) [1241844]
- [bluetooth] Fix racy acquire of rfcomm_dev reference (Lubomir Rintel) [1241844]
- [bluetooth] revert "bluetooth: Move rfcomm_get_device() before rfcomm_dev_activate()" (Lubomir Rintel) [1241844]
- [bluetooth] revert "bluetooth: Always wait for a connection on RFCOMM open()" (Lubomir Rintel) [1241844]
- [bluetooth] revert "bluetooth: Remove rfcomm_carrier_raised()" (Lubomir Rintel) [1241844]
- [bluetooth] Refuse peer RFCOMM address reading when not connected (Lubomir Rintel) [1241844]
- [bluetooth] Remove rfcomm_carrier_raised() (Lubomir Rintel) [1241844]
- [bluetooth] Always wait for a connection on RFCOMM open() (Lubomir Rintel) [1241844]
- [bluetooth] Move rfcomm_get_device() before rfcomm_dev_activate() (Lubomir Rintel) [1241844]
- [bluetooth] Release RFCOMM port when the last user closes the TTY (Lubomir Rintel) [1241844]
- [bluetooth] Fix to set proper bdaddr_type for RFCOMM connect (Lubomir Rintel) [1241844]
- [bluetooth] Fix RFCOMM bind fail for L2CAP sock (Lubomir Rintel) [1241844]
- [bluetooth] Fix issue with RFCOMM getsockopt operation (Lubomir Rintel) [1241844]
- [bluetooth] Use IS_ERR_OR_NULL for checking bt_debugfs (Lubomir Rintel) [1241844]
- [bluetooth] Store RFCOMM address information in its own socket structure (Lubomir Rintel) [1241844]
- [bluetooth] don't release the port in rfcomm_dev_state_change() (Lubomir Rintel) [1241844]
- [bluetooth] Fix waiting for clearing of BT_SK_SUSPEND flag (Lubomir Rintel) [1241844]
- [bluetooth] Purge the dlc->tx_queue to avoid circular dependency (Lubomir Rintel) [1241844]
- [bluetooth] Fix the reference counting of tty_port (Lubomir Rintel) [1241844]
- [bluetooth] Implement .activate, .shutdown and .carrier_raised methods (Lubomir Rintel) [1241844]
- [bluetooth] Move the tty initialization and cleanup out of open/close (Lubomir Rintel) [1241844]
- [bluetooth] Remove the device from the list in the destructor (Lubomir Rintel) [1241844]
- [bluetooth] Take proper tty_struct references (Lubomir Rintel) [1241844]
- [net] netfilter: arptables: use percpu jumpstack (Florian Westphal) [1237126]
- [pci] pciehp: Stop disabling notifications during init (Myron Stowe) [1243009]
- [x86] build: Don't get confused by local symbols (Prarit Bhargava) [1245781]
- [x86] perf: Fix CQM feature detection (Jiri Olsa) [1036948]
- [crypto] nx - Fixing the limit number of bytes to be processed (Herbert Xu) [1190103]
- [crypto] nx - Fix SHA concurrence issue and sg limit bounds (Herbert Xu) [1190103]
- [crypto] nx - Moving NX-AES-XCBC to be processed logic (Herbert Xu) [1190103]
- [crypto] nx - Moving NX-AES-GCM to be processed logic (Herbert Xu) [1190103]
- [crypto] nx - Moving NX-AES-ECB to be processed logic (Herbert Xu) [1190103]
- [crypto] nx - Moving limit and bound logic in CTR and fix IV vector (Herbert Xu) [1190103]
- [crypto] nx - Moving NX-AES-CCM to be processed logic and sg_list bounds (Herbert Xu) [1190103]
- [crypto] nx - Moving NX-AES-CBC to be processed logic (Herbert Xu) [1190103]
- [crypto] nx - Check for bogus firmware properties (Herbert Xu) [1190103]
- [kernel] kabi: remove RH_KABI_CHANGE_TYPE (Hannes Frederic Sowa) [1241854]
- [kernel] kabi: alignment and sizeof checks in RH_KABI_REPLACE/CHANGE_TYPE macros (Hannes Frederic Sowa) [1241854]
- [block] use RH_KABI_REPLACE_UNSAFE in blk-mq.h (Hannes Frederic Sowa) [1241854]
- [kernel] kabi: introduce RH_KABI_REPLACE_UNSAFE (Hannes Frederic Sowa) [1241854]
- [kernel] kabi: introduce RH_KABI_USE2_P (Sabrina Dubroca) [1241515]
- [kernel] kabi: remove RH_KABI_REPLACE_P (Sabrina Dubroca) [1241515]
- [kernel] include/*: stop using RH_KABI_REPLACE_P (Sabrina Dubroca) [1241515]
- [kernel] kabi: introduce RH_KABI_RENAME (Sabrina Dubroca) [1241515]
- [net] sk_buff: don't use RH_KABI_REPLACE_P for bitfields (Sabrina Dubroca) [1241515]
- [kernel] kabi: modify _RH_KABI_REPLACE to integrate RH_KABI_REPLACE_P with RH_KABI_REPLACE (Sabrina Dubroca) [1241515]
- [netdrv] fm10k: fix use of ifla_vf_info->tx_rate (Sabrina Dubroca) [1241515]
- [netdrv] sfc: fix use of ifla_vf_info->tx_rate (Sabrina Dubroca) [1241515]
- [kernel] revert "softirq: Add support for triggering softirq work on softirqs" (Sabrina Dubroca) [1241515]
- [netdrv] be2net: bump up the driver version to 10.6.0.3 (Ivan Vecera) [1245683]
- [netdrv] be2net: make SET_LOOPBACK_MODE cmd asynchrounous (Ivan Vecera) [1245683]
- [netdrv] be2net: make the RX_FILTER command asynchronous (Ivan Vecera) [1245683]
- [netdrv] be2net: return error status from be_mcc_notify() (Ivan Vecera) [1245683]
- [netdrv] be2net: convert dest field in udp-hdr to host-endian (Ivan Vecera) [1245683]
- [netdrv] be2net: fix wrong return value in be_check_ufi_compatibility() (Ivan Vecera) [1245683]
- [netdrv] be2net: remove redundant D0 power state set (Ivan Vecera) [1245683]
- [netdrv] be2net: query FW to check if EVB is enabled (Ivan Vecera) [1245683]
- [netdrv] be2net: remove duplicate code in be_setup_wol() (Ivan Vecera) [1245683]
- [netdrv] remove all references to obsolete Ethernet-HOWTO (Ivan Vecera) [1245683]
- [infiniband] ocrdma: Destroy ocrdma_dev_id IDR on module exit (Honggang Li) [1244604]
- [infiniband] ucma: Destroy multcast_idr on module exit (Honggang Li) [1244604]
- [infiniband] ipoib: Set MTU to max allowed by mode when mode changes (Honggang Li) [1244604]
- [infiniband] ipoib: Scatter-Gather support in connected mode (Honggang Li) [1244604]
- [infiniband] ucm: Fix bitmap wrap when devnum > IB_UCM_MAX_DEVICES (Honggang Li) [1244604]
- [infiniband] ipoib: Prevent lockdep warning in __ipoib_ib_dev_flush (Honggang Li) [1244604]
- [infiniband] ucma: Fix lockdep warning in ucma_lock_files (Honggang Li) [1244604]
- [net] rds: rds_ib_device.refcount overflow (Honggang Li) [1244604]
- [infiniband] nes: Fix for incorrect recording of the MAC address (Honggang Li) [1244604]
- [infiniband] nes: Fix for resolving the neigh (Honggang Li) [1244604]
- [infiniband] core: Fixes for port mapper client registration (Honggang Li) [1244604]
- [infiniband] cm: Do not queue work to a device that's going away (Honggang Li) [1244604]
- [infiniband] mad: Remove improper use of BUG_ON (Honggang Li) [1244604]
- [infiniband] mad: Fix compare between big endian and cpu endian (Honggang Li) [1244604]
- [infiniband] Add rdma_cap_ib_switch helper and use where appropriate (Honggang Li) [1244604]
- [infiniband] mlx4: Do not attemp to report HCA clock offset on VFs (Amir Vadai) [1238185]
- [infiniband] ipoib: Fix bad error flow in ipoib_add_port() (Amir Vadai) [1238185]
- [security] selinux: reduce the number of calls to synchronize_net() when flushing caches (Paul Moore) [1030405]
- [security] selinux: conditionally reschedule in hashtab_insert while loading selinux policy (Paul Moore) [1030405]
- [security] selinux: conditionally reschedule in mls_convert_context while loading selinux policy (Paul Moore) [1030405]

* Thu Jul 23 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-299.el7]
- [inifniband] mlx4: Add support for CQ time-stamping (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [inifniband] mlx4: Add mmap call to map the hardware clock (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [inifniband] core: Pass hardware specific data in query_device (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [inifniband] core: Add timestamp_mask and hca_core_clock to query_device (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [inifniband] core: Extend ib_uverbs_create_cq (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [inifniband] core: Add CQ creation time-stamping flag (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [inifniband] core: Change ib_create_cq to use struct ib_cq_init_attr (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [inifniband] core: Change provider's API of create_cq to be extendible (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Disable HA for SRIOV PF RoCE devices (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [inifniband] mlx4: Fix error paths in mlx4_ib_create_flow() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Fix wrong csum complete report when rxvlan offload is disabled (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Wake TX queues only when there's enough room (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Release TX QP when destroying TX ring (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Use HW counters for rx/tx bytes/packets in PF device (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Fix off-by-four in ethtool (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Prefetch skb data on RX (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Pop cq outside mlx5e_get_cqe (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Remove mlx5e_cq.sqrq back-pointer (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Remove extra spaces (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Avoid TX CQE generation if more xmit packets expected (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Avoid redundant dev_kfree_skb() upon NOP completion (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Remove re-assignment of wq type in mlx5e_enable_rq() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Use skb_shinfo(skb)->gso_segs rather than counting them (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Static mapping of netdev priv resources to/from netdev TX queues (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Support NETIF_F_SG (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Enable TX rate limit per VF (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: use napi_complete_done() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Disable Granular QoS per VF under IB/Eth VPI configuration (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Support ndo_get_vf_stats (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Show PF own statistics via ethtool (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Add helper to query counters (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Set VF to read from QP counters (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Add RoCE/IB dedicated counters (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Allocate default counter per port (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Add port attribute when tracking counters (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Adjust counter grant policy in the resource tracker (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Remove counters table allocation from VF flow (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Add sink counter (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Reset counters data when freed (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Check before cleaning counters bitmap (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Add transport domain to the ethernet TIRs/TISs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Add transport domain alloc/dealloc support (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Enforce max flow-tables level >= 3 (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Disable client vlan TX acceleration (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Add HW cacheline start padding (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5e: Fix HW MTU settings (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: fix an error code (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: use swap() in mlx4_make_profile() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: use swap() in mlx4_init_qp_table() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Prevent setting invalid RSS hash function (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Support for configurable RSS hash function (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] ptp: mlx4: use helpers for converting ns to timespec (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] ptp: mlx4: convert to the 64 bit get/set time methods (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: only pull headers into skb head (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] configs: Enable ConnectX-4 IB/Ethernet HCA (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Fix static checker warnings around system guid query flow (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5: Enable mutual support for IB and Ethernet (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Don't create IB instance over Ethernet ports (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Avoid using the MAD_IFC command under ISSI > 0 mode (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Add more query port helpers (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Use port number when querying port ptys (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Use port number in the query port mtu helpers (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Get vendor-id using the query adapter command (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Add new query HCA vport commands (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Make the vport helpers available for the IB driver too (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Check the return bitmask when querying ISSI (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Enable XRCs and SRQs when using ISSI > 0 (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Apply proper name convention to helpers (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_en: Add missing check for memory allocation failure (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: fix typo in mlx4_set_vf_mac (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: need to call close fw if alloc icm is called twice (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: double free of dev_vfs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix build failure introduced by the EQ pool changes (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Make sure there are no pending async events when freeing CQ (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Move affinity hints to mlx4_core ownership (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Add EQ pool (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Demote simple multicast and broadcast flow steering rules (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5: Extend mlx5_core to support ConnectX-4 Ethernet functionality (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5: Ethernet resource handling files (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5: Ethernet Datapath files (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Set/Query port MTU commands (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Modify CQ moderation parameters (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Implement get/set port status (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Implement access functions of ptys register fields (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: New device capabilities handling (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: HW data structs/types definitions cleanup (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Set irq affinity hints (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core, mlx5_ib: Do not use vmap() on coherent memory (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix fallback from MSI-X to INTx (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Enable single ported IB VFs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Adjust the schedule queue port in reset-to-init too (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Adjust the schedule queue port for single ported IB VFs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Modify port values when generting EQEs for VFs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Convert slave port before building address-handle (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Enhance the MAD_IFC wrapper to convert VF port to physical (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Avoid 'may be used uninitialized' warnings (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] infiniband: Remove duplicated KERN_<LEVEL> from pr_<level> uses (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Work properly with EQ numbers > 256 in SRIOV (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Fix off-by-one in counters manipulation (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Schedule napi when RX buffers allocation fails (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix unaligned accesses (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Use correct loop cursor in error path (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix reading HCA max message size in mlx4_QUERY_DEV_CAP (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5: wrong page mask if CONFIG_ARCH_DMA_ADDR_T_64BIT enabled for 32Bit architectures (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] infiniband/mlx4: check for mapping error (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Fix WQE LSO segment calculation (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Change alias guids default to be host assigned (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Return the admin alias GUID upon host view request (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Raise slave shutdown event upon FLR (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Request alias GUID on demand (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Change init flow to request alias GUIDs for active VFs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Manage admin alias GUID upon admin request (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Set initial admin GUIDs for VFs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Manage alias GUID per VF (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Alias GUID adding persistency support (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4/mlx5: Use dma_wmb/rmb where appropriate (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix error message deprecation for ConnectX-2 cards (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Extend struct mlx5_interface to support multiple protocols (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Modify arm CQ in preparation for upcoming Ethernet driver (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Move completion eqs from mlx5_ib to mlx5_core (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Update module info macros for ConnectX4 Support (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Fix Mellanox copyright note (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Fix Mellanox copyright note (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Fix a bug in alloc_token (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Avoid usage command work entry after writing command doorbell (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Avoid copying outbox in aysnc command completion (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Use coherent memory for command interface page (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Use the right inbox struct in destroy mkey command (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Clear doorbell record inside mlx5_db_alloc() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Avoid setting DC requestor/responder resources (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Coding style fix (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Fix call to mlx5_core_qp_modify (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Allocate firmware pages from device's NUMA node (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Add RX-ALL support (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Add RX-FCS support (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Add interface identify support (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Add SET_PORT opcode modifiers enumeration (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Set enhanced QoS support by default when ETS supported (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Warn users of depracated QoS Firmware (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Added qos_vport QP configuration in VST mode (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Allocate VPPs for each port on PF init (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Query device for QoS per VF support (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Add mlx4_SET_VPORT_QOS implementation (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Add mlx4_ALLOCATE_VPP implementation (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: New file for QoS related firmware commands (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Aesthetic code changes in multi_func_init (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Make mlx4_is_eth visible inline funcion (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Change loopback only upon feature change (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Add RSS support for fragmented IP datagrams (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Moderate ethtool callback to show more statistics (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Add Flow control statistics display via ethtool (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Protect access to the statistics bitmap (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Support general selective view of ethtool statistics (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Move statistics bitmap setting to the Ethernet driver (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Create new header file for all statistics info (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Fix port counters statistics bitmask (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix GEN_EQE accessing uninitialixed mutex (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Call register_netdevice in the proper location (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Set statistics bitmap at port init (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Saturate RoCE port PMA counters in case of overflow (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Fix off-by-one in ethtool statistics display (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Verify net device validity on port change event (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Add basic support for QP max-rate limiting (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: don't export static symbol (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: codespell comment spelling fixes (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Use eth_<foo>_addr instead of memset (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Disbale GRO for incoming loopback/selftest packets (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix wrong mask and error flow for the update-qp command (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Update the dev in reg_create (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: In mlx4_ib_demux_cm, print out GUID in host-endian order (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Bug fixes in mlx4_ib_resize_cq (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Fix memory leak in __mlx4_ib_modify_qp (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Fix error code in get_port_caps() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Fix configuration of log_uar_page_sz (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] net: mellanox: Delete unnecessary checks before the function call "vunmap" (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Reset flow support for IB kernel ULPs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Always use the correct port for mirrored multicast attachments (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Notify TX Vlan offload change (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Adjust RX frag strides to frag sizes (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Print page allocator information (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Move to use hex PCI device IDs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix misleading debug print on CQE stride support (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix mpt_entry initialization in mlx4_mr_rereg_mem_write() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Load balance ports in port aggregation mode (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Create mirror flows in port aggregation mode (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Add port aggregation support (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Reuse mlx4_mac_to_u64() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Port aggregation upper layer interface (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Port aggregation low level interface (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix kernel Oops (mem corruption) when working with more than 80 VFs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Update the HCA core clock frequency after INIT_PORT (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix device capabilities dumping (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Fix memory corruption in mlx4_MAD_IFC_wrapper (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Use ethtool cmd->autoneg as a hint for ethtool set settings (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Remove duplicate code line from procedure mlx4_bf_alloc (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix struct mlx4_vhcr_cmd to make implicit padding explicit (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix HW2SW_EQ to conform to the firmware spec (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Adjust command timeouts to conform to the firmware spec (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix mem leak in SRIOV mlx4_init_one error flow (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Add reserved lkey for VFs to QUERY_FUNC_CAP (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Add bad-cable event support (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Reset flow activation upon SRIOV fatal command cases (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Enable device recovery flow with SRIOV (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Handle AER flow properly (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Manage interface state for Reset flow cases (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Activate reset flow upon fatal command cases (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Enhance the catas flow to support device reset (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Refactor the catas flow to work per device (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Set device configuration data to be persistent across reset (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Maintain a persistent memory for mlx4 device (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Don't disable vxlan offloads under DMFS-A0 optimized steering (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] infiniband: mlx5: avoid a compile-time warning (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5: avoid build warnings on 32-bit (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: include clocksource.h again (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix error flow in mlx4_init_hca() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Correcly update the mtt's offset in the MR re-reg flow (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Doorbell is byteswapped in Little Endian archs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Implement on demand paging by adding support for MMU notifiers (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Add support for RDMA read/write responder page faults (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Handle page faults (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Page faults handling infrastructure (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Add mlx5_ib_update_mtt to update page tables after creation (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Changes in memory region creation to support on-demand paging (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Implement the ODP capability query verb (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Add support for page faults events and low level handling (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Add function to read WQE from user-space (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Enhance UMR support to allow partial page table update (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Remove per-MR pas and dma pointers (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Check for DPDP violation only when DPDP is not supported (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Fix an incorrectly shadowed variable in mlx4_ib_rereg_user_mr (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Avoid double dumping of the PF device capabilities (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fixed memory leak and incorrect refcount in mlx4_load_one (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Add support for A0 steering (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Refactor QUERY_PORT (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Add explicit error message when rule doesn't meet configuration (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Add A0 hybrid steering (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Add mlx4_bitmap zone allocator (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Add a check if there are too many reserved QPs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Change QP allocation scheme (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Use tasklet for user-space CQ completion events (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Mask out host side virtualization features for guests (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Set csum level for encapsulated packets (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5: Fix error flow in add_keys (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5: Fix sparse warnings (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Clear outbox of dealloc uar (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Print resource number on QP/SRQ async events (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Fix command queue size enforcement (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Fix min vectors value in mlx5_enable_msix (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Request the mlx5 IB module on driver load (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Limit count field to 24 bits in qp_alloc_res (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: don't duplicate kvfree() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5: don't duplicate kvfree() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Support more than 64 VFs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Flexible (asymmetric) allocation of EQs and MSI-X vectors for PF/VFs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Add QUERY_FUNC firmware command (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Refactor mlx4_load_one (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Refactor mlx4_cmd_init and mlx4_cmd_cleanup (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Use correct variable type for mlx4_slave_cap (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Fix wrong reading of reserved_eqs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Extend checksum offloading by CHECKSUM COMPLETE (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Extend usage of napi_gro_frags (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Fix race on driver load (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Fix race in create EQ (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Add retrieval of CONFIG_DEV parameters (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Add __GFP_COLD gfp flags in alloc_pages (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Remove RX buffers alignment to IP_ALIGN (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Prevent VF from changing port configuration (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: use napi_schedule_irqoff() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Report actual number of rings in indirection table (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Move spinlocks and work initalizations to beginning of init_netdev (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Call napi_synchronize on stop_port (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Cleanups suggested by clang static checker (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Add ethtool support for [rx|tx]vlan offload set to OFF/ON (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Add support for setting rxvlan offload OFF/ON (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Call synchronize_irq() before freeing EQ buffer (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Call synchronize_irq() before freeing EQ buffer (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: fix race accessing page->_count (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Use extended internal signature layout (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Use enumerations for PI copy mask (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Modify to work with arbitrary page size (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Remove duplicate code from mlx5_set_path (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Fix possible array overflow (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Improve debug prints in mlx5_ib_reg_user_mr (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx5: Clear umr resources after ib_unregister_device (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: remove NETDEV_TX_BUSY (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Enable the compiler to make is_inline() inlined (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Use local var for skb_headlen(skb) (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Use local var in tx flow for skb_shinfo(skb) (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: mlx4_en_xmit() reads ring->cons once, and ahead of time to avoid stalls (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Avoid false sharing in mlx4_en_en_process_tx_cq() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Use prefetch in tx path (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Avoid a cache line miss in TX completion for single frag skb's (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: tx_info allocated with kmalloc() instead of vmalloc() (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Avoid calling bswap in tx fast path (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Align tx path structures to cache lines (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_en: Code cleanups in tx path (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: add a new xmit_more counter (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Identify resources by their type (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: use set/get macros in device caps (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Use hardware registers description header file (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx5_core: Update device capabilities handling (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Deprecate error message at ConnectX-2 cards startup to debug (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Protect QUERY_PORT wrapper from untrusted guests (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: New init and exit flow for mlx4_core (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Don't disable SRIOV if there are active VFs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: exploit skb->xmit_more to conditionally send doorbell (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4_core: Allow not to specify probe_vf in SRIOV IB mode (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mellanox: Change en_print to return void (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Fix VF mac handling in RoCE (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Do not allow APM under RoCE (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Don't update QP1 in native mode (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Avoid accessing netdevice when building RoCE qp1 header (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Fix mlx4 reg/unreg mac to work properly with 0-mac addresses (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [netdrv] mlx4: Correct error flows in rereg_mr (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [infiniband] mlx4: Disable TSO for Connect-X rev. A0 HCAs (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [net] netif_set_xps_queue: make cpu mask const (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]
- [net] core: Add reading VF statistics through the PF netdevice (Amir Vadai) [1164527 1164530 1164531 1164536 1164537]

* Thu Jul 23 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-298.el7]
- [fs] sunrpc: Adjust rpciod workqueue parameters (Benjamin Coddington) [1191956]
- [fs] ovl: lookup whiteouts outside iterate_dir() (David Howells) [1178942]
- [fs] ovl: allow distributed fs as lower layer (David Howells) [1178942]
- [fs] ovl: don't traverse automount points (David Howells) [1178942]
- [fs] ovl: mount read-only if workdir can't be created (David Howells) [1178942]
- [fs] ovl: don't remove non-empty opaque directory (David Howells) [1178942]
- [fs] ovl: rearrange ovl_follow_link to it doesn't need to call ->put_link (David Howells) [1178942]
- [fs] ovl: upper fs should not be R/O (David Howells) [1178942]
- [fs] ovl: check lowerdir amount for non-upper mount (David Howells) [1178942]
- [fs] ovl: print error message for invalid mount options (David Howells) [1178942]
- [fs] ovl: discard independent cursor in readdir() (David Howells) [1178942]
- [fs] ovl: Prevent rw remount when it should be ro mount (David Howells) [1178942]
- [fs] ovl: Fix opaque regression in ovl_lookup (David Howells) [1178942]
- [fs] ovl: Fix kernel panic while mounting overlayfs (David Howells) [1178942]
- [fs] ovl: Use macros to present ovl_xattr (David Howells) [1178942]
- [fs] ovl: Cleanup redundant blank lines (David Howells) [1178942]
- [fs] ovl: support multiple lower layers (David Howells) [1178942]
- [fs] ovl: make upperdir optional (David Howells) [1178942]
- [fs] ovl: improve mount helpers (David Howells) [1178942]
- [fs] ovl: mount: change order of initialization (David Howells) [1178942]
- [fs] ovl: allow statfs if no upper layer (David Howells) [1178942]
- [fs] ovl: lookup ENAMETOOLONG on lower means ENOENT (David Howells) [1178942]
- [fs] ovl: check whiteout on lowest layer as well (David Howells) [1178942]
- [fs] ovl: multi-layer lookup (David Howells) [1178942]
- [fs] ovl: multi-layer readdir (David Howells) [1178942]
- [fs] ovl: helper to iterate layers (David Howells) [1178942]
- [fs] ovl: add mutli-layer infrastructure (David Howells) [1178942]
- [fs] ovl: dont replace opaque dir (David Howells) [1178942]
- [fs] ovl: make path-type a bitmap (David Howells) [1178942]
- [fs] ovl: check whiteout while reading directory (David Howells) [1178942]
- [fs] coredump: add i/I in core_pattern to report the tid of the crashed thread (Oleg Nesterov) [1240966]
- [fs] bio-integrity: do not assume bio_integrity_pool exists if bioset exists (Mike Snitzer) [1198035]
- [md] dm-btree: silence lockdep lock inversion in dm_btree_del() (Mike Snitzer) [1186625]
- [md] dm-thin: allocate the cell_sort_array dynamically (Mike Snitzer) [1244318]
- [md] dm-cache: avoid calls to prealloc_free_structs() if possible (Mike Snitzer) [1244247]
- [md] dm-cache: avoid preallocation if no work in writeback_some_dirty_blocks() (Mike Snitzer) [1244247]
- [md] dm-cache: do not wake_worker() in free_migration() (Mike Snitzer) [1244247]
- [md] dm-cache: display 'needs_check' in status if it is set (Mike Snitzer) [1243916]
- [md] dm-thin: display 'needs_check' in status if it is set (Mike Snitzer) [1243916]
- [md] dm-thin: stay in out-of-data-space mode once no_space_timeout expires (Mike Snitzer) [1243913]
- [char] ipmi_ssif: add arguments that were removed upstream (Tony Camuso) [1229675]
- [powerpc] msi: Use WARN_ON() in msi bitmap selftests (Steve Best) [1241612]
- [powerpc] msi: Fix the msi bitmap alignment tests (Steve Best) [1241612]

* Mon Jul 20 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-297.el7]
- [kernel] Make some warnings non-fatal for powerpc builds (Thomas Huth) [1243836]
- [edac] amd64_edac: Add F15h M60h support (Kim Naru) [1135004]
- [edac] Sync memory types and names (Kim Naru) [1135004]
- [edac] mc: Add DDR3 LRDIMM entries to edac_mem_types (Kim Naru) [1135004]
- [x86] amd_nb: Add device IDs to NB tables for F15h M60h (Kim Naru) [1135004]
- [edac] amd64_edac: Modify usage of amd64_read_dct_pci_cfg() (Kim Naru) [1135004]
- [edac] mce_amd: Add MCE decoding for F15h M60h (Kim Naru) [1135004]
- [edac] amd64_edac: Remove "amd64" prefix from static functions (Kim Naru) [1135004]
- [zram] don't grab mutex in zram_slot_free_noity (Seth Jennings) [1236697]
- [fs] revert "nfs: Fixing lease renewal" (Carlos Maiolino) [1205048]
- [md] raid0: Disable discard per default due to performance uncertainty (Jes Sorensen) [1215280]
- [net] udp: fix behavior of wrong checksums (Denys Vlasenko) [1240761] {CVE-2015-5364 CVE-2015-5366}
- [net] tcp: always send a quick ack when quickacks are enabled (Hannes Frederic Sowa) [1241718]
- [net] tcp: tcp_get_info() should fetch socket fields once (Sabrina Dubroca) [1235100]
- [net] tcp: add pacing_rate information into tcp_info (Sabrina Dubroca) [1235100]
- [net] tcp: do not pace pure ack packets (Sabrina Dubroca) [1235100]
- [net] ipv4: tcp: get rid of ugly unicast_sock (Sabrina Dubroca) [1235100]
- [net] ipv4: dst_entry leak in ip_send_unicast_reply() (Sabrina Dubroca) [1235100]
- [net] ipv4: rename ip_options_echo to __ip_options_echo() (Sabrina Dubroca) [1235100]
- [net] tcp: ipv4: initialize unicast_sock sk_pacing_rate (Sabrina Dubroca) [1235100]
- [net] tcp: refine TSO autosizing (Sabrina Dubroca) [1235100]
- [net] tcp: use ACCESS_ONCE() in tcp_update_pacing_rate() (Sabrina Dubroca) [1235100]
- [net] introduce SO_MAX_PACING_RATE (Sabrina Dubroca) [1235100]
- [net] configs: enable Fair Queue scheduler (CONFIG_NET_SCH_FQ) (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: correct spelling of locally (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: better control of DDOS traffic (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: avoid hang when quantum 0 (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: remove useless TIME_WAIT check (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: increase max delay from 125 ms to one second (Sabrina Dubroca) [1235102]
- [net] net_sched: avoid costly atomic operation in fq_dequeue() (Sabrina Dubroca) [1235102]
- [net] netem: Fixes byte backlog accounting for the first of two chained netem instances (Sabrina Dubroca) [1235102]
- [net] net_sched: implement qstat helper routines (Sabrina Dubroca) [1235102]
- [net] sch_tbf: handle too small burst (Sabrina Dubroca) [1235102]
- [net] sch_tbf: segment too big GSO packets (Sabrina Dubroca) [1235102]
- [net] netem: update backlog after drop (Sabrina Dubroca) [1235102]
- [net] net_sched: increment drop counters in qdisc_tree_decrease_qlen() (Sabrina Dubroca) [1235102]
- [net] netem: fix possible NULL deref in netem_dequeue() (Sabrina Dubroca) [1235102]
- [net] netem: use rb tree to implement the time queue (Sabrina Dubroca) [1235102]
- [net] net_sched: return nla_nest_end() instead of skb->len (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: do not hold qdisc lock while allocating memory (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: more robust memory allocation (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: fix pacing for small frames (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: warn users using defrate (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: change classification of control packets (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: clear time_next_packet for reused flows (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: fix non TCP flows pacing (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: fix typo for initial_quantum (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: rate limiting improvements (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: qdisc dismantle fixes (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: prefetch() fix (Sabrina Dubroca) [1235102]
- [net] pkt_sched: fq: Fair Queue packet scheduler (Sabrina Dubroca) [1235102]

* Fri Jul 17 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-296.el7]
- [x86] irq: hide HYP in /proc/interrupts when not on Xen/Hyper-V (Vitaly Kuznetsov) [1238596 1238599]
- [x86] hyperv: restore irq accounting (Vitaly Kuznetsov) [1238596 1238599]
- [x86] xen: Add proper irq accounting for HYPERCALL vector (Vitaly Kuznetsov) [1238596 1238599]
- [x86] irq: Properly tag virtualization entry in /proc/interrupts (Vitaly Kuznetsov) [1238596 1238599]
- [x86] Add proper vector accounting for HYPERVISOR_CALLBACK_VECTOR (Vitaly Kuznetsov) [1238596 1238599]
- [x86] kvm: keep track of LVT0 changes under APICv (Radim Krcmar) [1236434]
- [x86] kvm: properly restore LVT0 (Radim Krcmar) [1236434]
- [x86] kvm: make vapics_in_nmi_mode atomic (Radim Krcmar) [1236434]
- [netdrv] sfc: Report TX completions to BQL after all TX events in interrupt (Jarod Wilson) [1242006]
- [netdrv] sfc: Ensure down_write(&filter_sem) and up_write() are matched before calling efx_net_open() (Jarod Wilson) [1242006]
- [netdrv] sfc: suppress handled MCDI failures when changing the MAC address (Jarod Wilson) [1242006]
- [netdrv] sfc: add legacy method for changing a PF's MAC address (Jarod Wilson) [1242006]
- [netdrv] sfc: refactor code in efx_ef10_set_mac_address() (Jarod Wilson) [1242006]
- [crypto] nx - replace NX842_MEM_COMPRESS with function (Gustavo Duarte) [1221925]
- [crypto] nx - move include/linux/nx842.h into drivers/crypto/nx/nx-842.h (Gustavo Duarte) [1221925]
- [crypto] nx - fix nx-842 pSeries driver minimum buffer size (Gustavo Duarte) [1221925]
- [crypto] nx - prevent nx 842 load if no hw driver (Gustavo Duarte) [1221925]
- [crypto] nx - remove 842-nx null checks (Gustavo Duarte) [1221925]
- [lib] correct 842 decompress for 32 bit (Gustavo Duarte) [1221925]
- [lib] make lib/842 decompress functions static (Gustavo Duarte) [1221925]
- [crypto] nx - add hardware 842 crypto comp alg (Gustavo Duarte) [1221925]
- [crypto] nx - simplify pSeries nx842 driver (Gustavo Duarte) [1221925]
- [crypto] nx - add PowerNV platform NX-842 driver (Gustavo Duarte) [1221925]
- [crypto] nx - add nx842 constraints (Gustavo Duarte) [1221925]
- [crypto] nx - add NX-842 platform frontend driver (Gustavo Duarte) [1221925]
- [crypto] nx - rename nx-842.c to nx-842-pseries.c (Gustavo Duarte) [1221925]
- [crypto] 842 - change 842 alg to use software (Gustavo Duarte) [1221925]
- [lib] add software 842 compression/decompression (Gustavo Duarte) [1221925]
- [powerpc] Add ICSWX instruction (Gustavo Duarte) [1221925]
- [powerpc] export of_get_ibm_chip_id function (Gustavo Duarte) [1221925]
- [crypto] Add 2 missing __exit_p (Gustavo Duarte) [1221925]
- [crypto] nx-842: dev_set_drvdata can no longer fail (Gustavo Duarte) [1221925]
- [crypto] nx - Use RCU_INIT_POINTER(x, NULL) (Gustavo Duarte) [1221925]
- [crypto] nx-842: Fix handling of vmalloc addresses (Gustavo Duarte) [1221925]
- [powerpc] perf: Fail 24x7 initcall if create_events_from_catalog() fails (Gustavo Duarte) [1182055]
- [powerpc] perf: 24x7: Fix lockdep warning (Gustavo Duarte) [1182055]
- [powerpc] perf: Document sysfs event description entries (Gustavo Duarte) [1182055]
- [powerpc] perf: add the remaining gpci requests (Gustavo Duarte) [1182055]
- [powerpc] perf: generate requests with counters annotated (Gustavo Duarte) [1182055]
- [powerpc] perf: parse catalog and populate sysfs with events (Gustavo Duarte) [1182055]
- [powerpc] perf: define EVENT_DEFINE_RANGE_FORMAT_LITE helper (Gustavo Duarte) [1182055]
- [powerpc] perf: documentation: Add event parameters (Gustavo Duarte) [1182055]
- [powerpc] perf: documentation: Remove duplicated docs for powerpc cpu specific events (Gustavo Duarte) [1182055]
- [powerpc] perf: documentation: sysfs events/ interfaces (Gustavo Duarte) [1182055]
- [powerpc] perf: Use common PMU interrupt disabled code (Gustavo Duarte) [1182055]
- [powerpc] mm: Serialize pmd clear against a linux page table walk (Gustavo Duarte) [1233071]
- [powerpc] mm: Return NULL for not present hugetlb page (Gustavo Duarte) [1233071]
- [powerpc] mm: Return pte address if we find trans_splitting (Gustavo Duarte) [1233071]
- [powerpc] mm: Make page table walk safe against thp split/collapse (Gustavo Duarte) [1233071]
- [powerpc] kvm: Remove page table walk helpers (Gustavo Duarte) [1233071]

* Wed Jul 15 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-295.el7]
- [powerpc] powernv: Fix race in updating core_idle_state (Steve Best) [1237270]
- [cpuidle] powernv: Auto-promotion of snooze to deeper idle state (Gustavo Duarte) [1235256]
- [netdrv] e1000, e1000e: Use dma_rmb instead of rmb for descriptor read ordering (John Greene) [1173781]
- [netdrv] e1000: add dummy allocator to fix race condition between mtu change and netpoll (John Greene) [1173781]
- [netdrv] e1000: call netif_carrier_off early on down (John Greene) [1173781]
- [netdrv] e1000: support txtd update delay via xmit_more (John Greene) [1173781]
- [netdrv] e1000: fix time comparison (John Greene) [1173781]
- [netdrv] bna: revert "Update the Driver and Firmware Version" (Ivan Vecera) [1240644]
- [kernel] module: remove TAINT_CRAP on staging modules (Prarit Bhargava) [1242024]
- [block] revert "remove artifical max_hw_sectors cap" (Jeff Moyer) [1238922]
- [perf] bench-numa: Show more stats of particular threads in verbose mode (Petr Holasek) [1018954]
- [scsi] don't add scsi_device if its already visible (Vitaly Kuznetsov) [1242390]
- [scsi] iscsi: let session recovery_tmo sysfs writes persist across recovery (Chris Leech) [1139038]
- [edac] Properly unwind on failure path in edac_init() (Seth Jennings) [1240814]
- [edac] Allow to pass driver-specific attribute groups (Seth Jennings) [1240814]
- [edac] Use static attribute groups for managing sysfs entries (Seth Jennings) [1240814]
- [edac] edac: edac_mc_sysfs: Make stuff static (Seth Jennings) [1240814]
- [edac] Fix the leak of mci->bus->name when bus_register fails (Seth Jennings) [1240814]
- [edac] Mark edac_create_debug_nodes as static (Seth Jennings) [1240814]
- [x86] revert "pci: Refine the way to release PCI IRQ resources" (Steve Best) [1231358 1238216]
- [x86] pci: Refine the way to release PCI IRQ resources (Steve Best) [1231358 1238216]
- [x86] irq: Keep balance of IOAPIC pin reference count (Steve Best) [1231358 1238216]
- [x86] irq: Fix placement of mp_should_keep_irq() (Steve Best) [1231358 1238216]
- [x86] irq, pci: Keep IRQ assignment for runtime power management (Steve Best) [1231358 1238216]
- [x86] irq, pci: Keep IRQ assignment for PCI devices during suspend/hibernation (Steve Best) [1231358 1238216]
- [x86] Mark Intel Skylake-S processor as supported (Steve Best) [1131729]
- [x86] bpf_jit: fix compilation of large bpf programs (Denys Vlasenko) [1236939] {CVE-2015-4700}
- [x86] ASLR bruteforce possible for vdso library (Jacob Tanenbaum) [1184899] {CVE-2014-9585}
- [x86] mm: Improve AMD Bulldozer ASLR workaround (Prarit Bhargava) [1240884]
- [dma] ioat: fix tasklet tear down ("Herton R. Krzesinski") [1210093]
- [md] revert "dm: only run the queue on completion if congested or no requests pending" (Mike Snitzer) [1241237]
- [fs] nfsv4: Always drain the slot table before re-establishing the lease (Benjamin Coddington) [1240790]
- [mm] export find_extend_vma() and handle_mm_fault() for driver use (Jerome Glisse) [1210492]
- [mm] mmu_notifier: add new callback for mmu_notifier without breaking kabi (Jerome Glisse) [1210492]
- [mm] mmu_notifier: call mmu_notifier_invalidate_range() from VMM (Jerome Glisse) [1210492]
- [mm] mmu_notifier: add mmu_notifier_invalidate_range() (Jerome Glisse) [1210492]

* Fri Jul 10 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-294.el7]
- [video] radeon: Conditionally compile PM code (Thomas Huth) [1238568]
- [char] ipmi: Fix backport of powernv IPMI driver (Thomas Huth) [1238568]
- [of] Silence warning due to bad backport in drivers/of/base.c (Thomas Huth) [1238568]
- [powerpc] boot/fdt: Use unsigned long for pointer casts (Thomas Huth) [1238568]
- [char] hwrng: pseries - remove incorrect __init/__exit markups (Thomas Huth) [1238568]
- [mm] page_alloc.c: use '__paginginit' instead of '__init' (Thomas Huth) [1238568]
- [fs] fuse: fix "uninitialized variable" warning (Thomas Huth) [1238568]
- [powerpc] powernv: Fix merge issue for opal-prd channel (Rafael Aquini) [1221110 1229224]
- [powerpc] PowerNV kernel is not able to manage 16G pages (Laurent Vivier) [1212273]
- [s390] kdump: fix REGSET_VX_LOW vector register ELF notes (Hendrik Brueckner) [1236566]
- [s390] zcrypt: Fixed reset and interrupt handling of AP queues (Hendrik Brueckner) [1238230]
- [kvm] ppc: book3s-hv: Implement dynamic micro-threading on POWER8 (Laurent Vivier) [1213669]
- [kvm] ppc: book3s-hv: Make use of unused threads when running guests (Laurent Vivier) [1213669]
- [kvm] ppc: book3s-hv: Use msgsnd for signalling threads on POWER8 (Laurent Vivier) [1213669]
- [kvm] ppc: book3s-hv: Translate kvmhv_commence_exit to C (Laurent Vivier) [1213669]
- [kvm] ppc: book3s-hv: Streamline guest entry and exit (Laurent Vivier) [1213669]
- [kvm] ppc: book3s-hv: Use bitmap of active threads rather than count (Laurent Vivier) [1213669]
- [kvm] ppc: book3s-hv: Use decrementer to wake napping threads (Laurent Vivier) [1213669]
- [kvm] ppc: book3s-hv: Don't wake thread with no vcpu on guest IPI (Laurent Vivier) [1213669]
- [kvm] ppc: book3s-hv: Get rid of vcore nap_count and n_woken (Laurent Vivier) [1213669]
- [kvm] ppc: book3s-hv: Fix list traversal in error case (Laurent Vivier) [1213669]
- [kvm] ppc: book3s-hv: Move vcore preemption point up into kvmppc_run_vcpu (Laurent Vivier) [1213669]
- [kvm] ppc: book3s-hv: Simplify handling of VCPUs that need a VPA update (Laurent Vivier) [1213669]
- [powerpc] powernv: Fixes for hypervisor doorbell handling (Laurent Vivier) [1213669]
- [x86] kvm: nsvm: Check for NRIPS support before updating control field (Bandan Das) [1167228]
- [security] keys: Increase root_maxkeys and root_maxbytes sizes (David Howells) [1014573]

* Thu Jul 09 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-293.el7]
- [fs] gfs2: add support for rename2 and RENAME_EXCHANGE (Benjamin Marzinski) [1163824]
- [fs] ext4: allocate entire range in zero range (Lukas Czerner) [1187071] {CVE-2015-0275}
- [fs] overlayfs: Warn on copy up if a process has a R/O fd open to the lower file (David Howells) [1226346]
- [fs] gfs2: make sure S_NOSEC flag isn't overwritten (Benjamin Marzinski) [1203446]
- [net] revert "[net] openvswitch: remove GFP_THISNODE" (Jiri Benc) [1238680]
- [net] revert "[net] dev: set iflink to 0 for virtual interfaces" (Jiri Benc) [1238672]
- [net] ipv4: __ip_local_out_sk() is static (Jiri Benc) [1234508]
- [netdrv] ixgbe: Allow flow director to use entire queue space (Thadeu Lima de Souza Cascardo) [1238421]
- [net] ethtool: Add helper routines to pass vf to rx_flow_spec (Thadeu Lima de Souza Cascardo) [1238421]
- [net] inet: remove old fragmentation hash initializing (Phil Sutter) [1235733]
- [net] ipv6: split inet6_hash_frag for netfilter and initialize secrets with net_get_random_once (Phil Sutter) [1235733]
- [net] ipv4: initialize ip4_frags hash secret as late as possible (Phil Sutter) [1235733]
- [net] switch net_secret key generation to net_get_random_once (Phil Sutter) [1235733]
- [net] tcp: Do not call tcp_fastopen_reset_cipher from interrupt context (Phil Sutter) [1235733]
- [net] tcp: switch tcp_fastopen key generation to net_get_random_once (Phil Sutter) [1235733]
- [net] inet: convert inet_ehash_secret and ipv6_hash_secret to net_get_random_once (Phil Sutter) [1235733]
- [net] ipv6: split inet6_ehashfn to hash functions per compilation unit (Phil Sutter) [1235733]
- [net] ipv4: split inet_ehashfn to hash functions per compilation unit (Phil Sutter) [1235733]
- [net] ipv4: harden fnhe_hashfun() (Phil Sutter) [1235733]
- [net] netfilter: nfnetlink_log: remove unused code (Phil Sutter) [1235733]
- [net] inet: split syncookie keys for ipv4 and ipv6 and initialize with net_get_random_once (Phil Sutter) [1235733]
- [net] tcp: fix child sockets to use system default congestion control if not set (Phil Sutter) [1235252]
- [net] netfilter: x_tables: align per cpu xt_counter (Phil Sutter) [1235240]
- [net] netfilter: x_tables: remove XT_TABLE_INFO_SZ and a dereference (Phil Sutter) [1235240]
- [net] esp6: Use high-order sequence number bits for IV generation (Herbert Xu) [1232741]
- [net] esp4: Use high-order sequence number bits for IV generation (Herbert Xu) [1232741]
- [net] xfrm: Always zero high-order sequence number bits (Herbert Xu) [1232741]
- [net] drop the packet when fails to do software segmentation or header check (Jason Wang) [1232621]
- [net] keep original skb which only needs header checking during software GSO (Jason Wang) [1232621]
- [net] remove some unless free on failure in alloc_netdev_mqs() (Jason Wang) [1231604]
- [netdrv] tuntap: Increase the number of queues in tun (Jason Wang) [1231604]
- [net] allow large number of rx queues (Jason Wang) [1231604]
- [net] allow large number of tx queues (Jason Wang) [1231604]
- [kernel] hrtimer: Avoid locking in hrtimer_cancel() if timer not active (Prarit Bhargava) [1217140]
- [kernel] hrtimer: Remove bogus hrtimer_active() check (Prarit Bhargava) [1217140]
- [kernel] alarmtimer: Get rid of unused return value (Prarit Bhargava) [1217140]
- [kernel] net: core: pktgen: Remove bogus hrtimer_active() check (Prarit Bhargava) [1217140]
- [kernel] rtmutex: Remove bogus hrtimer_active() check (Prarit Bhargava) [1217140]
- [kernel] futex: Remove bogus hrtimer_active() check (Prarit Bhargava) [1217140]
- [kernel] hrtimer: Get rid of __hrtimer_start_range_ns() (Prarit Bhargava) [1217140]
- [kernel] sched: core: Use hrtimer_start[_expires]() (Prarit Bhargava) [1217140]
- [kernel] perf: core: Use hrtimer_start() (Prarit Bhargava) [1217140]
- [kernel] x86: perf: uncore: Use hrtimer_start() (Prarit Bhargava) [1217140]
- [kernel] x86: perf: Use hrtimer_start() (Prarit Bhargava) [1217140]
- [kernel] tick: nohz: Rework next timer evaluation (Prarit Bhargava) [1217140]
- [kernel] tick: sched: Restructure code (Prarit Bhargava) [1217140]
- [kernel] tick: sched: Force tick interrupt and get rid of softirq magic (Prarit Bhargava) [1217140]
- [kernel] tick: sched: Remove hrtimer_active() checks (Prarit Bhargava) [1217140]
- [kernel] hrtimer: Get rid of hrtimer softirq (Prarit Bhargava) [1217140]
- [kernel] hrtimer: Get rid of softirq time (Prarit Bhargava) [1217140]
- [kernel] hrtimer: Fix incorrect tai offset calculation for non high-res timer systems (Prarit Bhargava) [1217140]
- [kernel] hrtimer: Cleanup hrtimer accessors to the timekepeing state (Prarit Bhargava) [1217140]
- [kernel] hrtimer: Prevent stale expiry time in hrtimer_interrupt() (Prarit Bhargava) [1217140]
- [kernel] hrtimer: Remove hrtimer_enqueue_reprogram() (Prarit Bhargava) [1217140]
- [kernel] hrtimer: Kick lowres dynticks targets on timer enqueue (Prarit Bhargava) [1217140]
- [kernel] hrtimer: Store cpu-number in struct hrtimer_cpu_base (Prarit Bhargava) [1217140]

* Mon Jul 06 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-292.el7]
- [fs] gfs2: handle NULL rgd in set_rgrp_preferences (Abhijith Das) [1211663]
- [fs] gfs2: Don't add all glocks to the lru (Robert S Peterson) [1232841]
- [fs] gfs2: Don't brelse rgrp buffer_heads every allocation (Robert S Peterson) [1154782]
- [char] ipmi: Fix merge issue for IPMI SMBus handler (SSFIF) (Rafael Aquini) [1229675]
- [kernel] sched: Avoid throttle_cfs_rq() racing with period_timer stopping (Rik van Riel) [1236413]
- [kernel] add support for gcc 5 (Prarit Bhargava) [1227950]
- [netdrv] vmxnet3: Changes for vmxnet3 adapter version 2 (fwd) (Neil Horman) [1237012]
- [netdrv] vmxnet3: Fix memory leaks in rx path (fwd) (Neil Horman) [1237012]
- [netdrv] vmxnet3: Register shutdown handler for device (fwd) (Neil Horman) [1237012]
- [netdrv] vmxnet3: spelling fixes (Neil Horman) [1237012]
- [netdrv] vmxnet3: Copy TCP header to mapped frame for IPv6 packets (Neil Horman) [1237012]
- [netdrv] vmxnet3: Change the hex constant to its decimal equivalent (Neil Horman) [1237012]
- [netdrv] vmxnet3: Fix ethtool -S to return correct rx queue stats (Neil Horman) [1237012]
- [netdrv] bnx2x: fix DMA API usage (Michal Schmidt) [1234874 1236582]
- [netdrv] bnx2x: fix lockdep splat (Michal Schmidt) [1236582]
- [netdrv] bnx2x: Fix linearization for encapsulated packets (Michal Schmidt) [1236582]
- [netdrv] bnx2x: Release nvram lock on error flow (Michal Schmidt) [1236582]
- [netdrv] bnx2x: Fix statistics gathering on link change (Michal Schmidt) [1236582]
- [netdrv] bnx2x: Fix self-test for 20g devices (Michal Schmidt) [1236582]
- [netdrv] bnx2x: Fix VF MAC removal (Michal Schmidt) [1236582]
- [netdrv] bnx2x: Don't notify about scratchpad parities (Michal Schmidt) [1236582]
- [netdrv] bnx2x: Prevent false warning when accessing MACs (Michal Schmidt) [1236582]
- [netdrv] bnx2x: Correct speed from baseT into KR (Michal Schmidt) [1236582]
- [netdrv] bnx2x: Correct asymmetric flow-control (Michal Schmidt) [1236582]

* Mon Jul 06 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-291.el7]
- [x86] perf: ibs: Update IBS MSRs and feature definitions (Jiri Olsa) [1135033]
- [x86] Mark Intel Skylake-Y processor as supported (Steve Best) [1176665]
- [edac] sb_edac: support for Broadwell -EP and -EX (Seth Jennings) [1223598]
- [edac] sb_edac: Fix support for systems with two home agents per socket (Seth Jennings) [1223598]
- [edac] sb_edac: Fix a typo and a thinko in address handling for Haswell (Seth Jennings) [1223598]
- [edac] Remove arbitrary limit on number of channels (Seth Jennings) [1223598]
- [edac] sb_edac: Fix detection on SNB machines (Seth Jennings) [1223598]
- [edac] sb_edac: Fix erroneous bytes->gigabytes conversion (Seth Jennings) [1223598]
- [edac] sb_edac: Claim a different PCI device (Seth Jennings) [1223598]
- [edac] Move Intel SNB device ids from sb_edac to pci_ids.h (Seth Jennings) [1223598]
- [edac] sb_edac: Mark get_mci_for_node_id as static (Seth Jennings) [1223598]
- [kernel] genirq: Fix memory leak when calling irq_free_hwirqs() (Steve Best) [1237186]
- [kernel] module: Call module notifier on failure after complete_formation() (Bandan Das) [1236273]
- [documentation] intel_pstate: Improve legacy mode internal governors description (Prarit Bhargava) [1236586]

* Thu Jul 02 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-290.el7]
- [hv] fcopy: set .owner reference for file operations (Vitaly Kuznetsov) [1236557]
- [md] dm-btree-remove: fix bug in redistribute3 (Mike Snitzer) [1236092]
- [x86] kvm: Enable PMU handling for AMD PERFCTRn and EVNTSELn MSRs (Wei Huang) [1076010]
- [x86] kvm: Implement AMD vPMU code for KVM (Wei Huang) [1076010]
- [x86] kvm: Define kvm_pmu_ops to support vPMU function dispatch (Wei Huang) [1076010]
- [x86] kvm: vpmu: introduce kvm_pmu_msr_idx_to_pmc (Wei Huang) [1076010]
- [x86] kvm: vpmu: reorder PMU functions (Wei Huang) [1076010]
- [x86] kvm: vpmu: whitespace and stylistic adjustments in PMU code (Wei Huang) [1076010]
- [x86] kvm: vpmu: use the new macros to go between PMC, PMU and VCPU (Wei Huang) [1076010]
- [x86] kvm: vpmu: introduce pmu.h header (Wei Huang) [1076010]
- [x86] kvm: vpmu: rename a few PMU functions (Wei Huang) [1076010]
- [s390] crypto: ghash - Fix incorrect ghash icv buffer handling (Herbert Xu) [1207598]
- [video] vt_buffer: drop console buffer copying optimisations (Dave Airlie) [1187449]
- [netdrv] i40evf: fix panic during MTU change (Stefan Assmann) [1233585]
- [netdrv] i40evf: don't configure unused RSS queues (Stefan Assmann) [1233649]
- [security] lsm: get comm using lock to avoid race in string printing (Richard Guy Briggs) [1056327]
- [kernel] audit: get comm using lock to avoid race in string printing (Richard Guy Briggs) [1056327]
- [kernel] sched: cope with kabi constraints (Stanislaw Gruszka) [1064059]
- [kernel] sched: Provide update_curr callbacks for stop/idle scheduling classes (Stanislaw Gruszka) [1064059]
- [kernel] sched/cputime: Fix clock_nanosleep()/clock_gettime() inconsistency (Stanislaw Gruszka) [1064059]
- [kernel] sched/cputime: Fix cpu_timer_sample_group() double accounting (Stanislaw Gruszka) [1064059]

* Wed Jul 01 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-289.el7]
- [crypto] krng: Remove krng (Herbert Xu) [1229738]
- [crypto] drbg: Add stdrng alias and increase priority (Herbert Xu) [1229738]
- [crypto] seqiv: Move IV seeding into init function (Herbert Xu) [1229738]
- [crypto] eseqiv: Move IV seeding into init function (Herbert Xu) [1229738]
- [crypto] chainiv: Move IV seeding into init function (Herbert Xu) [1229738]
- [security] selinux: convert WARN_ONCE() to printk() in selinux_nlmsg_perm() (Richard Guy Briggs) [1066686]
- [security] selinux: cleanup error reporting in selinux_nlmsg_perm() (Richard Guy Briggs) [1066686]
- [security] audit: fix dangling keywords in integrity ima message output (Richard Guy Briggs) [1066686]
- [security] audit: invalid op= values for rules (Richard Guy Briggs) [1066686]
- [security] selinux: normalize audit log formatting (Richard Guy Briggs) [1066686]
- [fs] Fix problem recognizing symlinks (Sachin Prabhu) [1232788]
- [fs] Fix mfsymlinks file size check (Sachin Prabhu) [1232788]
- [fs] Update version number displayed by modinfo for cifs.ko (Sachin Prabhu) [1232788]
- [fs] cifs: remove dead code (Sachin Prabhu) [1232788]
- [fs] Fix setting time before epoch (negative time values) (Sachin Prabhu) [1232788]
- [fs] Clarify Kconfig help text for CIFS and SMB2/SMB3 (Sachin Prabhu) [1232788]
- [fs] cifs: Fix wrong filename length for SMB2 (Sachin Prabhu) [1232788]
- [fs] cifs: Fix wrong restart readdir for SMB1 (Sachin Prabhu) [1232788]
- [fs] cifs: Fix directory rename error (Sachin Prabhu) [1232788]
- [fs] cifs: Allow directIO read/write during cache=strict (Sachin Prabhu) [1232788]
- [fs] cifs: remove unneeded check of null checking in if condition (Sachin Prabhu) [1232788]
- [fs] cifs: fix a possible use of uninit variable in SMB2_sess_setup (Sachin Prabhu) [1232788]
- [fs] cifs: fix memory leak when password is supplied multiple times (Sachin Prabhu) [1232788]
- [fs] cifs: fix a possible null pointer deref in decode_ascii_ssetup (Sachin Prabhu) [1232788]
- [fs] Trivial whitespace fix (Sachin Prabhu) [1232788]
- [fs] Enable fallocate -z support for SMB3 mounts (Sachin Prabhu) [1232788]
- [fs] enable fallocate punch hole ("fallocate -p") for SMB3 (Sachin Prabhu) [1232788]
- [fs] Incorrect error returned on setting file compressed on SMB2 (Sachin Prabhu) [1232788]
- [fs] cifs: Fix wrong directory attributes after rename (Sachin Prabhu) [1232788]
- [fs] cifs: Fix SMB2 readdir error handling (Sachin Prabhu) [1232788]
- [fs] Workaround MacOS server problem with SMB2.1 write response (Sachin Prabhu) [1232788]
- [fs] cifs: handle lease F_UNLCK requests properly (Sachin Prabhu) [1232788]
- [fs] Cleanup sparse file support by creating worker function for it (Sachin Prabhu) [1232788]
- [fs] Add sparse file support to SMB2/SMB3 mounts (Sachin Prabhu) [1232788]
- [fs] Add missing definitions for CIFS File System Attributes (Sachin Prabhu) [1232788]
- [fs] Add worker function to set allocation size (Sachin Prabhu) [1232788]
- [fs] Fix incorrect hex vs. decimal in some debug print statements (Sachin Prabhu) [1232788]
- [fs] Delete cifs specific helper functions for iter operations (Sachin Prabhu) [1232788]
- [fs] Backport iov_iter_truncate() (Sachin Prabhu) [1232788]
- [fs] new helper: copy_page_from_iter() (Sachin Prabhu) [1232788]
- [fs] Introduce copy_page_to_iter (Sachin Prabhu) [1232788]
- [fs] nfsv4: Ensure we skip delegations that are already being returned (Benjamin Coddington) [1206610]
- [fs] nfsv4: Pin the superblock while we're returning the delegation (Benjamin Coddington) [1206610]
- [fs] nfsv4: Ensure we honour NFS_DELEGATION_RETURNING in nfs_inode_set_delegation() (Benjamin Coddington) [1206610]
- [fs] nfsv4: Ensure that we don't reap a delegation that is being returned (Benjamin Coddington) [1206610]
- [fs] sunrpc: make debugfs file creation failure non-fatal (Benjamin Coddington) [1235634]
- [fs] sunrpc: add a debugfs rpc_xprt directory with an info file in it (Benjamin Coddington) [1235634]
- [fs] sunrpc: add debugfs file for displaying client rpc_task queue (Benjamin Coddington) [1235634]
- [fs] sunrpc: eliminate RPC_TRACEPOINTS (Benjamin Coddington) [1235634]
- [fs] nfsd: eliminate NFSD_DEBUG (Benjamin Coddington) [1235634]
- [fs] sunrpc: eliminate RPC_DEBUG (Benjamin Coddington) [1235634]
- [fs] lockd: eliminate LOCKD_DEBUG (Benjamin Coddington) [1235634]
- [fs] nfs: take extra reference to fl->fl_file when running a setlk (Benjamin Coddington) [1236569]
- [fs] xfs: don't truncate attribute extents if no extents exist (Brian Foster) [1236045]
- [fs] fixing infinite OPEN loop in 4.0 stateid recovery (Benjamin Coddington) [1219184]
- [fs] Recover from stateid-type error on SETATTR (Benjamin Coddington) [1214410]
- [fs] pnfs: Fix a memory leak when attempted pnfs fails (Steve Dickson) [1234986]
- [fs] nfs: Add a stub for GETDEVICELIST (Benjamin Coddington) [1234797]
- [fs] nfs: fix high load average due to callback thread sleeping (Benjamin Coddington) [1234797]
- [fs] sunrpc: fix braino in ->poll() (Benjamin Coddington) [1234797]
- [fs] nfs: Fix a regression in the read() syscall (Benjamin Coddington) [1234797]
- [fs] nfsv4: Don't call put_rpccred() under the rcu_read_lock() (Benjamin Coddington) [1234797]
- [fs] nfs: Don't invalidate a submounted dentry in nfs_prime_dcache() (Benjamin Coddington) [1234797]
- [fs] nfs: struct nfs_commit_info.lock must always point to inode->i_lock (Benjamin Coddington) [1234797]
- [fs] nfsv4.1: Fix a kfree() of uninitialised pointers in decode_cb_sequence_args (Benjamin Coddington) [1234797]
- [fs] nfsv4: Ensure we reference the inode for return-on-close in delegreturn (Benjamin Coddington) [1234797]
- [fs] sunrpc: NULL utsname dereference on NFS umount during namespace cleanup (Benjamin Coddington) [1234797]
- [fs] nfs: don't call blocking operations while !TASK_RUNNING (Benjamin Coddington) [1234797]
- [fs] nfs: fix dio deadlock when O_DIRECT flag is flipped (Benjamin Coddington) [1234797]
- [fs] nfsv4.1: Fix client id trunking on Linux (Benjamin Coddington) [1234797]
- [fs] nfs41: fix nfs4_proc_layoutget error handling (Benjamin Coddington) [1234797]
- [fs] nfs: fix subtle change in COMMIT behavior (Benjamin Coddington) [1234797]
- [fs] sunrpc: Fix locking around callback channel reply receive (Benjamin Coddington) [1234797]

* Wed Jul 01 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-288.el7]
- [unisys] add visorbus (Erik Arfvidson) [1228343]
- [acpi] pci: Account for ARI in _PRT lookups (Alex Williamson) [1222066]
- [pci] Move pci_ari_enabled() to global header (Alex Williamson) [1222066]
- [cpufreq] intel_pstate: Fix overflow in busy_scaled due to long delay (Prarit Bhargava) [1228346]
- [perf] tools: Add hint for 'Too many events are opened.' error message (Jiri Olsa) [990937]
- [tools] perf: Fix "Command" sort_entry's cmp and collapse function (Jiri Olsa) [1220686]
- [net] sctp: fix ASCONF list handling (Marcelo Leitner) [1206474] {CVE-2015-3212}
- [md] dm-cache-policy-smq: fix "default" version to be 1.4.0 (Mike Snitzer) [1236618]
- [of] Eliminate of_allnodes list (Gustavo Duarte) [1210533]
- [of] Fix sysfs_dirent cache integrity issue (Gustavo Duarte) [1225539]
- [powerpc] include: Add opal-prd to installed uapi headers (Gustavo Duarte) [1234370]
- [powerpc] powernv: fix construction of opal PRD messages (Gustavo Duarte) [1234370]
- [infiniband] mad: Add final OPA MAD processing (Honggang Li) [1229265]
- [infiniband] mad: Add partial Intel OPA MAD support (Honggang Li) [1229265]
- [infiniband] mad: Add partial Intel OPA MAD support (Honggang Li) [1229265]
- [infiniband] core: Add OPA MAD core capability flag (Honggang Li) [1229265]
- [infiniband] mad: Add support for additional MAD info to/from drivers (Honggang Li) [1229265]
- [infiniband] mad: Convert allocations from kmem_cache to kzalloc (Honggang Li) [1229265]
- [infiniband] core: Add ability for drivers to report an alternate MAD size (Honggang Li) [1229265]
- [infiniband] mad: Support alternate Base Versions when creating MADs (Honggang Li) [1229265]
- [infiniband] mad: Create a generic helper for DR forwarding checks (Honggang Li) [1229265]
- [infiniband] mad: Create a generic helper for DR SMP Recv processing (Honggang Li) [1229265]
- [infiniband] mad: Create a generic helper for DR SMP Send processing (Honggang Li) [1229265]
- [infiniband] mad: Split IB SMI handling from MAD Recv handler (Honggang Li) [1229265]
- [infiniband] mad cleanup: Generalize processing of MAD data (Honggang Li) [1229265]
- [infiniband] mad cleanup: Clean up function params -- find_mad_agent (Honggang Li) [1229265]
- [infiniband] ocrdma: fix double free on pd (Honggang Li) [1229265]
- [infiniband] usnic: clean up some error handling code (Honggang Li) [1229265]
- [infiniband] mthca: use swap() in mthca_make_profile() (Honggang Li) [1229265]
- [infiniband] core: Don't warn on no SA support in event handler (Honggang Li) [1229265]
- [infiniband] core: Don't advertise SA in RoCE port capabilities (Honggang Li) [1229265]
- [infiniband] core cleanup: Add const to args - agent_send_response (Honggang Li) [1229265]
- [infiniband] core cleanup: Add const on args - device->process_mad (Honggang Li) [1229265]
- [infiniband] core cleanup: Add const to RDMA helpers (Honggang Li) [1229265]
- [infiniband] ocrdma: Fix memory leak in _ocrdma_alloc_pd() (Honggang Li) [1229265]
- [net] rds: re-entry of rds_ib_xmit/rds_iw_xmit (Honggang Li) [1229265]
- [infiniband] ipoib: Fix RCU annotations in ipoib_neigh_hash_init() (Honggang Li) [1229265]
- [infiniband] nes: Enable the use of the tos field in the nes driver (Honggang Li) [1229265]
- [infiniband] iw_cm: Export tos field to iwarp providers (Honggang Li) [1229265]
- [infiniband] core: Change rdma_protocol_iboe to roce (Honggang Li) [1229265]
- [infiniband] core: Convert core to use bitfield for caps (Honggang Li) [1229265]
- [infiniband] core: Add per port immutable struct to ib_device (Honggang Li) [1229265]
- [infiniband] user_mad: Fix buggy usage of port index (Honggang Li) [1229265]
- [infiniband] user_mad: Use new start/end port functions (Honggang Li) [1229265]
- [infiniband] mad: Add const qualifiers to query only functions (Honggang Li) [1229265]
- [infiniband] mad: Clean up rcv_has_same_class (Honggang Li) [1229265]
- [infiniband] mad: Change ib_response_mad signature arguments (Honggang Li) [1229265]
- [infiniband] mad: Change validate_mad signature arguments (Honggang Li) [1229265]
- [net] rds: Switch to generic logging helpers (Honggang Li) [1229265]
- [infiniband] core, cma: Nice log-friendly string helpers (Honggang Li) [1229265]
- [infiniband] mad: Clean up comments in smi.c (Honggang Li) [1229265]
- [infiniband] mad: Rename is_data_mad to is_rmpp_data_mad (Honggang Li) [1229265]
- [infiniband] core: Create common start/end port functions (Honggang Li) [1229265]
- [infiniband] verbs: Improve docs for rdma-helpers (Honggang Li) [1229265]
- [infiniband] verbs: Use management helper rdma_cap_eth_ah() (Honggang Li) [1229265]
- [infiniband] verbs: Use management helper rdma_cap_af_ib() (Honggang Li) [1229265]
- [infiniband] verbs: Use management helper rdma_cap_read_multi_sge() (Honggang Li) [1229265]
- [infiniband] verbs: Use management helper rdma_cap_ib_mcast() (Honggang Li) [1229265]
- [infiniband] verbs: Use management helper rdma_cap_ib_sa() (Honggang Li) [1229265]
- [infiniband] verbs: Use management helper rdma_cap_iw_cm() (Honggang Li) [1229265]
- [infiniband] verbs: Use management helper rdma_cap_ib_cm() (Honggang Li) [1229265]
- [infiniband] verbs: Use management helper rdma_cap_ib_smi() (Honggang Li) [1229265]
- [infiniband] verbs: Use management helper rdma_cap_ib_mad() (Honggang Li) [1229265]
- [infiniband] verbs: Reform rest part in IB-core cma (Honggang Li) [1229265]
- [infiniband] verbs: Reform cma_acquire_dev() (Honggang Li) [1229265]
- [infiniband] verbs: Reform mcast related part in IB-core cma (Honggang Li) [1229265]
- [infiniband] verbs: Reform route related part in IB-core cma (Honggang Li) [1229265]
- [infiniband] verbs: Reform cm related part in IB-core cma/ucm (Honggang Li) [1229265]
- [infiniband] verbs: Reform IB-core verbs (Honggang Li) [1229265]
- [infiniband] verbs: Reform IB-ulp xprtrdma (Honggang Li) [1229265]
- [infiniband] verbs: Reform IB-ulp ipoib (Honggang Li) [1229265]
- [infiniband] verbs: Reform IB-core multicast (Honggang Li) [1229265]
- [infiniband] verbs: Reform IB-core sa_query (Honggang Li) [1229265]
- [infiniband] verbs: Reform IB-core cm (Honggang Li) [1229265]
- [infiniband] verbs: Reform IB-core mad/agent/user_mad (Honggang Li) [1229265]
- [infiniband] verbs: Implement raw management helpers (Honggang Li) [1229265]
- [infiniband] verbs: Implement new callback query_protocol() (Honggang Li) [1229265]

* Sun Jun 28 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-287.el7]
- [powerpc] misc: cxl: Add tracepoints (Gustavo Duarte) [1223004]
- [powerpc] cxl: Enable CAPP recovery (Gustavo Duarte) [1223004]
- [powerpc] cxl: Add missing return statement after handling AFU errror (Gustavo Duarte) [1223004]
- [powerpc] cxl: Fail AFU initialisation if an invalid configuration record is found (Gustavo Duarte) [1223004]
- [powerpc] cxl: Export optional AFU configuration record in sysfs (Gustavo Duarte) [1223004]
- [powerpc] cxl: Fix device_node reference counting (Gustavo Duarte) [1223004]
- [powerpc] cxl: Add ability to reset the card (Gustavo Duarte) [1223004]
- [powerpc] cxl: Use image state defaults for reloading FPGA (Gustavo Duarte) [1223004]
- [powerpc] cxl: Add image control to sysfs (Gustavo Duarte) [1223004]
- [powerpc] cxl: Update CXL ABI documentation (Gustavo Duarte) [1223004]
- [powerpc] cxl: remove redundant increment of hwirq (Gustavo Duarte) [1223004]
- [powerpc] cxl: Fix issues when unmapping contexts (Gustavo Duarte) [1223004]
- [powerpc] cxl: Disable SPAP register when freeing SPA (Gustavo Duarte) [1223004]
- [powerpc] cxl: Disable AFU debug flag (Gustavo Duarte) [1223004]
- [powerpc] cxl: Early return from cxl_handle_fault for a shut down context (Gustavo Duarte) [1223004]
- [powerpc] cxl: Fix leaking interrupts if attach process fails (Gustavo Duarte) [1223004]
- [powerpc] cxl: Unmap MMIO regions when detaching a context (Gustavo Duarte) [1223004]
- [powerpc] cxl: Add timeout to process element commands (Gustavo Duarte) [1223004]
- [powerpc] cxl: Change contexts_lock to a mutex to fix sleep while atomic bug (Gustavo Duarte) [1223004]
- [powerpc] mm: don't do tlbie for updatepp request with NO HPTE fault (Gustavo Duarte) [1223004]
- [powerpc] cxl: Name interrupts in /proc/interrupt (Gustavo Duarte) [1223004]
- [powerpc] cxl: Return error to PSL if IRQ demultiplexing fails & print clearer warning (Gustavo Duarte) [1223004]
- [powerpc] cxl: Fix PSL error due to duplicate segment table entries (Gustavo Duarte) [1223004]
- [powerpc] cxl: Refactor cxl_load_segment() and find_free_sste() (Gustavo Duarte) [1223004]
- [powerpc] cxl: Disable secondary hash in segment table (Gustavo Duarte) [1223004]
- [powerpc] cxl: Fix afu_read() not doing finish_wait() on signal or non-blocking (Gustavo Duarte) [1223004]
- [kernel] idr: Add new function idr_is_empty() (Gustavo Duarte) [1182022]
- [kernel] idr: remove unused prototype of idr_free() (Gustavo Duarte) [1182022]
- [misc] cxl: Add documentation for userspace APIs (Gustavo Duarte) [1182022]
- [misc] cxl: Add driver to Kbuild and Makefiles (Gustavo Duarte) [1182022]
- [misc] cxl: Add userspace header file (Gustavo Duarte) [1182022]
- [misc] cxl: Driver code for powernv PCIe based cards for userspace access (Gustavo Duarte) [1182022]
- [misc] cxl: Add base builtin support (Gustavo Duarte) [1182022]
- [powerpc] mm: Add hooks for cxl (Gustavo Duarte) [1182022]
- [powerpc] opal: Add PHB to cxl mode call (Gustavo Duarte) [1182022]
- [powerpc] mm: Add new hash_page_mm() (Gustavo Duarte) [1182022]
- [powerpc] Add new PCIe functions for allocating cxl interrupts (Gustavo Duarte) [1182022]
- [powerpc] cxl: Add new header for call backs and structs (Gustavo Duarte) [1182022]
- [powerpc] powernv: Split out set MSI IRQ chip code (Gustavo Duarte) [1182022]
- [powerpc] mm: Export mmu_kernel_ssize and mmu_linear_psize (Gustavo Duarte) [1182022]
- [powerpc] msi: Improve IRQ bitmap allocator (Gustavo Duarte) [1182022]
- [powerpc] cell: Make spu_flush_all_slbs() generic (Gustavo Duarte) [1182022]
- [powerpc] cell: Move data segment faulting code out of cell platform (Gustavo Duarte) [1182022]
- [powerpc] cell: Move spu_handle_mm_fault() out of cell platform (Gustavo Duarte) [1182022]
- [scsi] qla2xxx: Update the driver version to 8.07.00.18.07.2-k (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Restore physical port WWPN only, when port down detected for FA-WWPN port (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Fix virtual port configuration, when switch port is disabled/enabled (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Prevent multiple firmware dump collection for ISP27XX (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Disable Interrupt handshake for ISP27XX (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add debugging info for MBX timeout (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add serdes read/write support for ISP27XX (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add udev notification to save fw dump for ISP27XX (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add message for sucessful FW dump collected for ISP27XX (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add support to load firmware from file for ISP 26XX/27XX (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Fix beacon blink for ISP27XX (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Increase the wait time for firmware to be ready for P3P (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Fix crash due to wrong casting of reg for ISP27XX (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Fix warnings reported by static checker (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Fix printks in ql_log message (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Fix printk in qla25xx_setup_mode (Chad Dupuis) [1187302]
- [scsi] qla2xxx: fix busy wait regression (Chad Dupuis) [1187302]
- [scsi] qla2xxx: fix race in handling rport deletion during recovery causes panic (Chad Dupuis) [1187302]
- [scsi] qla2xxx: remove redundant declaration in 'qla_gbl.h' (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Increase room in request queue for sending priority packets (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Fix sparse warning in qla_iocb.c file (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Move warning message to debug level (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Fail adapter initialization on load ram failure (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Mark port lost when we receive an RSCN for it (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Restore WWPN in case of Loop Dead (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Honor FCP_RSP retry delay timer field (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add missing ISP27xx checks to optrom code (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Force use of mailbox interface for flash access commands for ISP27xx (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Free sysfs attributes for ISP27xx (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Disable laser for ISP2031 while unloading driver (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Enable diagnostic port using NVRAM parameters (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Declaration error cause stack corruption (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add fix in driver unload for pending activity (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Unload of qla2xxx driver crashes the machine (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Allow user to change ql2xfdmienable value (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Fix driver version string message (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add diagnostic port functionality (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add FA-WWN functionality (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add FDMI-2 functionality (Chad Dupuis) [1187302]
- [scsi] qla2xxx: ISPFx00 unexpected resets during adapter boot sequence (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Incorrect linked list semantic in qlafx00_get_fcport() (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Incorrect debug level on mailbox command print 0x1111 (Chad Dupuis) [1187302]
- [scsi] qla2xxx: ISPFX00 avoid writing semaphore register in request_irqs() (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Fix potential return count bug in qla2xxx_get_vpd_field() (Chad Dupuis) [1187302]
- [scsi] qla2xxx: ISP27xx fwdump template error print simplification (Chad Dupuis) [1187302]
- [scsi] qla2xxx: ISP25xx multiqueue shadow register crash fix (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add endianizer to max_payload_size modifier (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Enable fast flash access for ISP83xx (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add ISP27xx fwdump template entry T275 (insert buffer) (Chad Dupuis) [1187302]
- [scsi] qla2xxx: ISP27xx fwdump template fix insertbuf() routine (Chad Dupuis) [1187302]
- [scsi] qla2xxx: ISP27xx fwdump template remove high frequency debug logs (Chad Dupuis) [1187302]
- [scsi] qla2xxx: ISP27xx optimize fwdump entry table lookup (Chad Dupuis) [1187302]
- [scsi] qla2xxx: ISP27xx add tests for incomplete template (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Remove restriction on starting remote device discovery on port update (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Use pci_enable_msix_range() instead of pci_enable_msix() (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Use dma_zalloc_coherent (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Restrict max_lun to 16-bit for older HBAs (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Use kmemdup instead of kmalloc + memcpy (Chad Dupuis) [1187302]
- [scsi] qla2xxx: fix incorrect debug printk (Chad Dupuis) [1187302]
- [scsi] qla2xxx: ISP27xx queue index shadow registers (Chad Dupuis) [1187302]
- [scsi] qla2xxx: ISP27xx firmware dump template spec updates (including T274) (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Update entry type 270 to match spec update (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Correction to ISP27xx template entry types 256 and 258 (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add pci device id 0x2271 (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Correct ISP83xx/ISP27xx mislogic in setting out_mb in qla25xx_init_req_que() (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Allow ISP83XX and ISP27XX both to write req_q_out register (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Correct operations for ISP27xx template types 270 and 271 (Chad Dupuis) [1187302]
- [scsi] qla2xxx: Add support for ISP2071 (Chad Dupuis) [1187302]

* Sun Jun 28 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-286.el7]
- [usb] host: xhci: add mutex for non-thread-safe data (Don Zickus) [1232920]
- [usb] make module xhci_hcd removable (Don Zickus) [1232920]
- [usb] serial: ftdi_sio: Add support for a Motion Tracker Development Board (Don Zickus) [1232920]
- [usb] usb-storage: Add NO_WP_DETECT quirk for Lacie 059f:0651 devices (Don Zickus) [1232920]
- [usb] Added another USB product ID for ELAN touchscreen quirks (Don Zickus) [1232920]
- [usb] xhci: gracefully handle xhci_irq dead device (Don Zickus) [1232920]
- [usb] xhci: Solve full event ring by increasing TRBS_PER_SEGMENT to 256 (Don Zickus) [1232920]
- [usb] xhci: fix isoc endpoint dequeue from advancing too far on transaction error (Don Zickus) [1232920]
- [usb] visor: Match I330 phone more precisely (Don Zickus) [1232920]
- [usb] pl2303: Remove support for Samsung I330 (Don Zickus) [1232920]
- [usb] cdc-acm: prevent infinite loop when parsing CDC headers (Don Zickus) [1232920]
- [usb] uas: Set max_sectors_240 quirk for ASM1053 devices (Don Zickus) [1232920]
- [usb] uas: Add US_FL_MAX_SECTORS_240 flag (Don Zickus) [1232920]
- [usb] uas: Allow uas_use_uas_driver to return usb-storage flags (Don Zickus) [1232920]
- [usb] drivers/usb/core: devio.c: Removed an uneeded space before tab (Don Zickus) [1232920]
- [usb] core: hub: use new USB_RESUME_TIMEOUT (Don Zickus) [1232920]
- [usb] host: uhci: use new USB_RESUME_TIMEOUT (Don Zickus) [1232920]
- [usb] host: ehci: use new USB_RESUME_TIMEOUT (Don Zickus) [1232920]
- [usb] host: xhci: use new USB_RESUME_TIMEOUT (Don Zickus) [1232920]
- [usb] define a generic USB_RESUME_TIMEOUT macro (Don Zickus) [1232920]
- [usb] tracing: Add TRACE_SYSTEM_VAR to xhci-hcd (Don Zickus) [1232920]
- [usb] ehci-hub: use USB_DT_HUB (Don Zickus) [1232920]
- [usb] fhci-hub: use USB_DT_HUB (Don Zickus) [1232920]
- [usb] ohci-hub: use USB_DT_HUB (Don Zickus) [1232920]
- [usb] uhci-hub: use USB_DT_HUB (Don Zickus) [1232920]
- [usb] wusbcore: rh: use USB_DT_HUB (Don Zickus) [1232920]
- [usb] usb/misc: fix chaoskey build, needs HW_RANDOM (Don Zickus) [1232920]
- [usb] Fix warnings in chaoskey driver (Don Zickus) [1232920]
- [usb] cdc-wdm: error returns need to be translated (Don Zickus) [1232920]
- [usb] cdc-wdm: fix endianness bug in debug statements (Don Zickus) [1232920]
- [usb] cdc-wdm: unify error handling in write (Don Zickus) [1232920]
- [usb] cdc-acm: convert to not directly using urb->status (Don Zickus) [1232920]
- [usb] cdc-acm: surpress misleading message (Don Zickus) [1232920]
- [usb] cdc-acm: fix race between callback and unthrottle (Don Zickus) [1232920]
- [usb] usb/misc/usb3503: Always read refclk frequency from DT (Don Zickus) [1232920]
- [usb] cdc-wdm: return correct error codes (Don Zickus) [1232920]
- [usb] Move usb_disabled() towards top of the file (Don Zickus) [1232920]
- [usb] Use usb_disabled() consistently (Don Zickus) [1232920]
- [usb] Add driver for Altus Metrum ChaosKey device (v2) (Don Zickus) [1232920]
- [usb] ftdi_sio: Use jtag quirk for SNAP Connect E10 (Don Zickus) [1232920]
- [usb] xhci: apply XHCI_AVOID_BEI quirk to all Intel xHCI controllers (Don Zickus) [1232920]
- [usb] xhci: handle Config Error Change (CEC) in xhci driver (Don Zickus) [1232920]
- [usb] keyspan_pda: add new device id (Don Zickus) [1232920]
- [usb] storage: Fix trivial typo in isd200_log_config() (Don Zickus) [1232920]
- [usb] drivers: usb: storage: cypress_atacb.c: trivial checkpatch fixes (Don Zickus) [1232920]
- [usb] drivers: usb: storage: alauda.c: properly place braces after function declarations (Don Zickus) [1232920]
- [usb] appledisplay: Deletion of a check before backlight_device_unregister() (Don Zickus) [1232920]
- [usb] ueagle-atm: Delete unnecessary checks before the function call "release_firmware" (Don Zickus) [1232920]
- [usb] whci-hcd: Delete an unnecessary check before the function call "usb_put_hcd" (Don Zickus) [1232920]
- [usb] xhci: plat: Add USB phy support (Don Zickus) [1232920]
- [usb] xhci: unify cycle state toggling operation with 'XOR' (Don Zickus) [1232920]
- [usb] legotower: use msecs_to_jiffies for time conversion (Don Zickus) [1232920]
- [usb] image: use msecs_to_jiffies for time conversion (Don Zickus) [1232920]
- [usb] uas: Add US_FL_NO_ATA_1X for Initio Corporation controllers / devices (Don Zickus) [1232920]
- [usb] ftdi_sio: Added custom PID for Synapse Wireless product (Don Zickus) [1232920]
- [usb] revert "xhci: Clear the host side toggle manually when endpoint is 'soft reset'" (Don Zickus) [1232920]
- [usb] serial: fix infinite wait_until_sent timeout (Don Zickus) [1232920]
- [usb] xhci: Workaround for PME stuck issues in Intel xhci (Don Zickus) [1232920]
- [usb] xhci: fix reporting of 0-sized URBs in control endpoint (Don Zickus) [1232920]
- [usb] ch341: set tty baud speed according to tty struct (Don Zickus) [1232920]
- [usb] serial: cp210x: Adding Seletek device id's (Don Zickus) [1232920]
- [usb] ch341: remove redundant close from open error path (Don Zickus) [1232920]
- [usb] pl2303: disable break on shutdown (Don Zickus) [1232920]
- [usb] serial: clean up bus probe error handling (Don Zickus) [1232920]
- [usb] serial: fix port attribute-creation race (Don Zickus) [1232920]
- [usb] serial: fix tty-device error handling at probe (Don Zickus) [1232920]
- [usb] serial: fix potential use-after-free after failed probe (Don Zickus) [1232920]
- [usb] console: add dummy __module_get (Don Zickus) [1232920]
- [usb] revert "usb: serial: make bulk_out_size a lower limit" (Don Zickus) [1232920]
- [usb] cdc-acm: Add support for Denso cradle CU-321 (Don Zickus) [1232920]
- [usb] usb-storage: support for more than 8 LUNs (Don Zickus) [1232920]
- [usb] uas: Add US_FL_NO_REPORT_OPCODES for JMicron JMS539 (Don Zickus) [1232920]
- [usb] usbfs: don't leak kernel data in siginfo (Don Zickus) [1232920]
- [usb] xhci: Clear the host side toggle manually when endpoint is 'soft reset' (Don Zickus) [1232920]
- [usb] xhci: Allocate correct amount of scratchpad buffers (Don Zickus) [1232920]
- [usb] Retry port status check on resume to work around RH bugs (Don Zickus) [1232920]
- [usb] revert "usb: Reset USB-3 devices on USB-3 link bounce" (Don Zickus) [1232920]
- [usb] uhci-hub: use HUB_CHAR_* (Don Zickus) [1232920]
- [usb] kconfig: replace PPC_OF with PPC (Don Zickus) [1232920]
- [usb] ehci-pci: disable for Intel MID platforms (update) (Don Zickus) [1232920]
- [usb] ehci-pci: disable for Intel MID platforms (Don Zickus) [1232920]
- [usb] ehci-pci: USB host controller support for Intel Quark X1000 (Don Zickus) [1232920]
- [usb] host: pci_quirks: joing string literals (Don Zickus) [1232920]
- [usb] add flag for HCDs that can't receive wakeup requests (isp1760-hcd) (Don Zickus) [1232920]
- [usb] usbfs: allow URBs to be reaped after disconnection (Don Zickus) [1232920]
- [usb] cdc-acm: kill unnecessary messages (Don Zickus) [1232920]
- [usb] cdc-acm: add sanity checks (Don Zickus) [1232920]
- [usb] Add OTG PET device to TPL (Don Zickus) [1232920]
- [usb] usb-storage/scsi: blacklist FUA on JMicron 152d:2566 USB-SATA controller (Don Zickus) [1232920]
- [usb] uas: Add no-report-opcodes quirk for Simpletech devices with id 4971:8017 (Don Zickus) [1232920]
- [usb] storage: Revise/fix quirk for 04E6:000F SCM USB-SCSI converter (Don Zickus) [1232920]
- [usb] core: hub: modify hub reset logic in hub driver (Don Zickus) [1232920]
- [usb] wusbcore: rh: use HUB_CHAR_* (Don Zickus) [1232920]
- [usb] ohci-hub: use HUB_CHAR_* (Don Zickus) [1232920]
- [usb] ehci-hub: use HUB_CHAR_* (Don Zickus) [1232920]
- [usb] xhci: Silence "xHCI xhci_drop_endpoint called with disabled ep ..." messages (Don Zickus) [1232920]
- [usb] xhci: Print hcc params, version and quirks on init (Don Zickus) [1232920]
- [usb] don't cancel queued resets when unbinding drivers (Don Zickus) [1232920]
- [usb] Fix typo in `struct usb_host_interface' comment (Don Zickus) [1232920]
- [usb] mos7840: remove unused code (Don Zickus) [1232920]
- [usb] option: clean up blacklist handling (Don Zickus) [1232920]
- [usb] serial: handle -ENODEV quietly in generic_submit_read_urb (Don Zickus) [1232920]
- [usb] serial: silence all non-critical read errors (Don Zickus) [1232920]
- [usb] console: fix potential use after free (Don Zickus) [1232920]
- [usb] console: fix uninitialised ldisc semaphore (Don Zickus) [1232920]
- [usb] ohci: add a quirk for ULi M5237 blocking on reset (Don Zickus) [1232920]
- [usb] use *ph specifier in uss720 driver (Don Zickus) [1232920]
- [usb] use *ph specifier in mikrotek driver (Don Zickus) [1232920]
- [usb] core: buffer: smallest buffer should start at ARCH_DMA_MINALIGN (Don Zickus) [1232920]
- [usb] xhci: Add completion code to the debug ouput of unhandled transfer events (Don Zickus) [1232920]
- [usb] xhci: clean up work to remove unused parameters for functions in xhci-mem.c (Don Zickus) [1232920]
- [usb] xhci-mem: Use setup_timer (Don Zickus) [1232920]
- [usb] xhci: Use setup_timer (Don Zickus) [1232920]
- [usb] xhci: remove unused parameter 'xhci' in function xhci_handshake() (Don Zickus) [1232920]
- [usb] xhci: Clean up work to xhci_add_endpoint() (Don Zickus) [1232920]
- [usb] uas: Add US_FL_NO_ATA_1X for 2 more Seagate disk enclosures (Don Zickus) [1232920]
- [usb] uas: Do not blacklist ASM1153 disk enclosures (Don Zickus) [1232920]
- [usb] uas: disable UAS on Apricorn SATA dongles (Don Zickus) [1232920]
- [usb] uas: Add US_FL_NO_REPORT_OPCODES for JMicron JMS566 with usb-id 0bc2:a013 (Don Zickus) [1232920]
- [usb] uas: Add US_FL_NO_ATA_1X for Seagate devices with usb-id 0bc2:a013 (Don Zickus) [1232920]
- [usb] xhci: Add broken-streams quirk for Fresco Logic FL1000G xhci controllers (Don Zickus) [1232920]
- [usb] ehci: adjust error return code (Don Zickus) [1232920]
- [usb] ehci: fix initialization bug in iso_stream_schedule() (Don Zickus) [1232920]
- [usb] xhci: Check if slot is already in default state before moving it there (Don Zickus) [1232920]
- [usb] qcserial/option: make AT URCs work for Sierra Wireless MC73xx (Don Zickus) [1232920]
- [usb] keyspan: fix null-deref at probe (Don Zickus) [1232920]
- [usb] mos7720: delete some unneeded code (Don Zickus) [1232920]
- [usb] wusb: replace memset by memzero_explicit (Don Zickus) [1232920]
- [usb] xhci: fix comment for PORT_DEV_REMOVE (Don Zickus) [1232920]
- [usb] xhci: don't use the same variable for stopped and halted rings current TD (Don Zickus) [1232920]
- [usb] xhci: clear extra bits from slot context when setting max exit latency (Don Zickus) [1232920]
- [usb] xhci: cleanup finish_td function (Don Zickus) [1232920]
- [usb] adutux: NULL dereferences on disconnect (Don Zickus) [1232920]
- [usb] pci-quirks: Deletion of unnecessary checks before the function call "pci_dev_put" (Don Zickus) [1232920]
- [usb] usb-sis: Deletion of an unnecessary check before the function call "usb_put_dev" (Don Zickus) [1232920]
- [usb] storage: Fix bus scan and multi-LUN support for SCM eUSCSI devices (Don Zickus) [1232920]
- [usb] storage: Enable multi-target mode as vendor driver does for SCM eUSCSI bridge (Don Zickus) [1232920]
- [usb] cdc-acm: check for valid interfaces (Don Zickus) [1232920]
- [usb] cdc-acm: memory leak in error case (Don Zickus) [1232920]
- [usb] usb-quirks: Add reset-resume quirk for MS Wireless Laser Mouse 6000 (Don Zickus) [1232920]
- [usb] xhci: rework root port wake bits if controller isn't allowed to wakeup (Don Zickus) [1232920]
- [usb] xhci: Reset a halted endpoint immediately when we encounter a stall (Don Zickus) [1232920]
- [usb] revert "xhci: clear root port wake on bits if controller isn't wake-up capable" (Don Zickus) [1232920]
- [usb] xhci: don't start a halted endpoint before its new dequeue is set (Don Zickus) [1232920]
- [usb] ssu100: fix overrun-error reporting (Don Zickus) [1232920]
- [usb] keyspan: fix overrun-error reporting (Don Zickus) [1232920]
- [usb] keyspan: fix tty line-status reporting (Don Zickus) [1232920]
- [usb] qcserial: Add support for HP lt4112 LTE/HSPA+ Gobi 4G Modem (Don Zickus) [1232920]
- [usb] serial: ftdi_sio: add PIDs for Matrix Orbital products (Don Zickus) [1232920]
- [usb] phonet: Replace calls to __skb_alloc_page with __dev_alloc_page (Don Zickus) [1232920]
- [usb] serial: cp210x: add IDs for CEL MeshConnect USB Stick (Don Zickus) [1232920]
- [usb] Remove __init from early_dbgp_init() prototype (Don Zickus) [1232920]
- [usb] Create separate header for ehci-dbgp (Don Zickus) [1232920]
- [usb] host: xhci-plat: remove duplicate check on resource (Don Zickus) [1232920]
- [usb] host: uhci-platform: fix NULL pointer dereference on resource (Don Zickus) [1232920]
- [usb] storage: Reject bogus max LUN values (Don Zickus) [1232920]
- [usb] cdc-acm: add quirk for control-line state requests (Don Zickus) [1232920]
- [usb] storage: Fix timeout in usb_stor_euscsi_init() and usb_stor_huawei_e220_init() (Don Zickus) [1232920]
- [usb] cdc-acm: only raise DTR on transitions from B0 (Don Zickus) [1232920]
- [usb] revert "storage: Replace magic number with define in usb_stor_euscsi_init()" (Don Zickus) [1232920]
- [usb] serial: add Google simple serial SubClass support (Don Zickus) [1232920]
- [usb] uas: Add US_FL_NO_ATA_1X quirk for 2 more Seagate models (Don Zickus) [1232920]
- [usb] xhci: no switching back on non-ULT Haswell (Don Zickus) [1232920]
- [usb] misc: usb3503: delete unnecessary 'out of memory' messages (Don Zickus) [1232920]
- [usb] class: usbtmc: delete unnecessary 'out of memory' messages (Don Zickus) [1232920]
- [usb] ehci/ohci-platform: use SIMPLE_DEV_PM_OPS to support hibernation (Don Zickus) [1232920]
- [usb] hub: remove unused variable (Don Zickus) [1232920]
- [usb] storage: Convert usb_stor_dbg to return void (Don Zickus) [1232920]
- [usb] ohci: Eliminate platform-specific test in ohci.h (Don Zickus) [1232920]
- [usb] ehci: add ehci_port_power interface (Don Zickus) [1232920]
- [usb] uas: Make uas work with blk-mq (Don Zickus) [1232920]
- [usb] yurex: fixed sparse warning of incorrect type (Don Zickus) [1232920]
- [usb] Do not re-read descriptors for wired devices in usb_authorize_device() (Don Zickus) [1232920]
- [usb] cdc-acm: Drop the warning for unusual capabilities (Don Zickus) [1232920]
- [usb] quirks: enable device-qualifier quirk for yet another Elan touchscreen (Don Zickus) [1232920]
- [usb] quirks: enable device-qualifier quirk for another Elan touchscreen (Don Zickus) [1232920]
- [usb] storage: fix build warnings !CONFIG_PM (Don Zickus) [1232920]
- [usb] uas: Add NO_ATA_1X for VIA VL711 devices (Don Zickus) [1232920]
- [usb] xhci: Disable streams on Asmedia 1042 xhci controllers (Don Zickus) [1232920]
- [usb] hwa: fix a warning message (Don Zickus) [1232920]
- [usb] uas: Add US_FL_NO_ATA_1X quirk for 1 more Seagate model (Don Zickus) [1232920]
- [usb] usb-storage: handle a skipped data phase (Don Zickus) [1232920]
- [usb] Do not allow usb_alloc_streams on unconfigured devices (Don Zickus) [1232920]
- [usb] cdc-acm: ensure that termios get set when the port is activated (Don Zickus) [1232920]
- [usb] cdc-acm: add device id for GW Instek AFG-2225 (Don Zickus) [1232920]
- [usb] mos7840: replace unnecessary atomic allocations (Don Zickus) [1232920]
- [usb] mos7720: replace unnecessary atomic allocations (Don Zickus) [1232920]
- [usb] kobil_sct: replace unnecessary atomic allocation (Don Zickus) [1232920]
- [usb] opticon: fix non-atomic allocation in write path (Don Zickus) [1232920]
- [usb] kobil_sct: fix non-atomic allocation in write path (Don Zickus) [1232920]
- [usb] Fix typo in usb-serial-simple.c (Don Zickus) [1232920]
- [usb] usbnet: add a callback for set_rx_mode (Don Zickus) [1232920]
- [usb] serial: ftdi_sio: add "bricked" FTDI device PID (Don Zickus) [1232920]
- [usb] serial: keyspan_pda: fix Entrega company name spelling (Don Zickus) [1232920]
- [usb] kobil_sct: Remove unused transfer buffer allocs (Don Zickus) [1232920]
- [usb] option: add Haier CE81B CDMA modem (Don Zickus) [1232920]
- [usb] option: add support for Telit LE910 (Don Zickus) [1232920]
- [usb] serial: ftdi_sio: add Awinda Station and Dongle products (Don Zickus) [1232920]
- [usb] serial: cp210x: add Silicon Labs 358x VID and PID (Don Zickus) [1232920]
- [usb] misc: drop owner assignment from platform_drivers (Don Zickus) [1232920]
- [usb] uas: Reduce number of function arguments for uas_alloc_foo functions (Don Zickus) [1232920]
- [usb] xhci: Allow xHCI drivers to be built as separate modules (Don Zickus) [1232920]
- [usb] xhci: Export symbols used by host-controller drivers (Don Zickus) [1232920]
- [usb] xhci: Check for XHCI_COMP_MODE_QUIRK when disabling D3cold (Don Zickus) [1232920]
- [usb] xhci: Introduce xhci_init_driver() (Don Zickus) [1232920]
- [usb] uas: disable use of blk-mq I/O path (Don Zickus) [1232920]
- [usb] core: return -ENOTSUPP for all targeted hosts (Don Zickus) [1232920]
- [usb] Add LED triggers for USB activity (Don Zickus) [1232920]
- [usb] Rename usb-common.c (Don Zickus) [1232920]
- [usb] hub: allow to process more usb hub events in parallel (Don Zickus) [1232920]
- [usb] hub: rename khubd to hub_wq in documentation and comments (Don Zickus) [1232920]
- [usb] hub: rename usb_kick_khubd() to usb_kick_hub_wq() (Don Zickus) [1232920]
- [usb] hub: convert khubd into workqueue (Don Zickus) [1232920]
- [usb] hub: rename hub_events() to hub_event() and handle only one event there (Don Zickus) [1232920]
- [usb] hub: keep hub->dev reference all the time when struct usb_hub lives (Don Zickus) [1232920]
- [usb] storage: Add quirk for another SCM-based USB-SCSI converter (Don Zickus) [1232920]
- [usb] storage: Add quirks for Castlewood and Double-H USB-SCSI converters (Don Zickus) [1232920]
- [usb] storage: Replace magic number with define in usb_stor_euscsi_init() (Don Zickus) [1232920]
- [usb] quirks.h: use BIT() (Don Zickus) [1232920]
- [usb] Add device quirk for ASUS T100 Base Station keyboard (Don Zickus) [1232920]
- [usb] usb3503: clarify what the registers 'PDS' and 'CFG1' really do (Don Zickus) [1232920]
- [usb] usb3503: correct error message in probe ('connect' to 'interrupt') (Don Zickus) [1232920]
- [usb] Fixed a few typos (Don Zickus) [1232920]
- [usb] storage: use *ph specifier to dump small buffers (Don Zickus) [1232920]
- [usb] wusbcore: fix device disconnect on rekey timeout (Don Zickus) [1232920]
- [usb] wusbcore: skip done segs before completing aborted transfer (Don Zickus) [1232920]
- [usb] wusbcore: USB_WUSB_CBAF depends on USB (Don Zickus) [1232920]
- [usb] wusbcore: remove USB_WUSB build dependency on PCI (Don Zickus) [1232920]
- [usb] hwa: add USB build dependency for USB_HWA_HCD (Don Zickus) [1232920]
- [usb] wusb: delete double assignment (Don Zickus) [1232920]
- [usb] misc: yurex: remove useless casting of private_data (Don Zickus) [1232920]
- [usb] xhci: Log extra info on "ERROR Transfer event TRB DMA ptr not part of current TD" (Don Zickus) [1232920]
- [usb] xhci: Remove "FIXME - check all the stream rings for pending cancellations" (Don Zickus) [1232920]
- [usb] xhci: Always ring the doorbell for active eps when a Set TR deq ptr cmd completes (Don Zickus) [1232920]
- [usb] xhci: Fold queue_set_tr_deq into xhci_queue_new_dequeue_state (Don Zickus) [1232920]
- [usb] xhci: xhci_ring_device: Ring stream ring bells for endpoints with streams (Don Zickus) [1232920]
- [usb] xhci_suspend is not stopping the root hub timer for the shared HCD (Don Zickus) [1232920]
- [usb] xhci: Move allocating of command for new_dequeue_state to queue_set_tr_deq() (Don Zickus) [1232920]
- [usb] uas: Add response iu handling (Don Zickus) [1232920]
- [usb] uas: Log error codes when logging errors (Don Zickus) [1232920]
- [usb] uas: Cleanup uas_log_cmd_state usage (Don Zickus) [1232920]
- [usb] uas: Remove protype hardware usb interface info (Don Zickus) [1232920]
- [usb] uas: Remove support for old sense ui as used in pre-production hardware (Don Zickus) [1232920]
- [usb] uas: Drop COMMAND_COMPLETED flag (Don Zickus) [1232920]
- [usb] uas: Use scsi_print_command (Don Zickus) [1232920]
- [usb] uas: Do not log urb status error on cancellation (Don Zickus) [1232920]
- [usb] uas: Use streams on upcoming 10Gbps / 3.1 USB (Don Zickus) [1232920]
- [usb] uas: pre_reset and suspend: Fix a few races (Don Zickus) [1232920]
- [usb] uas: Fix memleak of non-submitted urbs (Don Zickus) [1232920]
- [usb] uas: Drop all references to a scsi_cmnd once it has been aborted (Don Zickus) [1232920]
- [usb] uas: Remove cmnd reference from the cmd urb (Don Zickus) [1232920]
- [usb] uas: Drop inflight list (Don Zickus) [1232920]
- [usb] uas: zap_pending: data urbs should have completed at this time (Don Zickus) [1232920]
- [usb] uas: Simplify reset / disconnect handling (Don Zickus) [1232920]
- [usb] uas: Free data urbs on completion (Don Zickus) [1232920]
- [usb] uas: Simplify unlink of data urbs on error (Don Zickus) [1232920]
- [usb] uas: Check against unexpected completions (Don Zickus) [1232920]
- [usb] uas: Do not use scsi_host_find_tag (Don Zickus) [1232920]
- [usb] uas: Add uas_get_tag() helper function (Don Zickus) [1232920]
- [usb] uas: Fix resetting flag handling (Don Zickus) [1232920]
- [usb] uas: Remove task-management / abort error handling code (Don Zickus) [1232920]
- [usb] uas: Add another ASM1051 usb-id to the uas blacklist (Don Zickus) [1232920]
- [usb] uas: Add US_FL_NO_ATA_1X quirk for Seagate (0bc2:ab20) drives (Don Zickus) [1232920]
- [usb] uas: Add no-report-opcodes quirk (Don Zickus) [1232920]
- [usb] uas: Add a quirk for rejecting ATA_12 and ATA_16 commands (Don Zickus) [1232920]
- [usb] document the 'u' flag for usb-storage quirks parameter (Don Zickus) [1232920]
- [usb] uas: replace WARN_ON_ONCE() with lockdep_assert_held() (Don Zickus) [1232920]
- [usb] host: ehci-st: Add EHCI support for ST STB devices (Don Zickus) [1232920]
- [usb] core: kconfig: TPL should apply for both OTG and EH (Don Zickus) [1232920]
- [usb] core: TPL should apply for both OTG and EH (Don Zickus) [1232920]
- [usb] hcd: add TPL support flag (Don Zickus) [1232920]
- [usb] serial: Remove unused tty->hw_stopped (Don Zickus) [1232920]
- [usb] quirks: enable device-qualifier quirk for Elan Touchscreen (Don Zickus) [1232920]
- [usb] core: add device-qualifier quirk (Don Zickus) [1232920]
- [usb] cp210x: add support for Seluxit USB dongle (Don Zickus) [1232920]
- [usb] serial: cp210x: added Ketra N1 wireless interface support (Don Zickus) [1232920]
- [usb] storage: Add quirks for Entrega/Xircom USB to SCSI converters (Don Zickus) [1232920]
- [usb] storage: Add quirk for Ariston Technologies iConnect USB to SCSI adapter (Don Zickus) [1232920]
- [usb] storage: Add quirk for Adaptec USBConnect 2000 USB-to-SCSI Adapter (Don Zickus) [1232920]
- [scsi] don't store LUN bits in CDB[1] for USB mass-storage devices (Don Zickus) [1232920]
- [usb] xhci: fix oops when xhci resumes from hibernate with hw lpm capable devices (Don Zickus) [1232920]
- [usb] xhci: Fix OOPS in xhci error handling code (Don Zickus) [1232920]
- [usb] xhci: Fix null pointer dereference if xhci initialization fails (Don Zickus) [1232920]
- [usb] storage: Add single-LUN quirk for Jaz USB Adapter (Don Zickus) [1232920]
- [usb] uas: Add missing le16_to_cpu calls to asm1051 / asm1053 usb-id check (Don Zickus) [1232920]
- [usb] uas: Disable uas on ASM1051 devices (Don Zickus) [1232920]
- [usb] bcma: store more alternative addresses (Don Zickus) [1232920]
- [usb] ftdi_sio: Add support for GE Healthcare Nemo Tracker device (Don Zickus) [1232920]
- [usb] host: xhci: fix compliance mode workaround (Don Zickus) [1232920]
- [usb] serial: xsens_mt: always bind to interface number 1 (Don Zickus) [1232920]
- [usb] serial: xsens_mt: add author and description (Don Zickus) [1232920]
- [usb] serial: add Medtronic CareLink USB driver (Don Zickus) [1232920]
- [usb] serial: add Novatel Wireless GPS driver (Don Zickus) [1232920]
- [usb] serial: add support for multi-port simple drivers (Don Zickus) [1232920]
- [usb] pl2303: use divisors for unsupported baud rates (Don Zickus) [1232920]
- [usb] sierra: add 1199:68AA device ID (Don Zickus) [1232920]
- [usb] sierra: avoid CDC class functions on "68A3" devices (Don Zickus) [1232920]
- [usb] ftdi_sio: add support for NOVITUS Bono E thermal printer (Don Zickus) [1232920]
- [usb] usbtest: Add interrupt EP testcases (Don Zickus) [1232920]
- [usb] fix build error with CONFIG_PM_RUNTIME disabled (Don Zickus) [1232920]
- [usb] xhci: Disable streams on Via XHCI with device-id 0x3432 (Don Zickus) [1232920]
- [usb] serial: fix potential heap buffer overflow (Don Zickus) [1232920]
- [usb] serial: fix potential stack buffer overflow (Don Zickus) [1232920]
- [usb] hub: Prevent hub autosuspend if usbcore.autosuspend is -1 (Don Zickus) [1232920]
- [usb] sisusb: add device id for Magic Control USB video (Don Zickus) [1232920]
- [usb] ehci: using wIndex + 1 for hub port (Don Zickus) [1232920]
- [usb] storage: add quirk for Newer Technology uSCSI SCSI-USB converter (Don Zickus) [1232920]
- [usb] wusbcore: fix below build warning (Don Zickus) [1232920]
- [usb] core: fix below build warning (Don Zickus) [1232920]
- [usb] xhci: rework cycle bit checking for new dequeue pointers (Don Zickus) [1232920]
- [usb] xhci: amd chipset also needs short TX quirk (Don Zickus) [1232920]
- [usb] xhci: Treat not finding the event_seg on COMP_STOP the same as COMP_STOP_INVAL (Don Zickus) [1232920]
- [usb] usbcore: Fix wrong device in an error message in hub_port_connect() (Don Zickus) [1232920]
- [usb] ftdi_sio: Added PID for new ekey device (Don Zickus) [1232920]
- [usb] serial: pl2303: add device id for ztek device (Don Zickus) [1232920]
- [usb] ftdi_sio: add Basic Micro ATOM Nano USB2Serial PID (Don Zickus) [1232920]
- [usb] revert "usb: option, zte_ev: move most ZTE CDMA devices to zte_ev" (Don Zickus) [1232920]
- [usb] option: add VIA Telecom CDS7 chipset device id (Don Zickus) [1232920]
- [usb] option: reduce interrupt-urb logging verbosity (Don Zickus) [1232920]
- [usb] cdc_subset: deal with a device that needs reset for timeout (Don Zickus) [1232920]
- [usb] devio: fix issue with log flooding (Don Zickus) [1232920]
- [usb] uas: Log a warning when we cannot use uas because the hcd lacks streams (Don Zickus) [1232920]
- [usb] uas: Only complain about missing sg if all other checks succeed (Don Zickus) [1232920]
- [usb] xhci: Add missing checks for xhci_alloc_command failure (Don Zickus) [1232920]
- [usb] xhci: Rename Asrock P67 pci product-id to EJ168 (Don Zickus) [1232920]
- [usb] xhci: Blacklist using streams on the Etron EJ168 controller (Don Zickus) [1232920]
- [usb] uas: Limit qdepth to 32 when connected over usb-2 (Don Zickus) [1232920]
- [usb] usb-core bInterval quirk (Don Zickus) [1232920]
- [usb] serial: ftdi_sio: Add support for new Xsens devices (Don Zickus) [1232920]
- [usb] serial: ftdi_sio: Annotate the current Xsens PID assignments (Don Zickus) [1232920]
- [usb] core: allow zero packet flag for interrupt urbs (Don Zickus) [1232920]
- [usb] lvstest: Fix sparse warnings generated by kbuild test bot (Don Zickus) [1232920]
- [usb] ohci: add check for stopped frame counter (Don Zickus) [1232920]
- [usb] ohci: add I/O watchdog for orphan TDs (Don Zickus) [1232920]
- [usb] ohci: make URB completions single-threaded (Don Zickus) [1232920]
- [usb] ohci: redesign the TD done list (Don Zickus) [1232920]
- [usb] ohci: no shortcut for unlinking URBS from a dead controller (Don Zickus) [1232920]
- [usb] ohci: revert the ZF Micro orphan-TD quirk (Don Zickus) [1232920]
- [usb] Fix persist resume of some SS USB devices (Don Zickus) [1232920]
- [usb] usb-core: Remove Fix mes in file hcd.c (Don Zickus) [1232920]
- [usb] usbcore: don't log on consecutive debounce failures of the same port (Don Zickus) [1232920]
- [usb] serial: cp210x: Removing unncessary `usb_reset_device` on startup (Don Zickus) [1232920]
- [usb] Add LVS Test device driver (Don Zickus) [1232920]
- [usb] Add EXPORT_SYMBOL for usb_alloc_dev (Don Zickus) [1232920]
- [usb] ohci: don't lose track of EDs when a controller dies (Don Zickus) [1232920]
- [usb] ohci: fix bugs in debug routines (Don Zickus) [1232920]
- [usb] ohci: add SG support (Don Zickus) [1232920]
- [usb] shutdown all URBs after controller death (Don Zickus) [1232920]
- [usb] add reset resume quirk for usb3503 (Don Zickus) [1232920]
- [usb] usb3503: add PM functions (Don Zickus) [1232920]
- [usb] uhci-platform: use devm_ioremap resource (Don Zickus) [1232920]
- [usb] ohci: don't allocate HCCA atomically (Don Zickus) [1232920]
- [usb] uhci: don't allocate frame list atomically (Don Zickus) [1232920]
- [usb] ehci: don't allocate hardware periodic table atomically by default (Don Zickus) [1232920]
- [usb] drivers/usb/host/fhci-dbg.c: remove unnecessary null test before debugfs_remove (Don Zickus) [1232920]
- [usb] class: usbtmc.c: Cleaning up uninitialized variables (Don Zickus) [1232920]
- [usb] host: xhci-plat: use devm_functions (Don Zickus) [1232920]
- [usb] xhci: make error messages grepable (Don Zickus) [1232920]
- [usb] force warm reset to break link re-connect livelock (Don Zickus) [1232920]
- [usb] allow lpm (en/dis)able only if device is atleast in default state (Don Zickus) [1232920]
- [usb] xhci: platform: Set xhci lpm support quirk based on platform data (Don Zickus) [1232920]
- [usb] documentation: dt-bindings: update xhci-platform DT binding (Don Zickus) [1232920]
- [usb] xhci: platform: Add (en/dis)able_usb3_lpm_timeout (Don Zickus) [1232920]
- [usb] xhci: A default implementation for Ux timeout calculation and tier policy check (Don Zickus) [1232920]
- [usb] kl5kusb105: Remove klsi_105_tiocmset function (Don Zickus) [1232920]
- [usb] mos7840: remove unnecessary null test before kfree (Don Zickus) [1232920]
- [usb] ftdi_sio: remove redundant mtxorb quirk (Don Zickus) [1232920]
- [usb] ftdi_sio: clean up ftdi_set_max_packet_size() (Don Zickus) [1232920]
- [usb] ftdi_sio: fix max-packet-size warning (Don Zickus) [1232920]
- [usb] ftdi_sio: make port probe less verbose (Don Zickus) [1232920]
- [usb] xhci: Correct last context entry calculation for Configure Endpoint (Don Zickus) [1232920]

* Fri Jun 26 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-285.el7]
- [x86] perf: Fix bug in unused code (Don Dugger) [1036948]
- [x86] Someone fat fingered a merge conflict and lost the Makefile hunk (Don Dugger) [1036948]
- [x86] perf: Enable conflicting event scheduling for CQM (Don Dugger) [1036948]
- [x86] perf: Perform rotation on Intel CQM RMIDs (Don Dugger) [1036948]
- [x86] perf: Implement LRU monitoring ID allocation for CQM (Don Dugger) [1036948]
- [x86] Add support for Intel Cache QoS Monitoring (CQM) detection (Don Dugger) [1036948]
- [x86] Mark Intel Broadwell-H processor as supported (Steve Best) [1131290]
- [kernel] sched/stop_machine: Fix deadlock between multiple stop_two_cpus() (Jiri Olsa) [1223796]
- [x86] edac: Disable EDAC debug logging by default (Prarit Bhargava) [1232712]
- [kernel] sched/clock: Fixup early initialization (Prarit Bhargava) [1234322]
- [kernel] sched/clock: Fix up clear_sched_clock_stable() (Prarit Bhargava) [1234322]
- [mm] memory-hotplug: set zone->wait_table to null after freeing it (Yasuaki Ishimatsu) [1222754]
- [mm] memory-hotplug: postpone the reset of obsolete pgdat (Yasuaki Ishimatsu) [1222754]
- [mm] memory-failure: me_huge_page() does nothing for thp (Tomoaki Nishimura) [1226196]
- [mm] soft-offline: don't free target page in successful page migration (Tomoaki Nishimura) [1226196]
- [mm] memory-failure: introduce get_hwpoison_page() for consistent refcount handling (Tomoaki Nishimura) [1226196]
- [mm] memory-failure: split thp earlier in memory error handling (Tomoaki Nishimura) [1226196]
- [mm] soft-offline: fix num_poisoned_pages counting on concurrent events (Tomoaki Nishimura) [1226196]
- [mm] hugetlb: cleanup using paeg_huge_active() (Tomoaki Nishimura) [1226196]
- [mm] hugetlb: introduce page_huge_active (Tomoaki Nishimura) [1226196]
- [mm] soft-offline: use migrate_pages() instead of migrate_huge_page() (Tomoaki Nishimura) [1226196]
- [mm] migrate: make core migration code aware of hugepage (Tomoaki Nishimura) [1226196]
- [mm] hwpoison: drop lru_add_drain_all() in __soft_offline_page() (Tomoaki Nishimura) [1226196]
- [mm] hwpoison-inject: check PageLRU of hpage (Tomoaki Nishimura) [1226196]
- [mm] hwpoison-inject: fix refcounting in no-injection case (Tomoaki Nishimura) [1226196]
- [mm] hwpoison: fix the lack of one reference count against poisoned page (Tomoaki Nishimura) [1226196]
- [mm] memory-failure: call shake_page() when error hits thp tail page (Tomoaki Nishimura) [1226196]
- [mm] hwpoison: fix race with changing page during offlining (Tomoaki Nishimura) [1226196]
- [mm] hwpoison: Fix wrong error recovery status (Tomoaki Nishimura) [1226196]
- [mm] hwpoison: call action_result() in failure path of hwpoison_user_mappings() (Tomoaki Nishimura) [1226196]
- [mm] hwpoison: fix hugetlbfs/thp precheck in hwpoison_user_mappings() (Tomoaki Nishimura) [1226196]
- [mm] hwpoison: fix the handling path of the victimized page frame that belong to non-LRU (Tomoaki Nishimura) [1226196]
- [mm] memory-failure: fix memory leak by race between poison and unpoison (Tomoaki Nishimura) [1226196]
- [mm] hwpoison: lock_page/unlock_page does not match for handling a free hugepage (Tomoaki Nishimura) [1226196]
- [mm] memory-failure: move refcount only in !MF_COUNT_INCREASED (Tomoaki Nishimura) [1226196]
- [infiniband] iser: Rewrite bounce buffer code path (Amir Vadai) [1164539]
- [infiniband] iser: Bump version to 1.6 (Amir Vadai) [1164539]
- [infiniband] iser: Remove code duplication for a single DMA entry (Amir Vadai) [1164539]
- [infiniband] iser: Pass struct iser_mem_reg to iser_fast_reg_mr and iser_reg_sig_mr (Amir Vadai) [1164539]
- [infiniband] iser: Modify struct iser_mem_reg members (Amir Vadai) [1164539]
- [infiniband] iser: Make fastreg pool cache friendly (Amir Vadai) [1164539]
- [infiniband] iser: Move PI context alloc/free to routines (Amir Vadai) [1164539]
- [infiniband] iser: Move fastreg descriptor pool get/put to helper functions (Amir Vadai) [1164539]
- [infiniband] iser: Merge build page-vec into register page-vec (Amir Vadai) [1164539]
- [infiniband] iser: Get rid of struct iser_rdma_regd (Amir Vadai) [1164539]
- [infiniband] iser: Remove redundant assignments in iser_reg_page_vec (Amir Vadai) [1164539]
- [infiniband] iser: Move memory reg/dereg routines to iser_memory.c (Amir Vadai) [1164539]
- [infiniband] iser: Don't pass ib_device to fall_to_bounce_buff routine (Amir Vadai) [1164539]
- [infiniband] iser: Remove a redundant struct iser_data_buf (Amir Vadai) [1164539]
- [infiniband] iser: Remove redundant cmd_data_len calculation (Amir Vadai) [1164539]
- [infiniband] iser: Fix wrong calculation of protection buffer length (Amir Vadai) [1164539]
- [infiniband] iser: Handle fastreg/local_inv completion errors (Amir Vadai) [1164539]
- [infiniband] iser: Fix unload during ep_poll wrong dereference (Amir Vadai) [1164539]
- [infiniband] iser: Release the iscsi endpoint if ep_disconnect wasn't called (Amir Vadai) [1164539]
- [infiniband] iser: Fix memory regions possible leak (Amir Vadai) [1164539]
- [infiniband] iser: Use correct dma direction when unmapping SGs (Amir Vadai) [1164539]
- [infiniband] iser: Bump version to 1.5 (Amir Vadai) [1164539]
- [infiniband] iser: Micro-optimize iser_handle_wc (Amir Vadai) [1164539]
- [infiniband] iser: Micro-optimize iser logging (Amir Vadai) [1164539]
- [infiniband] iser: Use more completion queues (Amir Vadai) [1164539]
- [infiniband] iser: Remove redundant is_mr indicator (Amir Vadai) [1164539]
- [infiniband] iser: Centralize memory region invalidation to a function (Amir Vadai) [1164539]
- [infiniband] iser: Terminate connection before cleaning inflight tasks (Amir Vadai) [1164539]
- [infiniband] iser: Fix race between iser connection teardown and scsi TMFs (Amir Vadai) [1164539]
- [infiniband] iser: Fix possible NULL derefernce ib_conn->device in session_create (Amir Vadai) [1164539]
- [infiniband] iser: Fix sparse warnings (Amir Vadai) [1164539]
- [infiniband] iser: Fix possible SQ overflow (Amir Vadai) [1164539]
- [infiniband] iser: Decrement CQ's active QPs accounting when QP creation fails (Amir Vadai) [1164539]
- [infiniband] iser: Collapse cleanup and disconnect handlers (Amir Vadai) [1164539]
- [infiniband] iser: Fix catastrophic error flow hang (Amir Vadai) [1164539]
- [infiniband] iser: Re-adjust CQ and QP send ring sizes to HW limits (Amir Vadai) [1164539]
- [infiniband] iser: Centralize ib_sig_domain settings (Amir Vadai) [1164539]
- [infiniband] iser: Bump version, add maintainer (Amir Vadai) [1164539]
- [infiniband] iser: Fix/add kernel-doc style description in iscsi_iser.c (Amir Vadai) [1164539]
- [infiniband] iser: Add/Fix kernel doc style descriptions in iscsi_iser.h (Amir Vadai) [1164539]
- [infiniband] iser: Nit - add space after __func__ in iser logging (Amir Vadai) [1164539]
- [infiniband] iser: Change iscsi_conn_stop log level to info (Amir Vadai) [1164539]
- [infiniband] iser: Suppress scsi command send completions (Amir Vadai) [1164539]
- [infiniband] iser: Optimize completion polling (Amir Vadai) [1164539]
- [infiniband] iser: Use beacon to indicate all completions were consumed (Amir Vadai) [1164539]
- [infiniband] iser: Use single CQ for RX and TX (Amir Vadai) [1164539]
- [infiniband] iser: Use internal polling budget to avoid possible live-lock (Amir Vadai) [1164539]
- [infiniband] iser: Centralize iser completion contexts (Amir Vadai) [1164539]
- [infiniband] iser: Use iser_warn instead of BUG_ON in iser_conn_release (Amir Vadai) [1164539]
- [infiniband] iser: Signal iSCSI layer that transport is broken in error completions (Amir Vadai) [1164539]
- [infiniband] iser: Protect tasks cleanup in case IB device was already released (Amir Vadai) [1164539]
- [infiniband] iser: Unbind at conn_stop stage (Amir Vadai) [1164539]
- [infiniband] iser: Don't bound release_work completions timeouts (Amir Vadai) [1164539]
- [infiniband] iser: Fix DEVICE REMOVAL handling in the absence of iscsi daemon (Amir Vadai) [1164539]
- [infiniband] iser: Extend iser_free_ib_conn_res() (Amir Vadai) [1164539]
- [infiniband] iser: Remove unused variables and dead code (Amir Vadai) [1164539]
- [infiniband] iser: Re-introduce ib_conn (Amir Vadai) [1164539]
- [infiniband] iser: Rename ib_conn -> iser_conn (Amir Vadai) [1164539]
- [netdrv] tun: Allow to skip filter on attach (Oleg Nesterov) [1108829]
- [netdrv] tun: Report whether the queue is attached or not (Oleg Nesterov) [1108829]
- [netdrv] tun: Get skfilter layout (Oleg Nesterov) [1108829]
- [netdrv] tun: Add ability to create tun device with given index (Oleg Nesterov) [1108829]
- [mm] introduce VM_F_OP_EXTEND to fix KABI broken by file_operations->mremap (Oleg Nesterov) [1108829]
- [fs] aio: Make it possible to remap aio ring (Oleg Nesterov) [1108829]
- [net] make default ->i_fop have ->open() fail with ENXIO (Oleg Nesterov) [1108829]
- [fs] proc: show locks in /proc/pid/fdinfo/X (Oleg Nesterov) [1108829]
- [security] userns: Allow PR_CAPBSET_DROP in a user namespace (Oleg Nesterov) [1108829]
- [mm] shm: add memfd_create() syscall (Oleg Nesterov) [1108829]
- [kernel] prctl: PR_SET_MM -- introduce PR_SET_MM_MAP operation (Oleg Nesterov) [1108829]
- [kernel] prctl: PR_SET_MM -- factor out mmap_sem when updating mm::exe_file (Oleg Nesterov) [1108829]
- [mm] introduce check_data_rlimit helper (Oleg Nesterov) [1108829]
- [fs] timerfd: Implement timerfd_ioctl method to restore timerfd_ctx::ticks, v3 (Oleg Nesterov) [1108829]
- [documentation] procfs: Document timerfd output (Oleg Nesterov) [1108829]
- [fs] timerfd: Implement show_fdinfo method (Oleg Nesterov) [1108829]
- [fs] proc: show mnt_id in /proc/pid/fdinfo (Oleg Nesterov) [1108829]
- [uapi] ptrace: add ability to get/set signal-blocked mask (Oleg Nesterov) [1108829]
- [init] actually enable CONFIG_CHECKPOINT_RESTORE (Oleg Nesterov) [1108829]
- [kernel] userns: Allow creation of user namespaces if user_namespace.enable=1 ("Eric W. Biederman") [1138782]
- [fs] userns: Only allow privileged creation of the mount namespace ("Eric W. Biederman") [1138782]
- [kernel] userns: Correct the comment in map_write ("Eric W. Biederman") [1138782 1170689] {CVE-2014-8989}
- [kernel] userns: Allow setting gid_maps without privilege when setgroups is disabled ("Eric W. Biederman") [1138782 1170689] {CVE-2014-8989}
- [kernel] userns: fix KABI broken by introduction of struct user_namespace.flags ("Eric W. Biederman") [1138782 1170689] {CVE-2014-8989}
- [kernel] userns: Add a knob to disable setgroups on a per user namespace basis ("Eric W. Biederman") [1138782 1170689] {CVE-2014-8989}
- [kernel] userns: Rename id_map_mutex to userns_state_mutex ("Eric W. Biederman") [1138782 1170689] {CVE-2014-8989}
- [kernel] userns: Only allow the creator of the userns unprivileged mappings ("Eric W. Biederman") [1138782 1170689] {CVE-2014-8989}
- [kernel] userns: Check euid no fsuid when establishing an unprivileged uid mapping ("Eric W. Biederman") [1138782 1170689] {CVE-2014-8989}
- [kernel] userns: Don't allow unprivileged creation of gid mappings ("Eric W. Biederman") [1138782 1170689] {CVE-2014-8989}
- [kernel] userns: Don't allow setgroups until a gid mapping has been established ("Eric W. Biederman") [1138782 1170689] {CVE-2014-8989}
- [kernel] userns: Document what the invariant required for safe unprivileged mappings ("Eric W. Biederman") [1138782 1170689] {CVE-2014-8989}
- [kernel] groups: Consolidate the setgroups permission checks ("Eric W. Biederman") [1138782 1170689] {CVE-2014-8989}
- [fs] userns: Change inode_capable to capable_wrt_inode_uidgid ("Eric W. Biederman") [1109837 1138782] {CVE-2014-4014}
- [kernel] userns: Kill nsown_capable it makes the wrong thing easy ("Eric W. Biederman") [1138782]
- [kernel] userns: fix KABI broken by introduction of struct user_namespace.level ("Eric W. Biederman") [1138782]
- [kernel] userns: limit the maximum depth of user_namespace->parent chain ("Eric W. Biederman") [1109837]

* Fri Jun 26 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-284.el7]
- [md] make sure MD_RECOVERY_DONE is clear before starting recovery/resync (Jes Sorensen) [1173510 1231997]
- [md] Close race when setting 'action' to 'idle' (Jes Sorensen) [1173510 1231997]
- [md] don't return 0 from array_state_store (Jes Sorensen) [1173510 1231997]
- [md] dm-cache: switch the "default" cache replacement policy from mq to smq (Mike Snitzer) [1189059]
- [md] dm-thin-metadata: remove in-core 'read_only' flag (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: prefix all DMERR and DMINFO messages with cache device name (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: add fail io mode and needs_check flag (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: age and write back cache entries even without active IO (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: wake the worker thread every time we free a migration object (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: add stochastic-multi-queue (smq) policy (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: boost promotion of blocks that will be overwritten (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: defer whole cells (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-bio-prison: add dm_cell_promote_or_release() (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: pull out some bitset utility functions for reuse (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: pass a new 'critical' flag to the policies when requesting writeback work (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: track IO to the origin device using io_tracker (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: add io_tracker (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-cache: fix race when issuing a POLICY_REPLACE operation (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-raid: add support for the MD RAID0 personality (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-raid: a few cleanups (Mike Snitzer) [1189058 1189059 1191604]
- [md] dm-raid: fixup documentation for discard support (Mike Snitzer) [1189058 1189059 1191604]
- [perf] x86: Enforce HT bug workaround with PEBS for SNB/IVB/HSW (Jiri Olsa) [1210494]
- [perf] x86/intel: Fix SLM cache event list (Jiri Olsa) [1210494]
- [perf] x86: Improve HT workaround GP counter constraint (Jiri Olsa) [1210494]
- [perf] x86: Fix event/group validation (Jiri Olsa) [1210494]
- [perf] x86: Disable PEBS-LL in intel_pmu_pebs_disable() (Jiri Olsa) [1210494]
- [perf] x86/intel: Reset more state in PMU reset (Jiri Olsa) [1210494]
- [perf] x86/intel: Make the HT bug workaround conditional on HT enabled (Jiri Olsa) [1210494]
- [perf] x86/intel: Limit to half counters when the HT workaround is enabled, to avoid exclusive mode starvation (Jiri Olsa) [1210494]
- [perf] x86/intel: Fix intel_get_event_constraints() for dynamic constraints (Jiri Olsa) [1210494]
- [perf] x86/intel: Enforce HT bug workaround for SNB/IVB/HSW (Jiri Olsa) [1210494]
- [perf] x86/intel: Implement cross-HT corruption bug workaround (Jiri Olsa) [1210494]
- [perf] x86/intel: Add cross-HT counter exclusion infrastructure (Jiri Olsa) [1210494]
- [perf] watchdog: Add watchdog enable/disable all functions (Jiri Olsa) [1210494]
- [perf] x86: Add 'index' param to get_event_constraint() callback (Jiri Olsa) [1210494]
- [perf] x86: Add 3 new scheduling callbacks (Jiri Olsa) [1210494]
- [perf] x86: Vectorize cpuc->kfree_on_online (Jiri Olsa) [1210494]
- [perf] x86: Rename x86_pmu::er_flags to 'flags' (Jiri Olsa) [1210494]
- [netdrv] ibmveth: Add support for Large Receive Offload (Gustavo Duarte) [1233261]
- [netdrv] ibmveth: Add GRO support (Gustavo Duarte) [1233261]
- [netdrv] ibmveth: Add support for TSO (Gustavo Duarte) [1233261]
- [netdrv] ibmveth: change rx buffer default allocation for CMO (Gustavo Duarte) [1233261]
- [powerpc] powernv: reboot when requested by firmware (Gustavo Duarte) [1221072]
- [kernel] reboot: add orderly_reboot for graceful reboot (Gustavo Duarte) [1221072]
- [powerpc] sbus: ignore orderly_poweroff return value (Gustavo Duarte) [1221072]
- [powerpc] powernv: Add OPAL soft-poweroff routine (Gustavo Duarte) [1221072]
- [net] openvswitch: remove GFP_THISNODE (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Return vport module ref before destruction (Jiri Benc) [1156461 1211348]
- [net] mpls: Fix the openvswitch select of NET_MPLS_GSO (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix serialization of non-masked set actions (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix key serialization (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Add missing initialization in validate_and_copy_set_tun() (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Reset key metadata for packet execution (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Only set TUNNEL_VXLAN_OPT if VXLAN-GBP metadata is set (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Initialize unmasked key and uid len (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Support masked set actions (Jiri Benc) [1156461 1211348]
- [net] udptunnels: Call handle_offloads after inserting vlan tag (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Add support for checksums on UDP tunnels (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Add support for unique flow IDs (Jiri Benc) [1156461 1211348]
- [net] genetlink: Add genlmsg_parse() helper function (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Use sw_flow_key_range for key ranges (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Refactor ovs_flow_tbl_insert() (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Refactor ovs_nla_fill_match() (Jiri Benc) [1156461 1211348]
- [net] openvswitch: pass vxflags to vxlan_xmit_skb (Jiri Benc) [1156461 1211348]
- [net] openvswitch: ignore genlmsg_end return value (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Support VXLAN Group Policy extension (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Allow for any level of nesting in flow attributes (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Rename GENEVE_TUN_OPTS() to TUN_METADATA_OPTS() (Jiri Benc) [1156461 1211348]
- [net] openvswitch: packet messages need their own probe attribtue (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Introduce ovs_tunnel_route_lookup (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Remove unnecessary version.h inclusion (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Consistently include VLAN header in flow and port stats (Jiri Benc) [1156461 1211348]
- [net] genetlink: pass only network namespace to genl_has_listeners() (Jiri Benc) [1156461 1211348]
- [net] openvswitch: fix odd_ptr_err.cocci warnings (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix vport_send double free (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix GSO with multiple MPLS label (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix MPLS action validation (Jiri Benc) [1156461 1211348]
- [net] openvswitch: replace remaining users of arch_fast_hash with jhash (Jiri Benc) [1156461 1211348]
- [net] openvswitch: set correct protocol on route lookup (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix flow mask validation (Jiri Benc) [1156461 1211348]
- [net] vlan: move vlan pop/push functions into common code (Jiri Benc) [1156461 1211348]
- [net] move make_writable helper into common code (Jiri Benc) [1156461 1211348]
- [net] vlan: introduce __vlan_insert_tag helper which does not free skb (Jiri Benc) [1156461 1211348]
- [net] vlan: Call dev_kfree_skb_any instead of kfree_skb (Jiri Benc) [1156461 1211348]
- [net] vlan: introduce *vlan_hwaccel_push_inside helpers (Jiri Benc) [1156461 1211348]
- [net] vlan: validate_xmit_vlan() is static (Jiri Benc) [1156461 1211348]
- [net] vlan: rename __vlan_put_tag to vlan_insert_tag_set_proto (Jiri Benc) [1156461 1211348]
- [net] vlan: kill vlan_put_tag helper (Jiri Benc) [1156461 1211348]
- [net] vlan: remove unused HAVE_VLAN_PUT_TAG (Jiri Benc) [1156461 1211348]
- [net] openvswitch: actions: use skb_postpull_rcsum when possible (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Don't validate IPv6 label masks (Jiri Benc) [1156461 1211348]
- [net] openvswitch: use PTR_ERR_OR_ZERO (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Validate IPv6 flow key and mask values (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Convert dp rcu read operation to locked operations (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix NDP flow mask validation (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix checksum calculation when modifying ICMPv6 packets (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix memory leak (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix build failure (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Add support for OVS_FLOW_ATTR_PROBE (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Constify various function arguments (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Remove redundant key ref from upcall_info (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Optimize recirc action (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Extend packet attribute for egress tunnel info (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Export symbols as GPL symbols (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Avoid NULL mask check while building mask (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Refactor action alloc and copy api (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Move key_attr_size() to flow_netlink.h (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Remove flow member from struct ovs_skb_cb (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix the type of struct ovs_key_nd nd_target field (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Drop packets when interdev is not up (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Refactor get_dp() function into multiple access APIs (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Refactor ovs_flow_cmd_fill_info() (Jiri Benc) [1156461 1211348]
- [net] openvswitch: refactor do_output() to move NULL check out of fast path (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Additional logging for -EINVAL on flow setups (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Remove redundant tcp_flags code (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Move table destroy to dp-rcu callback (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Add basic MPLS support to kernel (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Export lockdep_ovsl_is_held to modules (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Rename last_action() as nla_is_last() and move to netlink.h (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Turn vports with dependencies into separate modules (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Set flow-key members (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Create right mask with disabled megaflows (Jiri Benc) [1156461 1211348]
- [net] openvswitch: fix a use after free (Jiri Benc) [1156461 1211348]
- [net] openvswitch: use vport instead of p (Jiri Benc) [1156461 1211348]
- [net] openvswitch: kerneldoc warning fix (Jiri Benc) [1156461 1211348]
- [net] openvswitch: fix a sparse warning (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Add support for Geneve tunneling (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Factor out allocation and verification of actions (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Wrap struct ovs_key_ipv4_tunnel in a new structure (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Add support for matching on OAM packets (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Eliminate memset() from flow_extract (Jiri Benc) [1156461 1211348]
- [net] mpls: Fix config check for mpls (Jiri Benc) [1156461 1211348]
- [net] mpls: Use mpls_features to activate software MPLS GSO segmentation (Jiri Benc) [1156461 1211348]
- [net] geneve: Pass UDP socket down through udp_tunnel{, 6}_xmit_skb() (Jiri Benc) [1156461 1211348]
- [net] geneve: coding style: comparison for inequality with NULL (Jiri Benc) [1156461 1211348]
- [net] geneve: coding style: comparison for equality with NULL (Jiri Benc) [1156461 1211348]
- [net] geneve: Do not require sock in udp_tunnel_xmit_skb (Jiri Benc) [1156461 1211348]
- [net] geneve: pass udp_offload struct to UDP gro callbacks (Jiri Benc) [1156461 1211348]
- [net] geneve: Check family when reusing sockets (Jiri Benc) [1156461 1211348]
- [net] geneve: Remove socket hash table (Jiri Benc) [1156461 1211348]
- [net] geneve: Simplify locking (Jiri Benc) [1156461 1211348]
- [net] geneve: Remove workqueue (Jiri Benc) [1156461 1211348]
- [net] geneve: Add Geneve GRO support (Jiri Benc) [1156461 1211348]
- [net] geneve: Fix races between socket add and release (Jiri Benc) [1156461 1211348]
- [net] geneve: Remove socket and offload handlers at destruction (Jiri Benc) [1156461 1211348]
- [net] geneve: Unregister pernet subsys on module unload (Jiri Benc) [1156461 1211348]
- [net] geneve: Set GSO type on transmit (Jiri Benc) [1156461 1211348]
- [net] ipv4: minor spelling fixes (Jiri Benc) [1156461 1211348]
- [net] openvswitch: fix a compilation error when CONFIG_INET is not set (Jiri Benc) [1156461 1211348]
- [net] geneve: fix a sparse warning (Jiri Benc) [1156461 1211348]
- [net] geneve: Add Geneve tunneling protocol driver (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Replace rcu_dereference() with rcu_access_pointer() (Jiri Benc) [1156461 1211348]
- [net] openvswitch: replace macros net_random and net_srandom with direct calls to prandom (Jiri Benc) [1156461 1211348]
- [net] openvswitch: check CONFIG_OPENVSWITCH_GRE in makefile (Jiri Benc) [1156461 1211348]
- [net] openvswitch: Fix struct comment (Jiri Benc) [1156461 1211348]
- [net] vxlan: fix a shadow local variable (Jiri Benc) [1230935]
- [net] ipv6: call iptunnel_xmit with NULL sock pointer if no tunnel sock is available (Jiri Benc) [1230935]
- [net] udp_tunnel: Pass UDP socket down through udp_tunnel{, 6}_xmit_skb() (Jiri Benc) [1230935]
- [net] kabi: whitelist struct nf_hook_state (Jiri Benc) [1230935]
- [net] netfilter: Pass socket pointer down through okfn() (Jiri Benc) [1230935]
- [net] netfilter: Add socket pointer to nf_hook_state (Jiri Benc) [1230935]
- [net] netfilter: Add nf_hook_state initializer function (Jiri Benc) [1230935]
- [net] netfilter: Pass nf_hook_state through arpt_do_table() (Jiri Benc) [1230935]
- [net] netfilter: Pass nf_hook_state through nft_set_pktinfo*() (Jiri Benc) [1230935]
- [net] netfilter: Pass nf_hook_state through ip6t_do_table() (Jiri Benc) [1230935]
- [net] netfilter: Pass nf_hook_state through nf_nat_ipv6_{in, out, fn, local_fn}() (Jiri Benc) [1230935]
- [net] netfilter: Pass nf_hook_state through ipt_do_table() (Jiri Benc) [1230935]
- [net] netfilter: Pass nf_hook_state through nf_nat_ipv4_{in, out, fn, local_fn}() (Jiri Benc) [1230935]
- [net] netfilter: Make nf_hookfn use nf_hook_state (Jiri Benc) [1230935]
- [net] netfilter: Use nf_hook_state in nf_queue_entry (Jiri Benc) [1230935]
- [net] netfilter: Create and use nf_hook_state (Jiri Benc) [1230935]
- [net] netfilter: Remove extern from function prototypes (Jiri Benc) [1230935]
- [net] bridge: fix netfilter/NF_BR_LOCAL_OUT for own, locally generated queries (Jiri Benc) [1230935]
- [net] ipv6: Fix udp checksums with raw sockets (Vlad Yasevich) [1105064]

* Fri Jun 26 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-283.el7]
- [scsi] storvsc: Set the SRB flags correctly when no data transfer is needed (Vitaly Kuznetsov) [1075441 1209811 1221298 1228231]
- [scsi] storvsc: Fix a bug in copy_from_bounce_buffer() (Vitaly Kuznetsov) [1075441 1209811 1221298 1228231]
- [scsi] storvsc: force SPC-3 compliance on win8 and win8 r2 hosts (Vitaly Kuznetsov) [1075441 1209811 1221298 1228231]
- [scsi] storvsc: use cmd_size to allocate per-command data (Vitaly Kuznetsov) [1075441 1209811 1221298 1228231]
- [hv] vmbus: unregister panic notifier on module unload (Vitaly Kuznetsov) [1210721]
- [hv] vmbus: hyperv_panic_event() can be static (Vitaly Kuznetsov) [1210721]
- [hv] vmbus: Correcting truncation error for constant HV_CRASH_CTL_CRASH_NOTIFY (Vitaly Kuznetsov) [1210721]
- [hv] vmbus: Add support for VMBus panic notifier handler (Vitaly Kuznetsov) [1210721]
- [hv] vmbus: Don't wait after requesting offers (Vitaly Kuznetsov) [1211914]
- [hv] channel_mgmt: match var type to return type of wait_for_completion (Vitaly Kuznetsov) [1211914]
- [hv] vmbus: Get rid of some unnecessary messages (Vitaly Kuznetsov) [1211914]
- [hv] vmbus: Fix a bug in the error path in vmbus_open() (Vitaly Kuznetsov) [1211914]
- [hv] vmbus_open(): reset the channel state on ENOMEM (Vitaly Kuznetsov) [1211914]
- [hv] vmbus_post_msg: retry the hypercall on some transient errors (Vitaly Kuznetsov) [1211914]
- [hv] vmbus: Fix a bug in vmbus_establish_gpadl() (Vitaly Kuznetsov) [1211914]
- [hv] x86: Mark the Hyper-V clocksource as being continuous (Vitaly Kuznetsov) [1211914]
- [hv] vmbus: Enable interrupt driven flow control (Vitaly Kuznetsov) [1211914]
- [hv] vmbus: Cleanup hv_post_message() (Vitaly Kuznetsov) [1211914]
- [hv] vmbus: Cleanup vmbus_establish_gpadl() (Vitaly Kuznetsov) [1211914]
- [hv] vmbus: Cleanup vmbus_teardown_gpadl() (Vitaly Kuznetsov) [1211914]
- [hv] vmbus: Cleanup vmbus_post_msg() (Vitaly Kuznetsov) [1211914]
- [hv] vmbus: Cleanup the packet send path (Vitaly Kuznetsov) [1211914]
- [hv] hv_balloon: do not online pages in offline blocks (Vitaly Kuznetsov) [1133403 1218868]
- [hv] hv_balloon: don't lose memory when onlining order is not natural (Vitaly Kuznetsov) [1133403 1218868]
- [pnp] convert bus code to use dev_groups (Jarod Wilson) [1232626]
- [rtc] convert rtc-cmos to dev_pm_ops from legacy pm_ops (Jarod Wilson) [1232626]
- [pnp] fix restoring devices after hibernation (Jarod Wilson) [1232626]
- [pnp] convert PNP driver bus legacy pm_ops to dev_pm_ops (Jarod Wilson) [1232626]
- [pnp] change pnp bus pm_ops to invoke pnp driver dev_pm_ops if specified (Jarod Wilson) [1232626]
- [pci] pciehp: Wait for hotplug command completion where necessary (Myron Stowe) [1227034]
- [pci] pciehp: Add more Slot Control debug output (Myron Stowe) [1227034]
- [pci] pciehp: Fix wait time in timeout message (Myron Stowe) [1227034]
- [pci] pciehp: Reduce PCIe slot_ctrl to 16 bits (Myron Stowe) [1227034]
- [infiniband] srp: Use P_Key cache for P_Key lookups (Honggang Li) [1164541]
- [infiniband] srp: Allow newline separator for connection string (Honggang Li) [1164541]
- [infiniband] srp: Fix a race condition triggered by destroying a queue pair (Honggang Li) [1164541]
- [infiniband] srp: Separate target and channel variables (Honggang Li) [1164541]
- [infiniband] srp: Introduce two new srp_target_port member variables (Honggang Li) [1164541]
- [infiniband] srp: Avoid that I/O hangs due to a cable pull during LUN scanning (Honggang Li) [1164541]
- [infiniband] srp: Remove stale connection retry mechanism (Honggang Li) [1164541]
- [infiniband] srp: Move ib_destroy_cm_id() call into srp_free_ch_ib() (Honggang Li) [1164541]
- [infiniband] srp: Fix return value check in srp_init_module() (Honggang Li) [1164541]
- [infiniband] srp: Fix residual handling (Honggang Li) [1164541]
- [infiniband] srp: Fix deadlock between host removal and multipathd (Honggang Li) [1164541]
- [infiniband] srp: Avoid problems if a header uses pr_fmt (Honggang Li) [1164541]
- [infiniband] srp: Add fast registration support (Honggang Li) [1164541]
- [infiniband] srp: Rename FMR-related variables (Honggang Li) [1164541]
- [infiniband] srp: One FMR pool per SRP connection (Honggang Li) [1164541]
- [infiniband] srp: Introduce the 'register_always' kernel module parameter (Honggang Li) [1164541]
- [infiniband] srp: Introduce srp_finish_mapping() (Honggang Li) [1164541]
- [infiniband] srp: Introduce srp_map_fmr() (Honggang Li) [1164541]
- [infiniband] srp: Introduce an additional local variable (Honggang Li) [1164541]
- [infiniband] srp: Fix kernel-doc warnings (Honggang Li) [1164541]
- [infiniband] srp: Fix a sporadic crash triggered by cable pulling (Honggang Li) [1164541]
- [infiniband] srp: Fix a race condition between failing I/O and I/O completion (Honggang Li) [1164541]
- [infiniband] srp: Avoid that writing into "add_target" hangs due to a cable pull (Honggang Li) [1164541]
- [infiniband] srp: Make writing into the "add_target" sysfs attribute interruptible (Honggang Li) [1164541]
- [infiniband] srp: Avoid duplicate connections (Honggang Li) [1164541]
- [infiniband] srp: Add more logging (Honggang Li) [1164541]
- [infiniband] srp: Check ib_query_gid return value (Honggang Li) [1164541]
- [infiniband] ocrdma: Update ocrdma version number (Honggang Li) [1184955]
- [infiniband] ocrdma: Fail connection for MTU lesser than 512 (Honggang Li) [1184955]
- [infiniband] ocrdma: Fix dmac resolution for link local address (Honggang Li) [1184955]
- [infiniband] ocrdma: Prevent allocation of DPP PDs if FW doesnt support it (Honggang Li) [1184955]
- [infiniband] ocrdma: Fix the request length for RDMA_QUERY_QP mailbox command to FW (Honggang Li) [1184955]
- [infiniband] ocrdma: Use VID 0 if PFC is enabled and vlan is not configured (Honggang Li) [1184955]
- [infiniband] ocrdma: Fix QP state transition in destroy_qp (Honggang Li) [1184955]
- [infiniband] ocrdma: Report EQ full fatal error (Honggang Li) [1184955]
- [infiniband] ocrdma: Fix EQ destroy failure during driver unload (Honggang Li) [1184955]
- [infiniband] ocrdma: Fix off by one in ocrdma_query_gid() (Honggang Li) [1184955]
- [infiniband] ocrdma: Use unsigned for bit index (Honggang Li) [1184955]
- [infiniband] ocrdma: Help gcc generate better code for ocrdma_srq_toggle_bit (Honggang Li) [1184955]
- [infiniband] ocrdma: Update the ocrdma module version string (Honggang Li) [1184955]
- [infiniband] ocrdma: set vlan present bit for user AH (Honggang Li) [1184955]
- [infiniband] ocrdma: remove reference of ocrdma_dev out of ocrdma_qp structure (Honggang Li) [1184955]
- [infiniband] ocrdma: Add support for interrupt moderation (Honggang Li) [1184955]
- [infiniband] ocrdma: Honor return value of ocrdma_resolve_dmac (Honggang Li) [1184955]
- [infiniband] ocrdma: Allow expansion of the SQ CQEs via buddy CQ expansion of the QP (Honggang Li) [1184955]
- [infiniband] ocrdma: Discontinue support of RDMA-READ-WITH-INVALIDATE (Honggang Li) [1184955]
- [infiniband] ocrdma: Host crash on destroying device resources (Honggang Li) [1184955]
- [infiniband] ocrdma: Report correct state in ibv_query_qp (Honggang Li) [1184955]
- [infiniband] ocrdma: Debugfs enhancments for ocrdma driver (Honggang Li) [1184955]
- [infiniband] ocrdma: Report correct count of interrupt vectors while registering ocrdma device (Honggang Li) [1184955]
- [infiniband] ocrdma: Move PD resource management to driver (Honggang Li) [1184955]
- [infiniband] ocrdma: Increase the GID table size (Honggang Li) [1184955]
- [infiniband] ocrdma: Add support for IB stack compliant stats in sysfs (Honggang Li) [1184955]
- [infiniband] ocrdma: Save the bit environment, spare unncessary parenthesis (Honggang Li) [1184955]
- [infiniband] ocrdma: The kernel has a perfectly good BIT() macro - use it (Honggang Li) [1184955]
- [infiniband] ocrdma: Don't memset() buffers we just allocated with kzalloc() (Honggang Li) [1184955]
- [infiniband] ocrdma: Remove a unused-label warning (Honggang Li) [1184955]
- [infiniband] ipoib: Fix indentation level (Honggang Li) [1230203]
- [infiniband] ipoib: Remove IPOIB_MCAST_RUN bit (Honggang Li) [1230203]
- [infiniband] ipoib: Save only IPOIB_MAX_PATH_REC_QUEUE skb's (Honggang Li) [1230203]
- [infiniband] ipoib: Handle QP in SQE state (Honggang Li) [1230203]
- [infiniband] ipoib: Update broadcast record values after each successful join request (Honggang Li) [1230203]
- [infiniband] ipoib: Use one linear skb in RX flow (Honggang Li) [1230203]
- [fs] rbd: end I/O the entire obj_request on error (Sage Weil) [1229488]
- [fs] rbd: rbd_wq comment is obsolete (Sage Weil) [1229488]
- [fs] libceph: announce support for straw2 buckets (Sage Weil) [1229488]
- [fs] crush: straw2 bucket type with an efficient 64-bit crush_ln() (Sage Weil) [1229488]
- [fs] crush: ensuring at most num-rep osds are selected (Sage Weil) [1229488]
- [fs] crush: drop unnecessary include from mapper.c (Sage Weil) [1229488]
- [fs] ceph: fix uninline data function (Sage Weil) [1229488]
- [fs] ceph: rename snapshot support (Sage Weil) [1229488]
- [fs] ceph: fix null pointer dereference in send_mds_reconnect() (Sage Weil) [1229488]
- [fs] ceph: hold on to exclusive caps on complete directories (Sage Weil) [1229488]
- [fs] libceph: simplify our debugfs attr macro (Sage Weil) [1229488]
- [fs] ceph: show non-default options only (Sage Weil) [1229488]
- [fs] libceph: expose client options through debugfs (Sage Weil) [1229488]
- [fs] libceph, ceph: split ceph_show_options() (Sage Weil) [1229488]
- [fs] rbd: mark block queue as non-rotational (Sage Weil) [1229488]
- [fs] libceph: don't overwrite specific con error msgs (Sage Weil) [1229488]
- [fs] ceph: cleanup unsafe requests when reconnecting is denied (Sage Weil) [1229488]
- [fs] ceph: don't zero i_wrbuffer_ref when reconnecting is denied (Sage Weil) [1229488]
- [fs] ceph: don't mark dirty caps when there is no auth cap (Sage Weil) [1229488]
- [fs] ceph: keep i_snap_realm while there are writers (Sage Weil) [1229488]
- [fs] libceph: osdmap.h: Add missing format newlines (Sage Weil) [1229488]
- [fs] ceph: kstrdup() memory handling (Sage Weil) [1229488]
- [fs] ceph: properly release page upon error (Sage Weil) [1229488]
- [fs] rbd: be more informative on -ENOENT failures (Sage Weil) [1229488]
- [fs] ceph: match wait_for_completion_timeout return type (Sage Weil) [1229488]
- [fs] ceph: use msecs_to_jiffies for time conversion (Sage Weil) [1229488]
- [fs] ceph: remove redundant declaration (Sage Weil) [1229488]
- [fs] ceph: fix dcache/nocache mount option (Sage Weil) [1229488]
- [fs] ceph: drop cap releases in requests composed before cap reconnect (Sage Weil) [1229488]
- [fs] Revert "libceph: use memalloc flags for net IO" (Sage Weil) [1229488]
- [fs] libceph: kfree() in put_osd() shouldn't depend on authorizer (Sage Weil) [1229488]
- [fs] libceph: fix double __remove_osd() problem (Sage Weil) [1229488]
- [fs] rbd: convert to blk-mq (Carlos Maiolino) [1229488]
- [fs] ceph: return error for traceless reply race (Sage Weil) [1229488]
- [fs] ceph: fix dentry leaks (Sage Weil) [1229488]
- [fs] ceph: re-send requests when MDS enters reconnecting stage (Sage Weil) [1229488]
- [fs] ceph: show nocephx_require_signatures and notcp_nodelay options (Sage Weil) [1229488]
- [fs] rbd: do not treat standalone as flatten (Sage Weil) [1229488]
- [fs] ceph: fix atomic_open snapdir (Sage Weil) [1229488]
- [fs] ceph: properly mark empty directory as complete (Sage Weil) [1229488]
- [fs] client: include kernel version in client metadata (Sage Weil) [1229488]
- [fs] ceph: provide seperate {inode, file}_operations for snapdir (Sage Weil) [1229488]
- [fs] ceph: fix request time stamp encoding (Sage Weil) [1229488]
- [fs] ceph: fix reading inline data when i_size > PAGE_SIZE (Sage Weil) [1229488]
- [fs] ceph: avoid block operation when !TASK_RUNNING (ceph_mdsc_close_sessions) (Sage Weil) [1229488]
- [fs] ceph: avoid block operation when !TASK_RUNNING (ceph_get_caps) (Sage Weil) [1229488]
- [fs] ceph: avoid block operation when !TASK_RUNNING (ceph_mdsc_sync) (Sage Weil) [1229488]
- [fs] rbd: fix error paths in rbd_dev_refresh() (Sage Weil) [1229488]
- [fs] ceph: improve reference tracking for snaprealm (Sage Weil) [1229488]
- [fs] ceph: properly zero data pages for file holes (Sage Weil) [1229488]
- [fs] rbd: nuke copy_token() (Sage Weil) [1229488]
- [fs] ceph: handle SESSION_FORCE_RO message (Sage Weil) [1229488]
- [fs] libceph: use mon_client.c/put_generic_request() more (Sage Weil) [1229488]
- [fs] libceph: nuke pool op infrastructure (Sage Weil) [1229488]
- [fs] rbd: drop parent_ref in rbd_dev_unprobe() unconditionally (Sage Weil) [1229488]
- [fs] rbd: fix rbd_dev_parent_get() when parent_overlap == 0 (Sage Weil) [1229488]
- [fs] libceph: fix sparse endianness warnings (Sage Weil) [1229488]
- [fs] ceph: use zu for len in ceph_fill_inline_data() (Sage Weil) [1229488]
- [fs] ceph: fix setting empty extended attribute (Sage Weil) [1229488]
- [fs] ceph: fix mksnap crash (Sage Weil) [1229488]
- [fs] ceph: do_sync is never initialized (Sage Weil) [1229488]
- [fs] ceph: support inline data feature (Sage Weil) [1229488]
- [fs] ceph: flush inline version (Sage Weil) [1229488]
- [fs] ceph: convert inline data to normal data before data write (Sage Weil) [1229488]
- [fs] ceph: sync read inline data (Sage Weil) [1229488]
- [fs] ceph: fetch inline data when getting Fcr cap refs (Sage Weil) [1229488]
- [fs] ceph: use getattr request to fetch inline data (Sage Weil) [1229488]
- [fs] ceph: add inline data to pagecache (Sage Weil) [1229488]
- [fs] ceph: parse inline data in MClientReply and MClientCaps (Sage Weil) [1229488]
- [fs] libceph: specify position of extent operation (Sage Weil) [1229488]
- [fs] libceph: add CREATE osd operation support (Sage Weil) [1229488]
- [fs] libceph: add SETXATTR/CMPXATTR osd operations support (Sage Weil) [1229488]
- [fs] rbd: don't treat CEPH_OSD_OP_DELETE as extent op (Sage Weil) [1229488]
- [fs] ceph: remove unused stringification macros (Sage Weil) [1229488]
- [fs] libceph: require cephx message signature by default (Sage Weil) [1229488]
- [fs] ceph: introduce global empty snap context (Sage Weil) [1229488]
- [fs] ceph: message versioning fixes (Sage Weil) [1229488]
- [fs] libceph: update ceph_msg_header structure (Sage Weil) [1229488]
- [fs] libceph: message signature support (Sage Weil) [1229488]
- [fs] libceph: store session key in cephx authorizer (Sage Weil) [1229488]
- [fs] ceph, rbd: delete unnecessary checks before two function calls (Sage Weil) [1229488]
- [fs] ceph: introduce a new inode flag indicating if cached dentries are ordered (Sage Weil) [1229488]
- [fs] libceph: nuke ceph_kvfree() (Sage Weil) [1229488]
- [fs] ceph: fix file lock interruption (Sage Weil) [1229488]

* Thu Jun 25 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-282.el7]
- [mtd] powernv: Add powernv flash MTD abstraction driver (Gustavo Duarte) [1221094]
- [of] Ensure unique names without sacrificing determinism (Gustavo Duarte) [1230093]
- [of] kill off of_can_translate_address (Gustavo Duarte) [1230093]
- [of] platform: fix device naming for non-translatable addresses (Gustavo Duarte) [1230093]
- [of] base: Fix PowerPC address parsing hack (Gustavo Duarte) [1230093]
- [of] address: Don't throw errors on absent ranges properties (Gustavo Duarte) [1230093]
- [of] platform: Move platform devices under /sys/devices/platform (Gustavo Duarte) [1230093]
- [of] Fix dereferencing node name in debug output to be safe (Gustavo Duarte) [1230093]
- [powerpc] powernv: Add opal-prd channel (Gustavo Duarte) [1221110 1229224]
- [powerpc] powernv: Expose OPAL APIs required by PRD interface (Gustavo Duarte) [1221110 1229224]
- [powerpc] powernv: Merge common platform device initialisation (Gustavo Duarte) [1221110 1229224]
- [powerpc] powernv: Add interfaces for flash device access (Gustavo Duarte) [1221072 1229224]
- [powerpc] vfio: powerpc/spapr: Support Dynamic DMA windows (David Gibson) [1213665]
- [powerpc] vfio: powerpc/spapr: Register memory and define IOMMU v2 (David Gibson) [1213665]
- [powerpc] mmu: Add userspace-to-physical addresses translation cache (David Gibson) [1213665]
- [powerpc] vfio: powerpc/spapr: powerpc/powernv/ioda2: Use DMA windows API in ownership control (David Gibson) [1213665]
- [powerpc] iommu/ioda2: Add get_table_size() to calculate the size of future table (David Gibson) [1213665]
- [powerpc] powernv/ioda2: Use new helpers to do proper cleanup on PE release (David Gibson) [1213665]
- [powerpc] vfio: powerpc/spapr: powerpc/powernv/ioda: Define and implement DMA windows API (David Gibson) [1213665]
- [powerpc] powernv: Implement multilevel TCE tables (David Gibson) [1213665]
- [powerpc] powernv/ioda2: Introduce pnv_pci_ioda2_set_window (David Gibson) [1213665]
- [powerpc] powernv/ioda2: Introduce helpers to allocate TCE pages (David Gibson) [1213665]
- [powerpc] powernv/ioda2: Rework iommu_table creation (David Gibson) [1213665]
- [powerpc] iommu/powernv: Release replaced TCE (David Gibson) [1213665]
- [powerpc] powernv: Implement accessor to TCE entry (David Gibson) [1213665]
- [powerpc] powernv/ioda2: Add TCE invalidation for all attached groups (David Gibson) [1213665]
- [powerpc] powernv/ioda2: Move TCE kill register address to PE (David Gibson) [1213665]
- [powerpc] iommu: Fix IOMMU ownership control functions (David Gibson) [1213665]
- [powerpc] vfio: powerpc/spapr/iommu/powernv/ioda2: Rework IOMMU ownership control (David Gibson) [1213665]
- [powerpc] spapr: vfio: Switch from iommu_table to new iommu_table_group (David Gibson) [1213665]
- [powerpc] spapr: vfio: Replace iommu_table with iommu_table_group (David Gibson) [1213665]
- [powerpc] powernv/ioda/ioda2: Rework TCE invalidation in tce_build()/tce_free() (David Gibson) [1213665]
- [powerpc] iommu: Move tce_xxx callbacks from ppc_md to iommu_table (David Gibson) [1213665]
- [powerpc] powernv: Do not set "read" flag if direction==DMA_NONE (David Gibson) [1213665]
- [powerpc] vfio: powerpc/spapr: Rework groups attaching (David Gibson) [1213665]
- [powerpc] vfio: powerpc/spapr: Moving pinning/unpinning to helpers (David Gibson) [1213665]
- [powerpc] vfio: powerpc/spapr: Disable DMA mappings on disabled container (David Gibson) [1213665]
- [powerpc] vfio: powerpc/spapr: Move locked_vm accounting to helpers (David Gibson) [1213665]
- [powerpc] vfio: powerpc/spapr: Use it_page_size (David Gibson) [1213665]
- [powerpc] vfio: powerpc/spapr: Check that IOMMU page is fully contained by system page (David Gibson) [1213665]
- [powerpc] vfio: powerpc/spapr: Move page pinning from arch code to VFIO IOMMU driver (David Gibson) [1213665]
- [powerpc] iommu: Always release iommu_table in iommu_free_table() (David Gibson) [1213665]
- [powerpc] iommu: Put IOMMU group explicitly (David Gibson) [1213665]
- [powerpc] powernv/ioda: Clean up IOMMU group registration (David Gibson) [1213665]
- [powerpc] iommu/powernv: Get rid of set_iommu_table_base_and_group (David Gibson) [1213665]
- [powerpc] eeh/ioda2: Use device::iommu_group to check IOMMU group (David Gibson) [1213665]
- [netdrv] sfc: mark state UNINIT after unregister (Jarod Wilson) [1199178]
- [netdrv] sfc: leak vports if a VF is assigned during PF unload (Jarod Wilson) [1199178]
- [netdrv] sfc: force removal of VF and vport on driver removal (Jarod Wilson) [1199178]
- [netdrv] sfc: do not allow VFs to be destroyed if assigned to guests (Jarod Wilson) [1199178]
- [netdrv] sfc: don't update stats on VF when called in atomic context (Jarod Wilson) [1199178]
- [netdrv] sfc: suppress vadaptor stats when EVB is not present (Jarod Wilson) [1199178]
- [netdrv] sfc: suppress ENOENT error messages from MC_CMD_MAC_STATS (Jarod Wilson) [1199178]
- [netdrv] sfc: update netdevice statistics to use vadaptor stats (Jarod Wilson) [1199178]
- [netdrv] sfc: DMA the VF stats only when requested (Jarod Wilson) [1199178]
- [netdrv] sfc: display vadaptor statistics for all interfaces (Jarod Wilson) [1199178]
- [netdrv] sfc: set the port-id when calling MC_CMD_MAC_STATS (Jarod Wilson) [1199178]
- [netdrv] sfc: add "port_" prefix to MAC stats (Jarod Wilson) [1199178]
- [netdrv] sfc: Implement ndo_gets_phys_port_id() for EF10 VFs (Jarod Wilson) [1199178]
- [netdrv] sfc: Add sysfs entry for flags (link control and primary) (Jarod Wilson) [1199178]
- [netdrv] sfc: Add paranthesis correctly on all branches of the if statement (Jarod Wilson) [1199178]
- [netdrv] sfc: Add code to export port_num in netdev->dev_port (Jarod Wilson) [1199178]
- [netdrv] sfc: free multiple Rx buffers when required (Jarod Wilson) [1199178]
- [netdrv] sfc: add module parameter to enable MCDI logging on new functions (Jarod Wilson) [1199178]
- [netdrv] sfc: add sysfs entry to control MCDI tracing (Jarod Wilson) [1199178]
- [netdrv] sfc: add tracing of MCDI commands (Jarod Wilson) [1199178]
- [netdrv] sfc: set the MAC address using MC_CMD_VADAPTOR_SET_MAC (Jarod Wilson) [1199178]
- [netdrv] sfc: Implement dummy disable of VF spoof check for EF10 (Jarod Wilson) [1199178]
- [netdrv] sfc: add ndo_set_vf_link_state() function for EF10 (Jarod Wilson) [1199178]
- [netdrv] sfc: add ndo_set_vf_vlan() function for EF10 (Jarod Wilson) [1199178]
- [netdrv] sfc: Change entity reset on MC reboot to a new datapath-only reset (Jarod Wilson) [1199178]
- [netdrv] sfc: Add ndo_get_vf_config() function for EF10 (Jarod Wilson) [1199178]
- [netdrv] sfc: add ndo_set_vf_mac() function for EF10 (Jarod Wilson) [1199178]
- [netdrv] sfc: Initialise MCDI buffers to 0 on declaration (Jarod Wilson) [1199178]
- [netdrv] sfc: Enable a VF to get its own MAC address (Jarod Wilson) [1199178]
- [netdrv] sfc: protect filter table against use-after-free (Jarod Wilson) [1199178]
- [netdrv] sfc: Store the efx_nic struct of the current VF in the VF data struct (Jarod Wilson) [1199178]
- [netdrv] sfc: save old MAC address in case sriov_mac_address_changed fails (Jarod Wilson) [1199178]
- [netdrv] sfc: Store vf_index in nic_data for Ef10 (Jarod Wilson) [1199178]
- [netdrv] sfc: MC_CMD_SET_MAC can only be called by the link control Function (Jarod Wilson) [1199178]
- [netdrv] sfc: change definition of MC_CMD_VADAPTOR_ALLOC (Jarod Wilson) [1199178]
- [netdrv] sfc: Add permissions to MCDI commands (Jarod Wilson) [1199178]
- [netdrv] sfc: nicer log message on Siena SR-IOV probe fail (Jarod Wilson) [1199178]
- [netdrv] sfc: suppress some MCDI error messages in PTP (Jarod Wilson) [1199178]
- [netdrv] sfc: nicer log message on PTP probe fail (Jarod Wilson) [1199178]
- [netdrv] sfc: Bind the sfc driver to any available VF's (Jarod Wilson) [1199178]
- [netdrv] sfc: Add use of shared RSS contexts (Jarod Wilson) [1199178]
- [netdrv] sfc: Cope with permissions enforcement added to firmware for SR-IOV (Jarod Wilson) [1199178]
- [netdrv] sfc: manually allocate and free vadaptors (Jarod Wilson) [1199178]
- [netdrv] sfc: create vports for VFs and assign random MAC addresses (Jarod Wilson) [1199178]
- [netdrv] sfc: Prepare to bind the sfc driver to the VF (Jarod Wilson) [1199178]
- [netdrv] sfc: get the PF number and record in nic_data (Jarod Wilson) [1199178]
- [netdrv] sfc: create VEB vswitch and vport above default firmware setup (Jarod Wilson) [1199178]
- [netdrv] sfc: record the PF's vport ID in nic_data (Jarod Wilson) [1199178]
- [netdrv] sfc: Record [rt]x_dpcpu_fw_id in EF10 nic_data (Jarod Wilson) [1199178]
- [netdrv] sfc: Use MCDI to set FILTER_OP_IN_TX_DOMAIN (Jarod Wilson) [1199178]
- [netdrv] sfc: Enable VF's via a write to the sysfs file sriov_numvfs (Jarod Wilson) [1199178]
- [netdrv] sfc: Move and rename efx_vf struct to siena_vf (Jarod Wilson) [1199178]
- [netdrv] sfc: Own header for nic-specific sriov functions, single instance of netdev_ops and sriov removed from Falcon code (Jarod Wilson) [1199178]
- [netdrv] sfc: Fix memcpy() with const destination compiler warning (Jarod Wilson) [1199178]
- [netdrv] sfc: Revert SRIOV changes (Jarod Wilson) [1199178]
- [netdrv] sfc: Enable VF's via a write to the sysfs file sriov_numvfs (Jarod Wilson) [1199178]
- [netdrv] sfc: Own header for nic-specific sriov functions, single instance of netdev_ops and sriov removed from Falcon code (Jarod Wilson) [1199178]
- [netdrv] sfc: codespell comment spelling fixes (Jarod Wilson) [1199178]
- [netdrv] sfc: use netdev_rss_key_fill() helper (Jarod Wilson) [1199178]
- [netdrv] sfc: don't BUG_ON efx->max_channels == 0 in probe (Jarod Wilson) [1199178]
- [netdrv] sfc: Add NIC type operations to replace direct calls from efx.c into siena_sriov.c (Jarod Wilson) [1199178]
- [netdrv] sfc: Rename implementations in siena_sriov.c to have a 'siena' prefix (Jarod Wilson) [1199178]
- [netdrv] sfc: Move the current VF state from efx_nic into siena_nic_data (Jarod Wilson) [1199178]
- [netdrv] sfc: remove incorrect EFX_BUG_ON_PARANOID check (Jarod Wilson) [1199178]
- [netdrv] sfc: add support for skb->xmit_more (Jarod Wilson) [1199178]
- [netdrv] sfc: fix addr_list_lock spinlock use before init (Jarod Wilson) [1199178]
- [netdrv] sfc: Convert the normal transmit complete path to dev_consume_skb_any() (Jarod Wilson) [1199178]
- [netdrv] sfc: Use ether_addr_copy and eth_broadcast_addr (Jarod Wilson) [1199178]
- [netdrv] fm10k: Support for configurable RSS hash function (Neil Horman) [1173790]
- [netdrv] fm10k: Add CONFIG_FM10K_VXLAN configuration option (Neil Horman) [1173790]
- [netdrv] fm10k: Bump driver version to 0.15.2 (Neil Horman) [1173790]
- [netdrv] fm10k: corrected VF multicast update (Neil Horman) [1173790]
- [netdrv] fm10k: mbx_update_max_size does not drop all oversized messages (Neil Horman) [1173790]
- [netdrv] fm10k: reset head instead of calling update_max_size (Neil Horman) [1173790]
- [netdrv] fm10k: renamed mbx_tx_dropped to mbx_tx_oversized (Neil Horman) [1173790]
- [netdrv] fm10k: update xcast mode before synchronizing multicast addresses (Neil Horman) [1173790]
- [netdrv] fm10k: start service timer on probe (Neil Horman) [1173790]
- [netdrv] fm10k: fix function header comment (Neil Horman) [1173790]
- [netdrv] fm10k: comment next_vf_mbx flow (Neil Horman) [1173790]
- [netdrv] fm10k: don't handle mailbox events in iov_event path and always process mailbox (Neil Horman) [1173790]
- [netdrv] fm10k: use separate workqueue for fm10k driver (Neil Horman) [1173790]
- [netdrv] fm10k: Set PF queues to unlimited bandwidth during virtualization (Neil Horman) [1173790]
- [netdrv] fm10k: expose tx_timeout_count as an ethtool stat (Neil Horman) [1173790]
- [netdrv] fm10k: only increment tx_timeout_count in Tx hang path (Neil Horman) [1173790]
- [netdrv] fm10k: remove extraneous "Reset interface" message (Neil Horman) [1173790]
- [netdrv] fm10k: separate PF only stats so that VF does not display them (Neil Horman) [1173790]
- [netdrv] fm10k: use hw->mac.max_queues for stats (Neil Horman) [1173790]
- [netdrv] fm10k: only show actual queues, not the maximum in hardware (Neil Horman) [1173790]
- [netdrv] fm10k: allow creation of VLAN on default vid (Neil Horman) [1173790]
- [netdrv] fm10k: fix unused warnings (Neil Horman) [1173790]
- [netdrv] fm10k: Add netconsole support (Neil Horman) [1173790]
- [netdrv] fm10k: Have the VF get the default VLAN during init (Neil Horman) [1173790]
- [netdrv] fm10k: Correct spelling mistake (Neil Horman) [1173790]
- [netdrv] fm10k: Remove redundant rx_errors in ethtool (Neil Horman) [1173790]
- [netdrv] fm10k: Corrected an error in Tx statistics (Neil Horman) [1173790]
- [netdrv] fm10k: Resolve various spelling errors and checkpatch warnings (Neil Horman) [1173790]
- [netdrv] fm10k: Resolve compile warnings with W=1 (Neil Horman) [1173790]
- [netdrv] fm10k: Validate VLAN ID in fm10k_update_xc_addr_pf (Neil Horman) [1173790]
- [netdrv] fm10k: Increase the timeout for the data path reset (Neil Horman) [1173790]
- [netdrv] fm10k: Check tunnel header length in encap offload (Neil Horman) [1173790]
- [netdrv] fm10k: Avoid double setting of NETIF_F_SG for the HW encapsulation feature mask (Neil Horman) [1173790]
- [netdrv] fm10k: Clean-up page reuse code (Neil Horman) [1173790]
- [netdrv] fm10k: Use dma_rmb on Rx descriptor reads (Neil Horman) [1173790]
- [netdrv] fm10k: Unlock mailbox on VLAN addition failures (Neil Horman) [1173790]
- [netdrv] fm10k: Check the host state when bringing the interface up (Neil Horman) [1173790]
- [netdrv] fm10k: fix race accessing page->_count (Neil Horman) [1173790]
- [netdrv] fm10k: Correctly set the number of Tx queues (Neil Horman) [1173790]
- [netdrv] fm10k: Reduce buffer size when pages are larger than 4K (Neil Horman) [1173790]
- [netdrv] fm10k: using vmalloc requires including linux/vmalloc.h (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for PTP (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for ptp to hw specific files (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for debugfs (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for IEEE DCBx (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for SR-IOV to driver (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for SR-IOV to PF core files (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for VF (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for PF <-> VF mailbox (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for MACVLAN acceleration (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for netdev offloads (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for multiple queues (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for PCI power management and error handling (Neil Horman) [1173790]
- [netdrv] fm10k: Add ethtool support (Neil Horman) [1173790]
- [netdrv] fm10k: Add transmit and receive fastpath and interrupt handlers (Neil Horman) [1173790]
- [netdrv] fm10k: Add Tx/Rx hardware ring bring-up/tear-down (Neil Horman) [1173790]
- [netdrv] fm10k: Add service task to handle delayed events (Neil Horman) [1173790]
- [netdrv] fm10k: add support for Tx/Rx rings (Neil Horman) [1173790]
- [netdrv] fm10k: Add interrupt support (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for ndo_open/stop (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for L2 filtering (Neil Horman) [1173790]
- [net] Add support for device specific address syncing (Neil Horman) [1173790]
- [net] remove dead code for add/del multiple (Neil Horman) [1173790]
- [netdrv] fm10k: Add netdev (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for configuring PF interface (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for PF (Neil Horman) [1173790]
- [netdrv] fm10k: Implement PF <-> SM mailbox operations (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for mailbox (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for basic interaction with hardware (Neil Horman) [1173790]
- [netdrv] fm10k: Add support for TLV message parsing and generation (Neil Horman) [1173790]
- [netdrv] fm10k: Add register defines and basic structures (Neil Horman) [1173790]
- [netdrv] fm10k: Add skeletal frame for Intel(R) FM10000 Ethernet Switch Host Interface Driver (Neil Horman) [1173790]
- [netdrv] qlcnic: Fix trivial typo in comment (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Delete existing multicast MAC list before adding new (Chad Dupuis) [1187297]
- [netdrv] qlogic: Deletion of unnecessary checks before two function calls (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Fix NAPI poll routine for Tx completion (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Fix dump_skb output (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Fix return value in qlcnic_probe() (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Fix number of arguments in destroy tx context command (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Fix programming number of arguments in a command (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Fix ordering of stats in stats buffer (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Remove __QLCNIC_DEV_UP bit check to read TX queues statistics (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Fix memory corruption while reading stats using ethtool (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Use qlcnic_83xx_flash_read32() API instead of lockless version of the API (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Set skb->csum_level for encapsulated checksum (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Update version to 5.3.62 (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Add support to run firmware POST (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Use usleep_range() instead of msleep() for sleep less than 20ms (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Add support for 0x8830 device ID (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Update Link speed and port type info for 83xx adapter (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Fix endianess issue in firmware load from file operation (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Fix endianess issue in FW dump template header (Chad Dupuis) [1187297]
- [netdrv] qlcnic: Fix flash access interface to application (Chad Dupuis) [1187297]

* Thu Jun 25 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-281.el7]
- [scsi] megaraid: initialise block layer for using tagged commands (Tomas Henzl) [1234834]
- [x86] irq: Fix bug in setting IOAPIC pin attributes (Steve Best) [1231358 1234860]
- [x86] mm: Fix missing change to call of flush_tlb_others() in flush_tlb_mm_range() (Larry Woodman) [1172891]
- [net] svcrpc: fix potential GSSX_ACCEPT_SEC_CONTEXT decoding failures (Scott Mayhew) [1120860]
- [md] dm-space-map-metadata: fix occasional leak of a metadata block on resize (Mike Snitzer) [1222004]
- [md] dm-thin-metadata: fix a race when entering fail mode (Mike Snitzer) [1222004]
- [md] dm-thin: fail messages with EOPNOTSUPP when pool cannot handle messages (Mike Snitzer) [1222004]
- [md] dm-thin: range discard support (Mike Snitzer) [1222004]
- [md] dm-thin-metadata: add dm_thin_remove_range() (Mike Snitzer) [1222004]
- [md] dm-thin-metadata: add dm_thin_find_mapped_range() (Mike Snitzer) [1222004]
- [md] dm-btree: add dm_btree_remove_leaves() (Mike Snitzer) [1222004]
- [md] dm-thin: cleanup schedule_zero() to read more logically (Mike Snitzer) [1222004]
- [md] dm-thin: cleanup overwrite's endio restore to be centralized (Mike Snitzer) [1222004]
- [md] bio: fix kABI breakage when __bi_remaining was added to struct bio (Mike Snitzer) [1222004]
- [md] bio: extend struct bio with RHEL-specific struct bio_aux (Mike Snitzer) [1222004]
- [md] block: remove management of bi_remaining when restoring original bi_end_io (Mike Snitzer) [1222004]
- [md] bio: skip atomic inc_dec of ->bi_remaining for non-chains (Mike Snitzer) [1222004]
- [md] block: remove unused BIO_RW_BLOCK and BIO_EOF flags (Mike Snitzer) [1222004]
- [md] block: Fix BUG_ON when pi errors occur (Mike Snitzer) [1222004]
- [md] dm-raid1: fix immutable biovec related BUG when retrying read bio (Mike Snitzer) [1222004]
- [md] btrfs: fix wrong error handle when the device is missing or is not writeable (Mike Snitzer) [1222004]
- [md] btrfs: fix deadlock when mounting a degraded fs (Mike Snitzer) [1222004]
- [md] btrfs: use bio_endio_nodec instead of open code (Mike Snitzer) [1222004]
- [md] btrfs: fix missing increment of bi_remaining (Mike Snitzer) [1222004]
- [md] block: fixup for generic bio chaining (Mike Snitzer) [1222004]
- [md] block: Generic bio chaining (Mike Snitzer) [1222004]
- [vhost] relax used address alignment (Thomas Huth) [1227341]
- [virtio] virtio_ring: document alignment requirements (Thomas Huth) [1227341]
- [s390] pci: fix possible information leak in mmio syscall (Hendrik Brueckner) [1182169]
- [s390] pci: add missing address space annotation (Hendrik Brueckner) [1182169]
- [s390] kernel: add system calls for PCI memory access (Hendrik Brueckner) [1182169]
- [s390] hmcdrv: HMC drive CD/DVD access (Hendrik Brueckner) [1182294]
- [s390] irq: Use defines for external interruption codes (Hendrik Brueckner) [1182294]
- [s390] irq: Add defines for external interruption codes (Hendrik Brueckner) [1182294]
- [vfio] Fix runaway interruptible timeout (Alex Williamson) [1211739]
- [vfio] vfio-pci: Log device requests more verbosely (Alex Williamson) [1211739]
- [vfio] pci: Fix racy vfio_device_get_from_dev() call (Alex Williamson) [1230362]
- [scsi] iscsi: Fix iscsi endpoints leak (Chris Leech) [1231606]
- [scsi] libiscsi: fix potential buffer overrun in (Chris Leech) [1231606]
- [scsi] iscsi_tcp: export port being used (Chris Leech) [1231606]
- [scsi] iscsi_class: Fix freeing of skb in get host error path (Chris Leech) [1231606]
- [scsi] libiscsi: return new error code when nop times out (Chris Leech) [1231606]
- [scsi] iscsi_class: fix get_host_stats return code when not (Chris Leech) [1231606]
- [scsi] iscsi_class: fix get_host_stats error handling (Chris Leech) [1231606]
- [scsi] iscsi: kill redundant casts (Chris Leech) [1231606]
- [scsi] libiscsi: Fix static checker warning on bh locking (Chris Leech) [1231606]
- [scsi] iscsi_tcp: check for valid session before accessing (Chris Leech) [1231606]
- [scsi] iscsi_boot_sysfs: Fix a memory leak in (Chris Leech) [1231606]
- [scsi] libiscsi: remove unneeded queue work when max_cmdsn is (Chris Leech) [1231606]
- [scsi] libiscsi: Reduce locking contention in fast path (Chris Leech) [1231606]
- [scsi] libiscsi: Restructure iscsi_tcp r2t response logic (Chris Leech) [1231606]
- [scsi] iscsi: fix wrong order of opcode and itt in (Chris Leech) [1231606]
- [scsi] libiscsi: Add local_ipaddr parameter in iscsi_conn (Chris Leech) [1231606]
- [net] rename local_df to ignore_df (Jiri Benc) [1200759]
- [net] netlink: implement nla_get_in_addr and nla_get_in6_addr (Jiri Benc) [1200759]
- [net] netlink: implement nla_put_in_addr and nla_put_in6_addr (Jiri Benc) [1200759]
- [net] xfrm: simplify xfrm_address_t use (Jiri Benc) [1200759]
- [net] tcp: simplify inetpeer_addr_base use (Jiri Benc) [1200759]
- [net] Introduce possible_net_t (Jiri Benc) [1200759]
- [net] Replace u64_stats_fetch_begin_bh to u64_stats_fetch_begin_irq (Jiri Benc) [1200759]
- [net] Add support to configure SR-IOV VF minimum and maximum Tx rate through ip tool (Ivan Vecera) [1200759]
- [net] gro: add a per device gro flush timer (Ivan Vecera) [1200759]
- [net] introduce extended napi_struct (Ivan Vecera) [1200759]
- [net] xfrm: announce deleation of temporary SA (Herbert Xu) [1210334]
- [net] rtnetlink: fix userspace API breakage for iproute2 < v3.9.0 (Michal Schmidt) [1191660]
- [net] netlink: rate-limit leftover bytes warning and print process name (Michal Schmidt) [1191660]
- [net] tcp: RFC7413 option support for Fast Open client (Marcelo Leitner) [1219204]
- [net] tcp: RFC7413 option support for Fast Open server (Marcelo Leitner) [1219204]
- [net] tcp: fix saving TX flow hash in sock for outgoing connections (Ivan Vecera) [1215920]
- [net] flow_dissector: Call skb_get_hash in get_xps_queue and __skb_tx_hash (Ivan Vecera) [1215920]
- [net] ipv6: provide stubs for ip6_set_txhash and ip6_make_flowlabel (Ivan Vecera) [1215920]
- [net] ip: Save TX flow hash in sock and set in skbuf on xmit (Ivan Vecera) [1215920]
- [net] flow_dissector: Abstract out hash computation (Ivan Vecera) [1215920]
- [net] Rename skb->rxhash to skb->hash (Ivan Vecera) [1215920]
- [netdrv] sky2: sky2 calls skb_set_hash (Ivan Vecera) [1215920]
- [netdrv] cxgb4: cxgb4 calls skb_set_hash (Ivan Vecera) [1215920]
- [net] flow_dissector: initialize hashrnd in flow_dissector with net_get_random_once (Ivan Vecera) [1215920]
- [net] netfilter: x_tables: avoid percpu ruleset duplication (Phil Sutter) [1231910]
- [net] netfilter: x_tables: xt_free_table_info() cleanup (Phil Sutter) [1231910]
- [net] netfilter: x_tables: use percpu rule counters (Phil Sutter) [1231910]
- [net] fix wrong mac_len calculation for vlans (Vlad Yasevich) [1135619]
- [net] Start with correct mac_len in skb_network_protocol (Vlad Yasevich) [1135619]
- [net] Account for all vlan headers in skb_mac_gso_segment (Vlad Yasevich) [1135619]
- [net] vti6: Add pmtu handling to vti6_xmit (Alexander Duyck) [1129761]
- [net] vti, vti6: Preserve skb->mark after rcv_cb call (Alexander Duyck) [1129761]
- [net] xfrm: Override skb->mark with tunnel->parm.i_key in xfrm_input (Alexander Duyck) [1129761]
- [net] vti, vti6: Do not touch skb->mark on xmit (Alexander Duyck) [1129761]
- [net] ip_tunnel: Report Rx dropped in ip_tunnel_get_stats64 (Alexander Duyck) [1129761]
- [net] vti6: implement ndo_get_iflink (Alexander Duyck) [1129761]
- [net] vti6: advertise link netns via netlink (Alexander Duyck) [1129761]
- [net] ah6: Use the IPsec protocol multiplexer API (Alexander Duyck) [1129761]
- [net] ipcomp6: Use the IPsec protocol multiplexer API (Alexander Duyck) [1129761]
- [net] esp6: Use the IPsec protocol multiplexer API (Alexander Duyck) [1129761]
- [net] esp: fix potential MTU calculation overflows (Alexander Duyck) [1129761]
- [net] vti: Simplify error handling in module init and exit (Alexander Duyck) [1129761]
- [net] xfrm6: Properly handle unsupported protocols (Alexander Duyck) [1129761]
- [net] vti6: fix uninit when using x-netns (Alexander Duyck) [1129761]
- [net] vti6: Add a lookup method for tunnels with wildcard endpoints (Alexander Duyck) [1129761]
- [net] vti6: Allow sending packets through tunnels with wildcard endpoints (Alexander Duyck) [1129761]
- [net] vti6: Use vti6_dev_init as the ndo_init function (Alexander Duyck) [1129761]
- [net] better IFF_XMIT_DST_RELEASE support (Alexander Duyck) [1129761]
- [net] move net_device priv_flags out from UAPI (Alexander Duyck) [1129761]
- [net] kdoc struct net_device flags and priv_flags (Alexander Duyck) [1129761]
- [net] vti6: Return an error when adding an existing tunnel (Alexander Duyck) [1129761]
- [net] vti6: Simplify error handling in module init and exit (Alexander Duyck) [1129761]
- [net] vti6: delete unneeded call to netdev_priv (Alexander Duyck) [1129761]
- [net] vti6: Use the tunnel mark for lookup in the error handlers (Alexander Duyck) [1129761]
- [net] vti6: Don't unregister pernet ops twice on init errors (Alexander Duyck) [1129761]
- [net] vti6: Enable namespace changing (Alexander Duyck) [1129761]
- [net] vti6: Check the tunnel endpoints of the xfrm state and the vti interface (Alexander Duyck) [1129761]
- [net] vti6: Support inter address family tunneling (Alexander Duyck) [1129761]
- [net] vti6: Update the ipv6 side to use its own receive hook (Alexander Duyck) [1129761]
- [net] xfrm6: Add IPsec protocol multiplexer (Alexander Duyck) [1129761]
- [net] xfrm: Introduce xfrm_input_afinfo to access the the callbacks properly (Alexander Duyck) [1129761]
- [net] vti6: Remove caching of flow informations (Alexander Duyck) [1129761]
- [net] vti6: Remove dst_entry caching (Alexander Duyck) [1129761]
- [net] vti6: unify the pcpu_tstats and br_cpu_netstats as one (Alexander Duyck) [1129761]
- [net] ipv6: fix the use of pcpu_tstats in ip6_vti.c (Alexander Duyck) [1129761]
- [net] ip_tunnel: the lack of vti_link_ops' dellink() cause kernel panic (Alexander Duyck) [1129761]
- [net] ipv6: Add support for IPsec virtual tunnel interfaces (Alexander Duyck) [1129761]
- [net] ipv6: Add a receive path hook for vti6 in xfrm6_mode_tunnel (Alexander Duyck) [1129761]
- [netdrv] netxen_nic: use spin_[un]lock_bh around tx_clean_lock (2) (Tony Camuso) [1217748]
- [netdrv] netxen_nic: use spin_[un]lock_bh around tx_clean_lock (Tony Camuso) [1217748]

* Wed Jun 24 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-280.el7]
- [block] xen-blkfront: fix accounting of reqs when migrating (Vitaly Kuznetsov) [1096909]
- [block] xen-blkfront: remove redundant flush_op (Vitaly Kuznetsov) [1096909]
- [block] xen-blkfront: improve protection against issuing unsupported REQ_FUA (Vitaly Kuznetsov) [1096909]
- [block] xen-blkfront: factor out flush-related checks from do_blkif_request() (Vitaly Kuznetsov) [1096909]
- [block] xen-blkfront: remove type check from blkfront_setup_discard (Vitaly Kuznetsov) [1096909]
- [block] xen-blkif: drop struct blkif_request_segment_aligned (Vitaly Kuznetsov) [1096909]
- [block] xen-blkfront: Fix possible NULL ptr dereference (Vitaly Kuznetsov) [1096909]
- [block] xen-blkfront: Silence pfn maybe-uninitialized warning (Vitaly Kuznetsov) [1096909]
- [block] xen-blkfront: restore the non-persistent data path (Vitaly Kuznetsov) [1096909]
- [block] xen-blkfront: improve aproximation of required grants per request (Vitaly Kuznetsov) [1096909]
- [block] xen-blkfront: revoke foreign access for grants not mapped by the backend (Vitaly Kuznetsov) [1096909]
- [netdrv] e1000e: Bump the version to 3.2.5 (John Greene) [1173782]
- [netdrv] e1000e: fix unit hang during loopback test (John Greene) [1173782]
- [netdrv] e1000e: fix systim issues (John Greene) [1173782]
- [netdrv] e1000e: fix legacy interrupt handling in i219 (John Greene) [1173782]
- [netdrv] e1000e: fix flush_desc_ring implementation (John Greene) [1173782]
- [netdrv] e1000e: fix logical error in flush_desc_rings (John Greene) [1173782]
- [netdrv] e1000e: remove call to do_div and sign mismatch warning (John Greene) [1173782]
- [netdrv] e1000e: i219 execute unit hang fix on every reset or power state transition (John Greene) [1173782]
- [netdrv] e1000e: i219 fix unit hang on reset and runtime D3 (John Greene) [1173782]
- [netdrv] e1000e: Add pm_qos header (John Greene) [1173782]
- [netdrv] e1000e: fix call to do_div() to use u64 arg (John Greene) [1173782]
- [netdrv] e1000e: Do not allow CRC stripping to be disabled on 82579 w/ jumbo frames (John Greene) [1173782]
- [netdrv] e1000e: Cleanup handling of VLAN_HLEN as a part of max frame size (John Greene) [1173782]
- [netdrv] e1000e: Use dma_rmb instead of rmb for descriptor read ordering (John Greene) [1173782]
- [netdrv] e1000e: NVM write protect access removed from SPT HW (John Greene) [1173782]
- [netdrv] e1000e: call netif_carrier_off early on down (John Greene) [1173782]
- [netdrv] e1000e: remove calls to ioremap/unmap for NVM addr (John Greene) [1173782]
- [netdrv] e1000e: fix obscure comments (John Greene) [1173782]
- [netdrv] e1000e: initial support for i219 (John Greene) [1173782]
- [netdrv] e1000e: support txtd update delay via xmit_more (John Greene) [1173782]
- [netdrv] e1000e: Use eth_skb_pad and skb_put_padto helpers (John Greene) [1173782]
- [netdrv] e1000e: Eliminate CONFIG_PM_RUNTIME (John Greene) [1173782]
- [netdrv] e1000e: use netdev_rss_key_fill() helper (John Greene) [1173782]
- [netdrv] e1000e: Cleanup return values in ethtool (John Greene) [1173782]
- [netdrv] e1000e: delete excessive space character in debug message (John Greene) [1173782]
- [netdrv] e1000e: fix trivial kernel doc typos (John Greene) [1173782]
- [virtio] Add virtio-input driver (Gerd Hoffmann) [1231743]
- [kvm] ioapic: Record edge-triggered interrupts delivery status (Gerd Hoffmann) [1173817]
- [kernel] sched: Fix KMALLOC_MAX_SIZE overflow during cpumask allocation (Frank Ramsay) [1209156]
- [x86] kvm: fix lapic.timer_mode on restore (Radim Krcmar) [1228342]
- [pci] Add ACS quirks for Intel 1G NICs (Alex Williamson) [1176512]
- [mfd] lpc_ich: Assign subdevice ids automatically (Prarit Bhargava) [1231296]
- [x86] kernel: Load TLS descriptors before switching DS and ES (Adrian Reber) [1223330] {CVE-2014-9419}
- [powerpc] kvm: Correct backport of h_logical_ci_{load, store} (David Gibson) [1229952]
- [powerpc] rcu: Make list_splice_init_rcu() account for RCU readers (David Gibson) [1232550]
- [powerpc] powernv: Remove powernv RTAS support (David Gibson) [1232550]
- [powerpc] powernv/iommu: disable IOMMU bypass with param iommu=nobypass (David Gibson) [1232550]
- [powerpc] pseries: Avoid deadlock on removing ddw (David Gibson) [1232550]
- [powerpc] iommu: Remove IOMMU device references via bus notifier (David Gibson) [1232550]
- [powerpc] powernv: Use it_page_shift for TCE invalidation (David Gibson) [1232550]
- [powerpc] powernv: Use it_page_shift in TCE build (David Gibson) [1232550]
- [powerpc] iommu: Fix comments with it_page_shift (David Gibson) [1232550]
- [powerpc] powernv: Shift VF resource with an offset (David Gibson) [1232550]
- [powerpc] powernv: Set PELTV for compound PEs (David Gibson) [1232550]
- [powerpc] powernv: Reserve additional space for IOV BAR according to the number of total_pe (David Gibson) [1232550]
- [powerpc] pci: Keep individual VF BAR size in struct pci_sriov (David Gibson) [1232550]
- [powerpc] pci: Remove fixed parameter in pci_iov_resource_bar() (David Gibson) [1232550]
- [powerpc] pci: Print PF SR-IOV resource that contains all VF(n) BAR space (David Gibson) [1232550]
- [powerpc] pci-ioda: Use a single function to emit logging messages (David Gibson) [1232550]
- [powerpc] pci-ioda: Remove unnecessary return value from printk (David Gibson) [1232550]
- [powerpc] powernv: Allocate struct pnv_ioda_pe iommu_table dynamically (David Gibson) [1232550]
- [powerpc] add real mode support for dma operations on powernv (David Gibson) [1232550]
- [powerpc] powernv: Add a page size parameter to pnv_pci_setup_iommu_table() (David Gibson) [1232550]
- [powerpc] powernv: only register log if OPAL supports doing so (Gustavo Duarte) [1221918]
- [powerpc] powernv: only call OPAL_ELOG_RESEND if firmware supports it (Gustavo Duarte) [1221918]
- [powerpc] powernv: Check OPAL elog calls exist before using (Gustavo Duarte) [1221918]
- [powerpc] powernv: fix world-writable sysfs files (Gustavo Duarte) [1221918]
- [powerpc] powernv: only call OPAL_RESEND_DUMP if firmware supports it (Gustavo Duarte) [1221918]
- [powerpc] powernv: Check OPAL dump calls exist before using (Gustavo Duarte) [1221918]
- [powerpc] powernv: Improve error messages in dump code (Gustavo Duarte) [1221918]
- [powerpc] powernv: fix world-writable sysfs files (0/8) (Gustavo Duarte) [1221918]
- [perf] probe: Ignore tail calls to probed functions (Gustavo Duarte) [1223850]
- [perf] probe: ppc64le: Fixup function entry if using kallsyms lookup (Gustavo Duarte) [1223850]
- [perf] probe: ppc64le: Prefer symbol table lookup over DWARF (Gustavo Duarte) [1223850]
- [perf] probe: ppc64le: Fix ppc64 ABIv2 symbol decoding (Gustavo Duarte) [1223850]
- [perf] probe: ppc: Enable matching against dot symbols automatically (Gustavo Duarte) [1223850]
- [perf] probe: ppc: Use the right prefix when ignoring SyS symbols on ppc (Gustavo Duarte) [1223850]
- [perf] probe: ppc: Fix symbol fixup issues due to ELF type (Gustavo Duarte) [1223850]
- [perf] probe: Improve detection of file/function name in the probe: pattern (Gustavo Duarte) [1223850]
- [perf] powerpc/kprobes: Fix kallsyms lookup across powerpc ABIv1 and ABIv2 (Gustavo Duarte) [1223850]
- [powerpc] eeprom: at24: extend driver to allow writing via i2c_smbus_write_byte_data (Gustavo Duarte) [1221093]
- [powerpc] misc/at24: avoid infinite loop on write() (Gustavo Duarte) [1221093]
- [powerpc] misc: at24: move header to linux/platform_data/ (Gustavo Duarte) [1221093]
- [powerpc] drivers/misc: at24: convert to use devm_kzalloc (Gustavo Duarte) [1221093]
- [hwmon] config: Enable IBM POWERNV platform sensors for ppc64le (Gustavo Duarte) [1224367]
- [hwmon] powerpc/powernv: handle OPAL_SUCCESS return in opal_sensor_read (Gustavo Duarte) [1224367]
- [hwmon] powerpc/powernv: convert codes returned by OPAL calls (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: Fix build error seen for some configurations (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: pretty print labels (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: add a label attribute (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: add support for the new device tree (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: add a helper routine create_hwmon_attr (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: do not use the OPAL index for hwmon attribute names (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: change create_hwmon_attr_name() prototype (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: add a convert_opal_attr_name() routine (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: add a get_sensor_type() routine (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: replace AMBIENT_TEMP by TEMP (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: Convert to module_platform_driver (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: Use platform 'id_table' to probe the device (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: Quieten when probing finds no device (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: Use of_property_read_u32 at appropriate place (Gustavo Duarte) [1224367]
- [hwmon] ibmpowernv: hwmon driver for power, fan rpm, voltage and temperature (Gustavo Duarte) [1224367]
- [powerpc] kvm: book3s: hv: Fix an issue where guest is paused on receiving HMI (Gustavo Duarte) [1221091]
- [powerpc] powernv: Fix the hmi event version check (Gustavo Duarte) [1221091]
- [powerpc] powernv: Fallback to old HMI handling behavior for old firmware (Gustavo Duarte) [1221091]
- [powerpc] book3s: Don't clear MSR_RI in hmi handler (Gustavo Duarte) [1221091]
- [powerpc] use machine_subsys_initcall() for opal_hmi_handler_init() (Gustavo Duarte) [1221091]
- [powerpc] book3s: Fix endianess issue for HMI handling on napping cpus (Gustavo Duarte) [1221091]
- [powerpc] book3s: handle HMIs for cpus in nap mode (Gustavo Duarte) [1221091]
- [powerpc] powernv: Invoke opal call to handle hmi (Gustavo Duarte) [1221091]
- [powerpc] book3s: Add basic infrastructure to handle HMI in Linux (Gustavo Duarte) [1221091]
- [i2c] move OF helpers into the core (Gustavo Duarte) [1221075]
- [i2c] Improve logging on failure to probe for ->class devices (Gustavo Duarte) [1221075]
- [i2c] add sanity check to i2c_put_adapter (Gustavo Duarte) [1221075]
- [i2c] opal: Update quirk flags to do write-then-anything (Gustavo Duarte) [1221075]
- [i2c] opal: make use of the new infrastructure for quirks (Gustavo Duarte) [1221075]
- [i2c] add quirk checks to core (Gustavo Duarte) [1221075]
- [i2c] add quirk structure to describe adapter flaws (Gustavo Duarte) [1221075]
- [i2c] Driver to expose PowerNV platform i2c busses (Gustavo Duarte) [1221075]

* Wed Jun 24 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-279.el7]
- [fs] vfs: atomic f_pos access in llseek() (Zach Brown) [1175954]
- [fs] vfs: atomic f_pos accesses as per POSIX (Zach Brown) [1175954]
- [fs] nfs: remove WARN_ON_ONCE from nfs_direct_good_bytes (Steve Dickson) [1217590]
- [fs] nfs: fix DIO good bytes calculation (Steve Dickson) [1217590]
- [fs] pnfs: Refactor the *_layout_mark_request_commit to use pnfs_layout_mark_request_commit (Steve Dickson) [1217590]
- [fs] sunrpc: Fix a compile error when #undef CONFIG_PROC_FS (Steve Dickson) [1217590]
- [fs] pnfs/flexfiles: Do not dprintk after the free (Steve Dickson) [1217590]
- [fs] nfs: mirroring support for direct io (Steve Dickson) [1217590]
- [fs] pnfs: lookup new lseg at lseg boundary (Steve Dickson) [1217590]
- [fs] nfs41: .init_read and .init_write can be called with valid pg_lseg (Steve Dickson) [1217590]
- [fs] pnfs: Update documentation on the Layout Drivers (Steve Dickson) [1217590]
- [fs] pnfs/flexfiles: Add the FlexFile Layout Driver (Steve Dickson) [1217590]
- [fs] nfs: count DIO good bytes correctly with mirroring (Steve Dickson) [1217590]
- [fs] nfs41: wait for LAYOUTRETURN before retrying LAYOUTGET (Steve Dickson) [1217590]
- [fs] nfs: add a helper to set NFS_ODIRECT_RESCHED_WRITES to direct writes (Steve Dickson) [1217590]
- [fs] nfs41: add NFS_LAYOUT_RETRY_LAYOUTGET to layout header flags (Steve Dickson) [1217590]
- [fs] nfs/flexfiles: send layoutreturn before freeing lseg (Steve Dickson) [1217590]
- [fs] nfs41: introduce NFS_LAYOUT_RETURN_BEFORE_CLOSE (Steve Dickson) [1217590]
- [fs] nfs41: allow async version layoutreturn (Steve Dickson) [1217590]
- [fs] nfs41: add range to layoutreturn args (Steve Dickson) [1217590]
- [fs] pnfs: allow LD to ask to resend read through pnfs (Steve Dickson) [1217590]
- [fs] nfs: add nfs_pgio_current_mirror helper (Steve Dickson) [1217590]
- [fs] nfs: only reset desc->pg_mirror_idx when mirroring is supported (Steve Dickson) [1217590]
- [fs] nfs41: add a debug warning if we destroy an unempty layout (Steve Dickson) [1217590]
- [fs] pnfs: fail comparison when bucket verifier not set (Steve Dickson) [1217590]
- [fs] nfs: add mirroring support to pgio layer (Steve Dickson) [1217590]
- [fs] pnfs: pass ds_commit_idx through the commit path (Steve Dickson) [1217590]
- [fs] nfs: rename pgio header ds_idx to ds_commit_idx (Steve Dickson) [1217590]
- [fs] nfs: handle overlapping reqs in lock_and_join (Steve Dickson) [1217590]
- [fs] pnfs: release lseg in pnfs_generic_pg_cleanup (Steve Dickson) [1217590]
- [fs] nfs: introduce pg_cleanup op for pgio descriptors (Steve Dickson) [1217590]
- [fs] nfs/filelayout: use pnfs_error_mark_layout_for_return (Steve Dickson) [1217590]
- [fs] nfs41: clear NFS_LAYOUT_RETURN if layoutreturn is sent or failed to send (Steve Dickson) [1217590]
- [fs] nfs41: send layoutreturn in last put_lseg (Steve Dickson) [1217590]
- [fs] nfs41: don't use a layout if it is marked for returning (Steve Dickson) [1217590]
- [fs] nfs41: add a helper to mark layout for return (Steve Dickson) [1217590]
- [fs] nfs41: make a helper function to send layoutreturn (Steve Dickson) [1217590]
- [fs] nfs41: pass iomode through layoutreturn args (Steve Dickson) [1217590]
- [fs] nfs: save server READ/WRITE/COMMIT status (Steve Dickson) [1217590]
- [fs] nfs41: serialize first layoutget of a file (Steve Dickson) [1217590]
- [fs] nfs41: close a small race window when adding new layout to global list (Steve Dickson) [1217590]
- [fs] nfs/flexclient: export pnfs_layoutcommit_inode (Steve Dickson) [1217590]
- [fs] nfs: set hostname when creating nfsv3 ds connection (Steve Dickson) [1217590]
- [fs] sunrpc: add rpc_count_iostats_idx (Steve Dickson) [1217590]
- [fs] sunrpc: serialize iostats updates (Steve Dickson) [1217590]
- [fs] nfsv4.1/nfsv3: Add pNFS callbacks for nfs3_(read|write|commit)_done() (Steve Dickson) [1217590]
- [fs] nfs: allow to specify cred in nfs_initiate_pgio (Steve Dickson) [1217590]
- [fs] nfs4: export nfs4_sequence_done (Steve Dickson) [1217590]
- [fs] nfs4: pass slot table to nfs40_setup_sequence (Steve Dickson) [1217590]
- [fs] nfs: allow different protocol in nfs_initiate_commit (Steve Dickson) [1217590]
- [fs] pnfs: Add nfs_rpc_ops in calls to nfs_initiate_pgio (Steve Dickson) [1217590]
- [fs] nfs41: create NFSv3 DS connection if specified (Steve Dickson) [1217590]
- [fs] nfs41: allow LD to choose DS connection version/minor_version (Steve Dickson) [1217590]
- [fs] nfsv3: introduce nfs3_set_ds_client (Steve Dickson) [1217590]
- [fs] nfs41: move file layout macros to generic pnfs (Steve Dickson) [1217590]
- [fs] nfs41: allow LD to choose DS connection auth flavor (Steve Dickson) [1217590]
- [fs] nfs41: pull nfs4_ds_connect from file layout to generic pnfs (Steve Dickson) [1217590]
- [fs] nfs41: pull decode_ds_addr from file layout to generic pnfs (Steve Dickson) [1217590]
- [fs] nfs41: pull data server cache from file layout to generic pnfs (Steve Dickson) [1217590]
- [fs] pnfs: Do not grab the commit_info lock twice when rescheduling writes (Steve Dickson) [1217590]
- [fs] pnfs: Prepare for flexfiles by pulling out common code (Steve Dickson) [1217590]
- [fs] cifs: Fix readpages retrying on reconnects (Sachin Prabhu) [1197696]
- [fs] Update cifs version (Sachin Prabhu) [1197696]
- [fs] cifs: Fix STATUS_CANNOT_DELETE error mapping for SMB2 (Sachin Prabhu) [1197696]
- [fs] cifs: Optimize readpages in a short read case on reconnects (Sachin Prabhu) [1197696]
- [fs] cifs: Optimize cifs_user_read() in a short read case on reconnects (Sachin Prabhu) [1197696]
- [fs] cifs: Improve indentation in cifs_user_read() (Sachin Prabhu) [1197696]
- [fs] cifs: Fix possible buffer corruption in cifs_user_read() (Sachin Prabhu) [1197696]
- [fs] cifs: Count got bytes in read_into_pages() (Sachin Prabhu) [1197696]
- [fs] cifs: Use separate var for the number of bytes got in async read (Sachin Prabhu) [1197696]
- [fs] cifs: Indicate reconnect with ECONNABORTED error code (Sachin Prabhu) [1197696]
- [fs] cifs: Use multicredits for SMB 2.1/3 reads (Sachin Prabhu) [1197696]
- [fs] cifs: Fix rsize usage for sync read (Sachin Prabhu) [1197696]
- [fs] cifs: Fix rsize usage in user read (Sachin Prabhu) [1197696]
- [fs] cifs: Separate page reading from user read (Sachin Prabhu) [1197696]
- [fs] cifs: Fix rsize usage in readpages (Sachin Prabhu) [1197696]
- [fs] cifs: Separate page search from readpages (Sachin Prabhu) [1197696]
- [fs] cifs: Use multicredits for SMB 2.1/3 writes (Sachin Prabhu) [1197696]
- [fs] cifs: Fix wsize usage in iovec write (Sachin Prabhu) [1197696]
- [fs] cifs: Separate writing from iovec write (Sachin Prabhu) [1197696]
- [fs] cifs: Separate filling pages from iovec write (Sachin Prabhu) [1197696]
- [fs] cifs: Fix cifs_writev_requeue when wsize changes (Sachin Prabhu) [1197696]
- [fs] cifs: Fix wsize usage in writepages (Sachin Prabhu) [1197696]
- [fs] cifs: Separate pages initialization from writepages (Sachin Prabhu) [1197696]
- [fs] cifs: Separate page sending from writepages (Sachin Prabhu) [1197696]
- [fs] Remove sparse build warning (Sachin Prabhu) [1197696]
- [fs] cifs: Separate page processing from writepages (Sachin Prabhu) [1197696]
- [fs] cifs: Fix async reading on reconnects (Sachin Prabhu) [1197696]
- [fs] cifs: Separate rawntlmssp auth from CIFS_SessSetup() (Sachin Prabhu) [1197696]
- [fs] cifs: Split Kerberos authentication off CIFS_SessSetup() (Sachin Prabhu) [1197696]
- [fs] cifs: Split ntlm and ntlmv2 authentication methods off CIFS_SessSetup() (Sachin Prabhu) [1197696]
- [fs] cifs: Split lanman auth from CIFS_SessSetup() (Sachin Prabhu) [1197696]
- [fs] cifs: replace code with free_rsp_buf() (Sachin Prabhu) [1197696]
- [fs] fix mount failure with broken pathnames when smb3 mount with mapchars option (Sachin Prabhu) [1197696]
- [fs] cifs: revalidate mapping prior to satisfying read_iter request with cache=loose (Sachin Prabhu) [1197696]
- [fs] cifs: switch to ->write_iter() (Sachin Prabhu) [1197696]
- [fs] cifs: switch to ->read_iter() (Sachin Prabhu) [1197696]
- [fs] kill iov_iter_copy_from_user() (Partial) (Sachin Prabhu) [1197696]
- [fs] cifs: Use min_t() when comparing "size_t" and "unsigned long" (Sachin Prabhu) [1197696]
- [fs] fold cifs_iovec_read() into its (only) caller (Sachin Prabhu) [1197696]
- [fs] cifs_iovec_read: keep iov_iter between the calls of cifs_readdata_to_iov() (Sachin Prabhu) [1197696]
- [fs] cifs: Add helpers copy_page_from_iter(), copy_page_to_iter() and iov_iter_truncate() (Sachin Prabhu) [1197696]
- [fs] cifs_iovec_read(): resubmit shouldn't restart the loop (Sachin Prabhu) [1197696]
- [fs] gfs2: limit quota log messages (Abhijith Das) [1174295]
- [fs] gfs2: fix quota updates on block boundaries (Abhijith Das) [1174295]
- [fs] gfs2: fix quota refresh race in do_glock() (Abhijith Das) [1174295]
- [fs] gfs2: allow fallocate to max out quotas/fs efficiently (Abhijith Das) [1174295]
- [fs] gfs2: allow quota_check and inplace_reserve to return available blocks (Abhijith Das) [1174295]
- [fs] gfs2: perform quota checks against allocation parameters (Abhijith Das) [1174295]

* Tue Jun 23 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-278.el7]
- [alsa] regmap: regcache-rbtree: Fix present bitmap resize (Jaroslav Kysela) [1197064]
- [alsa] regmap: rbtree: improve 64bits memory alignment (Jaroslav Kysela) [1197064]
- [alsa] regmap: rbtree: Make cache_present bitmap per node (Jaroslav Kysela) [1197064]
- [alsa] regmap: Add support for discarding parts of the register cache (Jaroslav Kysela) [1197064]
- [alsa] regmap: rbtree: Reduce number of nodes, take 2 (Jaroslav Kysela) [1197064]
- [alsa] regmap: rbtree: Simplify adjacent node look-up (Jaroslav Kysela) [1197064]
- [alsa] regcache-rbtree: Fix reg_stride != 1 (Jaroslav Kysela) [1197064]
- [alsa] regmap: rbtree: Use range information to allocate nodes (Jaroslav Kysela) [1197064]
- [alsa] regmap: rbtree: Factor out node allocation (Jaroslav Kysela) [1197064]
- [alsa] pci/msi: Add device flag indicating that 64-bit MSIs don't work (Jaroslav Kysela) [1197064]
- [alsa] pm: Add pm_runtime_suspend|resume_force functions (Jaroslav Kysela) [1197064]
- [alsa] pm / runtime: Implement the pm_generic_runtime functions for CONFIG_PM (Jaroslav Kysela) [1197064]
- [alsa] pm / runtime: Fetch runtime PM callbacks using a macro (Jaroslav Kysela) [1197064]
- [alsa] pm / runtime: Respect autosuspend when idle triggers suspend (Jaroslav Kysela) [1197064]
- [alsa] drm/i915/audio: add codec wakeup override enabled/disable callback (Jaroslav Kysela) [1197064]
- [alsa] hda - fix number of devices query on hotplug (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: add native DSD support for JLsounds I2SoverUSB (Jaroslav Kysela) [1197064]
- [alsa] hda - remove controller dependency on i915 power well for SKL (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: fix missing input volume controls in MAYA44 USB(+) (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: add MAYA44 USB+ mixer control names (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Add a fixup for another Acer Aspire 9420 (Jaroslav Kysela) [1197064]
- [alsa] hda - moved alloc/free stream pages function to controller library (Jaroslav Kysela) [1197064]
- [alsa] hda - add generic functions to set hdac stream params (Jaroslav Kysela) [1197064]
- [alsa] Close holes in struct snd_pcm_constraint_list (Jaroslav Kysela) [1197064]
- [alsa] Close holes in struct snd_pcm_hw_rule (Jaroslav Kysela) [1197064]
- [alsa] core: remove .wall_clock (Jaroslav Kysela) [1197064]
- [alsa] core: selection of audio_tstamp type and accuracy reports (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix jack detection at resume with VT codecs (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: don't try to get Outlaw RR2150 sample rate (Jaroslav Kysela) [1197064]
- [alsa] jack: Fix the id uniqueness check (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add mic volume fix quirk for Logitech Quickcam Fusion (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Suooprt Dell headset mode for ALC256 (Jaroslav Kysela) [1197064]
- [alsa] hda - Set patch_ops before calling auto-parser (Jaroslav Kysela) [1197064]
- [alsa] pci: Drop superfluous ifdef CONFIG_PROC_FS (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: Fix/cleanup ifdef CONFIG_PROC_FS (Jaroslav Kysela) [1197064]
- [alsa] cs46xx: Fix old ifdef CONFIG_PROC_FS (Jaroslav Kysela) [1197064]
- [alsa] ca0106: Fix/cleanup ifdef CONFIG_PROC_FS (Jaroslav Kysela) [1197064]
- [alsa] ac97: Fix ifdef CONFIG_PROC_FS (Jaroslav Kysela) [1197064]
- [alsa] ak4xxx-adda: Drop unnecessary ifdef CONFIG_PROC_FS (Jaroslav Kysela) [1197064]
- [alsa] opl4: Fix / cleanup ifdef CONFIG_PROC_FS (Jaroslav Kysela) [1197064]
- [alsa] dummy: Replace CONFIG_PROC_FS with CONFIG_SND_PROC_FS (Jaroslav Kysela) [1197064]
- [alsa] aloop: Drop unnecessary ifdef CONFIG_PROC_FS (Jaroslav Kysela) [1197064]
- [alsa] core: Fix randconfig build wrt CONFIG_PROC_FS (Jaroslav Kysela) [1197064]
- [alsa] hda - Drop unused fields from struct hda_codec_preset (Jaroslav Kysela) [1197064]
- [alsa] replace CONFIG_PROC_FS with CONFIG_SND_PROC_FS (Jaroslav Kysela) [1197064]
- [alsa] kconfig: add config item SND_PROC_FS for expert (Jaroslav Kysela) [1197064]
- [alsa] bcd2000: Make local data static (Jaroslav Kysela) [1197064]
- [alsa] lx6464es: Use NULL for pointers (Jaroslav Kysela) [1197064]
- [alsa] lx6464es: Fix duplicated SSID entries (Jaroslav Kysela) [1197064]
- [alsa] dummy: make local data static (Jaroslav Kysela) [1197064]
- [alsa] pcm: add IEC958 channel status helper (Jaroslav Kysela) [1197064]
- [alsa] pcm: add DRM ELD helper (Jaroslav Kysela) [1197064]
- [alsa] jack: Remove MODULE_*() macros (Jaroslav Kysela) [1197064]
- [alsa] hda - Move hda_i915.c from sound/pci/hda to sound/hda (Jaroslav Kysela) [1197064]
- [alsa] hda - Add headset-mode* model options for ALC269 & co (Jaroslav Kysela) [1197064]
- [alsa] hda/ca0132: support for Alienware 15 Creative Sound Core3D-EX (Jaroslav Kysela) [1197064]
- [alsa] hda - add hda_intel_trace.h (Jaroslav Kysela) [1197064]
- [alsa] hda - rename hda_intel_trace.h to hda_controller_trace.h (Jaroslav Kysela) [1197064]
- [alsa] hda/hdmi - Add Tegra210 support (Jaroslav Kysela) [1197064]
- [alsa] hda/hdmi - Add Tegra114 support (Jaroslav Kysela) [1197064]
- [alsa] hda/hdmi - Add Tegra30 support (Jaroslav Kysela) [1197064]
- [alsa] hda/tegra - Improve error reporting (Jaroslav Kysela) [1197064]
- [alsa] hda/hdmi - Implement Tegra-specific patch (Jaroslav Kysela) [1197064]
- [alsa] hda/tegra - Set CORBRP self-clear flag (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Support Dell headset mode for ALC298 (Jaroslav Kysela) [1197064]
- [alsa] info: Drop kerneldoc comment from snd_info_create_entry() (Jaroslav Kysela) [1197064]
- [alsa] info: Move list addition to snd_info_create_entry() (Jaroslav Kysela) [1197064]
- [alsa] info: Register proc entries recursively, too (Jaroslav Kysela) [1197064]
- [alsa] info: Fix leaks of child entries at snd_info_free_entry() (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Support headset mode for ALC298 (Jaroslav Kysela) [1197064]
- [alsa] hda - Remove unused call to "get_pin" in patch_hdmi.c (Jaroslav Kysela) [1197064]
- [alsa] hda/tegra - Fix oops (Jaroslav Kysela) [1197064]
- [alsa] hda - reset display codec when power on (Jaroslav Kysela) [1197064]
- [alsa] jack: fix a randconfig build issue (Jaroslav Kysela) [1197064]
- [alsa] jack: Fix another NULL dereference due to empty input jack (Jaroslav Kysela) [1197064]
- [alsa] jack: don't report input event for phantom jack (Jaroslav Kysela) [1197064]
- [alsa] hda - Reduce ifdef CONFIG_SND_HDA_I915 (Jaroslav Kysela) [1197064]
- [alsa] hda - remove controller dependency on i915 power well for Baytrail/Braswell (Jaroslav Kysela) [1197064]
- [alsa] hda - divide controller and codec dependency on i915 gfx power well (Jaroslav Kysela) [1197064]
- [alsa] hda - implement link_power ops for i915 display power control (Jaroslav Kysela) [1197064]
- [alsa] hda - allow a codec to control the link power (Jaroslav Kysela) [1197064]
- [alsa] hda - implement a refcount for i915 power well switch (Jaroslav Kysela) [1197064]
- [alsa] jack: remove exporting ctljack functions (Jaroslav Kysela) [1197064]
- [alsa] hda - Update to use the new jack kctls method (Jaroslav Kysela) [1197064]
- [alsa] jack: extend snd_jack_new to support phantom jack (Jaroslav Kysela) [1197064]
- [alsa] jack: handle jack embedded kcontrol creating within ctljack (Jaroslav Kysela) [1197064]
- [alsa] jack: implement kctl creating for jack devices (Jaroslav Kysela) [1197064]
- [alsa] core: Clean up OSS proc file management (Jaroslav Kysela) [1197064]
- [alsa] core: Build conditionally and remove superfluous ifdefs (Jaroslav Kysela) [1197064]
- [alsa] core: Don't ignore errors at creating proc files (Jaroslav Kysela) [1197064]
- [alsa] core: Remove superfluous exit calls for proc entries (Jaroslav Kysela) [1197064]
- [alsa] core: Manage asound root directory with snd_info_entry (Jaroslav Kysela) [1197064]
- [alsa] core: Remove child proc file elements recursively (Jaroslav Kysela) [1197064]
- [alsa] core: Fix possible memory leaks at error path in info.c (Jaroslav Kysela) [1197064]
- [alsa] Replace with IS_ENABLED() (Jaroslav Kysela) [1197064]
- [alsa] core: Use seq_file for text proc file reads (Jaroslav Kysela) [1197064]
- [alsa] hda - Replace open codes with snd_hdac_stream_set_params() (Jaroslav Kysela) [1197064]
- [alsa] hda - Move prepared flag into struct hdac_stream (Jaroslav Kysela) [1197064]
- [alsa] hda - Replace hda_bus_ops with static binding (Jaroslav Kysela) [1197064]
- [alsa] remove deprecated use of pci api (Jaroslav Kysela) [1197064]
- [alsa] hda - Drop azx_sd_read*/write*() macros (Jaroslav Kysela) [1197064]
- [alsa] hda/tegra - Fix build error and warning (Jaroslav Kysela) [1197064]
- [alsa] hda - Reenable tracepoints for controller (Jaroslav Kysela) [1197064]
- [alsa] hda - Move PCM format and rate handling code to core library (Jaroslav Kysela) [1197064]
- [alsa] hda - Minor refactoring (Jaroslav Kysela) [1197064]
- [alsa] hda - Embed bus into controller object (Jaroslav Kysela) [1197064]
- [alsa] hda - Migrate more hdac_stream codes (Jaroslav Kysela) [1197064]
- [alsa] hda - Migrate hdac_stream into legacy driver (Jaroslav Kysela) [1197064]
- [alsa] hda - Pass bus io_ops directly from the top-level driver (Jaroslav Kysela) [1197064]
- [alsa] hda - Move send_cmd / get_response to hdac_bus_ops (Jaroslav Kysela) [1197064]
- [alsa] hda - Merge codec and controller helpers (Jaroslav Kysela) [1197064]
- [alsa] hda - Add DSP loader to core library code (Jaroslav Kysela) [1197064]
- [alsa] hda - Add the controller helper codes to hda-core module (Jaroslav Kysela) [1197064]
- [alsa] hda - Handle error from get_response bus ops directly (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix lost sound due to stream_pm ops cleanup (Jaroslav Kysela) [1197064]
- [alsa] hda - Disable Headphone Mic boost for ALC662 (Jaroslav Kysela) [1197064]
- [alsa] hda - Disable power_save_node for IDT92HD71bxx (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix noise on AMD radeon 290x controller (Jaroslav Kysela) [1197064]
- [alsa] hda - Set stream_pm ops automatically by generic parser (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Add ALC256 alias name for Dell (Jaroslav Kysela) [1197064]
- [alsa] revert "alsa: hda - Add mute-LED mode control to Thinkpad" (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add quirk for MS LifeCam HD-3000 (Jaroslav Kysela) [1197064]
- [alsa] hda - Disable widget power-saving for ALC292 & co (Jaroslav Kysela) [1197064]
- [alsa] hda - Reduce verbs by node power-saves (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add quirk for MS LifeCam Studio (Jaroslav Kysela) [1197064]
- [alsa] pcm: Modify double acknowledged interrupts check condition (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - ALC292 dock fix for Thinkpad L450 (Jaroslav Kysela) [1197064]
- [alsa] hda - Add Conexant codecs CX20721, CX20722, CX20723 and CX20724 (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix headset mic and mic-in for a Dell desktop (Jaroslav Kysela) [1197064]
- [alsa] hda - Add headset mic quirk for Dell Inspiron 5548 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Add ALC298 alias name for Dell (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Fix typo for ALC286/ALC288 (Jaroslav Kysela) [1197064]
- [alsa] hda - Add headphone quirk for Lifebook E752 (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: Emu10k2 32 bit DMA mode (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix missing va_end() call in snd_hda_codec_pcm_new() (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: Fix card shortname string buffer overflow (Jaroslav Kysela) [1197064]
- [alsa] hda - Add mute-LED mode control to Thinkpad (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix mute-LED fixed mode (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix click noise at start on Dell XPS13 (Jaroslav Kysela) [1197064]
- [alsa] hda - fix headset mic detection problem for one more machine (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Fix Headphone Mic doesn't recording for ALC256 (Jaroslav Kysela) [1197064]
- [alsa] hda - fix "num_steps = 0" error on ALC256 (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Fix audio output on Roland SC-D70 sound module (Jaroslav Kysela) [1197064]
- [alsa] hda - add AZX_DCAPS_I915_POWERWELL to Baytrail (Jaroslav Kysela) [1197064]
- [alsa] hda - only sync BCLK to the display clock for Haswell & Broadwell (Jaroslav Kysela) [1197064]
- [alsa] hda - Mute headphone pin on suspend on XPS13 9333 (Jaroslav Kysela) [1197064]
- [alsa] hda - potential (but unlikely) uninitialized variable (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix regression for slave SPDIF setups (Jaroslav Kysela) [1197064]
- [alsa] intel8x0: Check pci_iomap() success for DEVICE_ALI (Jaroslav Kysela) [1197064]
- [alsa] hda - simplify azx_has_pm_runtime (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Enable the ALC292 dock fixup on the Thinkpad T450 (Jaroslav Kysela) [1197064]
- [alsa] ctl: fix to handle several elements added by one operation for userspace element (Jaroslav Kysela) [1197064]
- [alsa] control: Fix a typo of SNDRV_CTL_ELEM_ACCESS_TLV_* with SNDRV_CTL_TLV_OP_* (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Don't attempt to get Microsoft Lifecam Cinema sample rate (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: add toggles for E-mu 1010 optical ports (Jaroslav Kysela) [1197064]
- [alsa] ctl: fill identical information to return value when adding userspace elements (Jaroslav Kysela) [1197064]
- [alsa] ctl: fix a bug to return no identical information in info operation for userspace controls (Jaroslav Kysela) [1197064]
- [alsa] ctl: confirm to return all identical information in 'activate' event (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: handle dock disconnects (Jaroslav Kysela) [1197064]
- [alsa] hda - Add dock support for ThinkPad X250 (17aa:2226) (Jaroslav Kysela) [1197064]
- [alsa] seq: fill client ID in return value of pool operation (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: don't deadlock in proc-functions (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Fix a typo (Jaroslav Kysela) [1197064]
- [alsa] ctl: evaluate macro instead of numerical value (Jaroslav Kysela) [1197064]
- [alsa] usb - Creative USB X-Fi Pro SB1095 volume knob support (Jaroslav Kysela) [1197064]
- [alsa] hda/via - Add missing stream_pm ops setup (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Fix the regression by widget power-saving (Jaroslav Kysela) [1197064]
- [alsa] hda/generic - Don't override power_filter when power_save_node is set (Jaroslav Kysela) [1197064]
- [alsa] hda/generic - Make snd_hda_gen_path_power_filter() always applicable (Jaroslav Kysela) [1197064]
- [alsa] hda/generic - Fix wrong initial power state for fixed pins (Jaroslav Kysela) [1197064]
- [alsa] hda/generic - Check power state cap at updating the widget power (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix headphone pin config for Lifebook T731 (Jaroslav Kysela) [1197064]
- [alsa] hda - Work around races of power up/down with runtime PM (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Support Dell headset mode for ALC288 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Support headset mode for ALC286/288 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Make more stable to get pin sense for ALC283 (Jaroslav Kysela) [1197064]
- [alsa] hda_intel: add AZX_DCAPS_I915_POWERWELL for SKL and BSW (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: add Audigy 5/Rx (Jaroslav Kysela) [1197064]
- [alsa] Use const struct ac97_quirk (Jaroslav Kysela) [1197064]
- [alsa] hda: fix possible null dereference (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: don't try to get Benchmark DAC1 sample rate (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Support Dell headset mode for ALC256 (Jaroslav Kysela) [1197064]
- [alsa] hda - Enable widget power saving for Realtek codecs (Jaroslav Kysela) [1197064]
- [alsa] hda - Sync node attributes at resume from widget power saving (Jaroslav Kysela) [1197064]
- [alsa] hda - Add a fake stereo amp register support (Jaroslav Kysela) [1197064]
- [alsa] hda - Allow driver to add vendor-specific verbs for regmap (Jaroslav Kysela) [1197064]
- [alsa] hda - Add one more node in the EAPD supporting candidate list (Jaroslav Kysela) [1197064]
- [alsa] hda_intel: apply the Seperate stream_tag for Sunrise Point (Jaroslav Kysela) [1197064]
- [alsa] hda/via - Add beep controls to VIA codecs (Jaroslav Kysela) [1197064]
- [alsa] hda - Remove superfluous hda_nid_t definition in hda_codec.h (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Fix duplicate const for clock sources (Jaroslav Kysela) [1197064]
- [alsa] hda - Add dock support for Thinkpad T450s (17aa:5036) (Jaroslav Kysela) [1197064]
- [alsa] echoaudio: read past end of array (Jaroslav Kysela) [1197064]
- [alsa] ak411x: simplify snd_ak4113_create() a bit (Jaroslav Kysela) [1197064]
- [alsa] hda - Use regmap for command verb caches, too (Jaroslav Kysela) [1197064]
- [alsa] hda - Use regmap for parameter caches, too (Jaroslav Kysela) [1197064]
- [alsa] hda - Use regmap for amp accesses (Jaroslav Kysela) [1197064]
- [alsa] hda - Implement uncached version of parameter reads (Jaroslav Kysela) [1197064]
- [alsa] hda - Use regmap for codec parameter reads (Jaroslav Kysela) [1197064]
- [alsa] hda - Add regmap support (Jaroslav Kysela) [1197064]
- [alsa] hda - Move generic array helpers to core lib (Jaroslav Kysela) [1197064]
- [alsa] hda - Re-add tracepoints to HD-audio core driver (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix possible runtime PM refcount unbalance (Jaroslav Kysela) [1197064]
- [alsa] hda - Support indirect execution of verbs (Jaroslav Kysela) [1197064]
- [alsa] hda - Add widget sysfs tree (Jaroslav Kysela) [1197064]
- [alsa] hda - Move a part of hda_codec stuff into hdac_device (Jaroslav Kysela) [1197064]
- [alsa] hda - Move some codes up to hdac_bus struct (Jaroslav Kysela) [1197064]
- [alsa] hda - Make snd_hda_bus_type public (Jaroslav Kysela) [1197064]
- [alsa] hda - Rename power_mgmt flag with power_save_node (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix power of pins used for mute LED with vrefs (Jaroslav Kysela) [1197064]
- [alsa] hda - Adjust power of beep widget and outputs (Jaroslav Kysela) [1197064]
- [alsa] hda - Use the new power control for VIA codecs (Jaroslav Kysela) [1197064]
- [alsa] hda - Support advanced power state controls (Jaroslav Kysela) [1197064]
- [alsa] ice1724: esi w192m: Add sampling rate control of the ADC/DAC (Jaroslav Kysela) [1197064]
- [alsa] ice1724: esi w192m: Add text Line in/Mic for selecting input gain state (Jaroslav Kysela) [1197064]
- [alsa] ice1724: esi w192m: Add TLV support for control value in dB scale (Jaroslav Kysela) [1197064]
- [alsa] ice1724: esi w192m: Enable midi i/o of port envy24 chip as available (Jaroslav Kysela) [1197064]
- [alsa] ice1724: esi w192m: Update eeprom structure to C99 standard (Jaroslav Kysela) [1197064]
- [alsa] ice1724: esi w192m: Correct copy/paste from prodigy driver (Jaroslav Kysela) [1197064]
- [alsa] hda - Simplify PCM setup overrides (Jaroslav Kysela) [1197064]
- [alsa] hda - Treat stereo-to-mono mix properly (Jaroslav Kysela) [1197064]
- [alsa] hda - Use shutdown driver ops instead of reboot notifier (Jaroslav Kysela) [1197064]
- [alsa] hda - Don't access stereo amps for mono channel widgets (Jaroslav Kysela) [1197064]
- [alsa] control: Fix breakage of user ctl element addition (Jaroslav Kysela) [1197064]
- [alsa] hda - Add workaround for MacBook Air 5,2 built-in mic (Jaroslav Kysela) [1197064]
- [alsa] hda - Set single_adc_amp flag for CS420x codecs (Jaroslav Kysela) [1197064]
- [alsa] snd-usb: add quirks for Roland UA-22 (Jaroslav Kysela) [1197064]
- [alsa] control: Add sanity checks for user ctl id name string (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix built-in mic on Compaq Presario CQ60 (Jaroslav Kysela) [1197064]
- [alsa] seq: Fix init order of snd_seq_device stuff (Jaroslav Kysela) [1197064]
- [alsa] core: Drop superfluous error/debug messages after malloc failures (Jaroslav Kysela) [1197064]
- [alsa] seq: Drop superfluous error/debug messages after malloc failures (Jaroslav Kysela) [1197064]
- [alsa] seq_oss: Drop superfluous error/debug messages after malloc failures (Jaroslav Kysela) [1197064]
- [alsa] core: reduce stack usage related to snd_ctl_new() (Jaroslav Kysela) [1197064]
- [alsa] core: use precomputed table to check userspace control params (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix regression of HD-audio controller fallback modes (Jaroslav Kysela) [1197064]
- [alsa] ac97: ac97_patch: Simplify patch_vt1613_specific() (Jaroslav Kysela) [1197064]
- [alsa] ac97: Add VT1613 AC97 codec support (Jaroslav Kysela) [1197064]
- [alsa] hda - One more Dell macine needs DELL1_MIC_NO_PRESENCE quirk (Jaroslav Kysela) [1197064]
- [alsa] opl3: small array underflow (Jaroslav Kysela) [1197064]
- [alsa] line6: Clamp values correctly (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Check Marantz/Denon USB DACs in a single place (Jaroslav Kysela) [1197064]
- [alsa] Fix spelling typo in Documentation/DocBook/alsa-driver-api.xml (Jaroslav Kysela) [1197064]
- [alsa] hda - Release resources in device release callback (Jaroslav Kysela) [1197064]
- [alsa] hda - Use standard workqueue for unsol and jack events (Jaroslav Kysela) [1197064]
- [alsa] hda - Build PCMs and controls at codec driver probe (Jaroslav Kysela) [1197064]
- [alsa] hda - Implement unbind more safely (Jaroslav Kysela) [1197064]
- [alsa] core: Re-add snd_device_disconnect() (Jaroslav Kysela) [1197064]
- [alsa] hda - Don't assume non-NULL PCM ops (Jaroslav Kysela) [1197064]
- [alsa] hda - Allocate hda_pcm objects dynamically (Jaroslav Kysela) [1197064]
- [alsa] hda - Remove superfluous memory allocation error messages (Jaroslav Kysela) [1197064]
- [alsa] hda - Add card field to hda_codec struct (Jaroslav Kysela) [1197064]
- [alsa] hda - Split snd_hda_build_pcms() (Jaroslav Kysela) [1197064]
- [alsa] hda - Clear pcm pointer assigned to hda_pcm at device removal (Jaroslav Kysela) [1197064]
- [alsa] hda - Remove channel mode helper functions (Jaroslav Kysela) [1197064]
- [alsa] hda - Set parent of input beep devices (Jaroslav Kysela) [1197064]
- [alsa] hda - Power down codec automatically at registration (Jaroslav Kysela) [1197064]
- [alsa] hda - Replace bus pm_notify with the standard runtime PM framework (Jaroslav Kysela) [1197064]
- [alsa] hda - Drop power_save value indirection in hda_bus (Jaroslav Kysela) [1197064]
- [alsa] cmipci: remove a stray space character (Jaroslav Kysela) [1197064]
- [alsa] azt3328: some indenting cleanups (Jaroslav Kysela) [1197064]
- [alsa] hda - Disable runtime PM for Panther Point again (Jaroslav Kysela) [1197064]
- [alsa] hda: controller code - do not export static functions (Jaroslav Kysela) [1197064]
- [alsa] pcm: Don't leave PREPARED state after draining (Jaroslav Kysela) [1197064]
- [alsa] hda - Use standard runtime PM for codec power-save control (Jaroslav Kysela) [1197064]
- [alsa] hda - Move codec suspend/resume to codec driver (Jaroslav Kysela) [1197064]
- [alsa] hda - Bind codecs via standard bus (Jaroslav Kysela) [1197064]
- [alsa] hda - Decouple PCM and hwdep devices from codec object (Jaroslav Kysela) [1197064]
- [alsa] hda - Add pin configs for ASUS mobo with IDT 92HD73XX codec (Jaroslav Kysela) [1197064]
- [alsa] pcm: Don't ignore internal PCMs in snd_pcm_dev_disconnect() (Jaroslav Kysela) [1197064]
- [alsa] pcm: Don't notify internal PCMs (Jaroslav Kysela) [1197064]
- [alsa] pcm: Don't add internal PCMs to PCM device list (Jaroslav Kysela) [1197064]
- [alsa] pcm: Minor refactoring in snd_pcm_attach_substream() (Jaroslav Kysela) [1197064]
- [alsa] hda: replace .wallclock by .get_time_info (Jaroslav Kysela) [1197064]
- [alsa] core: add .get_time_info (Jaroslav Kysela) [1197064]
- [alsa] core: pass audio tstamp config from userspace in compat mode (Jaroslav Kysela) [1197064]
- [alsa] core: pass audio tstamp config from userspace (Jaroslav Kysela) [1197064]
- [alsa] hda - Avoid unnecessary power-up at mixer amp changes (Jaroslav Kysela) [1197064]
- [alsa] hda - Split azx_codec_create() to two phases (Jaroslav Kysela) [1197064]
- [alsa] hda - Drop azx_mixer_create() (Jaroslav Kysela) [1197064]
- [alsa] hda - Fold hda_priv.h into hda_controller.h (Jaroslav Kysela) [1197064]
- [alsa] hda - Introduce azx_has_pm_runtime() macro (Jaroslav Kysela) [1197064]
- [alsa] usb: Fix support for Denon DA-300USB DAC (ID 154e:1003) (Jaroslav Kysela) [1197064]
- [alsa] hda - Embed struct hda_bus_unsolicited into struct hda_bus (Jaroslav Kysela) [1197064]
- [alsa] hda - Drop hda_bus_template for snd_hda_bus_new() (Jaroslav Kysela) [1197064]
- [alsa] hdspm - DRY cleanup of snd_pcm_ops (Jaroslav Kysela) [1197064]
- [alsa] hdspm - DRY cleanup in .release callback (Jaroslav Kysela) [1197064]
- [alsa] hdspm - DRY cleanup in .open callbacks (Jaroslav Kysela) [1197064]
- [alsa] Consolidate snd_find_free_minor() (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Don't attempt to get Lifecam HD-5000 sample rate (Jaroslav Kysela) [1197064]
- [alsa] hda/tegra check correct return value from ioremap_resource (Jaroslav Kysela) [1197064]
- [alsa] hdspm - Constrain periods to 2 on older cards (Jaroslav Kysela) [1197064]
- [alsa] hda - enable mute led quirk for one more hp machine (Jaroslav Kysela) [1197064]
- [alsa] seq: Drop snd_seq_autoload_lock() and _unlock() (Jaroslav Kysela) [1197064]
- [alsa] seq: Define driver object in each driver (Jaroslav Kysela) [1197064]
- [alsa] seq: Clean up device and driver structs (Jaroslav Kysela) [1197064]
- [alsa] seq: Rewrite sequencer device binding with standard bus (Jaroslav Kysela) [1197064]
- [alsa] seq: Don't compile snd_seq_device_load_drivers() for built-in (Jaroslav Kysela) [1197064]
- [alsa] seq: Move EXPORT_SYMBOL() after each function (Jaroslav Kysela) [1197064]
- [alsa] seq: potential out of bounds in do_control() (Jaroslav Kysela) [1197064]
- [alsa] line6: Improve line6_read/write_data() interfaces (Jaroslav Kysela) [1197064]
- [alsa] line6: toneport: Use explicit type for firmware version (Jaroslav Kysela) [1197064]
- [alsa] line6: Use explicit type for serial number (Jaroslav Kysela) [1197064]
- [alsa] line6: Return EIO if read/write not successful (Jaroslav Kysela) [1197064]
- [alsa] line6: Return error if device not responding (Jaroslav Kysela) [1197064]
- [alsa] line6: Add delay before reading status (Jaroslav Kysela) [1197064]
- [alsa] hda - Add docking station support for another HP machine (Jaroslav Kysela) [1197064]
- [alsa] control: fix failure to return new numerical ID in 'replace' event data (Jaroslav Kysela) [1197064]
- [alsa] usb: update trigger timestamp on first non-zero URB submitted (Jaroslav Kysela) [1197064]
- [alsa] hda: read trigger_timestamp immediately after starting DMA (Jaroslav Kysela) [1197064]
- [alsa] pcm: allow for trigger_tstamp snapshot in .trigger (Jaroslav Kysela) [1197064]
- [alsa] pcm: don't override timestamp unconditionally (Jaroslav Kysela) [1197064]
- [alsa] off by one bug in snd_riptide_joystick_probe() (Jaroslav Kysela) [1197064]
- [alsa] control: fix failure to return numerical ID in 'add' event (Jaroslav Kysela) [1197064]
- [alsa] line6: Pass driver name to line6_probe() (Jaroslav Kysela) [1197064]
- [alsa] line6: Pass toneport pointer to toneport_has_led() (Jaroslav Kysela) [1197064]
- [alsa] line6: Add toneport_has_source_select() (Jaroslav Kysela) [1197064]
- [alsa] line6: Get rid of unused variable in pod.c (Jaroslav Kysela) [1197064]
- [alsa] line6: Create sysfs via snd_card_add_dev_attr() (Jaroslav Kysela) [1197064]
- [alsa] Add a helper to add a new attribute group to card (Jaroslav Kysela) [1197064]
- [alsa] hda - Set up GPIO for Toshiba Satellite S50D (Jaroslav Kysela) [1197064]
- [alsa] line6: fixup of line6_start_timer argument type (Jaroslav Kysela) [1197064]
- [alsa] line6: use msecs_to_jiffies for conversion (Jaroslav Kysela) [1197064]
- [alsa] Drop snd_get_device() helper (Jaroslav Kysela) [1197064]
- [alsa] Simplify snd_device_register() variants (Jaroslav Kysela) [1197064]
- [alsa] compress: Embed struct device (Jaroslav Kysela) [1197064]
- [alsa] seq: Handle the device directly (Jaroslav Kysela) [1197064]
- [alsa] timer: Handle the device directly (Jaroslav Kysela) [1197064]
- [alsa] timer: Propagate the error at initialization (Jaroslav Kysela) [1197064]
- [alsa] rawmidi: Use rawmidi device file for kernel messages (Jaroslav Kysela) [1197064]
- [alsa] rawmidi: Embed struct device (Jaroslav Kysela) [1197064]
- [alsa] pcm: Embed struct device (Jaroslav Kysela) [1197064]
- [alsa] hwdep: Embed struct device (Jaroslav Kysela) [1197064]
- [alsa] control: Embed struct device (Jaroslav Kysela) [1197064]
- [alsa] Add a helper to initialize device (Jaroslav Kysela) [1197064]
- [alsa] control: Provide a helper to look for the preferred subdevice (Jaroslav Kysela) [1197064]
- [alsa] Allow to pass the device object to snd_register_device*() (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove unused line6_midibuf_skip_message() (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove unused line6_midibuf_status() (Jaroslav Kysela) [1197064]
- [alsa] ak411x: Fix race of reinit() calls (Jaroslav Kysela) [1197064]
- [alsa] ak411x: Add PM helper functions (Jaroslav Kysela) [1197064]
- [alsa] ak4114: Move EXPORT_SYMBOL() after each function (Jaroslav Kysela) [1197064]
- [alsa] ak411x: Fix stall in work callback (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove snd_line6_ prefix of pcm property fields (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove invalid capability bits for PODxt Live Variax (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove struct usb_line6_podhd (Jaroslav Kysela) [1197064]
- [alsa] line6: Move the contents of usbdefs.h into driver.h (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove revision.h (Jaroslav Kysela) [1197064]
- [alsa] line6: Tidy up and typo fixes in comments (Jaroslav Kysela) [1197064]
- [alsa] line6: Fix volume calculation for big-endian (Jaroslav Kysela) [1197064]
- [alsa] pcm: Add snd_interval_ranges() and snd_pcm_hw_constraint_ranges() (Jaroslav Kysela) [1197064]
- [alsa] usx2y: Move UAPI definition into include/uapi/sound/usb_stream.h (Jaroslav Kysela) [1197064]
- [alsa] au88x0: Remove superfluous ifdef __KERNEL__ (Jaroslav Kysela) [1197064]
- [alsa] Include linux/uaccess.h and linux/bitopts.h instead of asm/* (Jaroslav Kysela) [1197064]
- [alsa] Include linux/io.h instead of asm/io.h (Jaroslav Kysela) [1197064]
- [alsa] line6: Handle error from line6_pcm_acquire() (Jaroslav Kysela) [1197064]
- [alsa] line6: Make common PCM pointer callback (Jaroslav Kysela) [1197064]
- [alsa] line6: Reorganize PCM stream handling (Jaroslav Kysela) [1197064]
- [alsa] line6: Clear prev_fbuf and prev_fsize properly (Jaroslav Kysela) [1197064]
- [alsa] line6: Fix racy loopback handling (Jaroslav Kysela) [1197064]
- [alsa] line6: Minor tidy up in line6_probe() (Jaroslav Kysela) [1197064]
- [alsa] line6: Let snd_card_new() allocate private data (Jaroslav Kysela) [1197064]
- [alsa] line6: Drop interface argument from private_init and disconnect callbacks (Jaroslav Kysela) [1197064]
- [alsa] line6: Skip volume manipulation during silence copying (Jaroslav Kysela) [1197064]
- [alsa] line6: Do clipping in volume / monitor manipulations (Jaroslav Kysela) [1197064]
- [alsa] line6: Consolidate PCM stream buffer allocation and free (Jaroslav Kysela) [1197064]
- [alsa] line6: Use dev_err() (Jaroslav Kysela) [1197064]
- [alsa] line6: Consolidate URB unlink and sync helpers (Jaroslav Kysela) [1197064]
- [alsa] line6: Rearrange PCM structure (Jaroslav Kysela) [1197064]
- [alsa] line6: Drop voodoo workarounds (Jaroslav Kysela) [1197064]
- [alsa] line6: Use incremental loop (Jaroslav Kysela) [1197064]
- [alsa] line6: Drop superfluous spinlock for trigger (Jaroslav Kysela) [1197064]
- [alsa] line6: Fix the error recovery in line6_pcm_acquire() (Jaroslav Kysela) [1197064]
- [alsa] line6: Use logical OR (Jaroslav Kysela) [1197064]
- [alsa] line6: Fix missing error handling in line6_pcm_acquire() (Jaroslav Kysela) [1197064]
- [alsa] line6: Reduce superfluous spinlock in midi.c (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove unused line6_nop_read() (Jaroslav Kysela) [1197064]
- [alsa] line6: Fix memory leak at probe error path (Jaroslav Kysela) [1197064]
- [alsa] line6: Minor refactoring (Jaroslav Kysela) [1197064]
- [alsa] line6/toneport: Implement LED controls via LED class (Jaroslav Kysela) [1197064]
- [alsa] line6/toneport: Fix wrong argument for toneport_has_led() (Jaroslav Kysela) [1197064]
- [alsa] line6: Don't forget to call driver's destructor at error path (Jaroslav Kysela) [1197064]
- [alsa] line6/toneport: Move setup_timer() at the beginning (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove superfluous NULL checks in each driver (Jaroslav Kysela) [1197064]
- [alsa] line6: Abort if inconsistent usbdev is found at disconnect (Jaroslav Kysela) [1197064]
- [alsa] line6: Yet more cleanup of superfluous NULL checks (Jaroslav Kysela) [1197064]
- [alsa] seq: remove unused callback_all field (Jaroslav Kysela) [1197064]
- [alsa] seq: fix off-by-one error in port limit check (Jaroslav Kysela) [1197064]
- [alsa] seq: correctly report maximum number of ports (Jaroslav Kysela) [1197064]
- [alsa] seq-dummy: remove deadlock-causing events on close (Jaroslav Kysela) [1197064]
- [alsa] hda - Enable docking station for an HP machine (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove driver version from header comment (Jaroslav Kysela) [1197064]
- [alsa] line6: Refer to manufacturer as "Line 6" (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove superfluous NULL checks (Jaroslav Kysela) [1197064]
- [alsa] line6: Drop line6_send_program() and line6_transmit_parameter() (Jaroslav Kysela) [1197064]
- [alsa] line6: Make line6_send_raw_message() static (Jaroslav Kysela) [1197064]
- [alsa] line6: Sync PCM stop at disconnect (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove superfluous disconnect call in suspend handler (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove CHECK_RETURN macro (Jaroslav Kysela) [1197064]
- [alsa] line6: Drop MISSING_CASE macro (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove driver version string (Jaroslav Kysela) [1197064]
- [alsa] line6: Reorganize card resource handling (Jaroslav Kysela) [1197064]
- [alsa] line6: Drop superfluous irqsave/irqrestore in PCM trigger callback (Jaroslav Kysela) [1197064]
- [alsa] line6: Don't handle PCM trigger for other cards (Jaroslav Kysela) [1197064]
- [alsa] line6: Remove superfluous out-of-memory error messages (Jaroslav Kysela) [1197064]
- [alsa] line6: Drop usb_device sysfs symlink (Jaroslav Kysela) [1197064]
- [alsa] line6: Drop invalid SNDRV_PCM_INFO_RESUME flag (Jaroslav Kysela) [1197064]
- [alsa] line6: Drop superfluous snd_device for rawmidi (Jaroslav Kysela) [1197064]
- [alsa] line6: Drop superfluous snd_device for PCM (Jaroslav Kysela) [1197064]
- [alsa] line6: Handle impulse response via control API (Jaroslav Kysela) [1197064]
- [alsa] line6: Split to each driver (Jaroslav Kysela) [1197064]
- [alsa] line6: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] hdspm: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] hdsp: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] korg1212: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] echoaudio: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] ak4117: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] serial-u16550: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] opl3: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] mtpav: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] mpu401: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] aloop: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] timer: Use setup_timer() and mod_timer() (Jaroslav Kysela) [1197064]
- [alsa] dummy: use setup_timer and mod_timer (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add mic volume fix quirk for Logitech Webcam C210 (Jaroslav Kysela) [1197064]
- [alsa] add Studio Evolution SE6X support (Jaroslav Kysela) [1197064]
- [alsa] oxygen: add XIO2001 initialization (Jaroslav Kysela) [1197064]
- [alsa] oxygen: add support for third analog input (Jaroslav Kysela) [1197064]
- [alsa] oxygen: do not create useless S/PDIF controls (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix typo in hda_controller.c (Jaroslav Kysela) [1197064]
- [alsa] hda - Select INPUT for Realtek HD-audio codec (Jaroslav Kysela) [1197064]
- [alsa] move line6 usb driver into sound/usb (Jaroslav Kysela) [1197064]
- [alsa] rme*: Use snd_pcm_format_t (Jaroslav Kysela) [1197064]
- [alsa] hda: add component support (Jaroslav Kysela) [1197064]
- [alsa] hda: pass intel_hda to all i915 interface functions (Jaroslav Kysela) [1197064]
- [alsa] hda: export struct hda_intel (Jaroslav Kysela) [1197064]
- [alsa] ice1712: wm8766: Remove some unused functions (Jaroslav Kysela) [1197064]
- [alsa] fm801: remove FSF address (Jaroslav Kysela) [1197064]
- [alsa] hda - fixup input_free_device called after input_unregister_device (Jaroslav Kysela) [1197064]
- [alsa] ymfpci: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] vx222: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] via82xx-modem: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] via82xx: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] trident: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] sis7019: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] rme96: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] riptide: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] oxygen: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] nm256: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] maestro3: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] intel8x0m: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] intel8x0: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] ice1724: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] ice1712: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] hda: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] es1968: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] es1938: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] ens137x: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] echoaudio: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] ctxfi: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] cs5535audio: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] cs46xx: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] cs4281: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] cmipci: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] ca0106: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] azt3328: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] atiixp-modem: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] atiixp: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] als4000: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] als300: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] ali5451: Simplify PM callbacks (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add support for Akai MPC Element USB MIDI controller (Jaroslav Kysela) [1197064]
- [alsa] fm801: PCI core handles power state for us (Jaroslav Kysela) [1197064]
- [alsa] hda - Enable mic mute hotkey and LEDs for an HP machine (Jaroslav Kysela) [1197064]
- [alsa] fm801: move to pcim_* and devm_* functions (Jaroslav Kysela) [1197064]
- [alsa] hda - Debug output which type of fixup was selected (Jaroslav Kysela) [1197064]
- [alsa] hda - Print codec->chip_name in autoconfig (Jaroslav Kysela) [1197064]
- [alsa] Deletion of checks before the function call "iounmap" (Jaroslav Kysela) [1197064]
- [alsa] oxygen: Delete an unnecessary check before the function call "snd_pcm_suspend" (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: Delete an unnecessary check before the function call "kfree" (Jaroslav Kysela) [1197064]
- [alsa] seq: Deletion of unnecessary checks before the function call "snd_midi_event_free" (Jaroslav Kysela) [1197064]
- [alsa] oxygen: Remove unnecessary snd_pcm_lib_preallocate_free_for_all() (Jaroslav Kysela) [1197064]
- [alsa] ymfpci: Remove always NULL parameters (Jaroslav Kysela) [1197064]
- [alsa] trident: Remove always NULL parameters (Jaroslav Kysela) [1197064]
- [alsa] sonicvibes: Remove always NULL parameter (Jaroslav Kysela) [1197064]
- [alsa] riptide: Remove always NULL parameter (Jaroslav Kysela) [1197064]
- [alsa] ice1712: Remove always NULL parameters (Jaroslav Kysela) [1197064]
- [alsa] fm801: Remove always NULL parameter (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: Remove always NULL parameters (Jaroslav Kysela) [1197064]
- [alsa] ens1370: Remove always NULL parameters (Jaroslav Kysela) [1197064]
- [alsa] cs46xx: Remove always NULL parameters (Jaroslav Kysela) [1197064]
- [alsa] cs4281: Remove always NULL parameters (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Remove always NULL parameter (Jaroslav Kysela) [1197064]
- [alsa] asla: ad1889: Remove always NULL parameter (Jaroslav Kysela) [1197064]
- [alsa] asoc: sb16: Simplify snd_sb16dsp_pcm() (Jaroslav Kysela) [1197064]
- [alsa] ml403-ac97cr: Remove always NULL parameter (Jaroslav Kysela) [1197064]
- [alsa] pcm: add SNDRV_PCM_TRIGGER_DRAIN trigger (Jaroslav Kysela) [1197064]
- [alsa] asihpi: fix an information leak in asihpi_hpi_ioctl() (Jaroslav Kysela) [1197064]
- [alsa] snd_pcm_oss_period_size: Use round{up,down}_pow_of_two() (Jaroslav Kysela) [1197064]
- [alsa] Add support for wildcard msbits constraints (Jaroslav Kysela) [1197064]
- [alsa] Fix handling of multiple msbits constraints on the same runtime (Jaroslav Kysela) [1197064]
- [alsa] hda - patch_analog.c: Remove some unused functions (Jaroslav Kysela) [1197064]
- [alsa] ice1712: wm8776.c: Remove some unused functions (Jaroslav Kysela) [1197064]
- [alsa] hda - Add new GPU codec ID 0x10de0072 to snd-hda (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix wrong gpio_dir & gpio_mask hint setups for IDT/STAC codecs (Jaroslav Kysela) [1197064]
- [alsa] snd-usb-caiaq: fix stream count check (Jaroslav Kysela) [1197064]
- [alsa] hda_intel: apply the Seperate stream_tag for Skylake (Jaroslav Kysela) [1197064]
- [alsa] hda_controller: Separate stream_tag for input and output streams (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: extend KEF X300A FU 10 tweak to Arcam rPAC (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - New codec support for ALC298 (Jaroslav Kysela) [1197064]
- [alsa] asihpi: update to HPI version 4.14 (Jaroslav Kysela) [1197064]
- [alsa] asihpi: increase tuner pad cache size (Jaroslav Kysela) [1197064]
- [alsa] asihpi: relax firmware version check (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Fix Scarlett 6i6 initialization typo (Jaroslav Kysela) [1197064]
- [alsa] hda - Add quirk for Packard Bell EasyNote MX65 (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: add native DSD support for Matrix Audio DACs (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - New codec support for ALC256 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Add new Dell desktop for ALC3234 headset mode (Jaroslav Kysela) [1197064]
- [alsa] hda/hdmi - apply Haswell fix-ups to Skylake display codec (Jaroslav Kysela) [1197064]
- [alsa] hda - Make add_stereo_mix_input flag tristate (Jaroslav Kysela) [1197064]
- [alsa] hda - Create capture source ctls when stereo mix input is added (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix typos in snd_hda_get_int_hint() kerneldoc comments (Jaroslav Kysela) [1197064]
- [alsa] hda - add codec ID for Skylake display audio codec (Jaroslav Kysela) [1197064]
- [alsa] sound / pm: Replace CONFIG_PM_RUNTIME with CONFIG_PM (Jaroslav Kysela) [1197064]
- [alsa] pcxhr: NULL dereference on probe failure (Jaroslav Kysela) [1197064]
- [alsa] lola: NULL dereference on probe failure (Jaroslav Kysela) [1197064]
- [alsa] hda - Add "eapd" model string for AD1986A codec (Jaroslav Kysela) [1197064]
- [alsa] hda - Add EAPD fixup for ASUS Z99He laptop (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Don't resubmit pending URBs at MIDI error recovery (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix built-in mic at resume on Lenovo Ideapad S210 (Jaroslav Kysela) [1197064]
- [alsa] ctxfi: Neaten get_daio_rsc (Jaroslav Kysela) [1197064]
- [alsa] hda - Drop AZX_DCAPS_ALIGN_BUFSIZE (Jaroslav Kysela) [1197064]
- [alsa] hda - Define the DCAPS preset for the old Intel chipsets (Jaroslav Kysela) [1197064]
- [alsa] trident: Deletion of a check before snd_util_memhdr_free() (Jaroslav Kysela) [1197064]
- [alsa] echoaudio: Deletion of a check before release_and_free_resource() (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Deletion of an unnecessary check before the function call "vfree" (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Add headset Mic support for new Dell machine (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add support for Zoom R16/24 capture and midi interfaces (Jaroslav Kysela) [1197064]
- [alsa] virmidi: Fix wrong error check (Jaroslav Kysela) [1197064]
- [alsa] virmidi: fixed code style issues (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add mode select quirk for Denon/Marantz DACs (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add native DSD support for Denon/Marantz DACs (Jaroslav Kysela) [1197064]
- [alsa] hda - Allow forcibly enabling/disabling snoop (Jaroslav Kysela) [1197064]
- [alsa] hda - Add AZX_DCAPS_SNOOP_OFF (and refactor snoop setup) (Jaroslav Kysela) [1197064]
- [alsa] hda - using uninitialized data (Jaroslav Kysela) [1197064]
- [alsa] sound/radeon: Move 64-bit MSI quirk from arch to driver (Jaroslav Kysela) [1197064]
- [alsa] hda - Limit 40bit DMA for AMD HDMI controllers (Jaroslav Kysela) [1197064]
- [alsa] asihpi: used parts of message/response are zeroed before use (Jaroslav Kysela) [1197064]
- [alsa] asihpi: don't fail probe if adapter mode read fails (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Use standard printk helpers (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Turn off msg/resp logging after DSP has crashed (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Add support for stream interrupt (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Refactor control cache code (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Use CONFIG_64BIT directly (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Logging format improvements (Jaroslav Kysela) [1197064]
- [alsa] asihpi: New I/O types - AVB & BLUlink, DAB Rf receiver (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Minor string and dead code cleanup (Jaroslav Kysela) [1197064]
- [alsa] core: Deletion of unnecessary checks before two function calls (Jaroslav Kysela) [1197064]
- [alsa] pcm: Add big-endian DSD sample formats and fix XMOS DSD sample format (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add resume support for Scarlett mixers (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add resume support for MicroII SPDIF ctls (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add resume support for FTU controls (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add resume support for Native Instruments controls (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add Digidesign Mbox 1 resume support (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add Xonar U1 resume support (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add Emu0204 channel switch resume support (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add audigy2nx resume support (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Allow quirks to handle own resume and proc dump (Jaroslav Kysela) [1197064]
- [alsa] hda - One more HP machine needs to change mute led quirk (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Supported HP mute Led for ALC286 (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Refactor ignore_ctl_error checks (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Use snd_usb_ctl_msg() for Native Instruments quirk (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Clean up mute/mic GPIO LED handling (Jaroslav Kysela) [1197064]
- [alsa] hda - fix the mic mute led problem for Latitude E5550 (Jaroslav Kysela) [1197064]
- [alsa] hda - move DELL_WMI_MIC_MUTE_LED to the tail in the quirk chain (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Set the Control Selector to SU_SELECTOR_CONTROL for UAC2 (Jaroslav Kysela) [1197064]
- [alsa] hdsp: Deletion of an unnecessary check before the function call "release_firmware" (Jaroslav Kysela) [1197064]
- [alsa] lola: Deletion of an unnecessary check before the function call "vfree" (Jaroslav Kysela) [1197064]
- [alsa] ice17xx: Deletion of unnecessary checks before the function call "snd_ac97_resume" (Jaroslav Kysela) [1197064]
- [alsa] hda: Deletion of unnecessary checks before two function calls (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add ctrl message delay quirk for Marantz/Denon devices (Jaroslav Kysela) [1197064]
- [alsa] ice1712: consider error value (Jaroslav Kysela) [1197064]
- [alsa] ice1712: remove unused variable (Jaroslav Kysela) [1197064]
- [alsa] ice1712: remove unneeded return statement (Jaroslav Kysela) [1197064]
- [alsa] 6fire: Convert byte_rev_table uses to bitrev8 (Jaroslav Kysela) [1197064]
- [alsa] hda - Add mute LED control for Lenovo Ideapad Z560 (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Scarlett mixer interface for 6i6, 18i6, 18i8 and 18i20 (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: make set_*_mix_values functions public (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add private_data pointer to usb_mixer_elem_info (Jaroslav Kysela) [1197064]
- [alsa] revert "alsa: usb-audio: Add quirk for Focusrite Scarlett (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Change EAPD to verb control (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Fix memory leak in FTU quirk (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add duplex mode for Digidesign Mbox 1 and enable mixer (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add mixer control for Digidesign Mbox 1 clock source (Jaroslav Kysela) [1197064]
- [alsa] Fix invalid kerneldoc markers (Jaroslav Kysela) [1197064]
- [alsa] mixart: Fix kerneldoc comments (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix kerneldoc errors in patch_ca0132.c (Jaroslav Kysela) [1197064]
- [alsa] vx: Fix missing kerneldoc parameter descriptions (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Fix Oops by composite quirk enhancement (Jaroslav Kysela) [1197064]
- [alsa] pcm: Fix document for snd_pcm_stop_xrun() (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Allow multiple entries for the same iface in composite quirk (Jaroslav Kysela) [1197064]
- [alsa] pcm: Add snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1197064]
- [alsa] snd_ctl_activate_id(): Fix index look-up (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Trigger PCM XRUN at XRUN (Jaroslav Kysela) [1197064]
- [alsa] pcm: Update the state properly before notification (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Restore default value for ALC668 (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Fix device_del() sysfs warnings at disconnect (Jaroslav Kysela) [1197064]
- [alsa] echoaudio: cleanup of unnecessary messages (Jaroslav Kysela) [1197064]
- [alsa] hda - fix mute led problem for three HP laptops (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Use strim() instead of open code (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Pass direct struct pointer instead of list_head (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Flatten probe and disconnect functions (Jaroslav Kysela) [1197064]
- [alsa] pcm: Add xrun_injection proc entry (Jaroslav Kysela) [1197064]
- [alsa] pcm: Replace PCM hwptr tracking with tracepoints (Jaroslav Kysela) [1197064]
- [alsa] pcm: Correct PCM BUG error message (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: Deletion of unnecessary checks before three function calls (Jaroslav Kysela) [1197064]
- [alsa] echoaudio: remove all snd_printk (Jaroslav Kysela) [1197064]
- [alsa] echoaudio: add reference of struct echoaudio (Jaroslav Kysela) [1197064]
- [alsa] pcm: Refactoring snd_pcm_action() (Jaroslav Kysela) [1197064]
- [alsa] pcm: Simplify snd_pcm_action_lock_irq() (Jaroslav Kysela) [1197064]
- [alsa] doc: More kerneldoc comments on core components (Jaroslav Kysela) [1197064]
- [alsa] pcm: More kerneldoc updates (Jaroslav Kysela) [1197064]
- [alsa] control: Add missing kerneldoc comments to exported functions (Jaroslav Kysela) [1197064]
- [alsa] Update au0828 quirks table (Jaroslav Kysela) [1197064]
- [alsa] simplify au0828 quirk table (Jaroslav Kysela) [1197064]
- [alsa] hda - Add kerneldoc comments to hda_generic.c (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Update Initial AMP for EAPD control (Jaroslav Kysela) [1197064]
- [alsa] hda - change three SSID quirks to one pin quirk (Jaroslav Kysela) [1197064]
- [alsa] hda - Set GPIO 4 low for a few HP machines (Jaroslav Kysela) [1197064]
- [alsa] es1968: Replace timeval with ktime_t (Jaroslav Kysela) [1197064]
- [alsa] hda - Add ultra dock support for Thinkpad X240 (Jaroslav Kysela) [1197064]
- [alsa] hda - Add workaround for CMI8888 snoop behavior (Jaroslav Kysela) [1197064]
- [alsa] hdspm: remove unused variable (Jaroslav Kysela) [1197064]
- [alsa] hda - More kerneldoc comments (Jaroslav Kysela) [1197064]
- [alsa] hda - Correct kerneldoc comments (Jaroslav Kysela) [1197064]
- [alsa] au88x0: Kill the rest snd_print*() (Jaroslav Kysela) [1197064]
- [alsa] pcxhr: Kill the rest snd_print*() (Jaroslav Kysela) [1197064]
- [alsa] ctxfi: Kill the rest snd_print*() (Jaroslav Kysela) [1197064]
- [alsa] pcxhr: convert timeval to ktime_t (Jaroslav Kysela) [1197064]
- [alsa] pcm: Zero-clear reserved fields of PCM status ioctl in compat mode (Jaroslav Kysela) [1197064]
- [alsa] hda - Pass printf argument directly to request_module() (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - New SSID for Headset quirk (Jaroslav Kysela) [1197064]
- [alsa] ad1889: Fix probable mask then right shift defects (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Update restore default value for ALC283 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - Update restore default value for ALC282 (Jaroslav Kysela) [1197064]
- [alsa] pcm: Avoid mmap warnings on x86 (Jaroslav Kysela) [1197064]
- [alsa] hda - Add missing terminating entry to SND_HDA_PIN_QUIRK macro (Jaroslav Kysela) [1197064]
- [alsa] pcm: Disable mmap for known broken archs (Jaroslav Kysela) [1197064]
- [alsa] pcm: Remove arch-dependent mmap kludges (Jaroslav Kysela) [1197064]
- [alsa] pcm: Fix false lockdep warnings (Jaroslav Kysela) [1197064]
- [alsa] ctxfi: remove unused variable (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] 6fire: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] via82xx: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] sonicvibes: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] rme9652: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] hdspm: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] hdsp: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] rme96: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] rme32: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] pcxhr: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] korg1212: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] ice1724: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] ice1712: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] hda: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] fm801: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] es1938: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] echoaudio: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] ca0106: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] azt3328: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] aw2: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] asihpi: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] ac97: Constify more text arrays (Jaroslav Kysela) [1197064]
- [alsa] ac97: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] ak4xxx-adda: Use snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] vx: Use snd_ctl_elem_info() (Jaroslav Kysela) [1197064]
- [alsa] mts64: Use snd_ctl_elem_info() (Jaroslav Kysela) [1197064]
- [alsa] control: Allow to pass items zero to snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] control: Warn if too long string is passed to snd_ctl_enum_info() (Jaroslav Kysela) [1197064]
- [alsa] drivers: pcsp: drop owner assignment from platform_drivers (Jaroslav Kysela) [1197064]
- [alsa] drivers: mpu401: drop owner assignment from platform_drivers (Jaroslav Kysela) [1197064]
- [alsa] drivers: drop owner assignment from platform_drivers (Jaroslav Kysela) [1197064]
- [alsa] hda - Use "Line Out" name instead of "PCM" when there are other outputs (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix "PCM" name being used on one DAC when there are two DACs (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix inverted LED gpio setup for Lenovo Ideapad (Jaroslav Kysela) [1197064]
- [alsa] hda - hdmi: Fix missing ELD change event on plug/unplug (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: Add support for Steinberg UR22 USB interface (Jaroslav Kysela) [1197064]
- [alsa] ALC283 codec - Avoid pop noise on headphones during suspend/resume (Jaroslav Kysela) [1197064]
- [alsa] snd-usb: drop unused varible assigments (Jaroslav Kysela) [1197064]
- [alsa] subject: alsa: seq: Remove autoload locks in driver registration (Jaroslav Kysela) [1197064]
- [alsa] seq: bind seq driver automatically (Jaroslav Kysela) [1197064]
- [alsa] pcm: use the same dma mmap codepath both for arm and arm64 (Jaroslav Kysela) [1197064]
- [alsa] seq: Use atomic ops for autoload refcount (Jaroslav Kysela) [1197064]
- [alsa] au88x0: pr_* replaced with dev_* (Jaroslav Kysela) [1197064]
- [alsa] au88x0: added reference of vortex_t (Jaroslav Kysela) [1197064]
- [alsa] emu10k1: Fix deadlock in synth voice lookup (Jaroslav Kysela) [1197064]
- [alsa] pcm: Fix referred substream in snd_pcm_action_group() unlock loop (Jaroslav Kysela) [1197064]
- [alsa] hda - Add dock port support to Thinkpad L440 (71aa:501e) (Jaroslav Kysela) [1197064]
- [alsa] Allow pass NULL dev for snd_pci_quirk_lookup() (Jaroslav Kysela) [1197064]
- [alsa] hda - Add dock support for Thinkpad T440 (17aa:2212) (Jaroslav Kysela) [1197064]
- [alsa] usb: caiaq: check for cdev->n_streams > 1 (Jaroslav Kysela) [1197064]
- [alsa] hda - Make the inv dmic handling for Realtek use generic parser (Jaroslav Kysela) [1197064]
- [alsa] hda - Add Inverted Internal mic for Samsung Ativ book 9 (NP900X3G) (Jaroslav Kysela) [1197064]
- [alsa] hda - Add inverted internal mic for Asus Aspire 4830T (Jaroslav Kysela) [1197064]
- [alsa] ctxfi: pr_* replaced with dev_* (Jaroslav Kysela) [1197064]
- [alsa] ctxfi: ctatc: added reference to snd_card (Jaroslav Kysela) [1197064]
- [alsa] ctxfi: initialized snd_card (Jaroslav Kysela) [1197064]
- [alsa] ctxfi: added reference of snd_card (Jaroslav Kysela) [1197064]
- [alsa] ctxfi: removed typecast to (struct hw *) (Jaroslav Kysela) [1197064]
- [alsa] ctxfi: changed void * to struct hw * (Jaroslav Kysela) [1197064]
- [alsa] usb: hub: rename khubd to hub_wq in documentation and comments (Jaroslav Kysela) [1197064]
- [alsa] ctxfi: sparse warning (Jaroslav Kysela) [1197064]
- [alsa] hda - Sort input pins depending on amp caps (Jaroslav Kysela) [1197064]
- [alsa] hda - Move the function "check_amp_caps" to hda_codec.c (Jaroslav Kysela) [1197064]
- [alsa] hda - add explicit include of err.h (Jaroslav Kysela) [1197064]
- [alsa] oxygen: set fifo_size (Jaroslav Kysela) [1197064]
- [alsa] virtuoso: add partial Xonar Xense support (Jaroslav Kysela) [1197064]
- [alsa] snd-usb-caiaq: Fix LED commands for Kore controller (Jaroslav Kysela) [1197064]
- [alsa] pcm: fix fifo_size frame calculation (Jaroslav Kysela) [1197064]
- [alsa] hda - Add fixup model name lookup for Lemote A1205 (Jaroslav Kysela) [1197064]
- [alsa] hda - Replace strnicmp with strncasecmp (Jaroslav Kysela) [1197064]
- [alsa] hda - Use standard hda_jack infrastructure for CA0132 driver (Jaroslav Kysela) [1197064]
- [alsa] hda - Remove superfluous hooks from VIA driver (Jaroslav Kysela) [1197064]
- [alsa] hda - Remove superfluous callbacks from STAC/IDT codecs (Jaroslav Kysela) [1197064]
- [alsa] hda - Allow multiple callbacks for jack (Jaroslav Kysela) [1197064]
- [alsa] lx6464es: Use nonatomic PCM ops (Jaroslav Kysela) [1197064]
- [alsa] pcxhr: Use nonatomic PCM ops (Jaroslav Kysela) [1197064]
- [alsa] mixart: Use nonatomic PCM ops (Jaroslav Kysela) [1197064]
- [alsa] vx: Use nonatomic PCM ops (Jaroslav Kysela) [1197064]
- [alsa] hda - Make snd_hda_jack_detect_enable_callback() returning the jack object (Jaroslav Kysela) [1197064]
- [alsa] hda - Make snd_hda_jack_tbl_new() static (Jaroslav Kysela) [1197064]
- [alsa] hda - Get rid of action field from struct hda_jack_tbl (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix invalid pin powermap without jack detection (Jaroslav Kysela) [1197064]
- [alsa] pci: au88x0: printk replacement (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: add native DSD support for XMOS based DACs (Jaroslav Kysela) [1197064]
- [alsa] pcm: add new DSD sampleformat for native DSD playback on XMOS based devices (Jaroslav Kysela) [1197064]
- [alsa] virtuoso: add Xonar Essence STX II daughterboard support (Jaroslav Kysela) [1197064]
- [alsa] virtuoso: add one more headphone impedance setting (Jaroslav Kysela) [1197064]
- [alsa] usb-audio: add MIDI port names for the Yamaha MOTIF XF (Jaroslav Kysela) [1197064]
- [alsa] pcm: snd_interval_step: fix changes of open intervals (Jaroslav Kysela) [1197064]
- [alsa] pcm: snd_interval_step: drop the min parameter (Jaroslav Kysela) [1197064]
- [alsa] hda - Add TLV_DB_SCALE_MUTE bit for relevant controls (Jaroslav Kysela) [1197064]
- [alsa] pcm: Uninline snd_pcm_stream_lock() and _unlock() (Jaroslav Kysela) [1197064]
- [alsa] pcm: Allow nonatomic trigger operations (Jaroslav Kysela) [1197064]
- [alsa] hda - Make the ALC269 pin quirk table shorter (Jaroslav Kysela) [1197064]
- [alsa] hda - Add common pin macros for ALC269 family (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - move HP_GPIO_MIC1_LED quirk for alc280 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - move HP_LINE1_MIC1_LED quirk for alc282 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - move HP_MUTE_LED_MIC1 quirk for alc290 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - move HP_MUTE_LED_MIC1 quirk for alc282 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - move DELL2_MIC_NO_PRESENCE quirk for alc255 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - move DELL1_MIC_NO_PRESENCE quirk for alc255 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - move DELL1_MIC_NO_PRESENCE quirk for alc283 (Jaroslav Kysela) [1197064]
- [alsa] hda/realtek - move DELL2_MIC_NO_PRESENCE quirk for alc292 (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix COEF setups for ALC1150 codec (Jaroslav Kysela) [1197064]
- [alsa] hda - Fix digital mic on Acer Aspire 3830TG (Jaroslav Kysela) [1197064]

* Mon Jun 22 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-277.el7]
- [kernel] sched: Fix compiler warnings (Jiri Olsa) [1222189]
- [block] fix ext_dev_lock lockdep report (Jeff Moyer) [1230924]
- [net] dcbnl: Disable software interrupts before taking dcb_lock (Chris Leech) [1175797]
- [net] dcbnl: Fix misleading dcb_app->priority explanation (Chris Leech) [1175797]
- [net] dcb: use __dev_get_by_name instead of dev_get_by_name to find (Chris Leech) [1175797]
- [net] dcbevent.h: Remove extern from function prototypes (Chris Leech) [1175797]
- [scsi] fcoe: extend ethtool to FC port speed mapping (Chris Leech) [1175797]
- [scsi] scsi_transport_fc: Add support for 25Gbit speed (Chris Leech) [1175797]
- [scsi] add defines for new FC port speeds (Chris Leech) [1175797]
- [scsi] megaraid: regression - fix irq setup process (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: Modify return value of megasas_issue_blocked_cmd() and wait_and_poll() to consider command status returned by firmware (Tomas Henzl) [1207092]
- [scsi] megaraid: --grep and Kconfig (Tomas Henzl) [1185944]
- [scsi] megaraid: remove unnecessary pci_set_drvdata() (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: fix bug in handling return value of pci_enable_msix_range() (Tomas Henzl) [1185944]
- [scsi] megaraid: Use pci_enable_msix_range() instead of pci_enable_msix() (Tomas Henzl) [1185944]
- [scsi] megaraid: use pci_zalloc_consistent (Tomas Henzl) [1185944]
- [scsi] megaraid: fixed several typos in comments (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: swap whole register in megasas_register_aen (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: fix megasas_fire_cmd_fusion calling convention (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: add missing byte swaps to the sriov code (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: bytewise or should be done on native endian variables (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: move endianness conversion into caller of megasas_get_seq_num (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: add endianness conversions for all ones (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: add endianness annotations (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: add missing __iomem annotations (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: megasas_complete_outstanding_ioctls() can be static (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: Support for Avago's Single server High Availability product (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: Add release date and update driver version (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: Modify driver's meta data to reflect Avago (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: Use Block layer tag support for internal command indexing (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: Enhanced few prints (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: Move controller's queue depth calculation in adapter specific function (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: Add separate functions for building sysPD IOs and non RW LDIOs (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: Add separate function for refiring MFI commands (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: Add separate function for setting up IRQs (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: use raw_smp_processor_id() (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: driver version update (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: remove redundant memset call (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: reserve commands for IOCTLs and internal DCMDs (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: complete outstanding IOCTLs before killing adapter (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: disable interrupt_mask before enabling hardware interrupts (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: fix the problem of non-existing VD exposed to host (Tomas Henzl) [1185944]
- [scsi] megaraid_sas: add support for secure JBOD (Tomas Henzl) [1185944]
- [scsi] mptsas: fix depth param in scsi_track_queue_full (Tomas Henzl) [1117348]
- [scsi] lpfc: Update version 10.7.0.1 for RHEL 7.2 release (Rob Evers) [1225165]
- [scsi] lpfc: Fix to drop PLOGIs from fabric node till LOGO processing completes (Rob Evers) [1225165]
- [scsi] lpfc: Fix cq_id masking problem (Rob Evers) [1225165]
- [scsi] lpfc: Fix scsi prep dma buf error (Rob Evers) [1225165]
- [scsi] lpfc: Devices are not discovered during takeaway/giveback testing (Rob Evers) [1225165]
- [scsi] lpfc: Fix vport deletion failure (Rob Evers) [1225165]
- [scsi] lpfc: Check for active portpeerbeacon (Rob Evers) [1225165]
- [scsi] lpfc: Change buffer pool empty message to miscellaneous category (Rob Evers) [1225165]
- [scsi] lpfc: Fix incorrect log message reported for empty FCF record (Rob Evers) [1225165]
- [scsi] lpfc: Fix rport leak (Rob Evers) [1225165]
- [scsi] lpfc: Correct loss of RSCNs during array takeaway/giveback testing (Rob Evers) [1225165]
- [scsi] lpfc: Fix crash in vport_delete (Rob Evers) [1225165]
- [scsi] lpfc: Fix to remove IRQF_SHARED flag for MSI/MSI-X vectors (Rob Evers) [1225165]
- [scsi] lpfc: Fix discovery issue when changing from Pt2Pt to Fabric (Rob Evers) [1225165]
- [scsi] lpfc: Correct reporting of vport state on fdisc command failure (Rob Evers) [1225165]
- [scsi] lpfc: Add support for RDP ELS command (Rob Evers) [1225165]
- [scsi] lpfc: Fix ABORTs WQ selection in terminate_rport_io (Rob Evers) [1225165]
- [scsi] lpfc: Correct reference counting of rport (Rob Evers) [1225165]
- [scsi] lpfc: Add support for ELS LCB (Rob Evers) [1225165]
- [scsi] lpfc: Correct loss of target discovery after cable swap (Rob Evers) [1225165]
- [scsi] lpfc: Fix crash in device reset handler (Rob Evers) [1225165]
- [scsi] lpfc: Fix OS crash when running loopback test in applications (Rob Evers) [1225165]
- [scsi] lpfc: Fix internal loopback failure (Rob Evers) [1225165]
- [scsi] lpfc: Fix premature release of rpi bit in bitmask (Rob Evers) [1225165]
- [scsi] lpfc: Initiator sends wrong BBCredit value for either FLOGI or FLOGI_ACC (Rob Evers) [1225165]
- [scsi] lpfc: Fix FDMI Fabric support in driver for Brocade (Rob Evers) [1225165]
- [scsi] lpfc: Fix null ndlp dereference in target_reset_handler (Rob Evers) [1225165]
- [scsi] lpfc: Parse the new 20G, 25G and 40G link speeds in the lpfc driver (Rob Evers) [1225165]
- [scsi] lpfc: Fix provide host name and OS name in RSNN-NN FC-GS command (Rob Evers) [1225165]
- [scsi] lpfc: Add support for reporting option_rom_version on newer adapters (Rob Evers) [1225165]
- [scsi] lpfc: Fix setting of EQ (interrupt) delay Multiplier (Rob Evers) [1225165]
- [scsi] lpfc: fix low priority issues from fortify source code scan (Rob Evers) [1225165]
- [scsi] lpfc: fix high priority issues from fortify source code scan (Rob Evers) [1225165]
- [scsi] lpfc: Fix host reset escalation killing all IOs (Rob Evers) [1225165]
- [scsi] lpfc: correct device removal deadlock after link bounce (Rob Evers) [1225165]
- [scsi] lpfc: Linux lpfc driver doesn't re-establish the link after a cable pull on LPe12002 (Rob Evers) [1225165]
- [scsi] lpfc: Fix to handle PLOGI when already logged in (Rob Evers) [1225165]
- [scsi] lpfc: Add new mbx cmd recognition (Rob Evers) [1225165]
- [scsi] lpfc: Add Lancer Temperature Event support to the lpfc driver (Rob Evers) [1225165]

* Mon Jun 22 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-276.el7]
- [pci] msi: Remove unnecessary braces around single statements (Steve Best) [1231358]
- [usb] core: hcd-pci: free IRQ before disabling PCI device when shutting down (Steve Best) [1231358]
- [x86] irq: Clean up irqdomain transition code (Steve Best) [1231358]
- [x86] irq, devicetree: Release IOAPIC pin when PCI device is disabled (Steve Best) [1231358]
- [x86] irq, mpparse: Release IOAPIC pin when PCI device is disabled (Steve Best) [1231358]
- [x86] irq, acpi: Release IOAPIC pin when PCI device is disabled (Steve Best) [1231358]
- [x86] irq: Introduce helper functions to release IOAPIC pin (Steve Best) [1231358]
- [x86] irq: Simplify the way to handle ISA IRQ (Steve Best) [1231358]
- [x86] irq: Clean up unused IOAPIC interface (Steve Best) [1231358]
- [x86] irq, devicetree: Use common irqdomain map interface to program IOAPIC pins (Steve Best) [1231358]
- [x86] irq, mpparse: Use common irqdomain map interface to program IOAPIC pins (Steve Best) [1231358]
- [x86] irq, acpi: Use common irqdomain map interface to program IOAPIC pins (Steve Best) [1231358]
- [x86] irq: Introduce two helper functions to support irqdomain map operation (Steve Best) [1231358]
- [x86] devicetree, irq: Use common mechanism to support irqdomain (Steve Best) [1231358]
- [x86] mpparse, irq: Provide basic irqdomain support (Steve Best) [1231358]
- [x86] acpi, irq: Provide basic irqdomain support (Steve Best) [1231358]
- [x86] irq: Enhance mp_register_ioapic() to support irqdomain (Steve Best) [1231358]
- [x86] irq: Introduce mechanisms to support dynamically allocate IRQ for IOAPIC (Steve Best) [1231358]
- [x86] irq, acpi: Change __acpi_register_gsi to return IRQ number instead of GSI (Steve Best) [1231358]
- [x86] acpi, irq: Consolidate algorithm of mapping (ioapic, pin) to IRQ number (Steve Best) [1231358]
- [x86] irq: Simplify arch_early_irq_init() (Steve Best) [1231358]
- [x86] irq: Count legacy IRQs by legacy_pic->nr_legacy_irqs instead of NR_IRQS_LEGACY (Steve Best) [1231358]
- [x86] ce4100, irq: Do not set legacy_pic to null_legacy_pic (Steve Best) [1231358]
- [x86] ce4100, irq: Make CE4100 depend on CONFIG_X86_IO_APIC (Steve Best) [1231358]
- [x86] irq: Introduce some helper utilities to improve readability (Steve Best) [1231358]
- [x86] irq: Reorganize IO_APIC_get_PCI_irq_vector() to prepare for irqdomain (Steve Best) [1231358]
- [x86] ioapic: Use irq_cfg() instead of irq_get_chip_data() for better readability (Steve Best) [1231358]
- [x86] ioapic: Introduce helper utilities to walk ioapics and pins (Steve Best) [1231358]
- [x86] ioapic: Kill static variable nr_irqs_gsi (Steve Best) [1231358]
- [x86] ioapic: Keep get_nr_irqs_gsi() (Steve Best) [1231358]
- [x86] genirq: Ensure that dynamic irq allocation does not conflict (Steve Best) [1231358]
- [x86] Remove create/destroy_irq() (Steve Best) [1231358]
- [x86] iommu: dmar: Provide arch specific irq allocation (Steve Best) [1231358]
- [x86] iommu: smar: Fix return value check of create_irq() (Steve Best) [1231358]
- [x86] hpet: Use irq_alloc/free_hwirq() (Steve Best) [1231358]
- [x86] uv: Use irq_alloc/free_hwirq() (Steve Best) [1231358]
- [x86] irq_remapping: Use irq_alloc/free_hwirq() (Steve Best) [1231358]
- [x86] htirq: Use irq_alloc/free_irq() (Steve Best) [1231358]
- [x86] ioapic: Use irq_alloc/free_hwirq() (Steve Best) [1231358]
- [x86] genirq: Provide generic hwirq allocation facility (Steve Best) [1231358]
- [x86] Implement arch_setup/teardown_hwirq() (Steve Best) [1231358]
- [x86] ioapic: Kill unused global variable timer_through_8259 (Steve Best) [1231358]
- [x86] irq, trivial: Minor improvements of IRQ related code (Steve Best) [1231358]
- [x86] acpi, irq: Fix possible eror in GSI to IRQ mapping for legacy IRQ (Steve Best) [1231358]
- [x86] acpi, irq: Enhance error handling in function acpi_register_gsi() (Steve Best) [1231358]
- [x86] acpi, trivial: Minor improvements to arch/x86/kernel/acpi/boot.c (Steve Best) [1231358]
- [x86] acpi, irq: Kill static function irq_to_gsi() (Steve Best) [1231358]
- [x86] pci, acpi: Use kmalloc_node() to optimize for performance (Steve Best) [1231358]
- [x86] acpi: Reorganize code to avoid forward declaration in boot.c (Steve Best) [1231358]
- [x86] apic: Remove support for ia32-based Unisys ES7000 (Steve Best) [1231358]
- [x86] mpparse: Simplify arch/x86/include/asm/mpspec.h (Steve Best) [1231358]
- [x86] mpparse: Use pr_lvl() helper utilities to replace printk(KERN_LVL) (Steve Best) [1231358]

* Mon Jun 22 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-275.el7]
- [char] ipmi: Update timespec usage to timespec64 (Tony Camuso) [1229675]
- [char] ipmi: Fix multi-part message handling (Tony Camuso) [1229675]
- [char] ipmi: Add alert handling to SSIF (Tony Camuso) [1229675]
- [char] ipmi: Fix a problem that messages are not issued in run_to_completion mode (Tony Camuso) [1229675]
- [char] ipmi: Report an error if ACPI _IFT doesn't exist (Tony Camuso) [1229675]
- [char] ipmi: Remove unused including <linux/version.h> (Tony Camuso) [1229675]
- [char] ipmi: Don't report err in the SI driver for SSIF devices (Tony Camuso) [1229675]
- [char] ipmi: Remove incorrect use of seq_has_overflowed (Tony Camuso) [1229675]
- [char] ipmi_ssif: Ignore spaces when comparing I2C adapter names (Tony Camuso) [1229675]
- [char] ipmi_ssif: Fix the logic on user-supplied addresses (Tony Camuso) [1229675]
- [char] ipmi_ssif: Use interruptible completion for waiting in the thread (Tony Camuso) [1229675]
- [char] ipmi: Handle BMCs that don't allow clearing the rcv irq bit (Tony Camuso) [1229675]
- [char] ipmi: constify of_device_id array (Tony Camuso) [1229675]
- [char] ipmi: Fix a memory ordering issue (Tony Camuso) [1229675]
- [char] ipmi: Remove uses of return value of seq_printf (Tony Camuso) [1229675]
- [char] ipmi: Use is_visible callback for conditional sysfs entries (Tony Camuso) [1229675]
- [char] ipmi: Free ipmi_recv_msg messages from the linked list on close (Tony Camuso) [1229675]
- [char] ipmi: avoid gcc warning (Tony Camuso) [1229675]
- [char] ipmi: Cleanup DEBUG_TIMING ifdef usage (Tony Camuso) [1229675]
- [char] ipmi: Remove unneeded FIXME comment in the file, ipmi_si_intf.c (Tony Camuso) [1229675]
- [char] ipmi: Remove obsolete cleanup for clientdata (Tony Camuso) [1229675]
- [char] ipmi: Remove a FIXME for slab conversion (Tony Camuso) [1229675]
- [char] ipmi: Fix compile warning with tv_usec (Tony Camuso) [1229675]
- [char] ipmi: Fix compile issue with isspace() (Tony Camuso) [1229675]
- [char] ipmi: Finish cleanup of BMC attributes (Tony Camuso) [1229675]
- [char] ipmi: Check the BT interrupt enable periodically (Tony Camuso) [1229675]
- [char] ipmi: Fix attention handling for system interfaces (Tony Camuso) [1229675]
- [char] ipmi: Periodically check to see if irqs and messages are set right (Tony Camuso) [1229675]
- [char] ipmi: Add SMBus interface driver (SSIF) (Tony Camuso) [1229675]
- [char] ipmi: Remove the now unnecessary message queue (Tony Camuso) [1229675]
- [char] ipmi: Make the message handler easier to use for SMI interfaces (Tony Camuso) [1229675]
- [char] ipmi: Move message sending into its own function (Tony Camuso) [1229675]
- [char] ipmi: rename waiting_msgs to waiting_rcv_msgs (Tony Camuso) [1229675]
- [char] ipmi: Fix handling of BMC flags (Tony Camuso) [1229675]
- [char] ipmi: Initialize BMC device attributes (Tony Camuso) [1229675]
- [char] ipmi: Unregister previously registered driver in error case (Tony Camuso) [1229675]
- [char] ipmi: Fix a bug in hot add/remove (Tony Camuso) [1229675]
- [char] ipmi: Remove useless sysfs_name parameters (Tony Camuso) [1229675]
- [char] ipmi: clean up the device handling for the bmc device (Tony Camuso) [1229675]
- [char] ipmi: Move the address source to string to ipmi-generic code (Tony Camuso) [1229675]
- [char] ipmi: Ignore SSIF in the PNP handling (Tony Camuso) [1229675]
- [char] ipmi: drop owner assignment from platform_drivers (Tony Camuso) [1229675]
- [powerpc] rtc/tpo: Driver to support rtc and wakeup on PowerNV platform (Gustavo Duarte) [1223687]
- [powerpc] powernv: Check OPAL RTC calls exists before using (Gustavo Duarte) [1223687]
- [base] devres: restore zeroing behavior of devres_alloc() (Gustavo Duarte) [1221064 1230136]
- [char] ipmi/powernv: Fix minor locking bug (Gustavo Duarte) [1221064]
- [char] ipmi: Add powernv IPMI driver (Gustavo Duarte) [1221064]
- [powerpc] powernv: Add OPAL IPMI interface (Gustavo Duarte) [1221064]
- [powerpc] devres: add kernel standard devm_k.alloc functions (Gustavo Duarte) [1221064]

* Fri Jun 19 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-274.el7]
- [netdrv] macvtap/tun: cross-endian support for little-endian hosts (Thomas Huth) [1213658]
- [vhost] cross-endian support for legacy devices (Thomas Huth) [1213658]
- [virtio] add explicit big-endian support to memory accessors (Thomas Huth) [1213658]
- [vhost] introduce vhost_is_little_endian() helper (Thomas Huth) [1213658]
- [virtio] vringh: introduce vringh_is_little_endian() helper (Thomas Huth) [1213658]
- [netdrv] macvtap: introduce macvtap_is_little_endian() helper (Thomas Huth) [1213658]
- [netdrv] tun: add tun_is_little_endian() helper (Thomas Huth) [1213658]
- [virtio] introduce virtio_is_little_endian() helper (Thomas Huth) [1213658]
- [netdrv] tun: remove bogus hardware vlan acceleration flags from vlan_features (Thomas Huth) [1231879]
- [kvm] move advertising of KVM_CAP_IRQFD to common code (Thomas Huth) [1231879]
- [kvm] Give IRQFD its own separate enabling Kconfig option (Thomas Huth) [1231879]
- [netdrv] vringh: update for virtio 1.0 APIs (Thomas Huth) [1231879]
- [netdrv] vringh: 64 bit features (Thomas Huth) [1231879]
- [vhost] net: fix up num_buffers endian-ness (Thomas Huth) [1231879]
- [vhost] net: enable virtio 1.0 (Thomas Huth) [1231879]
- [vhost] net: larger header for virtio 1.0 (Thomas Huth) [1231879]
- [vhost] net: length miscalculation (Thomas Huth) [1231879]
- [vhost] net: virtio 1.0 byte swap (Thomas Huth) [1231879]
- [vhost] virtio 1.0 endian-ness support (Thomas Huth) [1231879]
- [vhost] switch to __get/__put_user exclusively (Thomas Huth) [1231879]
- [vhost] net: force len for TX to host endian (Thomas Huth) [1231879]
- [vhost] add memory access wrappers (Thomas Huth) [1231879]
- [vhost] make features 64 bit (Thomas Huth) [1231879]
- [vhost] switch to use vhost_add_used_n() (Thomas Huth) [1231879]
- [netdrv] macvtap: drop broken IFF_VNET_LE (Thomas Huth) [1231879]
- [netdrv] macvtap: TUN_VNET_LE support (Thomas Huth) [1231879]
- [netdrv] macvtap: Fix csum_start when VLAN tags are present (Thomas Huth) [1231879]
- [netdrv] macvtap: remove the dead branch (Thomas Huth) [1231879]
- [netdrv] tun: drop broken IFF_VNET_LE (Thomas Huth) [1231879]
- [netdrv] if_tun: add TUNSETVNETLE/TUNGETVNETLE (Thomas Huth) [1231879]
- [netdrv] tun: TUN_VNET_LE support, fix sparse warnings for virtio headers (Thomas Huth) [1231879]
- [netdrv] tun: drop most type defines (Thomas Huth) [1231879]
- [netdrv] tun: move internal flag defines out of uapi (Thomas Huth) [1231879]
- [netdrv] tun: Report "persist" flag to userspace (Thomas Huth) [1231879]
- [netdrv] tun: Fix TUN_PKT_STRIP setting (Thomas Huth) [1231879]
- [netdrv] tun: Fix csum_start with VLAN acceleration (Thomas Huth) [1231879]
- [netdrv] tun: unbreak truncated packet signalling (Thomas Huth) [1231879]
- [netdrv] tuntap: hardware vlan tx support (Thomas Huth) [1231879]
- [netdrv] bnx2x: Alloc 4k fragment for each rx ring buffer element (Michal Schmidt) [1182054 1182736 1187290 1229122]
- [netdrv] bnx2x: Move statistics implementation into semaphores (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: limit fw delay in kdump to 5s after boot (Michal Schmidt) [1179882 1182054 1182736 1187290 1211883 1217325 1224087]
- [netdrv] bnx2x: Fix to prevent inner-reload (Michal Schmidt) [1182054 1182736 1187290 1191799]
- [netdrv] bnx2x: Delay during kdump load (Michal Schmidt) [1179882 1182054 1182736 1187290 1211883 1217325 1224087]
- [netdrv] bnx2x: remove {TPA,GRO}_ENABLE_FLAG (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: merge fp->disable_tpa with fp->mode (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: mark LRO as a fixed disabled feature if disable_tpa is set (Michal Schmidt) [1182054 1182736 1187290 1215700]
- [netdrv] bnx2x: really disable TPA if 'disable_tpa' option is set (Michal Schmidt) [1182054 1182736 1187290 1215700]
- [netdrv] bnx2x: Prevent inner-reload while VFs exist (Michal Schmidt) [1182054 1182736 1187290 1191799]
- [netdrv] bnx2x: Fix busy_poll vs netpoll (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] ptp: bnx2x: use helpers for converting ns to timespec (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: Use bool function returns of true/false instead of 1/0 (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: Prevent probe as early as possible (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: Count number of link changes (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: Configure IFir et al. according to nvram (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: codespell comment spelling fixes (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: Use eth_<foo>_addr instead of memset (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: Fix typo in printk messages (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: Fix kdump when iommu=on (Michal Schmidt) [1179882 1182054 1182736 1187290 1211883 1217325 1224087]
- [netdrv] bnx2x: Fix kdump on 4-port device (Michal Schmidt) [1179882 1182054 1182736 1187290 1211883 1217325 1224087]
- [netdrv] bnx2x: Fix statistics locking scheme (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: Force fundamental reset for EEH recovery (Michal Schmidt) [1182054 1182736 1187290 1198641]
- [netdrv] net: bnx2x: fix sparse warnings (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: fix napi poll return value for repoll (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] net: bnx2x: avoid macro redefinition (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] net: bnx2x: convert to timecounter adjtime (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: fix typos in "configure" (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: Limit 1G link enforcement (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] ethernet/broadcom: Use napi_alloc_skb instead of netdev_alloc_skb_ip_align (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: Use correct fastpath version for VFs (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: use netdev_rss_key_fill() helper (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: use napi_schedule_irqoff() (Michal Schmidt) [1182054 1182736 1187290]
- [netdrv] bnx2x: Add a fallback multi-function mode NPAR1.5 (Michal Schmidt) [1146035 1182054 1182298 1182736 1187290]
- [netdrv] bnx2x: new multi-function mode: UFP (Michal Schmidt) [1146035 1182054 1182298 1182736 1187290]
- [netdrv] bnx2x: Changes with storage & MAC macros (Michal Schmidt) [1146035 1182054 1182298 1182736 1187290]
- [netdrv] bnx2x: Fix link problems for 1G SFP RJ45 module (Michal Schmidt) [1182054 1182736 1187290]
- [fs] xfs: fix broken i_nlink accounting for whiteout tmpfile inode (Brian Foster) [1225075]
- [fs] xfs: xfs_iozero can return positive errno (Brian Foster) [1225075]
- [fs] xfs: xfs_attr_inactive leaves inconsistent attr fork state behind (Brian Foster) [1225075]
- [fs] xfs: extent size hints can round up extents past MAXEXTLEN (Brian Foster) [1225075]
- [fs] xfs: inode and free block counters need to use __percpu_counter_compare (Brian Foster) [1225075]
- [fs] percpu_counter: batch size aware __percpu_counter_compare() (Brian Foster) [1225075]
- [fs] xfs: use percpu_counter_read_positive for mp->m_icount (Brian Foster) [1225075]
- [fs] xfs: unlock i_mutex in xfs_break_layouts (Brian Foster) [1225075]
- [fs] xfs: kill unnecessary firstused overflow check on attr3 leaf removal (Brian Foster) [1225075]
- [fs] xfs: use larger in-core attr firstused field and detect overflow (Brian Foster) [1225075]
- [fs] xfs: pass attr geometry to attr leaf header conversion functions (Brian Foster) [1225075]
- [fs] xfs: Fix incorrect positive ENOMEM return (Brian Foster) [1225075]
- [fs] xfs: xfs_mru_cache_insert() should use GFP_NOFS (Brian Foster) [1225075]
- [fs] xfs: pF is only for function pointers (Brian Foster) [1225075]
- [fs] xfs: fix shadow warning in xfs_da3_root_split() (Brian Foster) [1225075]
- [fs] xfs: use bool instead of int in xfs_rename() (Brian Foster) [1225075]
- [fs] xfs: fix NULL pointer dereference in xfs_filestream_lookup_ag() (Brian Foster) [1225075]
- [fs] xfs: remove xfs_bmap_sanity_check() (Brian Foster) [1225075]
- [fs] xfs: xfs_alloc_fix_minleft can underflow near ENOSPC (Brian Foster) [1225075]
- [fs] xfs: cancel failed transaction in xfs_fs_commit_blocks() (Brian Foster) [1225075]
- [fs] xfs: remove old and redundant comment in xfs_mount_validate_sb (Brian Foster) [1225075]
- [fs] xfs: clarify async write failure ratelimit message (Brian Foster) [1225075]
- [fs] xfs: log unmount events on console (Brian Foster) [1225075]
- [fs] xfs: pass mp to XFS_WANT_CORRUPTED_RETURN (Brian Foster) [1225075]
- [fs] xfs: pass mp to XFS_WANT_CORRUPTED_GOTO (Brian Foster) [1225075]
- [fs] xfs: ensure truncate forces zeroed blocks to disk (Brian Foster) [1225075]
- [fs] xfs: Fix quota type in quota structures when reusing quota file (Brian Foster) [1225075]
- [fs] xfs: lock out page faults from extent swap operations (Brian Foster) [1225075]
- [fs] xfs: xfs_setattr_size no longer races with page faults (Brian Foster) [1225075]
- [fs] xfs: take i_mmap_lock on extent manipulation operations (Brian Foster) [1225075]
- [fs] xfs: use i_mmaplock on write faults (Brian Foster) [1225075]
- [fs] xfs: use i_mmaplock on read faults (Brian Foster) [1225075]
- [fs] xfs: introduce mmap/truncate lock (Brian Foster) [1225075]
- [fs] xfs: remove xfs_mod_incore_sb API (Brian Foster) [1225075]
- [fs] xfs: replace xfs_mod_incore_sb_batched (Brian Foster) [1225075]
- [fs] xfs: introduce xfs_mod_frextents (Brian Foster) [1225075]
- [fs] xfs: Remove icsb infrastructure (Brian Foster) [1225075]
- [fs] xfs: use generic percpu counters for free block counter (Brian Foster) [1225075]
- [fs] xfs: use generic percpu counters for free inode counter (Brian Foster) [1225075]
- [fs] xfs: use generic percpu counters for inode counter (Brian Foster) [1225075]
- [fs] xfs: recall pNFS layouts on conflicting access (Brian Foster) [1225075]
- [fs] xfs: implement pNFS export operations (Brian Foster) [1225075]
- [fs] xfs: report proper f_files in statfs if we overshoot imaxpct (Brian Foster) [1225075]
- [fs] xfs: xfs_ioctl_setattr_check_projid can be static (Brian Foster) [1225075]
- [fs] xfs: growfs should use synchronous transactions (Brian Foster) [1225075]
- [fs] xfs: change kmem_free to use generic kvfree() (Brian Foster) [1225075]
- [fs] xfs: factor out a xfs_update_prealloc_flags() helper (Brian Foster) [1225075]
- [fs] xfs: remove incorrect error negation in attr_multi ioctl (Brian Foster) [1225075]
- [fs] xfs: set superblock buffer type correctly (Brian Foster) [1225075]
- [fs] xfs: set buf types when converting extent formats (Brian Foster) [1225075]
- [fs] xfs: inode unlink does not set AGI buffer type (Brian Foster) [1225075]
- [fs] xfs: ensure buffer types are set correctly (Brian Foster) [1225075]
- [fs] xfs: sanitise sb_bad_features2 handling (Brian Foster) [1225075]
- [fs] xfs: consolidate superblock logging functions (Brian Foster) [1225075]
- [fs] xfs: remove bitfield based superblock updates (Brian Foster) [1225075]
- [fs] xfs: Remove some pointless quota checks (Brian Foster) [1225075]
- [fs] xfs: Remove some useless flags tests (Brian Foster) [1225075]
- [fs] xfs: Remove useless test (Brian Foster) [1225075]
- [fs] xfs: fix implicit bool to int conversion (Brian Foster) [1225075]
- [fs] xfs: pass a 64-bit count argument to xfs_iomap_write_unwritten (Brian Foster) [1225075]
- [fs] xfs: move xfs_bmap_finish prototype (Brian Foster) [1225075]
- [fs] xfs: move struct xfs_bmalloca to libxfs (Brian Foster) [1225075]
- [fs] xfs: move xfs_types.h to libxfs (Brian Foster) [1225075]
- [fs] xfs: move xfs_fs.h to libxfs (Brian Foster) [1225075]
- [fs] xfs: remove extra newlines from xfs messages (Brian Foster) [1225075]
- [fs] xfs: initialize log buf I/O completion wq on log alloc (Brian Foster) [1225075]

* Fri Jun 19 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-273.el7]
- [netdrv] i40e/i40evf: Fix mixed size frags and linearization (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: remove time_stamp member (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: force inline transmit functions (Stefan Assmann) [1173789]
- [netdrv] i40evf: skb->xmit_more support (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Remove unneeded TODO (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Add stats to count Tunnel ATR hits (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Add ATR support for tunneled TCP/IPv4/IPv6 packets (Stefan Assmann) [1173789]
- [netdrv] net: batch of last_rx update avoidance in ethernet drivers (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Save WR_CSR_PROT field from DEV/FUNC capabilities (Stefan Assmann) [1173789]
- [netdrv] i40evf: remove aq_pending (Stefan Assmann) [1173789]
- [netdrv] i40evf: fix bad indentation (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Use dma_rmb where appropriate (Stefan Assmann) [1173789]
- [netdrv] i40evf: Refactor VF RSS code (Stefan Assmann) [1173789]
- [netdrv] i40evf: protect VLAN filter list (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Set Ethernet protocol correctly when Tx VLAN offloads are disabled (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: fix bug when skb allocation fails (Stefan Assmann) [1173789]
- [netdrv] i40evf: Fix Outer UDP RX checksum code (Stefan Assmann) [1173789]
- [netdrv] i40evf: add FW version to ethtool info (Stefan Assmann) [1173789]
- [netdrv] i40evf: resequence close operations (Stefan Assmann) [1173789]
- [netdrv] i40evf: delay releasing rings (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: implement KR2 support (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Bump i40e/i40evf version (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: fix accidental write to ITR registers (Stefan Assmann) [1173789]
- [netdrv] i40vf: don't stop me now (Stefan Assmann) [1173789]
- [netdrv] ethernet: codespell comment spelling fixes (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Bump version (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: enable prefetch of Tx descriptors during cleanup (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Simplify tunnel selection logic (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Refactor i40e_debug_aq and make some functions static (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Version bump (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Clean up some formatting and other things (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: grab NVM devstarter version not image version (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Bump versions (Stefan Assmann) [1173789]
- [netdrv] i40evf: ethtool RSS fixes (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Add missing packet types for VXLAN encapsulated packet types (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: print FW build number in version string (Stefan Assmann) [1173789]
- [netdrv] i40evf: TCP/IPv6 over Vxlan Tx checksum offload fix (Stefan Assmann) [1173789]
- [netdrv] i40e: fix race in hang check (Stefan Assmann) [1173789]
- [netdrv] i40e: Fix TSO with more than 8 frags per segment issue (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Update driver versions (Stefan Assmann) [1173789]
- [netdrv] i40evf: Add more info to interrupt vector names (Stefan Assmann) [1173789]
- [netdrv] i40evf: allow enabling of debug prints via ethtool (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Use advertised speed settings in ethtool and refactor get_settings (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Fix output of i40e_debug_aq() for big endian machines (Stefan Assmann) [1173789]
- [netdrv] i40evf: don't wait forever (Stefan Assmann) [1173789]
- [netdrv] i40evf: refactor reset (Stefan Assmann) [1173789]
- [netdrv] i40evf: disable NAPI polling sooner (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Bump Driver Versions (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Remove unused variable an_enable and function update_link_info (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: i40e_register.h updates (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: restrict VC opcodes to their initial values (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Refactor the receive routines (Stefan Assmann) [1173789]
- [netdrv] i40e: Fix for stats init function call in Rx setup (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Add call to u64_stats_init to init (Stefan Assmann) [1173789]
- [netdrv] i40evf: Force Tx writeback on ITR (Stefan Assmann) [1173789]
- [netdrv] i40evf: stop the watchdog for shutdown (Stefan Assmann) [1173789]
- [netdrv] i40evf: ignore bogus messages from FW (Stefan Assmann) [1173789]
- [netdrv] i40evf: reset on module unload (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Bump i40e and i40evf versions (Stefan Assmann) [1173789]
- [netdrv] i40e: Support for NPAR iSCSI partition with DCB (Stefan Assmann) [1173789]
- [netdrv] i40e: AQ API updates for new commands (Stefan Assmann) [1173789]
- [netdrv] i40e: AQ API updates (Stefan Assmann) [1173789]
- [netdrv] i40e: add more struct size checks (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Bump i40e/i40evf versions (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Increase ASQ timeout (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: AdminQ updates ww36 (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: find partition_id in npar mode (Stefan Assmann) [1173789]
- [netdrv] i40evf: kick a stalled admin queue (Stefan Assmann) [1173789]
- [netdrv] i40evf: enable interrupt 0 appropriately (Stefan Assmann) [1173789]
- [netdrv] i40evf: don't fire traffic IRQs when the interface is down (Stefan Assmann) [1173789]
- [netdrv] i40evf: remove leftover VLAN filters (Stefan Assmann) [1173789]
- [netdrv] i40evf: refactor shutdown code (Stefan Assmann) [1173789]
- [netdrv] i40evf: Remove some scary log messages (Stefan Assmann) [1173789]
- [netdrv] i40evf: remove redundant code (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Convert macro to static inline (Stefan Assmann) [1173789]
- [netdrv] i40e: check for AQ timeout in aq_rc decode (Stefan Assmann) [1173789]
- [netdrv] i40e: set max limit for access polling (Stefan Assmann) [1173789]
- [netdrv] i40e: remove unused nvm_semaphore_wait (Stefan Assmann) [1173789]
- [netdrv] i40e: add range check to i40e_aq_rc_to_posix (Stefan Assmann) [1173789]
- [netdrv] i40e: let firmware catch the NVM busy error (Stefan Assmann) [1173789]
- [netdrv] i40e: Bump i40e version to 1.2.2 and i40evf version to 1.0.6 (Stefan Assmann) [1173789]
- [netdrv] i40evf: make early init sequence even more robust (Stefan Assmann) [1173789]
- [netdrv] i40e: Define and use i40e_is_vf macro (Stefan Assmann) [1173789]
- [netdrv] i40e: Add a virtual channel op to config RSS (Stefan Assmann) [1173789]
- [netdrv] i40e: remove useless debug noise (Stefan Assmann) [1173789]
- [netdrv] i40evf: remove unnecessary else (Stefan Assmann) [1173789]
- [netdrv] i40evf: make comparisons consistent (Stefan Assmann) [1173789]
- [netdrv] i40evf: make checkpatch happy (Stefan Assmann) [1173789]
- [netdrv] i40evf: update header comments (Stefan Assmann) [1173789]
- [netdrv] i40e: don't overload fields (Stefan Assmann) [1173789]
- [netdrv] i40e: use netdev_rss_key_fill() helper (Stefan Assmann) [1173789]
- [netdrv] i40evf: don't use more queues than CPUs (Stefan Assmann) [1173789]
- [netdrv] i40evf: make early init processing more robust (Stefan Assmann) [1173789]
- [netdrv] i40e: clean up throttle rate code (Stefan Assmann) [1173789]
- [netdrv] i40e: poll firmware slower (Stefan Assmann) [1173789]
- [netdrv] i40evf: Add support for 10G base T parts (Stefan Assmann) [1173789]
- [netdrv] i40evf: properly handle multiple AQ messages (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Use usleep_range() instead of udelay() (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Fix whitespace indentation (Stefan Assmann) [1173789]
- [netdrv] i40e/i40evf: Bump i40e/i40evf versions (Stefan Assmann) [1173789]
- [netdrv] i40evf: Set skb->csum_level for encapsulated checksum (Stefan Assmann) [1173789]
- [netdrv] i40e: Make sure to be in VEB mode if SRIOV is enabled at probe (Stefan Assmann) [1173788]
- [netdrv] i40e: start up in VEPA mode by default (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Fix mixed size frags and linearization (Stefan Assmann) [1173788]
- [netdrv] i40e: Bump version to 1.3.4 (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: remove time_stamp member (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: force inline transmit functions (Stefan Assmann) [1173788]
- [netdrv] i40e: Move the FD ATR/SB messages to a higher debug level (Stefan Assmann) [1173788]
- [netdrv] i40e: fix unrecognized FCOE EOF case (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Remove unneeded TODO (Stefan Assmann) [1173788]
- [netdrv] i40e: Remove unnecessary pf members (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Add stats to count Tunnel ATR hits (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Add ATR support for tunneled TCP/IPv4/IPv6 packets (Stefan Assmann) [1173788]
- [netdrv] i40e: Disable offline diagnostics if VFs are enabled (Stefan Assmann) [1173788]
- [netdrv] i40e: Collect PFC XOFF RX stats even in single TC case (Stefan Assmann) [1173788]
- [netdrv] net: batch of last_rx update avoidance in ethernet drivers (Stefan Assmann) [1173788]
- [netdrv] i40e: Bump version to 1.3.2 (Stefan Assmann) [1173788]
- [netdrv] i40e: Use new 40G speeds (Stefan Assmann) [1173788]
- [netdrv] i40e: get rid of unused locals (Stefan Assmann) [1173788]
- [netdrv] i40e: handle possible memory allocation failure (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Save WR_CSR_PROT field from DEV/FUNC capabilities (Stefan Assmann) [1173788]
- [netdrv] i40e: enable user dump of internal hardware state (Stefan Assmann) [1173788]
- [netdrv] i40e: print FCoE capability reported by the device function (Stefan Assmann) [1173788]
- [netdrv] i40e: For VF reset (VFR and VFLR) add some more delay (Stefan Assmann) [1173788]
- [netdrv] i40e: move VF notification routines up (Stefan Assmann) [1173788]
- [netdrv] i40e: notify VFs of link state (Stefan Assmann) [1173788]
- [netdrv] i40e: Add support to program FDir SB rules for VF from PF through ethtool (Stefan Assmann) [1173788]
- [netdrv] i40e: stop VF rings (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Use dma_rmb where appropriate (Stefan Assmann) [1173788]
- [netdrv] i40e: Bump to version 1.3.1 (Stefan Assmann) [1173788]
- [netdrv] i40e: Communicate VSI id in place of VSI index to the VFs (Stefan Assmann) [1173788]
- [netdrv] i40e: stop flow director on shutdown (Stefan Assmann) [1173788]
- [netdrv] i40e: fix up VXLAN messages (Stefan Assmann) [1173788]
- [netdrv] i40e: Don't register/de-register apps on NIC partitions in MFP mode (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Set Ethernet protocol correctly when Tx VLAN offloads are disabled (Stefan Assmann) [1173788]
- [netdrv] i40e: warn at the right time (Stefan Assmann) [1173788]
- [netdrv] i40e: fix invalid void return in FCoE code (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: fix bug when skb allocation fails (Stefan Assmann) [1173788]
- [netdrv] i40e: Change some memcpys to struct assignments (Stefan Assmann) [1173788]
- [netdrv] i40e: Print some more info to help figure out the cause of HMC error (Stefan Assmann) [1173788]
- [netdrv] i40e: validate VSI param from VFs (Stefan Assmann) [1173788]
- [netdrv] i40e: Bump version to 1.2.43 (Stefan Assmann) [1173788]
- [netdrv] i40e: Increase PF reset max loop limit (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: implement KR2 support (Stefan Assmann) [1173788]
- [netdrv] i40e: add NVM update events to AQ clean (Stefan Assmann) [1173788]
- [netdrv] i40e: add ethtool RSS support (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Bump i40e/i40evf version (Stefan Assmann) [1173788]
- [netdrv] i40e: add MAC printing to debugfs dump VSI (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix inconsistent use of PF/VF vs pf/vf (Stefan Assmann) [1173788]
- [netdrv] i40e: tame the nvmupdate read and write complaints (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: fix accidental write to ITR registers (Stefan Assmann) [1173788]
- [netdrv] i40e: future proof some sizeof calls (Stefan Assmann) [1173788]
- [netdrv] i40e: Remove "hello world" strings from i40e driver (Stefan Assmann) [1173788]
- [netdrv] i40e: Strip configfs code (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Bump version (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: enable prefetch of Tx descriptors during cleanup (Stefan Assmann) [1173788]
- [netdrv] i40e: Simplify code for rss_size_max config (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Simplify tunnel selection logic (Stefan Assmann) [1173788]
- [netdrv] i40e: FD filters flush policy changes (Stefan Assmann) [1173788]
- [netdrv] i40e: Avoid logs while adding/deleting FD-SB filters (Stefan Assmann) [1173788]
- [netdrv] i40e: print port stats only on partition 1 (Stefan Assmann) [1173788]
- [netdrv] i40e: Move code to enable/disable Loopback to the main file (Stefan Assmann) [1173788]
- [netdrv] i40e: rework vector reservation (Stefan Assmann) [1173788]
- [netdrv] i40e: clean up debug_read_register (Stefan Assmann) [1173788]
- [netdrv] i40e: store msg_enable in the right size (Stefan Assmann) [1173788]
- [netdrv] i40e: Remove unneeded conversion (Stefan Assmann) [1173788]
- [netdrv] i40e: Remove duplicate code (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Refactor i40e_debug_aq and make some functions static (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix mismatching type for ioremap_len (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Version bump (Stefan Assmann) [1173788]
- [netdrv] i40e: don't spam the system log (Stefan Assmann) [1173788]
- [netdrv] i40e: move IRQ tracking setup into MSIX setup (Stefan Assmann) [1173788]
- [netdrv] i40e: Ioremap changes (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Clean up some formatting and other things (Stefan Assmann) [1173788]
- [netdrv] i40e: Add AOC PHY types to case statements (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix ethtool offline test (Stefan Assmann) [1173788]
- [netdrv] i40e: Reassign incorrect PHY type to fix a FW bug (Stefan Assmann) [1173788]
- [netdrv] i40e: fix XPS mask when resetting (Stefan Assmann) [1173788]
- [netdrv] i40e: use more portable sign extension (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: grab NVM devstarter version not image version (Stefan Assmann) [1173788]
- [netdrv] i40e: Don't check operational or sync bit for App TLV (Stefan Assmann) [1173788]
- [netdrv] i40e: during LED interaction ignore activity LED src modes (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix NPAR Tx Scheduler init (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix dependencies in the i40e driver on configfs (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Bump versions (Stefan Assmann) [1173788]
- [netdrv] i40e: Only enable TC0 for NIC partition type (Stefan Assmann) [1173788]
- [netdrv] i40e: Register DCBNL ops in MFP mode (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix RSS size at init since default num queue calculation has changed (Stefan Assmann) [1173788]
- [netdrv] i40e: Move RSS table size for VSIs to the VSI struct (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Add missing packet types for VXLAN encapsulated packet types (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix issue with removal of apps from DBCNL app table (Stefan Assmann) [1173788]
- [netdrv] i40e: Add FW check to disable DCB and wrap autoneg workaround with FW check (Stefan Assmann) [1173788]
- [netdrv] i40e: Enable more than 64 qps for the Main VSI (Stefan Assmann) [1173788]
- [netdrv] i40e: don't disable PF LB when disabling VFs (Stefan Assmann) [1173788]
- [netdrv] i40e: Add safety net for switch calling (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: print FW build number in version string (Stefan Assmann) [1173788]
- [netdrv] i40e: Skip the priority tagging if DCB is not enabled (Stefan Assmann) [1173788]
- [netdrv] i40e: check pointers before use (Stefan Assmann) [1173788]
- [netdrv] i40e: catch NVM write semaphore timeout and retry (Stefan Assmann) [1173788]
- [netdrv] i40e: stop flow director on shutdown (Stefan Assmann) [1173788]
- [netdrv] i40e: disconnect irqs on shutdown (Stefan Assmann) [1173788]
- [netdrv] i40e: Issue a PF reset if Tx queue disable timeout (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix the Tx ring qset handle when DCB reconfigures (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix the case where per TC queue count was higher than queues enabled (Stefan Assmann) [1173788]
- [netdrv] i40e: fix race in hang check (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix TSO with more than 8 frags per segment issue (Stefan Assmann) [1173788]
- [netdrv] i40e: Don't check for Tx hang when PF down (Stefan Assmann) [1173788]
- [netdrv] i40e: fix shift precedence issue (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix memory leak at failure path in i40e_dbg_command_write() (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Update driver versions (Stefan Assmann) [1173788]
- [netdrv] i40e: Use ethtool private flags to display NPAR status (Stefan Assmann) [1173788]
- [netdrv] i40e: Set FLAG_RD when sending buffer FW must read (Stefan Assmann) [1173788]
- [netdrv] i40e: print Rx packet split status (Stefan Assmann) [1173788]
- [netdrv] i40e: setup FCoE device type (Stefan Assmann) [1173788]
- [netdrv] i40e: Set BUF flag for Set Version AQ command (Stefan Assmann) [1173788]
- [netdrv] i40e: Add support for getlink, setlink ndo ops (Stefan Assmann) [1173788]
- [netdrv] i40e: Implement configfs for NPAR BW configuration (Stefan Assmann) [1173788]
- [netdrv] i40e: Add NPAR BW get and set functions (Stefan Assmann) [1173788]
- [netdrv] i40e: enable packet split only when IOMMU present (Stefan Assmann) [1173788]
- [netdrv] i40e: Add method to keep track of current rxnfc settings (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Use advertised speed settings in ethtool and refactor get_settings (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Fix output of i40e_debug_aq() for big endian machines (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix i40e_ndo_set_vf_spoofchk (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Bump Driver Versions (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Remove unused variable an_enable and function update_link_info (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix the EMPR interrupt received handling (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: i40e_register.h updates (Stefan Assmann) [1173788]
- [netdrv] i40e: Use #define for the VSI connection type (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: restrict VC opcodes to their initial values (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Refactor the receive routines (Stefan Assmann) [1173788]
- [netdrv] i40e: rename debugfs clear_stats option (Stefan Assmann) [1173788]
- [netdrv] i40e: update Shadow RAM read/write functions (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix for stats init function call in Rx setup (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Add call to u64_stats_init to init (Stefan Assmann) [1173788]
- [netdrv] i40e: Enable Loopback for the FCOE vsi as well (Stefan Assmann) [1173788]
- [netdrv] i40e: use dev_port for fcoe netdev (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix function header (Stefan Assmann) [1173788]
- [netdrv] i40e: fix led blink toggle to enable steady state (Stefan Assmann) [1173788]
- [netdrv] i40evf: Force Tx writeback on ITR (Stefan Assmann) [1173788]
- [netdrv] i40e: stop the service task at shutdown (Stefan Assmann) [1173788]
- [netdrv] i40e: add locking around VF reset (Stefan Assmann) [1173788]
- [netdrv] i40e: Use even more ARQ descriptors (Stefan Assmann) [1173788]
- [netdrv] i40e: delay after VF reset (Stefan Assmann) [1173788]
- [netdrv] i40e: avoid use of uninitialized v_budget in i40e_init_msix (Stefan Assmann) [1173788]
- [netdrv] i40e: i40e_fcoe.c: Remove unused function (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Bump i40e and i40evf versions (Stefan Assmann) [1173788]
- [netdrv] i40e: Support for NPAR iSCSI partition with DCB (Stefan Assmann) [1173788]
- [netdrv] i40e: when Rx timestamps disabled set specific mode (Stefan Assmann) [1173788]
- [netdrv] i40e: use same check for Rx hang as for Rx timestamps (Stefan Assmann) [1173788]
- [netdrv] i40e: AQ API updates for new commands (Stefan Assmann) [1173788]
- [netdrv] i40e: AQ API updates (Stefan Assmann) [1173788]
- [netdrv] i40e: add more struct size checks (Stefan Assmann) [1173788]
- [netdrv] i40e: Issue "Stop LLDP" command for firmware older than v4.3 (Stefan Assmann) [1173788]
- [netdrv] i40e: check I40E_FLAG_PTP before handling Tx or Rx timestamps (Stefan Assmann) [1173788]
- [netdrv] i40e: only enable PTP interrupt cause if PTP is enabled (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Bump i40e/i40evf versions (Stefan Assmann) [1173788]
- [netdrv] i40e: Dump Stats string removed from debugfs help command (Stefan Assmann) [1173788]
- [netdrv] i40e: Add define for interrupt name string len (Stefan Assmann) [1173788]
- [netdrv] i40e: don't give up on DCB error after reset (Stefan Assmann) [1173788]
- [netdrv] i40e: fix proc/int descriptions (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Increase ASQ timeout (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: AdminQ updates ww36 (Stefan Assmann) [1173788]
- [netdrv] i40e: adds FCoE configure option (Stefan Assmann) [1173788]
- [netdrv] i40e: limit sriov to partition 1 of NPAR configurations (Stefan Assmann) [1173788]
- [netdrv] i40e: Don't exit link event early if link speed has changed (Stefan Assmann) [1173788]
- [netdrv] i40e: limit WoL and link settings to partition 1 (Stefan Assmann) [1173788]
- [netdrv] i40e: Adding function for reading PBA String (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: find partition_id in npar mode (Stefan Assmann) [1173788]
- [netdrv] i40e: remove VN2VN related mac filters (Stefan Assmann) [1173788]
- [netdrv] i40e: Add warning for NPAR partitions with link speed less than 10Gbps (Stefan Assmann) [1173788]
- [netdrv] i40e: disable IOV before freeing resources (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix bug with TCP over IPv6 over VXLAN (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix Rx checksum error counter (Stefan Assmann) [1173788]
- [netdrv] i40e: fix un-necessary Tx hangs (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix possible memory leak in i40e_dbg_dump_desc (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Convert macro to static inline (Stefan Assmann) [1173788]
- [netdrv] i40e: add to NVM update debug message (Stefan Assmann) [1173788]
- [netdrv] i40e: check for AQ timeout in aq_rc decode (Stefan Assmann) [1173788]
- [netdrv] i40e: poll on NVM semaphore only if not other error (Stefan Assmann) [1173788]
- [netdrv] i40e: fix up NVM update sm error handling (Stefan Assmann) [1173788]
- [netdrv] i40e: set max limit for access polling (Stefan Assmann) [1173788]
- [netdrv] i40e: remove unused nvm_semaphore_wait (Stefan Assmann) [1173788]
- [netdrv] i40e: init NVM update state on adminq init (Stefan Assmann) [1173788]
- [netdrv] i40e: add range check to i40e_aq_rc_to_posix (Stefan Assmann) [1173788]
- [netdrv] i40e: rework debug messages for NVM update (Stefan Assmann) [1173788]
- [netdrv] i40e: let firmware catch the NVM busy error (Stefan Assmann) [1173788]
- [netdrv] i40e: better error messages for NVM update issues (Stefan Assmann) [1173788]
- [netdrv] i40e: clear NVM update state on ethtool test (Stefan Assmann) [1173788]
- [netdrv] ptp: i40e: convert to the 64 bit get/set time methods (Stefan Assmann) [1173788]
- [netdrv] i40e: Use eth_skb_pad and skb_put_padto helpers (Stefan Assmann) [1173788]
- [netdrv] i40e: Reduce stack in i40e_dbg_dump_desc (Stefan Assmann) [1173788]
- [netdrv] i40e: Bump i40e version to 1.2.2 and i40evf version to 1.0.6 (Stefan Assmann) [1173788]
- [netdrv] i40e: Re enable Main VSI loopback setting in the reset path (Stefan Assmann) [1173788]
- [netdrv] i40e: Add new update VSI flow to accommodate FW fix with VSI Loopback mode (Stefan Assmann) [1173788]
- [netdrv] i40e: Increase reset delay (Stefan Assmann) [1173788]
- [netdrv] i40e: fix netdev_stat macro definition (Stefan Assmann) [1173788]
- [netdrv] i40e: Define and use i40e_is_vf macro (Stefan Assmann) [1173788]
- [netdrv] i40e: Add a virtual channel op to config RSS (Stefan Assmann) [1173788]
- [netdrv] i40e: don't enable PTP support on more than one PF per port (Stefan Assmann) [1173788]
- [netdrv] i40e: Add description to misc and fd interrupts (Stefan Assmann) [1173788]
- [netdrv] i40e: allow various base numbers in debugfs aq commands (Stefan Assmann) [1173788]
- [netdrv] i40e: remove useless debug noise (Stefan Assmann) [1173788]
- [netdrv] i40e: Remove unneeded break statement (Stefan Assmann) [1173788]
- [netdrv] i40e: enable fdb add code, remove unused code (Stefan Assmann) [1173788]
- [netdrv] i40e: trigger SW INT with no ITR wait (Stefan Assmann) [1173788]
- [netdrv] i40e: don't overload fields (Stefan Assmann) [1173788]
- [netdrv] i40e: Set XPS bit mask to zero in DCB mode (Stefan Assmann) [1173788]
- [netdrv] i40e: Prevent link flow control settings when PFC is enabled (Stefan Assmann) [1173788]
- [netdrv] i40e: Do not disable/enable FCoE VSI with DCB reconfig (Stefan Assmann) [1173788]
- [netdrv] i40e: Modify Tx disable wait flow in case of DCB reconfiguration (Stefan Assmann) [1173788]
- [netdrv] i40e: Update VEB's enabled_tc after reconfiguration (Stefan Assmann) [1173788]
- [netdrv] i40e: Check for LLDP AdminStatus before querying DCBX (Stefan Assmann) [1173788]
- [netdrv] i40e: Add support to firmware CEE DCBX mode (Stefan Assmann) [1173788]
- [netdrv] i40e: Resume Port Tx after DCB event (Stefan Assmann) [1173788]
- [netdrv] i40e: Bump version to 1.1.23 (Stefan Assmann) [1173788]
- [netdrv] i40e: re-enable VFLR interrupt sooner (Stefan Assmann) [1173788]
- [netdrv] i40e: only warn once of PTP nonsupport in 100Mbit speed (Stefan Assmann) [1173788]
- [netdrv] i40e: use netdev_rss_key_fill() helper (Stefan Assmann) [1173788]
- [netdrv] i40e: clean up throttle rate code (Stefan Assmann) [1173788]
- [netdrv] i40e: don't do link_status or stats collection on every ARQ (Stefan Assmann) [1173788]
- [netdrv] i40e: poll firmware slower (Stefan Assmann) [1173788]
- [netdrv] i40e: properly parse MDET registers (Stefan Assmann) [1173788]
- [netdrv] i40e: configure VM ID in qtx_ctl (Stefan Assmann) [1173788]
- [netdrv] i40e: enable debug earlier (Stefan Assmann) [1173788]
- [netdrv] i40e: better wording for resource tracking errors (Stefan Assmann) [1173788]
- [netdrv] i40e: scale msix vector use when more cores than vectors (Stefan Assmann) [1173788]
- [netdrv] i40e: remove debugfs dump stats (Stefan Assmann) [1173788]
- [netdrv] i40e: avoid disable of interrupt when changing ITR (Stefan Assmann) [1173788]
- [netdrv] i40e: fix link checking logic (Stefan Assmann) [1173788]
- [netdrv] i40e: Add condition to enter fdir flush and reinit (Stefan Assmann) [1173788]
- [netdrv] i40e: _MASK vs _SHIFT typo in i40e_handle_mdd_event() (Stefan Assmann) [1173788]
- [netdrv] i40e: Bump version (Stefan Assmann) [1173788]
- [netdrv] i40e: Moving variable declaration out of the loops (Stefan Assmann) [1173788]
- [netdrv] i40e: Add 10GBaseT support (Stefan Assmann) [1173788]
- [netdrv] i40e: process link events when setting up switch (Stefan Assmann) [1173788]
- [netdrv] i40e: Fix a bug where Rx would stop after some time (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Use usleep_range() instead of udelay() (Stefan Assmann) [1173788]
- [netdrv] i40e/i40evf: Fix whitespace indentation (Stefan Assmann) [1173788]
- [netdrv] i40e: enable LSE poke and simplify link state (Stefan Assmann) [1173788]
- [netdrv] i40e: mask phy events (Stefan Assmann) [1173788]
- [netdrv] i40e: skb->xmit_more support (Stefan Assmann) [1173788]
- [netdrv] i40e/igb: Convert to dev_consume_skb_any() (Stefan Assmann) [1173788]
- [netdrv] i40e: use global pci_vfs_assigned() to replace local i40e_vfs_are_assigned() (Stefan Assmann) [1173788]
- [netdrv] i40e: Set skb->csum_level for encapsulated checksum (Stefan Assmann) [1173788]
- [netdrv] i40e: enable CONFIG_I40E_VXLAN (Stefan Assmann) [1173788]

* Thu Jun 18 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-272.el7]
- [netdrv] enic: fix memory leak in rq_clean (Stefan Assmann) [1159148]
- [netdrv] enic: check return value for stat dump (Stefan Assmann) [1159148]
- [netdrv] enic: unlock napi busy poll before unmasking intr (Stefan Assmann) [1159148]
- [netdrv] enic: Grammar s/an negative/a negative/ (Stefan Assmann) [1159148]
- [netdrv] ethernet: Use eth_<foo>_addr instead of memset (Stefan Assmann) [1159148]
- [netdrv] enic: do notify_check before returning credits (Stefan Assmann) [1159148]
- [netdrv] enic: enic_main: fix sparse warnings (Stefan Assmann) [1159148]
- [netdrv] enic: enic_ethtool: fix sparse warning (Stefan Assmann) [1159148]
- [netdrv] enic: fix rx napi poll return value (Stefan Assmann) [1159148]
- [netdrv] enic: reconfigure resources for kdump crash kernel (Stefan Assmann) [1159148]
- [netdrv] enic: free all rq buffs when allocation fails (Stefan Assmann) [1159148]
- [netdrv] net: ethernet: cisco: enic: enic_dev: Remove some unused functions (Stefan Assmann) [1159148]
- [netdrv] enic: add stats for dma mapping error (Stefan Assmann) [1159148]
- [netdrv] enic: check dma_mapping_error (Stefan Assmann) [1159148]
- [netdrv] enic: make vnic_wq_buf doubly linked (Stefan Assmann) [1159148]
- [netdrv] igbvf: use netif_carrier_off earlier when bringing if down (Stefan Assmann) [1173785]
- [netdrv] igbvf: cleanup msleep() and min/max() usage (Stefan Assmann) [1173785]
- [netdrv] igbvf: Fix code comments and whitespace (Stefan Assmann) [1173785]
- [netdrv] igbvf: Fix checksum error when using stacked vlan (Stefan Assmann) [1173785]
- [netdrv] igb: Don't use NETDEV_FRAG_PAGE_MAX_SIZE in descriptor calculation (Stefan Assmann) [1173784]
- [netdrv] igb: Fix NULL assignment to incorrect variable in igb_reset_q_vector (Stefan Assmann) [1173784]
- [netdrv] igb: Fix oops on changing number of rings (Stefan Assmann) [1173784]
- [netdrv] igb: simplify and clean up igb_enable_mas() (Stefan Assmann) [1173784]
- [netdrv] ptp: igb: use helpers for converting ns to timespec (Stefan Assmann) [1173784]
- [netdrv] ptp: igb: convert to the 64 bit get/set time methods (Stefan Assmann) [1173784]
- [netdrv] igb: Enable TSO for stacked vlan (Stefan Assmann) [1173784]
- [netdrv] igb: use netif_carrier_off earlier when bringing if down (Stefan Assmann) [1173784]
- [netdrv] ethernet: codespell comment spelling fixes (Stefan Assmann) [1173784]
- [netdrv] igb: Make arrays on stack static const to avoid reallocation (Stefan Assmann) [1173784]
- [netdrv] igb: Fix warning pin may be used uninitialized (Stefan Assmann) [1173784]
- [netdrv] igb: Indicate failure on vf reset for empty mac address (Stefan Assmann) [1173784]
- [netdrv] igb: enable auxiliary PHC functions for the i210 (Stefan Assmann) [1173784]
- [netdrv] ptp: introduce programmable pins (Stefan Assmann) [1173784]
- [netdrv] igb: enable internal PPS for the i210 (Stefan Assmann) [1173784]
- [netdrv] igb: serialize access to the time sync interrupt registers (Stefan Assmann) [1173784]
- [netdrv] igb: refactor time sync interrupt handling (Stefan Assmann) [1173784]
- [netdrv] igb: Clean-up page reuse code (Stefan Assmann) [1173784]
- [netdrv] igb: convert to CYCLECOUNTER_MASK macro (Stefan Assmann) [1173784]
- [netdrv] igb_ptp: Include clocksource.h to get CLOCKSOURCE_MASK (Stefan Assmann) [1173784]
- [netdrv] igb: Remove unneeded FIXME (Stefan Assmann) [1173784]
- [netdrv] net: igb: convert to timecounter adjtime (Stefan Assmann) [1173784]
- [netdrv] fm10k/igb/ixgbe: Use dma_rmb on Rx descriptor reads (Stefan Assmann) [1173784]
- [netdrv] ethernet/intel: Use napi_alloc_skb (Stefan Assmann) [1173784]
- [netdrv] ethernet/intel: Use eth_skb_pad and skb_put_padto helpers (Stefan Assmann) [1173784]
- [netdrv] e1000e / igb / pm: Eliminate CONFIG_PM_RUNTIME (Stefan Assmann) [1173784]
- [netdrv] igb: Fixes needed for surprise removal support (Stefan Assmann) [1173784]
- [netdrv] igb: use netdev_rss_key_fill() helper (Stefan Assmann) [1173784]
- [netdrv] fm10k/igb/ixgbe: Replace __skb_alloc_page with dev_alloc_page (Stefan Assmann) [1173784]
- [netdrv] igb: don't reuse pages with pfmemalloc flag (Stefan Assmann) [1173784]
- [netdrv] igb: fix race accessing page->_count (Stefan Assmann) [1173784]
- [netdrv] igb: bump version to 5.2.15 (Stefan Assmann) [1173784]
- [netdrv] i40e/igb: Convert to dev_consume_skb_any() (Stefan Assmann) [1173784]
- [netdrv] igb: remove blocking phy read from inside spinlock (Stefan Assmann) [1173784]
- [netdrv] igb: add flags to set eee advertisement mode (Stefan Assmann) [1173784]
- [netdrv] igb: use new eth_get_headlen interface (Stefan Assmann) [1173784]
- [netdrv] igb: Convert to use devm_hwmon_device_register_with_groups (Stefan Assmann) [1173784]
- [netdrv] ptp: tg3: use helpers for converting ns to timespec (Ivan Vecera) [1182731]
- [netdrv] ptp: tg3: convert to the 64 bit get/set time methods (Ivan Vecera) [1182731]
- [netdrv] tg3: Hold tp->lock before calling tg3_halt() from tg3_init_one() (Ivan Vecera) [1182731]
- [netdrv] tg3: Release tp->lock before invoking synchronize_irq() (Ivan Vecera) [1182731]
- [netdrv] tg3: tg3_reset_task() needs to use rtnl_lock to synchronize (Ivan Vecera) [1182731]
- [netdrv] tg3: tg3_timer() should grab tp->lock before checking for tp->irq_sync (Ivan Vecera) [1182731]
- [netdrv] tg3: tg3_disable_ints using uninitialized mailbox value to disable interrupts (Ivan Vecera) [1182731]
- [netdrv] tg3: fix ring init when there are more TX than RX channels (Ivan Vecera) [1182731]
- [netdrv] tg3: use netdev_rss_key_fill() helper (Ivan Vecera) [1182731]
- [netdrv] tg3: Add skb->xmit_more support (Ivan Vecera) [1182731]
- [netdrv] tg3: Allow for recieve of full-size 8021AD frames (Ivan Vecera) [1182731]
- [netdrv] tg3: Work around HW/FW limitations with vlan encapsulated frames (Ivan Vecera) [1182731]
- [netdrv] tg3: Convert to use hwmon_device_register_with_groups (Ivan Vecera) [1182731]
- [netdrv] bnx2-cnic: Driver Version Update (Ivan Vecera) [1182732]
- [netdrv] bnx2: Fix for Chip Initialization (Ivan Vecera) [1182732]
- [netdrv] bnx2-cnic: Driver Rebranding Changes (Ivan Vecera) [1182732]
- [netdrv] bnx2: Correctly receive full sized 802.1ad frames (Ivan Vecera) [1182732]
- [netdrv] be2net: enable config options (Ivan Vecera) [1182733]
- [netdrv] be2net: Replace dma/pci_alloc_coherent() calls with dma_zalloc_coherent() (Ivan Vecera) [1182733]
- [netdrv] be2net: make hwmon interface optional (Ivan Vecera) [1182733]
- [netdrv] be2net: Support for OS2BMC (Ivan Vecera) [1182733]
- [netdrv] be2net: Report a "link down" to the stack when a fatal error or fw reset happens (Ivan Vecera) [1182733]
- [netdrv] be2net: Export board temperature using hwmon-sysfs interface (Ivan Vecera) [1182733]
- [netdrv] be2net: update the driver version to 10.6.0.2 (Ivan Vecera) [1182733]
- [netdrv] be2net: update copyright year to 2015 (Ivan Vecera) [1182733]
- [netdrv] be2net: use be_virtfn() instead of !be_physfn() (Ivan Vecera) [1182733]
- [netdrv] be2net: simplify UFI compatibility checking (Ivan Vecera) [1182733]
- [netdrv] be2net: post full RXQ on interface enable (Ivan Vecera) [1182733]
- [netdrv] be2net: check for INSUFFICIENT_VLANS error (Ivan Vecera) [1182733]
- [netdrv] be2net: receive pkts with L3, L4 errors on VFs (Ivan Vecera) [1182733]
- [netdrv] be2net: set interrupt moderation for Skyhawk-R using EQ-DB (Ivan Vecera) [1182733]
- [netdrv] be2net: add support for spoofchk setting (Ivan Vecera) [1182733]
- [netdrv] be2net: log link status (Ivan Vecera) [1182733]
- [netdrv] be2net: Fix a bug in Rx buffer posting (Ivan Vecera) [1182733]
- [netdrv] be2net: bump up the driver version to 10.6.0.1 (Ivan Vecera) [1182733]
- [netdrv] be2net: setup xps queue mapping (Ivan Vecera) [1182733]
- [netdrv] be2net: restrict MODIFY_EQ_DELAY cmd to a max of 8 EQs (Ivan Vecera) [1182733]
- [netdrv] be2net: Prevent VFs from enabling VLAN promiscuous mode (Ivan Vecera) [1182733]
- [netdrv] be2net: codespell comment spelling fixes (Ivan Vecera) [1182733]
- [netdrv] be2net: implement .sriov_configure() PCI callback (Ivan Vecera) [1182733]
- [netdrv] be2net: re-distribute SRIOV resources allowed by FW (Ivan Vecera) [1182733]
- [netdrv] be2net: avoid creating the non-RSS default RXQ if FW allows to (Ivan Vecera) [1182733]
- [netdrv] be2net: Use eth_<foo>_addr instead of memset (Ivan Vecera) [1182733]
- [netdrv] be2net: move be_func_init() call inside be_setup() (Ivan Vecera) [1182733]
- [netdrv] be2net: refactor adapter resource cleanup sequence into be_cleanup() (Ivan Vecera) [1182733]
- [netdrv] be2net: refactor adapter resource initialzation sequence into be_resume() (Ivan Vecera) [1182733]
- [netdrv] be2net: remove code duplication relating to Lancer reset sequence (Ivan Vecera) [1182733]
- [netdrv] be2net: refactor error detect/recovery function (Ivan Vecera) [1182733]
- [netdrv] be2net: use a wrapper to schedule and cancel error detection task (Ivan Vecera) [1182733]
- [netdrv] be2net: refactor function initalization sequence into be_func_init() (Ivan Vecera) [1182733]
- [netdrv] be2net: get rid of be_get_initial_config() call from be_probe() (Ivan Vecera) [1182733]
- [netdrv] be2net: move adapter fields alloc/free code to new routines (Ivan Vecera) [1182733]
- [netdrv] be2net: Add a few inline functions to test TXQ conditions (Ivan Vecera) [1182733]
- [netdrv] be2net: Minor code cleanup in tx completion process (Ivan Vecera) [1182733]
- [netdrv] be2net: Refactor be_xmit_enqueue() routine (Ivan Vecera) [1182733]
- [netdrv] be2net: Refactor wrb_fill_hdr() routine (Ivan Vecera) [1182733]
- [netdrv] be2net: avoid unncessary swapping of fields in eth_tx_wrb (Ivan Vecera) [1182733]
- [netdrv] be2net: process port misconfig async event (Ivan Vecera) [1182733]
- [netdrv] be2net: refactor be_set_rx_mode() and be_vid_config() for readability (Ivan Vecera) [1182733]
- [netdrv] be2net: remove duplicate code in be_cmd_rx_filter() (Ivan Vecera) [1182733]
- [netdrv] be2net: use offset based FW flashing for Skyhawk chip (Ivan Vecera) [1182733]
- [netdrv] be2net: avoid flashing SH-B0 UFI image on SH-P2 chip (Ivan Vecera) [1182733]
- [netdrv] be2net: refactor code that checks flash file compatibility (Ivan Vecera) [1182733]
- [netdrv] be2net: replace (1 << x) with BIT(x) (Ivan Vecera) [1182733]
- [netdrv] be2net: move un-exported routines from be.h to respective src files (Ivan Vecera) [1182733]
- [netdrv] be2net: fix sparse warning (Ivan Vecera) [1182733]
- [netdrv] be2net: move definitions related to FW cmdsfrom be_hw.h to be_cmds.h (Ivan Vecera) [1182733]
- [netdrv] be2net: issue function reset cmd in resume path (Ivan Vecera) [1182733]
- [netdrv] be2net: add a log message for POST timeout in Lancer (Ivan Vecera) [1182733]
- [netdrv] be2net: fix failure case in setting flow control (Ivan Vecera) [1182733]
- [netdrv] be2net: move interface create code to a separate routine (Ivan Vecera) [1182733]
- [netdrv] be2net: Allow GRE to work concurrently while a VxLAN tunnel is configured (Ivan Vecera) [1182733]
- [netdrv] be2net: support TX batching using skb->xmit_more flag (Ivan Vecera) [1182733]
- [netdrv] be2net: Fix incorrect setting of tunnel offload flag in netdev features (Ivan Vecera) [1182733]
- [netdrv] be2net: Export tunnel offloads only when a VxLAN tunnel is created (Ivan Vecera) [1182733]
- [netdrv] emulex: Use skb_put_padto instead of skb_padto() and skb->len assignment (Ivan Vecera) [1182733]
- [netdrv] be2net: Check for presence of IFLA_AF_SPEC (Ivan Vecera) [1182733]
- [netdrv] be2net: Validate IFLA_BRIDGE_MODE attribute length (Ivan Vecera) [1182733]
- [netdrv] be2net: use netdev_rss_key_fill() helper (Ivan Vecera) [1182733]
- [netdrv] be2net: Use dev_consume_skb_any() in the non-drop path (Ivan Vecera) [1182733]
- [netdrv] r8169: Do not use dev_kfree_skb in xmit path (Ivan Vecera) [1232244]
- [netdrv] r8169: Fix trivial typo in rtl_check_firmware (Ivan Vecera) [1232244]
- [netdrv] r8169: Revert BQL and xmit_more support (Ivan Vecera) [1232244]
- [netdrv] r8169: use PCI define for Max_Read_Request_Size (Ivan Vecera) [1232244]
- [netdrv] pci: Add defines for PCIe Max_Read_Request_Size (Ivan Vecera) [1232244]
- [netdrv] r8169: add support for xmit_more (Ivan Vecera) [1232244]
- [netdrv] r8169: update rtl8168g pcie ephy parameter (Ivan Vecera) [1232244]
- [netdrv] r8169: Use dma_rmb() and dma_wmb() for DescOwn checks (Ivan Vecera) [1232244]
- [netdrv] r8169: use napi_alloc_skb instead of netdev_alloc_skb_ip_align (Ivan Vecera) [1232244]
- [netdrv] r8169: Use eth_skb_pad function (Ivan Vecera) [1232244]
- [netdrv] r8169: disable rtl8168ep cmac engine (Ivan Vecera) [1232244]
- [netdrv] r8169: prevent enable hardware tx/rx too early (Ivan Vecera) [1232244]
- [netdrv] bna: use netdev_* and dev_* instead of printk and pr_* (Ivan Vecera) [1187298]
- [netdrv] bna: fix timeout API argument type (Ivan Vecera) [1187298]
- [netdrv] bna: use list_for_each_entry where appropriate (Ivan Vecera) [1187298]
- [netdrv] bna: get rid of private macros for manipulation with lists (Ivan Vecera) [1187298]
- [netdrv] bna: remove useless pointer assignment (Ivan Vecera) [1187298]
- [netdrv] bna: use memdup_user to copy userspace buffers (Ivan Vecera) [1187298]
- [netdrv] bna: correct comparisons/assignments to bool (Ivan Vecera) [1187298]
- [netdrv] bna: remove TX_E_PRIO_CHANGE event and BNA_TX_F_PRIO_CHANGED flag (Ivan Vecera) [1187298]
- [netdrv] bna: remove paused from bna_rx_config and flags from bna_rxf (Ivan Vecera) [1187298]
- [netdrv] bna: remove RXF_E_PAUSE and RXF_E_RESUME events (Ivan Vecera) [1187298]
- [netdrv] bna: remove prio_change_cbfn oper_state_cbfn from struct bna_tx (Ivan Vecera) [1187298]
- [netdrv] bna: remove oper_state_cbfn from struct bna_rxf (Ivan Vecera) [1187298]
- [netdrv] bna: remove pause_cbfn from struct bna_enet (Ivan Vecera) [1187298]
- [netdrv] bna: remove unused cbfn parameter (Ivan Vecera) [1187298]
- [netdrv] bna: use BIT(x) instead of (1 << x) (Ivan Vecera) [1187298]
- [netdrv] bna: get rid of duplicate and unused macros (Ivan Vecera) [1187298]
- [netdrv] bna: replace pragma(pack) with attribute __packed (Ivan Vecera) [1187298]
- [netdrv] bna: get rid of mac_t (Ivan Vecera) [1187298]
- [netdrv] bna: use ether_addr_copy instead of memcpy (Ivan Vecera) [1187298]
- [netdrv] bna: remove obsolete use of EXTRA_CFLAGS (Ivan Vecera) [1187298]
- [netdrv] bna: fix soft lock-up during firmware initialization failure (Ivan Vecera) [1187298]
- [netdrv] bna: remove unreasonable iocpf timer start (Ivan Vecera) [1187298]
- [netdrv] bna: fix firmware loading on big-endian machines (Ivan Vecera) [1187298]
- [netdrv] bna: codespell comment spelling fixes (Ivan Vecera) [1187298]
- [netdrv] bna: Update the Driver and Firmware Version (Ivan Vecera) [1187298]
- [netdrv] bna: QLogic BR-series Adapters Driver Rebranding (Ivan Vecera) [1187298]
- [netdrv] bna: incorrect use of init_completion fixup (Ivan Vecera) [1187298]
- [netdrv] bna: use netdev_rss_key_fill() helper (Ivan Vecera) [1187298]

* Thu Jun 18 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-271.el7]
- [net] inet_diag: use READ_ONCE (Phil Sutter) [1230886]
- [net] nfnetlink_log: unset nf_loggers for netns when unloading module (Hannes Frederic Sowa) [1231135]
- [net] sctp: allow authenticating DATA chunks that are bundled with COOKIE_ECHO (Marcelo Leitner) [1161510]
- [net] netfilter: conntrack: warn the user if there is a better helper to use (Marcelo Leitner) [1208239]
- [net] tcp: dctcp_update_alpha() fixes (Phil Sutter) [1230878]
- [net] sched: use pinned timers (Phil Sutter) [1230135]
- [net] add skb_clone_sk() and sock_efree() (Ivan Vecera) [1200759]
- [lib] cpumask: cpumask_set_cpu_local_first => cpumask_local_spread, lament (Ivan Vecera) [1200759]
- [netdrv] mlx4_en: Fix tx ring affinity_mask creation (Ivan Vecera) [1200759]
- [netdrv] be2net: assign CPU affinity hints to be2net IRQs (Ivan Vecera) [1200759]
- [kernel] ktime: Introduce ktime_ms_delta (Ivan Vecera) [1200759]
- [net] sctp: migrate cookie life from timeval to ktime (Ivan Vecera) [1200759]
- [kernel] timecounter: provide a macro to initialize the cyclecounter mask field (Ivan Vecera) [1200759]
- [kernel] timecounter: keep track of accumulated fractional nanoseconds (Ivan Vecera) [1200759]
- [kernel] timecounter: provide a helper function to shift the time (Ivan Vecera) [1200759]
- [kernel] time: move the timecounter/cyclecounter code into its own file (Ivan Vecera) [1200759]
- [net] Introduce passthru_features_check (Ivan Vecera) [1200759]
- [net] vlan: Move check for multiple vlans to drivers (Ivan Vecera) [1200759]
- [net] vlan: Introduce helper functions to check if skb is tagged (Ivan Vecera) [1200759]
- [net] vlan: rename vlan_tx_* helpers since "tx" is misleading there (Ivan Vecera) [1200759]
- [net] vlan: make __vlan_hwaccel_put_tag return void (Ivan Vecera) [1200759]
- [net] vlan: Add features for stacked vlan device (Ivan Vecera) [1200759]
- [net] Add device Rx page allocation function (Ivan Vecera) [1200759]
- [net] fix comment typo for __skb_alloc_pages() (Ivan Vecera) [1200759]
- [net] flow: Add function for parsing the header length out of linear ethernet frames (Ivan Vecera) [1200759]
- [net] flow: make skb an optional parameter for__skb_flow_dissect() (Ivan Vecera) [1200759]
- [net] flow: Allow raw buffers to be passed into the flow dissector (Ivan Vecera) [1200759]
- [net] ethtool: Support for configurable RSS hash function (Ivan Vecera) [1200759]
- [netdrv] mlx4_en: fix mlx4_en_set_rxfh() (Ivan Vecera) [1200759]
- [netdrv] mlx4_en: use netdev_rss_key_fill() helper (Ivan Vecera) [1200759]
- [netdrv] Replace ethtool_ops::{get, set}_rxfh_indir() with {get, set}_rxfh() (Ivan Vecera) [1200759]
- [net] Add functions for handling padding frame and adding to length (Ivan Vecera) [1200759]
- [net] introduce napi_schedule_irqoff() (Ivan Vecera) [1200759]
- [net] Replace get_cpu_var through this_cpu_ptr (Ivan Vecera) [1200759]
- [net] introduce dev_consume_skb_any() (Ivan Vecera) [1200759]
- [net] provide a per host RSS key generic infrastructure (Ivan Vecera) [1200759]
- [net] avoid dependency of net_get_random_once on nop patching (Ivan Vecera) [1200759]
- [net] make net_get_random_once irq safe (Ivan Vecera) [1200759]
- [net] fix build warnings because of net_get_random_once merge (Ivan Vecera) [1200759]
- [net] introduce new macro net_get_random_once (Ivan Vecera) [1200759]
- [net] net.h, skbuff.h: Remove extern from function prototypes (Ivan Vecera) [1200759]
- [net] Remove extern from function prototypes (Ivan Vecera) [1200759]
- [net] remove unused 'dev' argument from netif_needs_gso() (Ivan Vecera) [1200759]
- [net] Generalize ndo_gso_check to ndo_features_check (Ivan Vecera) [1200759]
- [net] vlan: Fix stacked vlan offload features computation (Ivan Vecera) [1200759]
- [net] fix checksum features handling in netif_skb_features() (Ivan Vecera) [1200759]
- [net] vlan: more careful checksum features handling (Ivan Vecera) [1200759]
- [netdrv] mlx4_en: Add VXLAN ndo calls to the PF net device ops too (Ivan Vecera) [1200759]
- [netdrv] bnx2x: Implement ndo_gso_check() (Ivan Vecera) [1200759]
- [netdrv] qlcnic: Implement ndo_gso_check() (Ivan Vecera) [1200759]
- [netdrv] be2net: Implement ndo_gso_check() (Ivan Vecera) [1200759]
- [netdrv] mlx4_en: Implement ndo_gso_check() (Ivan Vecera) [1200759]
- [net] Add ndo_gso_check (Ivan Vecera) [1200759]
- [net] ipv6: reject locally assigned nexthop addresses (Phil Sutter) [1228700]
- [net] ipv6: allow explicitly choosing optimistic addresses (Phil Sutter) [1228700]
- [net] openvswitch: disable LRO (Jiri Benc) [1181282]
- [net] unix, caif: sk_socket can disappear when state is unlocked (Hannes Frederic Sowa) [1226230]
- [net] af_unix: implement splice for stream af_unix sockets (Hannes Frederic Sowa) [1226230]
- [net] make skb_splice_bits more configureable (Hannes Frederic Sowa) [1226230]
- [net] af_unix: implement stream sendpage support (Hannes Frederic Sowa) [1226230]
- [net] skbuff: add skb_append_pagefrags and use it (Hannes Frederic Sowa) [1226230]
- [net] af_unix: remove 0 assignment on static (Hannes Frederic Sowa) [1226230]
- [net] unix: Align send data_len up to PAGE_SIZE (Hannes Frederic Sowa) [1226230]
- [net] unix: non blocking recvmsg() should not return -EINTR (Hannes Frederic Sowa) [1226230]
- [net] unix: allow bind to fail on mutex lock (Hannes Frederic Sowa) [1226230]
- [net] af_unix: fix bug on large send() (Hannes Frederic Sowa) [1226230]
- [net] attempt high order allocations in sock_alloc_send_pskb() (Hannes Frederic Sowa) [1226230]
- [net] af_unix: improve STREAM behavior with fragmented memory (Hannes Frederic Sowa) [1226230]

* Thu Jun 18 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-270.el7]
- [md] fix race when unfreezing sync_action (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: break stripe-batches when the array has failed (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: call break_stripe_batch_list from handle_stripe_clean_event (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: be more selective about distributing flags across batch (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: add handle_flags arg to break_stripe_batch_list (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: duplicate some more handle_stripe_clean_event code in break_stripe_batch_list (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: remove condition test from check_break_stripe_batch_list (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: Ensure a batch member is not handled prematurely (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: close race between STRIPE_BIT_DELAY and batching (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: ensure whole batch is delayed for all required bitmap updates (Jes Sorensen) [1150149 1173510 1194720]
- [md] bitmap: remove rcu annotation from pointer arithmetic (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: fix broken async operation chain (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: fix handling of degraded stripes in batches (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: fix allocation of 'scribble' array (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: don't record new size if resize_stripes fails (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: avoid reading parity blocks for full-stripe write to degraded array (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: more incorrect BUG_ON in handle_stripe_fill (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: new alloc_stripe() to allocate an initialize a stripe (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid0: conditional mddev->queue access to suit dm-raid (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: don't do chunk aligned read on degraded array (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: change ->inactive_blocked to a bit-flag (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: move max_nr_stripes management into grow_one_stripe and drop_one_stripe (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: pass gfp_t arg to grow_one_stripe() (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: introduce configuration option rmw_level (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: activate raid6 rmw feature (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid6 algorithms: delta syndrome functions (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: handle expansion/resync case with stripe batching (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: handle io error of batch list (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: batch adjacent full stripe write (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: track overwrite disk count (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: add a new flag to track if a stripe can be batched (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: use flex_array for scribble data (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid0: access mddev->queue (request queue member) conditionally because it is not set when accessed from dm-raid (Jes Sorensen) [1150149 1173510 1194720]
- [md] allow resync to go faster when there is competing IO (Jes Sorensen) [1150149 1173510 1194720]
- [md] remove 'go_faster' option from ->sync_request() (Jes Sorensen) [1150149 1173510 1194720]
- [md] don't require sync_min to be a multiple of chunk_size (Jes Sorensen) [1150149 1173510 1194720]
- [md] re-add a failed disk (Jes Sorensen) [1150149 1173510 1194720]
- [md] Export and rename find_rdev_nr_rcu (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: check faulty flag for array status during recovery (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid1: fix read balance when a drive is write-mostly (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: Fix livelock when array is both resyncing and degraded (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid10: round up to bdev_logical_block_size in narrow_write_error (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid1: round up to bdev_logical_block_size in narrow_write_error (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid10: fix conversion from RAID0 to RAID10 (Jes Sorensen) [1150149 1173510 1194720]
- [md] wakeup thread upon rdev_dec_pending() (Jes Sorensen) [1150149 1173510 1194720]
- [md] make reconfig_mutex optional for writes to md sysfs files (Jes Sorensen) [1150149 1173510 1194720]
- [md] move mddev_lock and related to md.h (Jes Sorensen) [1150149 1173510 1194720]
- [md] use mddev->lock to protect updates to resync_{min, max} (Jes Sorensen) [1150149 1173510 1194720]
- [md] minor cleanup in safe_delay_store (Jes Sorensen) [1150149 1173510 1194720]
- [md] move GET_BITMAP_FILE ioctl out from mddev_lock (Jes Sorensen) [1150149 1173510 1194720]
- [md] tidy up set_bitmap_file (Jes Sorensen) [1150149 1173510 1194720]
- [md] remove unnecessary 'buf' from get_bitmap_file (Jes Sorensen) [1150149 1173510 1194720]
- [md] remove mddev_lock from rdev_attr_show() (Jes Sorensen) [1150149 1173510 1194720]
- [md] remove mddev_lock() from md_attr_show() (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: use ->lock to protect accessing raid5 sysfs attributes (Jes Sorensen) [1150149 1173510 1194720]
- [md] remove need for mddev_lock() in md_seq_show() (Jes Sorensen) [1150149 1173510 1194720]
- [md] bitmap: protect clearing of ->bitmap by mddev->lock (Jes Sorensen) [1150149 1173510 1194720]
- [md] protect ->pers changes with mddev->lock (Jes Sorensen) [1150149 1173510 1194720]
- [md] level_store: group all important changes into one place (Jes Sorensen) [1150149 1173510 1194720]
- [md] rename ->stop to ->free (Jes Sorensen) [1150149 1173510 1194720]
- [md] split detach operation out from ->stop (Jes Sorensen) [1150149 1173510 1194720]
- [md] linear: remove rcu protections in favour of suspend/resume (Jes Sorensen) [1150149 1173510 1194720]
- [md] make merge_bvec_fn more robust in face of personality changes (Jes Sorensen) [1150149 1173510 1194720]
- [md] make ->congested robust against personality changes (Jes Sorensen) [1150149 1173510 1194720]
- [md] rename mddev->write_lock to mddev->lock (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: need_this_block: tidy/fix last condition (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: need_this_block: start simplifying the last two conditions (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: separate out the easy conditions in need_this_block (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: separate large if clause out of fetch_block() (Jes Sorensen) [1150149 1173510 1194720]
- [md] do_release_stripe(): No need to call md_wakeup_thread() twice (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: fix another livelock caused by non-aligned writes (Jes Sorensen) [1150149 1173510 1194720]
- [md] Check MD_RECOVERY_RUNNING as well as ->sync_thread (Jes Sorensen) [1150149 1173510 1194720]
- [md] fix semicolon.cocci warnings (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: fetch_block must fetch all the blocks handle_stripe_dirtying wants (Jes Sorensen) [1150149 1173510 1194720]
- [md] Always set RECOVERY_NEEDED when clearing RECOVERY_FROZEN (Jes Sorensen) [1150149 1173510 1194720]
- [md] move EXPORT_SYMBOL to after function in md.c (Jes Sorensen) [1150149 1173510 1194720]
- [md] discard PRINT_RAID_DEBUG ioctl (Jes Sorensen) [1150149 1173510 1194720]
- [md] remove MD_BUG() (Jes Sorensen) [1150149 1173510 1194720]
- [md] clean up 'exit' labels in md_ioctl() (Jes Sorensen) [1150149 1173510 1194720]
- [md] remove unnecessary test for MD_MAJOR in md_ioctl() (Jes Sorensen) [1150149 1173510 1194720]
- [md] don't allow "-sync" to be set for device in an active array (Jes Sorensen) [1150149 1173510 1194720]
- [md] remove unwanted white space from md.c (Jes Sorensen) [1150149 1173510 1194720]
- [md] don't start resync thread directly from md thread (Jes Sorensen) [1150149 1173510 1194720]
- [md] Just use RCU when checking for overlap between arrays (Jes Sorensen) [1150149 1173510 1194720]
- [md] avoid potential long delay under pers_lock (Jes Sorensen) [1150149 1173510 1194720]
- [md] simplify export_array() (Jes Sorensen) [1150149 1173510 1194720]
- [md] discard find_rdev_nr in favour of find_rdev_nr_rcu (Jes Sorensen) [1150149 1173510 1194720]
- [md] use wait_event() to simplify md_super_wait() (Jes Sorensen) [1150149 1173510 1194720]
- [md] be more relaxed about stopping an array which isn't started (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid1: process_checks doesn't use its return value (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: fix init_stripe() inconsistencies (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid10: another memory leak due to reshape (Jes Sorensen) [1150149 1173510 1194720]
- [md] use set_bit/clear_bit instead of shift/mask for bi_flags changes (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid1: minor typos and reformatting (Jes Sorensen) [1150149 1173510 1194720]
- [md] bitmap: always wait for writes on unplug (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid5: avoid livelock caused by non-aligned writes (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid56: Don't perform reads to support writes until stripe is ready (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid1: fix request counting bug in new 'barrier' code (Jes Sorensen) [1150149 1173510 1194720]
- [md] raid1: Rewrite the implementation of iobarrier (Jes Sorensen) [1150149 1173510 1194720]
- [fs] ext4: atomically set inode->i_flags in ext4_set_inode_flags() (Jes Sorensen) [1150149 1173510 1194720]

* Wed Jun 17 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-269.el7]
- [virtio] drop virtio-device_is_legacy_only (Jason Wang) [1227339]
- [virtio] virtio-pci: support non-legacy balloon devices (Jason Wang) [1227339]
- [virtio] virtio-mmio: support non-legacy balloon devices (Jason Wang) [1227339]
- [virtio] virtio-ccw: support non-legacy balloon devices (Jason Wang) [1227339]
- [virtio] balloon might not be a legacy device (Jason Wang) [1227339]
- [virtio] virtio-balloon: transitional interface (Jason Wang) [1227339]
- [virtio] virtio-pci_modern: switch to type-safe io accessors (Jason Wang) [1227339]
- [virtio] virtio-pci_modern: type-safe io accessors (Jason Wang) [1227339]
- [virtio] drop a useless config read (Jason Wang) [1227339]
- [virtio] virtio-config: reorder functions (Jason Wang) [1227339]
- [virtio] virtio-mmio: fix access width for mmio (Jason Wang) [1227339]
- [virtio] virtio-mmio: generation support (Jason Wang) [1227339]
- [virtio] virtio-rpmsg: set DRIVER_OK before using device (Jason Wang) [1227339]
- [virtio] virtio-blk: fix comment for virtio 1.0 (Jason Wang) [1227339]
- [virtio] virtio-blk: typo fix (Jason Wang) [1227339]
- [virtio] virtio-balloon: set DRIVER_OK before using device (Jason Wang) [1227339]
- [virtio] don't set VIRTIO_CONFIG_S_DRIVER_OK twice (Jason Wang) [1227339]
- [virtio] virtio-net: unconditionally define struct virtio_net_hdr_v1 (Jason Wang) [1227339]
- [virtio] Don't expose legacy net features when VIRTIO_NET_NO_LEGACY defined (Jason Wang) [1227339]
- [virtio] don't require a config space on the console device (Jason Wang) [1227339]
- [virtio] virtio-pci: use 16-bit accessor for queue_enable (Jason Wang) [1227339]
- [virtio] Don't expose legacy config features when VIRTIO_CONFIG_NO_LEGACY defined (Jason Wang) [1227339]
- [virtio] Don't expose legacy block features when VIRTIO_BLK_NO_LEGACY defined (Jason Wang) [1227339]
- [virtio] define VIRTIO_PCI_CAP_PCI_CFG in header (Jason Wang) [1227339]
- [virtio] Avoid possible kernel panic if DEBUG is enabled (Jason Wang) [1227339]
- [virtio] virtio-mmio: Update the device to OASIS spec version (Jason Wang) [1227339]
- [virtio] virtio-pci: add module param to force legacy mode (Jason Wang) [1227339]
- [virtio] virtio-pci: add an option to disable legacy driver (Jason Wang) [1227339]
- [virtio] redhat: enable virtio-pci_legacy (Jason Wang) [1227339]
- [virtio] virtio-pci: drop Kconfig warnings (Jason Wang) [1227339]
- [virtio] virtio-pci: Kconfig grammar fix (Jason Wang) [1227339]
- [virtio] virtio-rng: drop extra empty line (Jason Wang) [1227339]
- [virtio] virtio-ring: coding style fix (Jason Wang) [1227339]
- [virtio] virtio-blk: coding style fixes (Jason Wang) [1227339]
- [virtio] virtio-balloon: coding style fixes (Jason Wang) [1227339]
- [virtio] virtio-pci_modern: support devices with no config (Jason Wang) [1227339]
- [virtio] virtio-pci_modern: reduce number of mappings (Jason Wang) [1227339]
- [virtio] virtio-pci: macros for PCI layout offsets (Jason Wang) [1227339]
- [virtio] virtio-pci: modern driver (Jason Wang) [1227339]
- [virtio] virtio-pci: define layout for virtio 1.0 (Jason Wang) [1227339]
- [virtio] virtio-pci: move probe/remove code to common (Jason Wang) [1227339]
- [virtio] virtio-pci: drop useless del_vqs call (Jason Wang) [1227339]
- [virtio] s390: add pci_iomap_range (Jason Wang) [1227339]
- [virtio] pci: add pci_iomap_range (Jason Wang) [1227339]
- [virtio] balloon: verify device has config space (Jason Wang) [1227339]
- [virtio] scsi: verify device has config space (Jason Wang) [1227339]
- [virtio] net: verify device has config space (Jason Wang) [1227339]
- [virtio] console: verify device has config space (Jason Wang) [1227339]
- [virtio] blk: verify device has config space (Jason Wang) [1227339]
- [virtio] 9p: verify device has config space (Jason Wang) [1227339]
- [virtio] virtio-pci: drop virtio_config dependency (Jason Wang) [1227339]
- [virtio] virtio-pci: document why we defer kfree (Jason Wang) [1227339]
- [virtio] virtio-pci: defer kfree until release callback (Jason Wang) [1227339]
- [virtio] virtio-pci: device-specific release callback (Jason Wang) [1227339]
- [virtio] make del_vqs idempotent (Jason Wang) [1227339]
- [virtio] virtio-pci: restore module attributes (Jason Wang) [1227339]
- [virtio] core support for config generation (Jason Wang) [1227339]
- [virtio] virtio-pci: add VIRTIO_PCI_NO_LEGACY (Jason Wang) [1227339]
- [virtio] virtio-pci: move probe to common file (Jason Wang) [1227339]
- [virtio] virtio-pci_common.h: drop VIRTIO_PCI_NO_LEGACY (Jason Wang) [1227339]
- [virtio] virtio-config: fix virtio_cread_bytes (Jason Wang) [1227339]
- [virtio] set VIRTIO_CONFIG_S_FEATURES_OK on restore (Jason Wang) [1227339]
- [virtio] virtio-ccw: finalize_features error handling (Jason Wang) [1227339]
- [virtio] virtio-ccw: future-proof finalize_features (Jason Wang) [1227339]
- [virtio] virtio-pci: rename virtio_pci -> virtio_pci_common (Jason Wang) [1227339]
- [virtio] virtio-pci: update file descriptions and copyright (Jason Wang) [1227339]
- [virtio] virtio-pci: split out legacy device support (Jason Wang) [1227339]
- [virtio] virtio-pci: setup config vector indirectly (Jason Wang) [1227339]
- [virtio] virtio-pci: setup vqs indirectly (Jason Wang) [1227339]
- [virtio] virtio-pci: delete vqs indirectly (Jason Wang) [1227339]
- [virtio] virtio-pci: use priv for vq notification (Jason Wang) [1227339]
- [virtio] virtio-pci: free up vq->priv (Jason Wang) [1227339]
- [virtio] virtio-pci: fix coding style for structs (Jason Wang) [1227339]
- [virtio] virtio-pci: add isr field (Jason Wang) [1227339]
- [virtio] drop legacy_only driver flag (Jason Wang) [1227339]
- [virtio] virtio-balloon: drop legacy_only driver flag (Jason Wang) [1227339]
- [virtio] virtio-ccw: rev 1 devices set VIRTIO_F_VERSION_1 (Jason Wang) [1227339]
- [virtio] allow finalize_features to fail (Jason Wang) [1227339]
- [virtio] virtio-ccw: legacy: don't negotiate rev 1/features (Jason Wang) [1227339]
- [virtio] add API to detect legacy devices (Jason Wang) [1227339]
- [virtio] virtio-console: fix sparse warnings (Jason Wang) [1227339]
- [virtio] drop VIRTIO_F_VERSION_1 from drivers (Jason Wang) [1227339]
- [virtio] make VIRTIO_F_VERSION_1 a transport bit (Jason Wang) [1227339]
- [virtio] virtio-balloon: add legacy_only flag (Jason Wang) [1227339]
- [virtio] virtio-console: virtio 1.0 support (Jason Wang) [1227339]
- [virtio] af_packet: virtio 1.0 stubs (Jason Wang) [1227339]
- [virtio] virtio-scsi: export to userspace (Jason Wang) [1227339]
- [virtio] virtio-scsi: move to uapi (Jason Wang) [1227339]
- [virtio] virtio-scsi: v1.0 support (Jason Wang) [1227339]
- [virtio] virtio-net: enable v1.0 support (Jason Wang) [1227339]
- [virtio] virtio-net: disable mac write for virtio 1.0 (Jason Wang) [1227339]
- [virtio] virtio-net: bigger header when VERSION_1 is set (Jason Wang) [1227339]
- [virtio] virtio-net: stricter short buffer length checks (Jason Wang) [1227339]
- [virtio] virtio-net: get rid of virtio_net_hdr/skb_vnet_hdr (Jason Wang) [1227339]
- [virtio] virtio-net: Set needed_headroom for virtio-net when VIRTIO_F_ANY_LAYOUT is true (Jason Wang) [1227339]
- [virtio] virtio-net: pass vi around (Jason Wang) [1227339]
- [virtio] virtio-blk: fix race at module removal (Jason Wang) [1227339]
- [virtio] virtio-blk: make serial attribute static (Jason Wang) [1227339]
- [virtio] kvm: s390: enable virtio-ccw revision 1 (Jason Wang) [1227339]
- [virtio] kvm: s390 allow virtio-ccw status writes to fail (Jason Wang) [1227339]
- [virtio] kvm: s390: virtio-ccw revision 1 SET_VQ (Jason Wang) [1227339]
- [virtio] kvm: s390: Set virtio-ccw transport revision (Jason Wang) [1227339]
- [virtio] virtio-blk: v1.0 support (Jason Wang) [1227339]
- [virtio] virtio-net: v1.0 endianness (Jason Wang) [1227339]
- [virtio] add legacy feature table support (Jason Wang) [1227339]
- [virtio] simplify feature bit handling (Jason Wang) [1227339]
- [virtio] set FEATURES_OK (Jason Wang) [1227339]
- [virtio] allow transports to get avail/used addresses (Jason Wang) [1227339]
- [virtio] virtio-config: endian conversion for v1.0 (Jason Wang) [1227339]
- [virtio] virtio-ring: switch to new memory access APIs (Jason Wang) [1227339]
- [virtio] memory access APIs (Jason Wang) [1227339]
- [virtio] add virtio 1.0 feature bit (Jason Wang) [1227339]
- [virtio] virtio-ccw: add support for 64 bit features (Jason Wang) [1227339]
- [virtio] assert 32 bit features in transports (Jason Wang) [1227339]
- [virtio] add support for 64 bit features (Jason Wang) [1227339]
- [virtio] use u32, not bitmap for features (Jason Wang) [1227339]
- [virtio] virtio-balloon: enable VQs early on restore (Jason Wang) [1227339]
- [virtio] virtio-console: move early VQ enablement (Jason Wang) [1227339]
- [virtio] virtio-net: enable VQs early on restore (Jason Wang) [1227339]
- [virtio] virtio-console: enable VQs early on restore (Jason Wang) [1227339]
- [virtio] virtio-scsi: enable VQs early on restore (Jason Wang) [1227339]
- [virtio] virtio-blk: enable VQs early on restore (Jason Wang) [1227339]
- [virtio] virtio-scsi: move kick event out from virtscsi_init (Jason Wang) [1227339]
- [virtio] virtio-net: fix use after free on allocation failure (Jason Wang) [1227339]
- [virtio] 9p/trans_virtio: enable VQs early (Jason Wang) [1227339]
- [virtio] virtio-console: enable VQs early (Jason Wang) [1227339]
- [virtio] virtio-blk: enable VQs early (Jason Wang) [1227339]
- [virtio] virtio-net: enable VQs early (Jason Wang) [1227339]
- [virtio] virtio-net: minor cleanup (Jason Wang) [1227339]
- [virtio] virtio-net: drop config_mutex (Jason Wang) [1227339]
- [virtio] virtio-net: drop config_enable (Jason Wang) [1227339]
- [virtio] virtio-blk: drop config_mutex (Jason Wang) [1227339]
- [virtio] virtio-blk: drop config_enable (Jason Wang) [1227339]
- [virtio] virtio-pci: move freeze/restore to virtio core (Jason Wang) [1227339]
- [virtio] virtio-pci: fix virtio spec compliance on restore (Jason Wang) [1227339]
- [virtio] add low-level APIs for feature bits (Jason Wang) [1227339]
- [virtio] add API to enable VQs early (Jason Wang) [1227339]
- [virtio] virtio-ring: unify direct/indirect code paths (Jason Wang) [1227339]
- [virtio] virtio-ring: assume sgs are always well-formed (Jason Wang) [1227339]
- [virtio] virtio-net: pass well-formed sgs to virtqueue_add_*() (Jason Wang) [1227339]
- [virtio] remove virtqueue_add_buf() (Jason Wang) [1227339]
- [virtio] pci: remove unnecessary pci_set_drvdata() (Jason Wang) [1227339]
- [virtio] virtio-pci: pm: Use CONFIG_PM_SLEEP instead of CONFIG_PM (Jason Wang) [1227339]
- [virtio] virtio-pci: fix leaks of msix_affinity_masks (Jason Wang) [1227339]
- [virtio] virtio-pci: Use pci_enable_msix_exact() instead of pci_enable_msix() (Jason Wang) [1227339]

* Wed Jun 17 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-268.el7]
- [x86] mm: add memory tracking to native_pmdp_get_and_clear (David Bulkow) [1227357]
- [kvm] x86: advertise KVM_CAP_X86_SMM (Paolo Bonzini) [1202825]
- [kvm] x86: add SMM to the MMU role, support SMRAM address space (Paolo Bonzini) [1202825]
- [kvm] arch/x86/kvm/mmu.c: work around gcc-4.4.4 bug (Paolo Bonzini) [1202825]
- [kvm] x86: work on all available address spaces (Paolo Bonzini) [1202825]
- [kvm] x86: use vcpu-specific functions to read/write/translate GFNs (Paolo Bonzini) [1202825]
- [kvm] x86: pass struct kvm_mmu_page to gfn_to_rmap (Paolo Bonzini) [1202825]
- [kvm] implement multiple address spaces (Paolo Bonzini) [1202825]
- [kvm] add vcpu-specific functions to read/write/translate GFNs (Paolo Bonzini) [1202825]
- [kvm] x86: save/load state on SMM switch (Paolo Bonzini) [1202825]
- [kvm] x86: latch INITs while in system management mode (Paolo Bonzini) [1202825]
- [kvm] x86: stubs for SMM support (Paolo Bonzini) [1202825]
- [kvm] x86: API changes for SMM support (Paolo Bonzini) [1202825]
- [kvm] x86: pass the whole hflags field to emulator and back (Paolo Bonzini) [1202825]
- [kvm] x86: pass host_initiated to functions that read MSRs (Paolo Bonzini) [1202825]
- [kvm] x86: introduce num_emulated_msrs (Paolo Bonzini) [1202825]
- [kvm] x86: clear hidden CPU state at reset time (Paolo Bonzini) [1202825]
- [kvm] x86: fix kvm_apic_has_events to check for NULL pointer (Paolo Bonzini) [1202825]
- [kvm] remove unused argument from mark_page_dirty_in_slot (Paolo Bonzini) [1202825]
- [kvm] x86: Allow ARAT CPU feature (Paolo Bonzini) [1202825]
- [kvm] x86: preserve x2APIC LDR on INIT (Paolo Bonzini) [1202825]
- [kvm] x86: use correct APIC ID on x2APIC transition (Paolo Bonzini) [1202825]
- [kvm] x86: pass struct kvm_mmu_page to account/unaccount_shadowed (Paolo Bonzini) [1202825]
- [kvm] remove __gfn_to_pfn (Paolo Bonzini) [1202825]
- [kvm] pass kvm_memory_slot to gfn_to_page_many_atomic (Paolo Bonzini) [1202825]
- [kvm] add "new" argument to kvm_arch_commit_memory_region (Paolo Bonzini) [1202825]
- [kvm] add memslots argument to kvm_arch_memslots_updated (Paolo Bonzini) [1202825]
- [kvm] const-ify uses of struct kvm_userspace_memory_region (Paolo Bonzini) [1202825]
- [kvm] use kvm_memslots whenever possible (Paolo Bonzini) [1202825]
- [kvm] introduce kvm_alloc/free_memslots (Paolo Bonzini) [1202825]
- [kvm] x86: Make functions that have no external callers static (Paolo Bonzini) [1202825]
- [kvm] export __gfn_to_pfn_memslot, drop gfn_to_pfn_async (Paolo Bonzini) [1202825]
- [kvm] x86: do not reset mmu if CR0.CD and CR0.NW are changed (Paolo Bonzini) [1202825]
- [kvm] mmu: fix MTRR update (Paolo Bonzini) [1202825]
- [kvm] mmu: fix decoding cache type from MTRR (Paolo Bonzini) [1202825]
- [kvm] mmu: introduce kvm_zap_rmapp (Paolo Bonzini) [1202825]
- [kvm] mmu: use slot_handle_level and its helper to clean up the code (Paolo Bonzini) [1202825]
- [kvm] mmu: introduce slot_handle_level_range() and its helpers (Paolo Bonzini) [1202825]
- [kvm] mmu: introduce for_each_slot_rmap_range (Paolo Bonzini) [1202825]
- [kvm] mmu: introduce PT_MAX_HUGEPAGE_LEVEL (Paolo Bonzini) [1202825]
- [kvm] mmu: introduce for_each_rmap_spte() (Paolo Bonzini) [1202825]
- [kvm] x86: Fix zero iterations REP-string (Paolo Bonzini) [1202825]
- [kvm] x86: Fix update RCX/RDI/RSI on REP-string (Paolo Bonzini) [1202825]
- [kvm] x86: Fix DR7 mask on task-switch while debugging (Paolo Bonzini) [1202825]
- [kvm] remove pointless cpu hotplug messages (Paolo Bonzini) [1202825]
- [kvm] x86: Call-far should not be emulated as stack op (Paolo Bonzini) [1202825]
- [kvm] reuse memslot in kvm_write_guest_page (Paolo Bonzini) [1202825]
- [kvm] x86: dump VMCS on invalid entry (Paolo Bonzini) [1202825]
- [kvm] x86: kvmclock: drop rdtsc_barrier() (Paolo Bonzini) [1202825]
- [kvm] x86: drop unneeded null test (Paolo Bonzini) [1202825]
- [kvm] x86: load guest FPU context more eagerly (Paolo Bonzini) [1202825]
- [kvm] x86: Support for disabling quirks (Paolo Bonzini) [1202825]
- [kvm] fpu: Enable eager restore kvm FPU for MPX (Paolo Bonzini) [1202825]
- [kvm] revert "kvm: x86: drop fpu_activate hook" (Paolo Bonzini) [1202825]
- [kvm] fix crash in kvm_vcpu_reload_apic_access_page (Paolo Bonzini) [1202825]
- [kvm] mmu: fix SMAP virtualization (Paolo Bonzini) [1202825]
- [kvm] mmu: fix CR4.SMEP=1, CR0.WP=0 with shadow pages (Paolo Bonzini) [1202825]
- [kvm] mmu: fix smap permission check (Paolo Bonzini) [1202825]
- [kvm] x86: pvclock: Really remove the sched notifier for cross-cpu migrations (Paolo Bonzini) [1202825]
- [kvm] x86: vdso: fix pvclock races with task migration (Paolo Bonzini) [1202825]
- [kvm] x86: fix kvmclock update protocol (Paolo Bonzini) [1202825]
- [kvm] svm: use kvm_register_write()/read() (Paolo Bonzini) [1202825]
- [kvm] async_pf: Add missing call for async page present (Paolo Bonzini) [1202825]
- [kvm] async_pf: Provide additional direct page notification (Paolo Bonzini) [1202825]
- [kvm] remove kvm_read_hva and kvm_read_hva_atomic (Paolo Bonzini) [1202825]
- [kvm] x86: IRET emulation does not clear NMI masking (Paolo Bonzini) [1202825]
- [kvm] x86: POPA emulation may not clear bits [63:32] (Paolo Bonzini) [1202825]
- [kvm] remove unneeded return value of vcpu_postcreate (Paolo Bonzini) [1202825]
- [kvm] Get rid of kvm_kvfree() (Paolo Bonzini) [1202825]
- [kvm] Use pr_info/pr_err in kvm_main.c (Paolo Bonzini) [1202825]

* Tue Jun 16 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-267.el7]
- [infiniband] disable INFINIBAND_ON_DEMAND_PAGING for s390 platform (Honggang Li) [1229265]
- [infiniband] ib/ehca: use correct destination for memcpy (Honggang Li) [1229265]
- [infiniband] ib/cma: Fix broken AF_IB UD support (Honggang Li) [1229265]
- [infiniband] ib/cm: Change reject message type when destroying cm_id (Honggang Li) [1229265]
- [infiniband] rdma/core: Fix for parsing netlink string attribute (Honggang Li) [1229265]
- [infiniband] ib/core: Fix unaligned accesses (Honggang Li) [1229265]
- [infiniband] ib/core: change rdma_gid2ip into void function as it always return zero (Honggang Li) [1229265]
- [infiniband] ib/core: dma unmap optimizations (Honggang Li) [1229265]
- [infiniband] ib/core: dma map/unmap locking optimizations (Honggang Li) [1229265]
- [infiniband] rdma/core: Enable the iWarp Port Mapper to provide the actual address of the connecting peer to its clients (Honggang Li) [1229265]
- [infiniband] rdma/cma: Canonize IPv4 on IPV6 sockets properly (Honggang Li) [1229265]
- [infiniband] ib_uverbs: Fix pages leak when using XRC SRQs (Honggang Li) [1229265]
- [infiniband] ib/core: don't disallow registering region starting at 0x0 (Honggang Li) [1229265]
- [infiniband] ib/core: disallow registering 0-sized memory region (Honggang Li) [1229265]
- [infiniband] ib/core: Add on demand paging caps to ib_uverbs_ex_query_device (Honggang Li) [1229265]
- [infiniband] ib/core: Add support for extended query device caps (Honggang Li) [1229265]
- [infiniband] ib/core: Properly handle registration of on-demand paging MRs after dereg (Honggang Li) [1229265]
- [infiniband] ib/core: Fix deadlock on uverbs modify_qp error flow (Honggang Li) [1229265]
- [infiniband] ib/core: When marshaling ucma path from user-space, clear unused fields (Honggang Li) [1229265]
- [infiniband] revert "ib/core: Add support for extended query device caps" (Honggang Li) [1229265]
- [infiniband] ib/core: Temporarily disable ex_query_device uverb (Honggang Li) [1229265]
- [infiniband] ib/core: Implement support for MMU notifiers regarding on demand paging regions (Honggang Li) [1229265]
- [infiniband] ib/core: Add support for on demand paging regions (Honggang Li) [1229265]
- [infiniband] ib/core: Add flags for on demand paging support (Honggang Li) [1229265]
- [infiniband] ib/core: Add support for extended query device caps (Honggang Li) [1229265]
- [infiniband] ib/core: Add umem function to read data from user-space (Honggang Li) [1229265]
- [infiniband] ib/core: Replace ib_umem's offset field with a full address (Honggang Li) [1229265]
- [infiniband] ib/addr: Improve address resolution callback scheduling (Honggang Li) [1229265]
- [infiniband] ib/core: Fix mgid key handling in SA agent multicast data-base (Honggang Li) [1229265]
- [infiniband] ib/core: Do not resolve VLAN if already resolved (Honggang Li) [1229265]
- [infiniband] ib/core: Fix XRC race condition in ib_uverbs_open_qp (Honggang Li) [1229265]
- [infiniband] ib/core: Clear AH attr variable to prevent garbage data (Honggang Li) [1229265]
- [infiniband] ib/core: Avoid leakage from kernel to user space (Honggang Li) [1229265]
- [infiniband] ib/core: ib_umem_release() should decrement mm->pinned_vm from ib_umem_get (Honggang Li) [1229265]
- [fs] proc: fix BUG_ON() introduced by PAGE_SIZE cmdline limit fix (Jarod Wilson) [1193998 1225363]
- [pci] Add ACS quirks for Intel 9-series PCH root ports (Myron Stowe) [1206198]
- [pci] Add Wellsburg (X99) to Intel PCH root port ACS quirk (Myron Stowe) [1162360]
- [pci] Add DMA alias quirk for Adaptec 3405 (Myron Stowe) [1171802]
- [pci] Mark AMD/ATI VGA devices that don't reset on D3hot->D0 transition (Myron Stowe) [1171802]
- [pci] Add flag for devices that don't reset on D3hot->D0 transition (Myron Stowe) [1171802]
- [pci] Mark Atheros AR93xx to avoid bus reset (Myron Stowe) [1171802]
- [pci] Add flag for devices where we can't use bus reset (Myron Stowe) [1171802]
- [hid] i2c-hid: Limit reads to wMaxInputLength bytes for input events (Aristeu Rozanski) [1075108 1075114]
- [hid] rmi: only bind the hid-rmi driver to the mouse interface of composite USB devices (Aristeu Rozanski) [1075108 1075114]
- [hid] rmi: check that report ids exist in the report_id_hash before accessing their size (Aristeu Rozanski) [1075108 1075114]
- [i2c] move ACPI helpers into the core (Aristeu Rozanski) [1075108 1075114]
- [i2c] designware: remove HAVE_CLK build dependecy (Aristeu Rozanski) [1075108 1075114]
- [hid] rmi: do not handle touchscreens through hid-rmi (Aristeu Rozanski) [1075108 1075114]
- [hid] rmi: fix masks for x and w_x data (Aristeu Rozanski) [1075108 1075114]
- [hid] rmi: fix wrong struct field name (Aristeu Rozanski) [1075108 1075114]
- [hid] rmi: do not fetch more than 16 bytes in a query (Aristeu Rozanski) [1075108 1075114]
- [hid] rmi: check for the existence of some optional queries before reading query 12 (Aristeu Rozanski) [1075108 1075114]
- [hid] rmi: do not stop the device at the end of probe (Aristeu Rozanski) [1075108 1075114]
- [hid] rmi: introduce RMI driver for Synaptics touchpads (Aristeu Rozanski) [1075108 1075114]
- [hid] i2c-hid: support sending HID output reports using the output register (Aristeu Rozanski) [1075108 1075114]
- [scsi] bnx2fc: fix an error code in _bnx2fc_create() (Maurizio Lombardi) [1187300]
- [scsi] bnx2fc: check IS_ERR() instead of NULL (Maurizio Lombardi) [1187300]
- [scsi] iscsi_ibft: filter null v4-mapped v6 addresses (Chris Leech) [1212673]
- [scsi] mpt2sas: Bump driver version to 20.100.00.00 (Tomas Henzl) [1189021]
- [scsi] mpt2sas+mpt3sas: set cpu affinity for each MSIX vectors (Tomas Henzl) [1189021 1200405]
- [scsi] mpt2sas+mpt3sas: Update attribution language to Avago (Tomas Henzl) [1189021 1200405]
- [scsi] mpt2sas: map log_info value 0x0x32010081 to DID_RESET (Tomas Henzl) [1189021]
- [scsi] mpt2sas+mpt3sas: fix upper bound for the module parameter max_sgl_entries (Tomas Henzl) [1053119]
- [scsi] mpt2sas: MPI2 Rev BB (2.00.20) specification and 2.00.35 header files (Tomas Henzl) [1189021]
- [scsi] mpt2sas: Bump driver version to 19.100.00.00 (Tomas Henzl) [1189021]
- [scsi] mpt2sas+mpt3sas: Fail the host reset initiated due to discovery related I/O timeouts at driver load time (Tomas Henzl) [1189021 1200405]
- [scsi] mpt2sas+mpt3sas: log exceeded temperature thresholds (Tomas Henzl) [1189021 1200405]
- [scsi] mpt2sas: MPI2 Rev AA (2.00.19) specifications (Tomas Henzl) [1189021]
- [scsi] mpt3sas: issue_reset is uninitialized (Tomas Henzl) [1200405]
- [scsi] mpt2sas: issue_reset is uninitialized (Tomas Henzl) [1189021]
- [scsi] mpt3sas: Revert " mpt3sas: Remove phys on topology change" (Tomas Henzl) [1200405]
- [scsi] mpt2sas: Revert "mpt2sas: Remove phys on topology change." (Tomas Henzl) [1189021]
- [scsi] mpt2sas: fix ioctl in comment (Tomas Henzl) [1189021]
- [scsi] bnx2i: Fixed firmware assert, during target logout (Maurizio Lombardi) [1187301]
- [scsi] fix regression in SCSI_IOCTL_SEND_COMMAND (Ewan Milne) [1109348]
- [scsi] set REQ_QUEUE for the blk-mq case (Ewan Milne) [1109348]
- [scsi] move blk_mq_start_request call earlier (Ewan Milne) [1109348]
- [scsi] fix regression that accidentally disabled block-based tcq (Ewan Milne) [1109348]
- [lib] scatterlist: fix memory leak with scsi-mq (Ewan Milne) [1109348]
- [scsi] sg: fix EWOULDBLOCK errors with scsi-mq (Ewan Milne) [1109348]
- [scsi] sg: fix unkillable I/O wait deadlock with scsi-mq (Ewan Milne) [1109348]
- [scsi] sg: fix read() error reporting (Ewan Milne) [1109348]
- [scsi] fix random memory corruption with scsi-mq + T10 PI (Ewan Milne) [1109348]
- [scsi] Fix qemu boot hang problem (Ewan Milne) [1109348]
- [scsi] scsi-mq: Add call to mark_tech_preview() if "use_blk_mq" is specified (Ewan Milne) [1109348]
- [scsi] fnic: reject device resets without assigned tags for the blk-mq case (Ewan Milne) [1109348]
- [scsi] add support for a blk-mq based I/O path (Ewan Milne) [1109348]
- [scsi] scatterlist: allow chaining to preallocated chunks (Ewan Milne) [1109348]
- [scsi] unwind blk_end_request_all and blk_end_request_err calls (Ewan Milne) [1109348]
- [scsi] only maintain target_blocked if the driver has a target queue limit (Ewan Milne) [1109348]
- [scsi] fix the host/target/device_blocked counter mess (Ewan Milne) [1109348]
- [scsi] convert device_busy to atomic_t (Ewan Milne) [1109348]
- [scsi] convert host_busy to atomic_t (Ewan Milne) [1109348]
- [scsi] convert target_busy to an atomic_t (Ewan Milne) [1109348]
- [scsi] push host_lock down into scsi_host/target_queue_ready (Ewan Milne) [1109348]
- [scsi] set ->scsi_done before calling scsi_dispatch_cmd (Ewan Milne) [1109348]
- [scsi] centralize command re-queueing in scsi_dispatch_fn (Ewan Milne) [1109348]
- [scsi] split __scsi_queue_insert (Ewan Milne) [1109348]
- [scsi] add scsi_setup_cmnd helper (Ewan Milne) [1109348]
- [scsi] mark scsi_setup_blk_pc_cmnd static (Ewan Milne) [1109348]
- [scsi] sd: split sd_init_command (Ewan Milne) [1109348]
- [scsi] sd: retry discard commands (Ewan Milne) [1109348]
- [scsi] sd: retry write same commands (Ewan Milne) [1109348]
- [scsi] sd: don't use scsi_setup_blk_pc_cmnd for discard requests (Ewan Milne) [1109348]
- [scsi] sd: don't use scsi_setup_blk_pc_cmnd for write same requests (Ewan Milne) [1109348]
- [scsi] sd: don't use scsi_setup_blk_pc_cmnd for flush requests (Ewan Milne) [1109348]
- [scsi] set sc_data_direction in common code (Ewan Milne) [1109348]
- [scsi] restructure command initialization for TYPE_FS requests (Ewan Milne) [1109348]
- [scsi] move the nr_phys_segments assert into scsi_init_io (Ewan Milne) [1109348]

* Mon Jun 15 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-266.el7]
- [drm] upstream sync to v4.1-rc7 (Rob Clark) [1206718]
- [drm] i915: Fix DDC probe for passive adapters (Rob Clark) [1206718]
- [drm] i915: Properly initialize SDVO analog connectors (Rob Clark) [1206718]
- [acpi] video: Allow forcing native backlight on non win8 machines (Benjamin Tissoires) [1218354]
- [acpi] i915: Update the condition to ignore firmware backlight change request (Benjamin Tissoires) [1218354]
- [acpi] video: Propagate the error code for acpi_video_register (Benjamin Tissoires) [1218354]
- [acpi] video: Load the module even if ACPI is disabled (Benjamin Tissoires) [1218354]
- [acpi] video: Disable native backlight on Samsung Series 9 laptops (Benjamin Tissoires) [1218354]
- [acpi] video: Add disable_native_backlight quirk for Samsung 510R (Benjamin Tissoires) [1218354]
- [acpi] video: Add disable_native_backlight quirk for Samsung 730U3E/740U3E (Benjamin Tissoires) [1218354]
- [acpi] video: Add disable_native_backlight quirk for Dell XPS15 L521X (Benjamin Tissoires) [1218354]
- [acpi] video: Add some Samsung models to disable_native_backlight list (Benjamin Tissoires) [1218354]
- [acpi] video: update the skip case for acpi_video_device_in_dod() (Benjamin Tissoires) [1218354]
- [acpi] video: update condition to check if device is in _DOD list (Benjamin Tissoires) [1218354]
- [acpi] video: Run _BCL before deciding registering backlight (Benjamin Tissoires) [1218354]
- [acpi] video: check _DOD list when creating backlight devices (Benjamin Tissoires) [1218354]
- [acpi] video: disable native backlight for ThinkPad X201s (Benjamin Tissoires) [1218354]
- [acpi] video: Remove video_set_use_native_backlight quirk (Benjamin Tissoires) [1218354]
- [acpi] video: Disable native_backlight on HP ENVY 15 Notebook PC (Benjamin Tissoires) [1218354]
- [acpi] video: Add a disable_native_backlight quirk (Benjamin Tissoires) [1218354]
- [acpi] video: Fix use_native_backlight selection logic (Benjamin Tissoires) [1218354]
- [acpi] video: Add use_native_backlight quirk for HP EliteBook 2014 models (Benjamin Tissoires) [1218354]
- [acpi] move models with win8 brightness problems from win8 blacklist to use_native_backlight (Benjamin Tissoires) [1218354]
- [acpi] blacklist: Add dmi_enable_osi_linux quirk for Asus EEE PC 1015PX (Benjamin Tissoires) [1218354]
- [acpi] blacklist win8 OSI for Dell Inspiron 7737 (Benjamin Tissoires) [1218354]
- [acpi] revert "acpi: Blacklist Win8 OSI for some HP laptop 2013 models" (Benjamin Tissoires) [1218354]
- [acpi] video: Fix backlight taking 2 steps on a brightness up/down keypress (Benjamin Tissoires) [1218354]
- [acpi] video: Add use_native_backlight quirk for HP ProBook 4540s (Benjamin Tissoires) [1218354]
- [acpi] revert "acpi video: change acpi-video brightness_switch_enabled default to 0" (Benjamin Tissoires) [1218354]
- [acpi] video: Add Acer TravelMate B113 to native backlight blacklist (Benjamin Tissoires) [1218354]
- [acpi] i915: ignore firmware requests for backlight change (Benjamin Tissoires) [1218354]
- [acpi] video: Change the default for video.use_native_backlight to 1 (Benjamin Tissoires) [1218354]
- [acpi] video: Add 4 new models to the use_native_backlight DMI list (Benjamin Tissoires) [1218354]
- [acpi] video: Add use native backlight quirk for the ThinkPad W530 (Benjamin Tissoires) [1218354]
- [acpi] video: Unregister the backlight device if a raw one shows up later (Benjamin Tissoires) [1218354]
- [acpi] video: Add an acpi_video_unregister_backlight function (Benjamin Tissoires) [1218354]
- [acpi] video: Revert native brightness quirk for ThinkPad T530 (Benjamin Tissoires) [1218354]
- [acpi] video: Don't register acpi_video_resume notifier without backlight devices (Benjamin Tissoires) [1218354]
- [acpi] video: correct DMI tag for Dell Inspiron 7520 (Benjamin Tissoires) [1218354]
- [acpi] video: change acpi-video brightness_switch_enabled default to 0 (Benjamin Tissoires) [1218354]
- [acpi] video: Add use_native_backlight quirks for more systems (Benjamin Tissoires) [1218354]
- [acpi] video: Favor native backlight interface for ThinkPad Helix (Benjamin Tissoires) [1218354]
- [acpi] video: Add systems that should favour native backlight interface (Benjamin Tissoires) [1218354]
- [acpi] Blacklist Win8 OSI for some HP laptop 2013 models (Benjamin Tissoires) [1218354]
- [acpi] delete CONFIG_ACPI_BLACKLIST_YEAR (Benjamin Tissoires) [1218354]
- [acpi] blacklist: fix name of ThinkPad Edge E530 (Benjamin Tissoires) [1218354]
- [acpi] Add Toshiba NB100 to Vista _OSI blacklist (Benjamin Tissoires) [1218354]
- [acpi] add missing win8 OSI comment to blacklist (Benjamin Tissoires) [1218354]
- [acpi] update win8 OSI blacklist (Benjamin Tissoires) [1218354]
- [acpi] blacklist win8 OSI for buggy laptops (Benjamin Tissoires) [1218354]
- [acpi] blacklist win8 OSI for ASUS Zenbook Prime UX31A (Benjamin Tissoires) [1218354]
- [acpi] video: Filter the _BCL table for duplicate brightness values (Benjamin Tissoires) [1218354]
- [acpi] video: clean up DMI table for initial black screen problem (Benjamin Tissoires) [1218354]
- [acpi] revert "acpi video: Ignore BIOS initial backlight value for HP 250 G1" (Benjamin Tissoires) [1218354]
- [acpi] video: Quirk initial backlight level 0 (Benjamin Tissoires) [1218354]
- [acpi] video: Fix initial level validity test (Benjamin Tissoires) [1218354]
- [acpi] video: Ignore BIOS initial backlight value for HP 250 G1 (Benjamin Tissoires) [1218354]
- [acpi] video: Do not register backlight if win8 and native interface exists (Benjamin Tissoires) [1218354]
- [acpi] video: seperate backlight control and event interface (Benjamin Tissoires) [1218354]
- [acpi] revert "acpi video: Always call acpi_video_init_brightness() on init" (Benjamin Tissoires) [1218354]
- [acpi] video: drop unused fields from struct acpi_video_brightness_flags (Benjamin Tissoires) [1218354]
- [acpi] video: remove unnecessary type casting (Benjamin Tissoires) [1218354]
- [acpi] video: trivial style cleanups (Benjamin Tissoires) [1218354]
- [acpi] video: trivial costmetic cleanups (Benjamin Tissoires) [1218354]
- [acpi] revert "acpi video / i915: No ACPI backlight if firmware expects Windows 8" (Benjamin Tissoires) [1218354]
- [acpi] video: no automatic brightness changes by win8-compatible firmware (Benjamin Tissoires) [1218354]
- [acpi] video / i915: No ACPI backlight if firmware expects Windows 8 (Benjamin Tissoires) [1218354]
- [acpi] video: Always call acpi_video_init_brightness() on init (Benjamin Tissoires) [1218354]
- [acpi] backlight: Add backlight device (un)registration notification (Benjamin Tissoires) [1218354]
- [acpi] backlight: fix KABI breakage (Benjamin Tissoires) [1218354]
- [acpi] backlight: introduce backlight_device_registered (Benjamin Tissoires) [1218354]
- [acpi] acpica: expose OSI version (Benjamin Tissoires) [1218354]
- [x86] kvm: add module parameter to disable periodic kvmclock sync (Marcelo Tosatti) [1220952]
- [x86] kvm: increase user memory slots to 509 (Igor Mammedov) [1155581]
- [iommu] vt-d: Fix an off-by-one bug in __domain_mapping() (Myron Stowe) [1171802]
- [kernel] lockdep: Increase static allocations (Jiri Olsa) [1158087]

* Mon Jun 15 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-265.el7]
- [md] dm: fix casting bug in dm_merge_bvec() (Mike Snitzer) [1166127 1208542]
- [md] dm: fix reload failure of 0 path multipath mapping on blk-mq devices (Mike Snitzer) [1166127 1208542]
- [md] dm: fix false warning in free_rq_clone() for unmapped requests (Mike Snitzer) [1166127 1208542]
- [md] dm-mpath: fix leak of dm_mpath_io structure in blk-mq .queue_rq error path (Mike Snitzer) [1166127 1208542]
- [md] dm: requeue from blk-mq dm_mq_queue_rq() using BLK_MQ_RQ_QUEUE_BUSY (Mike Snitzer) [1166127 1208542]
- [md] dm: fix NULL pointer when clone_and_map_rq returns !DM_MAPIO_REMAPPED (Mike Snitzer) [1166127 1208542]
- [md] dm: run queue on re-queue (Mike Snitzer) [1166127 1208542]
- [md] dm-log-userspace-base: fix compile warning (Mike Snitzer) [1166127 1208542]
- [md] dm-log-userspace-transfer: match wait_for_completion_timeout return type (Mike Snitzer) [1166127 1208542]
- [md] dm-log-userspace: split flush_entry_pool to be per dirty-log (Mike Snitzer) [1166127 1208542]
- [md] dm-table: fall back to getting device using name_to_dev_t() (Mike Snitzer) [1166127 1208542]
- [init] fix regression by supporting devices with major:minor:offset format (Mike Snitzer) [1166127 1208542]
- [init] stricter checking of major:minor root= values (Mike Snitzer) [1166127 1208542]
- [init] export name_to_dev_t and mark name argument as const (Mike Snitzer) [1166127 1208542]
- [md] dm: fix free_rq_clone() NULL pointer when requeueing unmapped request (Mike Snitzer) [1166127 1208542]
- [md] dm: only initialize the request_queue once (Mike Snitzer) [1166127 1208542]
- [md] dm: add 'use_blk_mq' module param and expose in per-device ro sysfs attr (Mike Snitzer) [1166127 1208542]
- [md] dm: optimize dm_mq_queue_rq to _not_ use kthread if using pure blk-mq (Mike Snitzer) [1166127 1208542]
- [md] dm: add full blk-mq support to request-based DM (Mike Snitzer) [1166127 1208542]
- [md] dm-table: use bool function return values of true/false not 1/0 (Mike Snitzer) [1166127 1208542]
- [md] dm-delay: use msecs_to_jiffies for time conversion (Mike Snitzer) [1166127 1208542]
- [md] dm-verity: add error handling modes for corrupted blocks (Mike Snitzer) [1166127 1208542]
- [md] dm-crypt: fix missing error code return from crypt_ctr error path (Mike Snitzer) [1166127 1208542]
- [md] dm-crypt: update URLs to new cryptsetup project page (Mike Snitzer) [1166127 1208542]
- [md] dm-switch: fix Documentation to use plain text (Mike Snitzer) [1166127 1208542]
- [md] dm-thin: remove stale 'trim' message documentation (Mike Snitzer) [1166127 1208542]
- [md] dm-cache-policy-mq: try not to writeback data that changed in the last second (Mike Snitzer) [1166127 1208542]
- [md] dm-cache-policy-mq: remove unused generation member of struct entry (Mike Snitzer) [1166127 1208542]
- [md] dm-cache-policy-mq: track entries hit this 'tick' via sentinel objects (Mike Snitzer) [1166127 1208542]
- [md] dm-cache-policy-mq: remove queue_shift_down() (Mike Snitzer) [1166127 1208542]
- [md] dm-cache-policy-mq: keep track of the number of entries in a multiqueue (Mike Snitzer) [1166127 1208542]
- [md] dm: impose configurable deadline for dm_request_fn's merge heuristic (Mike Snitzer) [1166127 1208542]
- [kernel] ktime: add ktime_after and ktime_before helper (Mike Snitzer) [1166127 1208542]
- [md] dm-sysfs: introduce ability to add writable attributes (Mike Snitzer) [1166127 1208542]
- [md] dm: don't start current request if it would've merged with the previous (Mike Snitzer) [1166127 1208542]
- [md] dm: reduce the queue delay used in dm_request_fn from 100ms to 10ms (Mike Snitzer) [1166127 1208542]
- [md] dm: don't schedule delayed run of the queue if nothing to do (Mike Snitzer) [1166127 1208542]
- [md] dm: only run the queue on completion if congested or no requests pending (Mike Snitzer) [1166127 1208542]
- [md] dm: remove request-based logic from make_request_fn wrapper (Mike Snitzer) [1166127 1208542]
- [md] dm: remove request-based DM queue's lld_busy_fn hook (Mike Snitzer) [1166127 1208542]
- [md] dm: remove unnecessary wrapper around blk_lld_busy (Mike Snitzer) [1166127 1208542]
- [md] dm: rename __dm_get_reserved_ios() helper to __dm_get_module_param() (Mike Snitzer) [1166127 1208542]
- [powerpc] eeh: Delay probing EEH device during hotplug (Laurent Vivier) [1213675]
- [powerpc] eeh: Fix race condition in pcibios_set_pcie_reset_state() (Laurent Vivier) [1213675]
- [powerpc] tg3: Release IRQs on permanent error (Laurent Vivier) [1213675]
- [powerpc] powernv: Don't map M64 segments using M32DT (Laurent Vivier) [1213675]
- [powerpc] eeh: Fix PE#0 check in eeh_add_to_parent_pe() (Laurent Vivier) [1213675]
- [powerpc] pci: Create pci_dn for VFs (Laurent Vivier) [1213675]
- [powerpc] pci: Export pci_iov_virtfn_bus() and pci_iov_virtfn_devfn() (Laurent Vivier) [1213675]
- [powerpc] sfc: Don't use of_node_to_eeh_dev() (Laurent Vivier) [1213675]
- [powerpc] eeh: Remove device_node dependency (Laurent Vivier) [1213675]
- [powerpc] eeh: Replace device_node with pci_dn in eeh_ops (Laurent Vivier) [1213675]
- [powerpc] eeh: Do probe on pci_dn (Laurent Vivier) [1213675]
- [powerpc] eeh: Create eeh_dev from pci_dn instead of device_node (Laurent Vivier) [1213675]
- [powerpc] pci: Trace more information from pci_dn (Laurent Vivier) [1213675]
- [powerpc] powernv: Use pci_dn, not device_node, in PCI config accessor (Laurent Vivier) [1213675]
- [powerpc] pci: Refactor pci_dn (Laurent Vivier) [1213675]
- [powerpc] pci: remove the multi-init for pci_dn->phb (Laurent Vivier) [1213675]
- [powerpc] powernv: Remove unused file (Laurent Vivier) [1213675]
- [powerpc] powernv: Drop PHB operation reset() (Laurent Vivier) [1213675]
- [powerpc] powernv: Drop PHB operation next_error() (Laurent Vivier) [1213675]
- [powerpc] powernv: Drop PHB operation get_state() (Laurent Vivier) [1213675]
- [powerpc] powernv: Drop PHB operation set_option() (Laurent Vivier) [1213675]
- [powerpc] powernv: Drop PHB operation configure_bridge() (Laurent Vivier) [1213675]
- [powerpc] powernv: Drop PHB operation get_log() (Laurent Vivier) [1213675]
- [powerpc] powernv: Drop PHB operation post_init() (Laurent Vivier) [1213675]
- [powerpc] powernv: Drop PHB operation err_inject() (Laurent Vivier) [1213675]
- [powerpc] powernv: Shorten EEH function names (Laurent Vivier) [1213675]
- [powerpc] eeh: Enhance pcibios_set_pcie_reset_state() (Laurent Vivier) [1213675]
- [powerpc] eeh: Allow to set maximal frozen times (Laurent Vivier) [1213675]
- [powerpc] eeh: Introduce flag EEH_PE_REMOVED (Laurent Vivier) [1213675]
- [powerpc] eeh: Fix missed PE#0 on P7IOC (Laurent Vivier) [1213675]
- [powerpc] eeh: Dump PHB diag-data early (Laurent Vivier) [1213675]
- [powerpc] eeh: Recover EEH error on ownership change for BCM5719 (Laurent Vivier) [1213675]
- [powerpc] eeh: Set EEH_PE_RESET on PE reset (Laurent Vivier) [1213675]
- [powerpc] eeh: Refactor eeh_reset_pe() (Laurent Vivier) [1213675]
- [powerpc] powernv: Replace OPAL_DEASSERT_RESET with EEH_RESET_DEACTIVATE (Laurent Vivier) [1213675]
- [powerpc] eeh: Fix PE state format (Laurent Vivier) [1213675]
- [powerpc] eeh: Block CFG upon frozen Shiner adapter (Laurent Vivier) [1213675]
- [powerpc] eeh: Don't collect logs on PE with blocked config space (Laurent Vivier) [1213675]
- [powerpc] eeh: Block PCI config access upon frozen PE (Laurent Vivier) [1213675]
- [powerpc] powernv: Drop config requests in EEH accessors (Laurent Vivier) [1213675]
- [powerpc] eeh: Rename flag EEH_PE_RESET to EEH_PE_CFG_BLOCKED (Laurent Vivier) [1213675]
- [powerpc] eeh: Fix condition for isolated state (Laurent Vivier) [1213675]
- [powerpc] eeh: Show hex prefix for PE state sysfs (Laurent Vivier) [1213675]
- [powerpc] powernv: Fetch frozen PE on top level (Laurent Vivier) [1213675]
- [powerpc] eeh: Dump PCI config space for all child devices (Laurent Vivier) [1213675]
- [powerpc] eeh: Emulate EEH recovery for VFIO devices (Laurent Vivier) [1213675]
- [powerpc] eeh: Tag reset state for user owned PE (Laurent Vivier) [1213675]
- [powerpc] eeh: Block PCI config access during reset (Laurent Vivier) [1213675]
- [powerpc] eeh: Use eeh_unfreeze_pe() (Laurent Vivier) [1213675]
- [powerpc] eeh: Unfreeze PE on enabling EEH functionality (Laurent Vivier) [1213675]
- [powerpc] eeh: Fix improper condition in eeh_pci_enable() (Laurent Vivier) [1213675]
- [powerpc] eeh: Clear frozen device state in time (Laurent Vivier) [1213675]
- [powerpc] powernv: Clear PAPR error injection registers (Laurent Vivier) [1213675]
- [powerpc] powernv: Add PCI error injection debugfs entry (Laurent Vivier) [1213675]
- [powerpc] eeh: Introduce eeh_ops::err_inject (Laurent Vivier) [1213675]
- [powerpc] powernv: Sync header with firmware (Laurent Vivier) [1213675]
- [powerpc] eeh: Clear frozen state on passing device (Laurent Vivier) [1213675]
- [powerpc] eeh: Reenable PCI devices after reset (Laurent Vivier) [1213675]
- [powerpc] eeh: Freeze PE before PE reset (Laurent Vivier) [1213675]
- [powerpc] eeh: Add eeh_pe_state sysfs entry (Laurent Vivier) [1213675]
- [powerpc] eeh: Drop unused argument in eeh_check_failure() (Laurent Vivier) [1213675]
- [powerpc] eeh: Fix kernel crash when passing through VF (Laurent Vivier) [1213675]
- [powerpc] vfio: Export vfio_spapr_iommu_eeh_ioctl() with GPL (Laurent Vivier) [1213675]
- [powerpc] vfio/pci: Restore MSIx message prior to enabling (Laurent Vivier) [1213675]
- [powerpc] pci: Assume all Mellanox devices have broken INTx masking (Laurent Vivier) [1213675]
- [powerpc] pseries: Failure on removing device node (Laurent Vivier) [1213675]
- [powerpc] eeh: Export eeh_iommu_group_to_pe() (Laurent Vivier) [1213675]
- [powerpc] eeh: Add missing #ifdef CONFIG_IOMMU_API (Laurent Vivier) [1213675]
- [powerpc] vfio: Enable VFIO if EEH is not supported (Laurent Vivier) [1213675]
- [powerpc] vfio: Allow EEH to be built as module (Laurent Vivier) [1213675]
- [powerpc] vfio: Fix EEH build error (Laurent Vivier) [1213675]
- [powerpc] vfio: EEH support for VFIO PCI device (Laurent Vivier) [1213675]
- [hid] usbhid: yet another mouse with ALWAYS_POLL (Don Zickus) [914682]
- [hid] usbhid: more mice with ALWAYS_POLL (Don Zickus) [914682]
- [hid] add quirk for PIXART OEM mouse used by HP (Don Zickus) [914682]
- [hid] add HP OEM mouse to quirk ALWAYS_POLL (Don Zickus) [914682]
- [hid] add ALWAYS_POLL quirk for a Logitech 0xc007 (Don Zickus) [914682]
- [hid] usbhid: enable always-poll quirk for Elan Touchscreen 0103 (Don Zickus) [914682]
- [hid] usbhid: prevent unwanted events to be sent when re-opening the device (Don Zickus) [914682]
- [hid] usbhid: enable always-poll quirk for Elan Touchscreen 016f (Don Zickus) [914682]
- [hid] usbhid: enable always-poll quirk for Elan Touchscreen 009b (Don Zickus) [914682]
- [hid] usbhid: add another mouse that needs QUIRK_ALWAYS_POLL (Don Zickus) [914682]
- [hid] usbhid: fix PIXART optical mouse (Don Zickus) [914682]
- [hid] usbhid: enable always-poll quirk for Elan Touchscreen (Don Zickus) [914682]
- [hid] usbhid: add always-poll quirk (Don Zickus) [914682]
- [tools] turbostat: update version number to 4.7 (Prarit Bhargava) [1224005]
- [tools] turbostat: allow running without cpu0 (Prarit Bhargava) [1224005]
- [tools] turbostat: correctly decode of ENERGY_PERFORMANCE_BIAS (Prarit Bhargava) [1224005]
- [tools] turbostat: correctly display more than 2 threads/core (Prarit Bhargava) [1224005]
- [net] tcp: double default TSQ output bytes limit (Hannes Frederic Sowa) [1228113]
- [net] bridge: fix parsing of MLDv2 reports (Thadeu Lima de Souza Cascardo) [1219092]
- [net] conntrack: RFC5961 challenge ACK confuse conntrack LAST-ACK transition (Jesper Brouer) [1212829]
- [net] tcp: Restore RFC5961-compliant behavior for SYN packets (Jesper Brouer) [1212829]

* Thu Jun 11 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-264.el7]
- [powerpc] perf: hv-24x7: Add missing put_cpu_var() (Jiri Olsa) [1220106]
- [block] blk-mq: make plug work for mutiple disks and queues (Jeff Moyer) [1185689]
- [block] blk-mq: do limited block plug for multiple queue case (Jeff Moyer) [1185689]
- [block] blk-mq: avoid re-initialize request which is failed in direct dispatch (Jeff Moyer) [1185689]
- [block] blk-mq: fix plugging in blk_sq_make_request (Jeff Moyer) [1185689]
- [kernel] sched: Prevent recursion in io_schedule() (Jeff Moyer) [1185689]
- [scsi] ipr: Increase default adapter init stage change timeout (Steve Best) [1229217]
- [fs] fs-cache: Retain the netfs context in the retrieval op earlier (David Howells) [1130457 1204964]
- [fs] fs-cache: The operation cancellation method needs calling in more places (David Howells) [1130457 1204964]
- [fs] fs-cache: Put an aborted initialised op so that it is accounted correctly (David Howells) [1130457 1204964]
- [fs] fs-cache: Fix cancellation of in-progress operation (David Howells) [1130457 1204964]
- [fs] fs-cache: Count the number of initialised operations (David Howells) [1130457 1204964]
- [fs] fs-cache: Out of line fscache_operation_init() (David Howells) [1130457 1204964]
- [fs] fs-cache: Permit fscache_cancel_op() to cancel in-progress operations too (David Howells) [1130457 1204964]
- [fs] fs-cache: fscache_object_is_dead() has wrong logic, kill it (David Howells) [1130457 1204964]
- [fs] fs-cache: Synchronise object death state change vs operation submission (David Howells) [1130457 1204964]
- [fs] fs-cache: Handle a new operation submitted against a killed object (David Howells) [1130457 1204964]
- [fs] fs-cache: When submitting an op, cancel it if the target object is dying (David Howells) [1130457 1204964]
- [fs] fs-cache: Move fscache_report_unexpected_submission() to make it more available (David Howells) [1130457 1204964]
- [fs] fs-cache: Count culled objects and objects rejected due to lack of space (David Howells) [1130457 1204964]
- [fs] fs-cache: use __seq_open_private() (David Howells) [1130457 1204964]
- [fs] cachefiles: Fix incorrect test for in-memory object collision (David Howells) [1130457 1204964]
- [fs] cachefiles: Handle object being killed before being set up (David Howells) [1130457 1204964]
- [fs] cachefiles: add missing \n to kerror conversions (David Howells) [1130457 1204964]
- [fs] cachefiles: remove two unused pagevecs (David Howells) [1130457 1204964]
- [fs] fs-cache: refcount becomes corrupt under vma pressure (David Howells) [1130457 1204964]
- [fs] fs-cache: Reduce cookie ref count if submit fails (David Howells) [1130457 1204964]
- [fs] fs-cache: Timeout for releasepage() (David Howells) [1130457 1204964]
- [fs] fscache: make ctl_table static (David Howells) [1130457 1204964]
- [fs] fscache: convert use of typedef ctl_table to struct ctl_table (David Howells) [1130457 1204964]
- [fs] cachefiles: replace kerror by pr_err (David Howells) [1130457 1204964]
- [fs] cachefiles: convert printk to pr_foo() (David Howells) [1130457 1204964]
- [fs] fscache: replace seq_printf by seq_puts (David Howells) [1130457 1204964]
- [fs] fscache: convert printk to pr_foo() (David Howells) [1130457 1204964]
- [fs] get rid of pointless checks for NULL ->i_op (David Howells) [1130457 1204964]
- [fs] fs-cache: Handle removal of unadded object to the fscache_object_list rb tree (David Howells) [1130457 1204964]
- [fs] nfs: Use i_writecount to control whether to get an fscache cookie in nfs_open() (David Howells) [1130457 1204964]
- [fs] fs-cache: Provide the ability to enable/disable cookies (David Howells) [1130457 1204964]
- [fs] fs-cache: Add use/unuse/wake cookie wrappers (David Howells) [1130457 1204964]
- [fs] cachefiles: Don't try to dump the index key if the cookie has been cleared (David Howells) [1130457 1204964]
- [fs] cachefiles: Fix memory leak in cachefiles_check_auxdata error paths (David Howells) [1130457 1204964]
- [fs] fscache: check consistency does not decrement refcount (David Howells) [1130457 1204964]
- [fs] fscache: Netfs function for cleanup post readpages (David Howells) [1130457 1204964]
- [fs] cachefiles: Implement interface to check cache consistency (David Howells) [1130457 1204964]
- [fs] fs-cache: Add interface to check consistency of a cached object (David Howells) [1130457 1204964]
- [fs] fs-cache: Don't use spin_is_locked() in assertions (David Howells) [1130457 1204964]
- [fs] fs-cache: The retrieval remaining-pages counter needs to be atomic_t (David Howells) [1130457 1204964]
- [fs] cachefiles: remove unused macro list_to_page() (David Howells) [1130457 1204964]
- [fs] fs-cache: Simplify cookie retention for fscache_objects, fixing oops (David Howells) [1130457 1204964]
- [fs] fs-cache: Fix object state machine to have separate work and wait states (David Howells) [1129693 1130457 1204964]
- [fs] fs-cache: Wrap checks on object state (David Howells) [1130457 1204964]
- [fs] fs-cache: Uninline fscache_object_init() (David Howells) [1130457 1204964]
- [fs] fs-cache: Don't sleep in page release if __GFP_FS is not set (David Howells) [1130457 1204964]
- [fs] cachefiles: name i_mutex lock class explicitly (David Howells) [1130457 1204964]
- [fs] fscache: remove spin_lock() from the condition in while() (David Howells) [1130457 1204964]
- [kernel] wait: fix new kernel-doc warning in wait.c (David Howells) [1130457 1204964]
- [kernel] wait: Fix __wait_on_atomic_t() to call the action func if the counter != 0 (David Howells) [1130457 1204964]

* Wed Jun 10 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-263.el7]
- [fs] pipe: fix pipe corruption and iovec overrun on partial copy (Seth Jennings) [1198843] {CVE-2015-1805}
- [fs] xfs: add RENAME_WHITEOUT support (Carlos Maiolino) [1158888]
- [fs] xfs: make xfs_cross_rename() complete fully (Carlos Maiolino) [1158888]
- [fs] xfs: factor out xfs_finish_rename() (Carlos Maiolino) [1158888]
- [fs] xfs: cleanup xfs_rename error handling (Carlos Maiolino) [1158888]
- [fs] xfs: clean up inode locking for RENAME_WHITEOUT (Carlos Maiolino) [1158888]
- [fs] xfs: inodes are new until the dentry cache is set up (Carlos Maiolino) [1158888]
- [fs] xfs: fix tmpfile/selinux deadlock and initialize security (Carlos Maiolino) [1158888]
- [fs] allow the temp files created by open() to be linked to (Carlos Maiolino) [1158888]
- [fs] xfs: allow linkat() on O_TMPFILE files (Carlos Maiolino) [1158888]
- [fs] xfs: add O_TMPFILE support (Carlos Maiolino) [1158888]
- [fs] xfs: Add support to RENAME_EXCHANGE flag (Carlos Maiolino) [1158888]
- [fs] xfs: Make xfs_vn_rename compliant with renameat2() syscall (Carlos Maiolino) [1158888]
- [fs] xfs: Wrap dir inode operations inside inode_operation_wrapper (Carlos Maiolino) [1158888]
- [kvm] ppc: book3s hv: Endian fix for accessing VPA yield count (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Fix spinlock/mutex ordering issue in kvmppc_set_lpcr() (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: Enable in-kernel XICS emulation by default (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Improve H_CONFER implementation (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Fix instruction emulation (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Fix endianness of instruction obtained from HEIR register (Thomas Huth) [1226884 1227323]
- [kvm] powerpc/kvm: support to handle sw breakpoint (Thomas Huth) [1226884 1227323]
- [kvm] powerpc/kvm: Define struct kvm_debug_exit_arch for powerpc (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Tracepoints for KVM HV guest interactions (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Simplify locking around stolen time calculations (Thomas Huth) [1226884 1227323]
- [kvm] arch: powerpc: kvm: book3s_paired_singles.c: Remove unused function (Thomas Huth) [1226884 1227323]
- [kvm] arch: powerpc: kvm: book3s_pr.c: Remove unused function (Thomas Huth) [1226884 1227323]
- [kvm] arch: powerpc: kvm: book3s.c: Remove some unused functions (Thomas Huth) [1226884 1227323]
- [kvm] arch: powerpc: kvm: book3s_32_mmu.c: Remove unused function (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Fix computation of tlbie operand (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Check wait conditions before sleeping in kvmppc_vcore_blocked (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Fix inaccuracies in ICP emulation for H_IPI (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Add missing HPTE unlock (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Only accept host PVR value for guest PVR (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Increase timeout for grabbing secondary threads (Thomas Huth) [1226884 1227323]
- [kvm] ppc: Remove the tasklet used by the hrtimer (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Add register name when loading toc (Thomas Huth) [1226884 1227323]
- [kvm] ppc: pr: Handle FSCR feature deselects (Thomas Huth) [1226884 1227323]
- [kvm] ppc: drop duplicate tracepoint (Thomas Huth) [1226884 1227323]
- [kvm] ppc: hv: Remove generic instruction emulation (Thomas Huth) [1226884 1227323]
- [kvm] ppc: Expose helper functions for data/inst faults (Thomas Huth) [1226884 1227323]
- [kvm] ppc: Separate loadstore emulation from priv emulation (Thomas Huth) [1226884 1227323]
- [kvm] ppc: Handle magic page in kvmppc_ld/st (Thomas Huth) [1226884 1227323]
- [kvm] ppc: Use kvm_read_guest in kvmppc_ld (Thomas Huth) [1226884 1227323]
- [kvm] ppc: Remove kvmppc_bad_hva() (Thomas Huth) [1226884 1227323]
- [kvm] ppc: Move kvmppc_ld/st to common code (Thomas Huth) [1226884 1227323]
- [kvm] ppc: Implement kvmppc_xlate for all targets (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: hv: Update compute_tlbie_rb to handle 16MB base page (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: Provide different CAPs based on HV or PR mode (Thomas Huth) [1226884 1227323]
- [kvm] Use the POWER8 Micro Partition Prefetch Engine in KVM HV on POWER8 (Thomas Huth) [1226884 1227323]
- [kvm] Split out struct kvmppc_vcore creation to separate function (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: Make kvmppc_ld return a more accurate error indication (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: Fix LPCR one_reg interface (Thomas Huth) [1226884 1227323]
- [kvm] ppc: Allow kvmppc_get_last_inst() to fail (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: Remove kvmppc_read_inst() function (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: Make magic page properly 4k mappable (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: Add hack for split real mode (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: Stop PTE lookup on write errors (Thomas Huth) [1226884 1227323]
- [kvm] ppc: Deflect page write faults properly in kvmppc_st (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s pr: Fix sparse endian checks (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s pr: Handle hyp doorbell exits (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s hv: Fix tlbie compile error (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: pr: Emulate instruction counter (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: pr: Emulate virtual timebase register (Thomas Huth) [1226884 1227323]
- [kvm] ppc: book3s: pr: Fix PURR and SPURR emulation (Thomas Huth) [1226884 1227323]
- [x86] mm: numa: Fix kernel stack corruption in numa_init()->numa_clear_kernel_node_hotplug() (Dave Young) [1188542]
- [x86] mm: numa: fix boot failure when all nodes are hotpluggable (Dave Young) [1188542]
- [x86] mm: numa: use for_each_memblock() (Dave Young) [1188542]
- [ata] ahci: avoton port-disable reset-quirk (David Milburn) [1223189]
- [ata] libata: Blacklist queued TRIM on all Samsung 800-series (David Milburn) [1225622]
- [pci] hotplug: Drop pointless ACPI-based "slot detection" check (Jarod Wilson) [1211805]
- [block] loop: remove (now) unused 'out' label (Jarod Wilson) [1182243]
- [block] s390: dasd: remove obsolete while -EBUSY loop (Jarod Wilson) [1182243]
- [block] s390: dasd_genhd: convert to blkdev_reread_part (Jarod Wilson) [1182243]
- [block] nbd: convert to blkdev_reread_part() (Jarod Wilson) [1182243]
- [block] loop: fix another reread part failure (Jarod Wilson) [1182243]
- [block] loop: don't hold lo_ctl_mutex in lo_open (Jarod Wilson) [1182243]
- [block] replace trylock with mutex_lock in blkdev_reread_part() (Jarod Wilson) [1182243]
- [block] export blkdev_reread_part() and __blkdev_reread_part() (Jarod Wilson) [1182243]

* Mon Jun 08 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-262.el7]
- [drm] upstream sync to 4.0 (Rob Clark) [1195474]
- [drm] upstream sync to 3.19.0 (Rob Clark) [1195473]
- [drm] upstream sync to 3.18.0 (Rob Clark) [1195472]
- [drm] upstream sync to 3.17.0 (Rob Clark) [1195471]
- [drm] add drm_backport (Rob Clark) [1195471]
- [kernel] implement DIV_ROUND_CLOSEST_ULL (Rob Clark) [1195471]
- [mm] mmu_notifier: add call_srcu and sync function for listener to delay call and sync (Rob Clark) [1195471]
- [kernel] time: Export nsecs_to_jiffies() (Rob Clark) [1195471]
- [kernel] time: export nsec_to_jiffies64 (Rob Clark) [1195471]
- [acpi] pm: Export acpi_target_system_state() to modules (Rob Clark) [1195471]
- [base] component: fix bug with legacy API (Rob Clark) [1195471]
- [base] component: add support for component match array (Rob Clark) [1195471]
- [base] component: ignore multiple additions of the same component (Rob Clark) [1195471]
- [base] component: fix missed cleanup in case of devres failure (Rob Clark) [1195471]
- [base] fix devres handling for master device (Rob Clark) [1195471]
- [base] provide an infrastructure for componentised subsystems (Rob Clark) [1195471]
- [kernel] seqcount: backport __seqcount_init() (Rob Clark) [1195471]
- [drm] vgaswitcheroo: add vga_switcheroo_fini_domain_pm_ops (Rob Clark) [1195471]
- [netdrv] myri10ge: check for DMA mapping errors (Stanislaw Gruszka) [1120674]
- [cpufreq] powernv: Add pr_warn() on OPAL firmware failures (Steve Best) [1224148]
- [x86] perf: uncore: Move uncore_box_init() out of driver initialization (Jiri Olsa) [1220682]
- [input] elantech - fix semi-mt protocol for v3 HW (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - fix absolute mode setting on some ASUS laptops (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - add more Fujtisu notebooks to force crc_enabled (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - support new ICs types for version 4 (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - trust firmware about trackpoint presence (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - provide a sysfs knob for crc_enabled (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - report the middle button of the touchpad (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - fix crc_enabled for Fujitsu H730 (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - use elantech_report_trackpoint for hardware v4 too (Benjamin Tissoires) [1157840 1188234]
- [input] add missing POINTER / DIRECT properties to a bunch of drivers (Benjamin Tissoires) [1157840 1188234]
- [input] add INPUT_PROP_POINTING_STICK property (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - fix detection of touchpad on ASUS s301l (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - add support for trackpoint found on some v3 models (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - reset the device when elantech probe fails (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - don't set bit 1 of reg_10 when the no_hw_res quirk is set (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - deal with clickpads reporting right button events (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - fix touchpad initialization on Gigabyte U2442 (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - add support for newer elantech touchpads (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - improve clickpad detection (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - add support for newer (August 2013) devices (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - fix packet check for v3 and v4 hardware (Benjamin Tissoires) [1157840 1188234]
- [input] elantech - fix for newer hardware versions (v7) (Benjamin Tissoires) [1157840 1188234]
- [x86] kvm: zero kvmclock_offset when vcpu0 initializes kvmclock system MSR (Marcelo Tosatti) [1184155]
- [x86] kvmclock: set scheduler clock stable (Marcelo Tosatti) [1184155]
- [x86] kvmclock: add flag to indicate pvclock counts from zero (Marcelo Tosatti) [1184155]
- [pci] Expose pci_load_saved_state for public consumption (Myron Stowe) [1202603]
- [iommu] vt-d: Check return value of acpi_bus_get_device() (Myron Stowe) [1205900]
- [iommu] vt-d: Remove unused variable (Myron Stowe) [1225193]
- [iommu] vt-d: Detach domain *only* from attached iommus (Myron Stowe) [1225193]
- [iommu] core: Check for the right function pointer in iommu_map() (Myron Stowe) [1225193]
- [iommu] amd: Fix cleanup_domain for mass device removal (Myron Stowe) [1225193]
- [iommu] vt-d: Defer domain removal if device is assigned to a driver (Myron Stowe) [1225193]
- [iommu] powerpc/powernv: Fix IOMMU group lost (Myron Stowe) [1222546]
- [iommu] vt-d: Fix race setting IRQ CPU affinity while freeing IRQ (Myron Stowe) [1225193]
- [iommu] amd: Fix 2 typos in comments (Myron Stowe) [1225193]
- [iommu] amd: Fix device_state reference counting (Myron Stowe) [1225193]
- [iommu] amd: Remove change_pte mmu_notifier call-back (Myron Stowe) [1225193]
- [iommu] amd: Don't set pasid_state->mm to NULL in unbind_pasid (Myron Stowe) [1225193]
- [iommu] vt-d: Fix issue in computing domain's iommu_snooping flag (Myron Stowe) [1225193]
- [iommu] vt-d: Introduce helper function iova_size() to improve code readability (Myron Stowe) [1225193]
- [iommu] vt-d: Introduce helper domain_pfn_within_range() to simplify code (Myron Stowe) [1225193]
- [iommu] vt-d: Simplify intel_unmap_sg() and kill duplicated code (Myron Stowe) [1225193]
- [iommu] vt-d: Change iommu_enable/disable_translation to return void (Myron Stowe) [1225193]
- [iommu] vt-d: Simplify include/linux/dmar.h (Myron Stowe) [1225193]
- [iommu] vt-d: Avoid freeing virtual machine domain in free_dmar_iommu() (Myron Stowe) [1225193]
- [iommu] vt-d: Fix possible invalid memory access caused by free_dmar_iommu() (Myron Stowe) [1225193]
- [iommu] vt-d: Allocate dynamic domain id for virtual domains only (Myron Stowe) [1225193]
- [iommu] vt-d: Introduce helper functions to make code symmetric for readability (Myron Stowe) [1225193]
- [iommu] vt-d: Fix dmar_domain leak in iommu_attach_device (Myron Stowe) [1225193]
- [iommu] vt-d: Introduce helper functions to improve code readability (Myron Stowe) [1225193]
- [iommu] vt-d: Match segment number when searching for dev_iotlb capable devices (Myron Stowe) [1225193]
- [iommu] amd: Don't call the inv_ctx_cb when pasid is not set up (Myron Stowe) [1225193]
- [iommu] amd: Don't hold a reference to task_struct (Myron Stowe) [1225193]
- [iommu] amd: Don't hold a reference to mm_struct (Myron Stowe) [1225193]
- [iommu] amd: Add pasid_state->invalid flag (Myron Stowe) [1225193]
- [iommu] amd: Drop pasid_state reference in ppr_notifer error path (Myron Stowe) [1225193]
- [iommu] amd: Get rid of __unbind_pasid (Myron Stowe) [1225193]
- [iommu] amd: Don't free pasid_state in mn_release path (Myron Stowe) [1225193]
- [iommu] amd: Don't call mmu_notifer_unregister in __unbind_pasid (Myron Stowe) [1225193]
- [iommu] amd: Fix typo in amd_iommu_v2 driver (Myron Stowe) [1225193]
- [iommu] amd: Drop oprofile dependency (Myron Stowe) [1225193]
- [iommu] amd: Moving PPR fault flags macros definitions (Myron Stowe) [1225193]
- [iommu] amd: Fix for pasid initialization (Myron Stowe) [1225193]
- [iommu] vt-d: Remove the useless dma_pte_addr (Myron Stowe) [1225193]
- [iommu] vt-d: Don't use magic number in dma_pte_superpage (Myron Stowe) [1225193]
- [iommu] vt-d: Use inline function dma_pte_superpage instead of macros (Myron Stowe) [1225193]
- [iommu] vt-d: Clear the redundant assignment for domain->nid (Myron Stowe) [1225193]
- [iommu] vt-d: Clear the redundant assignment in dmar_enable_qi (Myron Stowe) [1225193]
- [iommu] vt-d: Use list_for_each_safe() to simplify code (Myron Stowe) [1225193]
- [iommu] amd: Fix small race between invalidate_range_end/start (Myron Stowe) [1225636]
- [iommu] amd: Fix recently introduced compile warnings (Myron Stowe) [1225636]
- [iommu] amd: Remove duplicate checking code (Myron Stowe) [1225636]
- [iommu] amd: Handle parallel invalidate_range_start/end calls correctly (Myron Stowe) [1225636]
- [iommu] amd: Remove IOMMUv2 pasid_state_list (Myron Stowe) [1225636]
- [iommu] amd: Implement mmu_notifier_release call-back (Myron Stowe) [1225636]
- [iommu] amd: Convert IOMMUv2 state_table into state_list (Myron Stowe) [1225636]
- [iommu] amd: Don't access IOMMUv2 state_table directly (Myron Stowe) [1225636]

* Fri Jun 05 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-261.el7]
- [block] nvme: Add translation for block limits (David Milburn) [1179447]
- [block] nvme: Fix error handling of class_create("nvme") (David Milburn) [1179447]
- [block] nvme: increase depth of admin queue (David Milburn) [1179447]
- [block] nvme: Fix PRP list calculation for non-4k system page size (David Milburn) [1179447]
- [block] nvme: Fix blk-mq hot cpu notification (David Milburn) [1179447]
- [block] nvme: embedded iod mask cleanup (David Milburn) [1179447]
- [block] nvme: Freeze admin queue on device failure (David Milburn) [1179447]
- [block] nvme: Initialize device list head before starting (David Milburn) [1179447]
- [block] nvme: Fix potential corruption on sync commands (David Milburn) [1179447]
- [block] nvme: Remove unused variables (David Milburn) [1179447]
- [block] nvme: Fix scsi mode select llbaa setting (David Milburn) [1179447]
- [block] nvme: Fix potential corruption during shutdown (David Milburn) [1179447]
- [block] nvme: Asynchronous controller probe (David Milburn) [1179447]
- [block] nvme: Register management handle under nvme class (David Milburn) [1179447]
- [block] nvme: Update SCSI Inquiry VPD 83h translation (David Milburn) [1179447]
- [block] nvme: avoid kmalloc/kfree for smaller IO (David Milburn) [1179447]
- [block] nvme: within nvme_free_queues(), delete RCU sychro/deferred free (David Milburn) [1179447]
- [block] nvme: cq_vector should be signed (David Milburn) [1179447]
- [block] nvme: Fix locking on abort handling (David Milburn) [1179447]
- [block] nvme: Start and stop h/w queues on reset (David Milburn) [1179447]
- [block] nvme: Command abort handling fixes (David Milburn) [1179447]
- [block] nvme: Admin queue removal handling (David Milburn) [1179447]
- [block] nvme: Reference count admin queue usage (David Milburn) [1179447]
- [block] nvme: Start all requests (David Milburn) [1179447]
- [block] nvme: Fix double free irq (David Milburn) [1179447]
- [block] nvme: fix race condition in nvme_submit_sync_cmd() (David Milburn) [1179447]
- [block] nvme: fix retry/error logic in nvme_queue_rq() (David Milburn) [1179447]
- [block] nvme: Fix FS mount issue (hot-remove followed by hot-add) (David Milburn) [1179447]
- [block] nvme: fix error return checking from blk_mq_alloc_request() (David Milburn) [1179447]
- [block] nvme: fix freeing of wrong request in abort path (David Milburn) [1179447]
- [block] nvme: Fix command setup on IO retry (David Milburn) [1179447]
- [block] nvme: Update module version major number (David Milburn) [1179447]
- [block] nvme: fail pci initialization if the device doesn't have any BARs (David Milburn) [1179447]
- [block] nvme: add ->exit_hctx() hook (David Milburn) [1179447]
- [block] nvme: make setup work for devices that don't do INTx (David Milburn) [1179447]
- [block] nvme: enable IO stats by default (David Milburn) [1179447]
- [block] nvme: nvme_submit_async_admin_req() must use atomic rq allocation (David Milburn) [1179447]
- [block] nvme: replace blk_put_request() with blk_mq_free_request() (David Milburn) [1179447]
- [block] nvme: __nvme_submit_admin_cmd() can be static (David Milburn) [1179447]
- [block] nvme: blk_mq_alloc_request() returns error pointers (David Milburn) [1179447]
- [block] nvme: Convert to blk-mq (David Milburn) [1179447]
- [block] nvme: Do not over allocate for discard requests (David Milburn) [1179447]
- [block] nvme: Do not open disks that are being deleted (David Milburn) [1179447]
- [block] nvme: Fix device probe waiting on kthread (David Milburn) [1179447]
- [block] nvme: Updates for 1.1 spec (David Milburn) [1179447]
- [block] nvme: Passthrough IOCTL for IO commands (David Milburn) [1179447]
- [block] nvme: Add revalidate_disk callback (David Milburn) [1179447]
- [block] nvme: Fix nvmeq waitqueue entry initialization (David Milburn) [1179447]
- [block] nvme: Translate NVMe status to errno (David Milburn) [1179447]
- [block] nvme: Fix SG_IO status values (David Milburn) [1179447]
- [block] nvme: Remove duplicate compat SG_IO code (David Milburn) [1179447]
- [block] nvme: Reference count pci device (David Milburn) [1179447]
- [block] nvme: Replace rcu_assign_pointer() with RCU_INIT_POINTER() (David Milburn) [1179447]
- [block] nvme: Correctly handle IOCTL_SUBMIT_IO when cpus > online queues (David Milburn) [1179447]
- [block] nvme: Fix filesystem sync deadlock on removal (David Milburn) [1179447]
- [block] nvme: Call nvme_free_queue directly (David Milburn) [1179447]
- [block] nvme: Add shutdown timeout as module parameter (David Milburn) [1179447]
- [block] nvme: Skip orderly shutdown on failed devices (David Milburn) [1179447]
- [block] nvme: Whitespace fixes (David Milburn) [1179447]
- [block] nvme: Use pci_stop_and_remove_bus_device_locked() (David Milburn) [1179447]
- [block] nvme: Handling devices incapable of I/O (David Milburn) [1179447]
- [block] nvme: Change nvme_enable_ctrl to set EN and manage CC thru ctrl_config (David Milburn) [1179447]
- [block] nvme: Mismatched host/device page size support (David Milburn) [1179447]
- [block] nvme: Update list of status codes (David Milburn) [1179447]
- [block] nvme: Async event request (David Milburn) [1179447]
- [s390] mm: implement software referenced bits (Hendrik Brueckner) [1182320]
- [s390] mm: cleanup page table definitions (Hendrik Brueckner) [1182320]
- [s390] mm: remove dead pfmf inline assembly (Hendrik Brueckner) [1182320]
- [s390] dasd: add support for control unit initiated reconfiguration (Hendrik Brueckner) [1182290]
- [s390] cio: fix multiple structure definitions (Hendrik Brueckner) [1182290]
- [s390] perf: make print_debug_cf() static (Hendrik Brueckner) [1182189]
- [s390] cpum_sf: fix printk format warnings (Hendrik Brueckner) [1182189]
- [s390] use IS_ENABLED to check if a CONFIG is set to y or m (Hendrik Brueckner) [1182189]
- [s390] perf: Add service level information for CPU-Measurement Facilities (Hendrik Brueckner) [1182189]
- [s390] delete new instances of __cpuinit usage (Hendrik Brueckner) [1182189]
- [s390] cpum_sf: Add flag to process full SDBs only (Hendrik Brueckner) [1182189]
- [s390] cpum_sf: Add raw data sampling to support the diagnostic-sampling function (Hendrik Brueckner) [1182189]
- [s390] cpum_sf: Filter perf events based event->attr.exclude_* settings (Hendrik Brueckner) [1182189]
- [s390] cpum_sf: Detect KVM guest samples (Hendrik Brueckner) [1182189]
- [s390] cpum_sf: Add helper to read TOD from trailer entries (Hendrik Brueckner) [1182189]
- [s390] cpum_sf: Dynamically extend the sampling buffer if overflows occur (Hendrik Brueckner) [1182189]
- [s390] perf, oprofile: Share sampling facility (Hendrik Brueckner) [1182189]
- [s390] perf: Improve PMU selection for PERF_COUNT_HW_CPU_CYCLES events (Hendrik Brueckner) [1182189]
- [s390] perf: add support for the CPU-Measurement Sampling Facility (Hendrik Brueckner) [1182189]
- [s390] irq: rework irq subclass handling (Hendrik Brueckner) [1182189]
- [s390] cpum_cf: Export event names in sysfs (Hendrik Brueckner) [1182189]
- [s390] oprofile: move hwsampler interfaces to cpu_mf.h (Hendrik Brueckner) [1182189]
- [s390] hwsampler: Updated misleading member names in hws_data_entry (Hendrik Brueckner) [1182189]
- [s390] perf: Remove print_hex_dump_bytes() debug output (Hendrik Brueckner) [1182189]
- [s390] hypfs: Eliminate hypfs interval (Hendrik Brueckner) [1182292]
- [s390] hypfs: Add diagnose 0c support (Hendrik Brueckner) [1182292]
- [s390] smp: reenable smt after resume (Hendrik Brueckner) [1182149]
- [s390] ftrace: fix crashes when switching tracers / add notrace to cpu_relax() (Hendrik Brueckner) [1182149]
- [s390] reintroduce diag 44 calls for cpu_relax() (Hendrik Brueckner) [1182149]
- [s390] remove diag 44 calls from cpu_relax() (Hendrik Brueckner) [1182149]
- [s390] add SMT support (Hendrik Brueckner) [1182149]
- [s390] process: free vx save area when releasing tasks (Hendrik Brueckner) [1102206]
- [s390] ptrace: always include vector registers in core files (Hendrik Brueckner) [1102206]
- [s390] simd: clear vector register pointer on fork/clone (Hendrik Brueckner) [1102206]
- [s390] fix ptrace of user area if the inferior uses vector registers (Hendrik Brueckner) [1102206]
- [s390] kdump: add support for vector extension (Hendrik Brueckner) [1102206]
- [s390] disassembler: add vector instructions (Hendrik Brueckner) [1102206]
- [s390] add support for vector extension (Hendrik Brueckner) [1102206]
- [s390] compat: correct ucontext layout for high gprs (Hendrik Brueckner) [1102206]
- [s390] uprobes: fix user space PER events (Hendrik Brueckner) [879647]
- [s390] uprobes: fix kprobes dependency (Hendrik Brueckner) [879647]
- [s390] uprobes: architecture backend for uprobes (Hendrik Brueckner) [879647]
- [s390] uprobes: common library for kprobes and uprobes (Hendrik Brueckner) [879647]
- [s390] ptrace: add struct psw and accessor function (Hendrik Brueckner) [879647]
- [s390] kprobes: allow kprobes only on known instructions (Hendrik Brueckner) [879647]
- [s390] dis: move disassembler function prototypes to proper header file (Hendrik Brueckner) [879647]
- [s390] kprobes: use insn_length helper function (Hendrik Brueckner) [879647]
- [s390] dis: move common definitions to a header file (Hendrik Brueckner) [879647]
- [s390] dis: rename structures for unique types (Hendrik Brueckner) [879647]
- [s390] mm: limit STACK_RND_MASK for compat tasks (Hendrik Brueckner) [1204860]
- [s390] mm: align 64-bit PIE binaries to 4GB (Hendrik Brueckner) [1204860]
- [s390] avoid z13 cache aliasing (Hendrik Brueckner) [1204860]
- [s390] add z13 code generation support (Hendrik Brueckner) [1204860]
- [s390] kernel: use stnsm 255 instead of stosm 0 (Hendrik Brueckner) [1204860]
- [s390] time: use stck clock fast for do_account_vtime (Hendrik Brueckner) [1204860]
- [s390] spinlock: optimize spin_unlock code (Hendrik Brueckner) [1204860]
- [s390] spinlock: refactor arch_spin_lock_wait[_flags] (Hendrik Brueckner) [1204860]
- [s390] rwlock: add missing local_irq_restore calls (Hendrik Brueckner) [1204860]
- [s390] spinlock, rwlock: always to a load-and-test first (Hendrik Brueckner) [1204860]
- [s390] spinlock: optimize spinlock code sequence (Hendrik Brueckner) [1204860]
- [s390] spinlock: cleanup spinlock code (Hendrik Brueckner) [1204860]
- [s390] enable ARCH_USE_CMPXCHG_LOCKREF (Hendrik Brueckner) [1204860]
- [s390] fix control register update (Hendrik Brueckner) [1204860]
- [s390] optimize control register update (Hendrik Brueckner) [1204860]
- [s390] smp: only send external call ipi if needed (Hendrik Brueckner) [1204860]
- [s390] ptrace: PTRACE_TE_ABORT_RAND (Hendrik Brueckner) [1204860]
- [s390] Remove zfcpdump NR_CPUS dependency (Hendrik Brueckner) [1204860]
- [s390] mm: do not initialize storage keys (Hendrik Brueckner) [1204860]
- [s390] zcrypt: Add support for new crypto express (CEX5S) adapter (Hendrik Brueckner) [1182171]
- [s390] zcrypt: Introduce new SHA-512 based Pseudo Random Generator (Hendrik Brueckner) [1182313]

* Fri Jun 05 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-260.el7]
- [netdrv] macvlan: fix a race on port dismantle and possible skb leaks (Herbert Xu) [971693]
- [netdrv] macvlan: optimize the receive path (Herbert Xu) [971693]
- [netdrv] macvlan: pass 'bool' type to macvlan_count_rx() (Herbert Xu) [971693]
- [netdrv] macvlan: allow to enqueue broadcast pkt on virtual device (Herbert Xu) [971693]
- [netdrv] macvlan: Fix leak and NULL dereference on error path (Herbert Xu) [971693]
- [netdrv] macvlan: Move broadcasts into a work queue (Herbert Xu) [971693]
- [net] core: Add __dev_forward_skb (Herbert Xu) [971693]
- [netdrv] macvlan: Remove custom recieve and forward handlers (Herbert Xu) [971693]
- [netdrv] macvtap: Add support of packet capture on macvtap device (Herbert Xu) [971693]
- [netdrv] macvtap: fix two races (Herbert Xu) [971693]
- [net] ipv4: Missing sk_nulls_node_init() in ping_unhash() (Denys Vlasenko) [1218105] {CVE-2015-3636}
- [net] ipv6: some ipv6 statistic counters failed to disable bh (Sabrina Dubroca) [1222129]
- [net] ipv6: move DAD and addrconf_verify processing to workqueue (Sabrina Dubroca) [1222129]
- [net] ipv6: remove old token ipv6 address as soon as possible (Sabrina Dubroca) [1222129]
- [net] ipv6: convert the uses of ADBG and remove the superfluous parentheses (Sabrina Dubroca) [1222129]
- [security] selinux/nlmsg: add RTM_DELNSID (Jiri Benc) [1210260]
- [net] netns: make nsid_lock per net (Jiri Benc) [1210260]
- [net] netns: fix unbalanced spin_lock on error (Jiri Benc) [1210260]
- [net] netns: return RTM_NEWNSID instead of RTM_GETNSID on a get (Jiri Benc) [1210260]
- [net] netlink: allow to listen "all" netns (Jiri Benc) [1210260]
- [net] netlink: rename private flags and states (Jiri Benc) [1210260]
- [net] netns: use a spin_lock to protect nsid management (Jiri Benc) [1210260]
- [net] netns: notify new nsid outside __peernet2id() (Jiri Benc) [1210260]
- [net] netns: rename peernet2id() to peernet2id_alloc() (Jiri Benc) [1210260]
- [net] netns: always provide the id to rtnl_net_fill() (Jiri Benc) [1210260]
- [net] netns: returns always an id in __peernet2id() (Jiri Benc) [1210260]
- [net] netns: remove duplicated include from net_namespace.c (Jiri Benc) [1210260]
- [net] netns: allow to dump netns ids (Jiri Benc) [1210260]
- [net] netns: notify netns id events (Jiri Benc) [1210260]
- [net] netns: minor cleanup in rtnl_net_getid() (Jiri Benc) [1210260]
- [net] netns: don't allocate an id for dead netns (Jiri Benc) [1210260]
- [net] veth: set iflink to the peer veth (Jiri Benc) [1210260]
- [net] dev: set iflink to 0 for virtual interfaces (Jiri Benc) [1210260]
- [infiniband] ipoib: Fix ndo_get_iflink (Jiri Benc) [1210260]
- [infiniband] ipoib: implement ndo_get_iflink (Jiri Benc) [1210260]
- [net] macvlan: implement ndo_get_iflink (Jiri Benc) [1210260]
- [net] vlan: implement ndo_get_iflink (Jiri Benc) [1210260]
- [net] ipmr,ip6mr: implement ndo_get_iflink (Jiri Benc) [1210260]
- [net] ipip, gre, vti, sit: implement ndo_get_iflink (Jiri Benc) [1210260]
- [net] sit: Fix ipip6_tunnel_lookup device matching criteria (Jiri Benc) [1210260]
- [net] ip6tnl, gre6, vti6: implement ndo_get_iflink (Jiri Benc) [1210260]
- [net] introduce dev_get_iflink() (Jiri Benc) [1210260]
- [net] Kill hold_net release_net (Jiri Benc) [1210260]
- [net] Handle unregister properly when netdev namespace change fails. (Jiri Benc) [1210260]
- [net] rtnetlink: call ->dellink on failure when ->newlink exists (Jiri Benc) [1210260]
- [net] do not use rcu in rtnl_dump_ifinfo() (Jiri Benc) [1210260]
- [net] Verify permission to link_net in newlink (Jiri Benc) [1210260]
- [net] Verify permission to dest_net in newlink (Jiri Benc) [1210260]
- [net] rtnetlink: pass link_net to the newlink handler (Jiri Benc) [1210260]
- [net] vxlan: setup the right link netns in newlink hdlr (Jiri Benc) [1210260]
- [net] vxlan: advertise link netns in fdb messages (Jiri Benc) [1210260]
- [net] vxlan: advertise netns of vxlan dev in fdb msg (Jiri Benc) [1210260]
- [net] veth: advertise link netns via netlink (Jiri Benc) [1210260]
- [net] macvlan: advertise link netns via netlink (Jiri Benc) [1210260]
- [net] macvlan: introduce macvlan_dev_real_dev() helper function (Jiri Benc) [1210260]
- [net] vlan: advertise link netns via netlink (Jiri Benc) [1210260]
- [net] ip6gretap: advertise link netns via netlink (Jiri Benc) [1210260]
- [net] rtnl: fix error path when adding an iface with a link net (Jiri Benc) [1210260]
- [net] rtnl: allow to create device with IFLA_LINK_NETNSID set (Jiri Benc) [1210260]
- [net] tunnels: advertise link netns via netlink (Jiri Benc) [1210260]
- [net] rtnl: add link netns id to interface messages (Jiri Benc) [1210260]
- [net] netns: add rtnl cmd to add and get peer netns ids (Jiri Benc) [1210260]
- [security] selinux/nlmsg: add RTM_NEWNSID and RTM_GETNSID (Jiri Benc) [1210260]
- [net] add a pre-check of net_ns in sk_change_net() (Jiri Benc) [1210260]
- [net] netns: remove one sparse warning (Jiri Benc) [1210260]
- [net] netlink: Fix do_one_broadcast() prototype. (Jiri Benc) [1210260]
- [net] net_namespace: trivial cleanup (Jiri Benc) [1210260]
- [net] dst: no need to take reference on DST_NOCACHE dsts (Marcelo Leitner) [1206570]
- [net] skbuff: Do not scrub skb mark within the same name space (Marcelo Leitner) [1206570]
- [net] ipv6: invert join/leave anycast rtnl/socket locking order (Marcelo Leitner) [1206570]
- [net] ipv6: restore the behavior of ipv6_sock_ac_drop() (Marcelo Leitner) [1206570]
- [net] ipv6: remove ipv6_sk_ac_lock (Marcelo Leitner) [1206570]
- [net] ipv6: drop useless rcu_read_lock() in anycast (Marcelo Leitner) [1206570]
- [net] vxlan: fix a free after use (Marcelo Leitner) [1206570]
- [net] vxlan: do not exit on error in vxlan_stop() (Marcelo Leitner) [1206570]
- [net] vxlan: fix indentation (Marcelo Leitner) [1206570]
- [net] vxlan: simplify if clause in dev_close (Marcelo Leitner) [1206570]
- [net] vxlan: fix possible use of uninitialized in vxlan_igmp_{join, leave} (Marcelo Leitner) [1206570]
- [net] vxlan: Move socket initialization to within rtnl scope (Marcelo Leitner) [1206570]
- [net] ipv4, ipv6: kill ip_mc_{join, leave}_group and ipv6_sock_mc_{join, drop} (Marcelo Leitner) [1206570]
- [net] ipv4, ipv6: grab rtnl before locking the socket (Marcelo Leitner) [1206570]
- [net] ip6_tunnel: fix error code when tunnel exists (Marcelo Leitner) [1206570]
- [net] vxlan: fix wrong usage of VXLAN_VID_MASK (Marcelo Leitner) [1206570]
- [net] vxlan: Correct path typo in comment (Marcelo Leitner) [1206570]
- [net] ipv6: igmp: add __ipv6_sock_mc_join and __ipv6_sock_mc_drop (Marcelo Leitner) [1206570]
- [net] ip6_tunnel: remove dead debug code from ip6_tunnel.c (Marcelo Leitner) [1206570]
- [net] igmp: add __ip_mc_{join|leave}_group() (Marcelo Leitner) [1206570]
- [net] igmp: fix the problem when mc leave group (Marcelo Leitner) [1206570]
- [net] gue: Use checksum partial with remote checksum offload (Marcelo Leitner) [1206570]
- [net] vxlan: Use checksum partial with remote checksum offload (Marcelo Leitner) [1206570]
- [net] Infrastructure for CHECKSUM_PARTIAL with remote checsum offload (Marcelo Leitner) [1206570]
- [net] Use more bit fields in napi_gro_cb (Marcelo Leitner) [1206570]
- [net] Clarify meaning of CHECKSUM_PARTIAL for receive path (Marcelo Leitner) [1206570]
- [net] gro: Fix remcsum in GRO path to not change packet (Marcelo Leitner) [1206570]
- [net] vxlan: Wrong type passed to pIS (Marcelo Leitner) [1206570]
- [net] vxlan: Only set has-GBP bit in header if any other bits would be set (Marcelo Leitner) [1206570]
- [net] add skb functions to process remote checksum offload (Marcelo Leitner) [1206570]
- [net] vxlan: Eliminate dependency on UDP socket in transmit path (Marcelo Leitner) [1206570]
- [net] udp: Do not require sock in udp_tunnel_xmit_skb (Marcelo Leitner) [1206570]
- [net] vxlan: Only bind to sockets with compatible flags enabled (Marcelo Leitner) [1206570]
- [net] vxlan: Group Policy extension (Marcelo Leitner) [1206570]
- [net] vxlan: Remote checksum offload (Marcelo Leitner) [1206570]
- [net] udp: pass udp_offload struct to UDP gro callbacks (Marcelo Leitner) [1206570]
- [net] vxlan: Improve support for header flags (Marcelo Leitner) [1206570]
- [net] ip: Move checksum convert defines to inet (Marcelo Leitner) [1206570]
- [net] Add Transparent Ethernet Bridging GRO support (Marcelo Leitner) [1206570]
- [net] vxlan: Fix double free of skb (Marcelo Leitner) [1206570]
- [net] ip_tunnel: Add missing validation of encap type to ip_tunnel_encap_setup() (Marcelo Leitner) [1206570]
- [net] ip_tunnel: Add sanity checks to ip_tunnel_encap_add_ops() (Marcelo Leitner) [1206570]
- [net] vxlan: Fix race condition between vxlan_sock_add and vxlan_sock_release (Marcelo Leitner) [1206570]
- [net] gue: Call remcsum_adjust (Marcelo Leitner) [1206570]
- [net] Add remcsum_adjust as common function for remote checksum offload (Marcelo Leitner) [1206570]
- [net] ip6_udp_tunnel: Fix checksum calculation (Marcelo Leitner) [1206570]
- [net] vxlan: Fix boolean flip in VXLAN_F_UDP_ZERO_CSUM6_[TX|RX] (Marcelo Leitner) [1206570]
- [net] vxlan: Inline vxlan_gso_check(). (Marcelo Leitner) [1206570]
- [net] vxlan: Add vxlan_gso_check() helper (Marcelo Leitner) [1206570]
- [net] fou: Fix no return statement warning for !CONFIG_NET_FOU_IP_TUNNELS (Marcelo Leitner) [1206570]
- [net] ip_tunnel: Ops registration for secondary encap (fou, gue) (Marcelo Leitner) [1206570]
- [net] udp_tunnel: Add SKB_GSO_UDP_TUNNEL during gro_complete (Marcelo Leitner) [1206570]
- [net] vxlan: Fix to enable UDP checksums on interface (Marcelo Leitner) [1206570]
- [net] ip6_tunnel: Add support for wildcard tunnel endpoints. (Marcelo Leitner) [1206570]
- [net] ip6_tunnel: Allow sending packets through tunnels with wildcard endpoints (Marcelo Leitner) [1206570]
- [net] gue: Receive side of remote checksum offload (Marcelo Leitner) [1206570]
- [net] gue: TX support for using remote checksum offload option (Marcelo Leitner) [1206570]
- [net] gso: fix kABI (Marcelo Leitner) [1206570]
- [net] udp: Changes to udp_offload to support remote checksum offload (Marcelo Leitner) [1206570]
- [net] gue: Protocol constants for remote checksum offload (Marcelo Leitner) [1206570]
- [net] gue: Add infrastructure for flags and options (Marcelo Leitner) [1206570]
- [net] udp: Offload outer UDP tunnel csum if available (Marcelo Leitner) [1206570]
- [net] fou: Move fou_build_header into fou.c and refactor (Marcelo Leitner) [1206570]
- [net] ip6_tunnel: Use ip6_tnl_dev_init as the ndo_init function. (Marcelo Leitner) [1206570]
- [net] ip6_tunnel: allow to change mode for the ip6tnl0 (Marcelo Leitner) [1206570]
- [net] fou: fix a potential use after free in fou.c (Marcelo Leitner) [1206570]
- [net] vxlan: using pskb_may_pull as early as possible (Marcelo Leitner) [1206570]
- [net] vxlan: fix a use after free in vxlan_encap_bypass (Marcelo Leitner) [1206570]
- [net] ip_tunnel: Add GUE support (Marcelo Leitner) [1206570]
- [net] gue: Receive side for Generic UDP Encapsulation (Marcelo Leitner) [1206570]
- [net] fou: eliminate IPv4, v6 specific GRO functions (Marcelo Leitner) [1206570]
- [net] ip_tunnel: Account for secondary encapsulation header in max_headroom (Marcelo Leitner) [1206570]
- [net] vxlan: Set inner protocol before transmit (Marcelo Leitner) [1206570]
- [net] gre: Set inner protocol in v4 and v6 GRE transmit (Marcelo Leitner) [1206570]
- [net] ipip: Set inner IP protocol in ipip (Marcelo Leitner) [1206570]
- [net] sit: Set inner IP protocol in sit (Marcelo Leitner) [1206570]
- [net] udp: Generalize skb_udp_segment (Marcelo Leitner) [1206570]
- [net] Remove gso_send_check as an offload callback (Marcelo Leitner) [1206570]
- [net] udp: move logic out of udp[46]_ufo_send_check (Marcelo Leitner) [1206570]
- [net] tcp: move logic out of tcp_v[64]_gso_send_check (Marcelo Leitner) [1206570]
- [net] vxlan: Fix bug introduced by commit acbf74a76300 (Marcelo Leitner) [1206570]
- [net] udp: Need to make ip6_udp_tunnel.c have GPL license (Marcelo Leitner) [1206570]
- [net] ip_tunnel: Changes to ip_tunnel to support foo-over-udp encapsulation (Marcelo Leitner) [1206570]
- [net] fou: Add GRO support (Marcelo Leitner) [1206570]
- [net] fou: Support for foo-over-udp RX path (Marcelo Leitner) [1206570]
- [net] Export inet_offloads and inet6_offloads (Marcelo Leitner) [1206570]
- [net] vxlan: Refactor vxlan driver to make use of the common UDP tunnel functions (Marcelo Leitner) [1206570]
- [net] udp_tunnel: Add a few more UDP tunnel APIs (Marcelo Leitner) [1206570]
- [net] udp_tunnel: Seperate ipv6 functions into its own file. (Marcelo Leitner) [1206570]
- [net] ipv6: drop some rcu_read_lock in mcast (Marcelo Leitner) [1206570]
- [net] ipv6: drop ipv6_sk_mc_lock in mcast (Marcelo Leitner) [1206570]
- [net] ipv4: udp4_gro_complete() is static (Marcelo Leitner) [1206570]
- [net] ipv6: fix rtnl locking in setsockopt for anycast and multicast (Marcelo Leitner) [1206570]
- [net] ip_tunnel: fix tunnels with "local any remote $remote_ip" (Marcelo Leitner) [1206570]
- [net] neighbour: fix ndm_type type error issue (Marcelo Leitner) [1206570]
- [net] vxlan: Call udp_sock_create (Marcelo Leitner) [1206570]
- [net] udp: Add udp_sock_create for UDP tunnels to open listener socket (Marcelo Leitner) [1206570]
- [net] udp: Move udp_tunnel_segment into udp_offload.c (Marcelo Leitner) [1206570]
- [net] ip_tunnel: fix ip_tunnel_lookup (Marcelo Leitner) [1206570]
- [net] ip_tunnel: fix dst race in sk_dst_get() (Marcelo Leitner) [1206570]
- [net] vxlan: use dev->needed_headroom instead of dev->hard_header_len (Marcelo Leitner) [1206570]
- [net] ip_vti: Fix 'ip tunnel add' with 'key' parameters (Marcelo Leitner) [1206570]
- [net] bridge: Add bridge ifindex to bridge fdb notify msgs (Marcelo Leitner) [1206570]
- [net] ip_tunnel: Initialize the fallback device properly (Marcelo Leitner) [1206570]
- [net] ip_tunnel: ip_tunnels: disable cache for nbma gre tunnels (Marcelo Leitner) [1206570]
- [net] vxlan, bridge: get rid of SET_ETHTOOL_OPS (Marcelo Leitner) [1206570]
- [net] vxlan: add x-netns support (Marcelo Leitner) [1206570]
- [net] vxlan: ensure to advertise the right fdb remote (Marcelo Leitner) [1206570]
- [net] ip_tunnel: use the right netns in ioctl handler (Marcelo Leitner) [1206570]
- [net] ip6_tunnel: use the right netns in ioctl handler (Marcelo Leitner) [1206570]
- [net] sit: fix panic with route cache in ip tunnels (Marcelo Leitner) [1206570]
- [net] ip_tunnel: Move ip_tunnel_get_stats64 into ip_tunnel_core.c (Marcelo Leitner) [1206570]
- [net] ip6_gre: use netdev_alloc_pcpu_stats() (Marcelo Leitner) [1206570]
- [net] introduce netdev_alloc_pcpu_stats() for drivers (Marcelo Leitner) [1206570]
- [net] unify the pcpu_tstats and br_cpu_netstats as one (Marcelo Leitner) [1206570]
- [net] ip_tunnel: fix panic in ip_tunnel_xmit() (Marcelo Leitner) [1206570]
- [net] ip_tunnel: remove the useless argument from ip_tunnel_hash() (Marcelo Leitner) [1206570]
- [net] vxlan: add vxlan description (Marcelo Leitner) [1206570]
- [net] ip_tunnel: fix a dst leak in tunnels (Marcelo Leitner) [1206570]
- [net] ip_tunnel: fix sparse non static symbol warning (Marcelo Leitner) [1206570]
- [net] ip_tunnel: Use percpu Cache route in IP tunnels (Marcelo Leitner) [1206570]
- [net] ip_tunnel: Cache dst in tunnels (Marcelo Leitner) [1206570]
- [net] ipv6: fix the use of pcpu_tstats in ip6_tunnel (Marcelo Leitner) [1206570]
- [net] vxlan: leave multicast group when vxlan device down (Marcelo Leitner) [1206570]
- [net] ipv6: move IPV6_TCLASS_MASK definition in ipv6.h (Marcelo Leitner) [1206570]
- [net] ipv6: add ip6_flowlabel helper (Marcelo Leitner) [1206570]
- [net] do not ignore dmac in dev_forward_skb() (Marcelo Leitner) [1206570]
- [net] Explicitly initialize u64_stats_sync structures for lockdep (Marcelo Leitner) [1206570]
- [net] ipv6: Allow the MTU of ipip6 tunnel to be set below 1280 (Marcelo Leitner) [1206570]
- [net] tunnels: harmonize cleanup done on skb on rx path (Marcelo Leitner) [1206570]
- [net] tunnels: harmonize cleanup done on skb on xmit path (Marcelo Leitner) [1206570]
- [net] vxlan: remove net arg from vxlan[6]_xmit_skb() (Marcelo Leitner) [1206570]
- [net] vxlan: Convert uses of compare_ether_addr to ether_addr_equal (Marcelo Leitner) [1206570]
- [net] ip6_tunnel: ensure to always have a link local address (Marcelo Leitner) [1206570]
- [net] vxlan: using kfree_rcu() to simplify the code (Marcelo Leitner) [1206570]
- [net] ip_tunnel: use net_eq() helper to check netns (Marcelo Leitner) [1206570]
- [net] move skb_scrub_packet() after eth_type_trans() (Marcelo Leitner) [1206570]
- [net] ipv6: fix ipv6_cow_metrics for non DST_HOST case (Marcelo Leitner) [1199862]
- [netdrv] pppoe: drop pppoe device in pppoe_unbind_sock_work (Beniamino Galvani) [1221922]
- [net] udp_diag: Fix socket skipping within chain (Thadeu Lima de Souza Cascardo) [1179617]
- [net] ptp: use the 64 bit get/set time methods for the posix clock (Jiri Benc) [1217408]
- [net] ptp: use the 64 bit gettime method for the SYS_OFFSET ioctl (Jiri Benc) [1217408]
- [net] ptp: introduce get/set time methods with explicit 64 bit seconds (Jiri Benc) [1217408]
- [kernel] timekeeping: Provide timespec64 based interfaces (Jiri Benc) [1217408]
- [kernel] timekeeping: Convert timekeeping core to use timespec64s (Jiri Benc) [1217408]
- [net] tcp: mitigate ACK loops for connections as tcp_timewait_sock (Florian Westphal) [1191261]
- [net] tcp: mitigate ACK loops for connections as tcp_sock (Florian Westphal) [1191261]
- [net] tcp: mitigate ACK loops for connections as tcp_request_sock (Florian Westphal) [1191261]
- [net] tcp: helpers to mitigate ACK loops by rate-limiting out-of-window dupacks (Florian Westphal) [1191261]
- [net] ipv6: Don't reduce hop limit for an interface (Denys Vlasenko) [1208496] {CVE-2015-2922}
- [x86] mm: Clean up the TLB flushing code (Larry Woodman) [1172891]
- [powerpc] Add a test of the switch_endian() syscall (Gustavo Duarte) [1221073]
- [powerpc] Add a proper syscall for switching endianness (Gustavo Duarte) [1221073]
- [powerpc] kernel: Make syscall_exit a local label (Gustavo Duarte) [1221073]
- [powerpc] Remove old compile time disabled syscall tracing code (Gustavo Duarte) [1221073]
- [scsi] libsas: Fix Kernel Crash in smp_execute_task (David Milburn) [1226041]
- [scsi] mvsas: fix panic on expander attached SATA devices (David Milburn) [1226041]
- [scsi] mvsas: Fix for possible null pointer dereference (David Milburn) [1226041]
- [netdrv] hyperv: Add IPv6 into the hash computation for vRSS (Jason Wang) [1174846]
- [x86] use optimized ioresource lookup in ioremap function (Frank Ramsay) [1217221]
- [kernel] optimize resource lookups for ioremap (Frank Ramsay) [1217221]
- [x86] ioremap: Speed up check for RAM pages (Frank Ramsay) [1217221]
- [fs] exec: take i_mutex during prepare_binprm for set[ug]id executables (Mateusz Guzik) [1216270] {CVE-2015-3339}
- [kernel] locking: Remove atomicy checks from {READ, WRITE}_ONCE (Mateusz Guzik) [1216270] {CVE-2015-3339}
- [kernel] make READ_ONCE() valid on const arguments (Mateusz Guzik) [1216270] {CVE-2015-3339}
- [kernel] Change ASSIGN_ONCE(val, x) to WRITE_ONCE(x, val) (Mateusz Guzik) [1216270] {CVE-2015-3339}
- [kernel] Provide READ_ONCE and ASSIGN_ONCE (Mateusz Guzik) [1216270] {CVE-2015-3339}
- [powerpc] powernv: Add OPAL check token call (Gustavo Duarte) [1223784]
- [powerpc] pseries: Correct cpu affinity for dlpar added cpus (Steve Best) [1226527]
- [thermal] intel_powerclamp: add id for Avoton SoC (Steve Best) [1225606]
- [platform] hp-wireless: new driver for hp wireless button for Windows 8 (Stanislaw Gruszka) [1174328]
- [include] pci-dma-compat: add pci_zalloc_consistent helper (Maurizio Lombardi) [1193494]
- [powerpc] kvm: book3s-hv: ptes are big endian (Thomas Huth) [1222472]

* Wed Jun 03 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-259.el7]
- [scsi] qla4xxx: v5.04.00.00.07.02-k0 (Chad Dupuis) [1225437]
- [scsi] qla4xxx: fix get_host_stats error propagation (Chad Dupuis) [1225437]
- [scsi] qla4xxx: check the return value of dma_alloc_coherent() (Chad Dupuis) [1225437]
- [scsi] qla4xxx: ql4_mbx.c: Cleaning up missing null-terminate in conjunction with strncpy (Chad Dupuis) [1225437]
- [scsi] qla4xxx: ql4_os.c: Cleaning up missing null-terminate in conjunction with strncpy (Chad Dupuis) [1225437]
- [net] bnx2-cnic: Driver Version Update (Maurizio Lombardi) [1187299]
- [net] bnx2-cnic: Driver Rebranding Changes (Maurizio Lombardi) [1187299]
- [net] cnic: Update the rcu_access_pointer() usages (Maurizio Lombardi) [1187299]
- [net] cnic: Cleanup CONFIG_IPV6 & VLAN check (Maurizio Lombardi) [1187299]
- [scsi] aacraid: driver version change (Rajinikanth Pandurangan) [1205339]
- [scsi] aacraid: AIF raw device remove support (Rajinikanth Pandurangan) [1205339]
- [scsi] aacraid: performance improvement changes (Rajinikanth Pandurangan) [1205339]
- [scsi] aacraid: IOCTL fix (Rajinikanth Pandurangan) [1205339]
- [scsi] aacraid: IOP RESET command handling changes (Rajinikanth Pandurangan) [1205339]
- [scsi] aacraid: 240 simple volume support (Rajinikanth Pandurangan) [1205339]
- [scsi] aacraid: vpd page code 0x83 support (Rajinikanth Pandurangan) [1205339]
- [scsi] aacraid: MSI-x support (Rajinikanth Pandurangan) [1205339]
- [scsi] aacraid: 4KB sector support (Rajinikanth Pandurangan) [1205339]
- [scsi] aacraid: IOCTL pass-through command fix (Rajinikanth Pandurangan) [1205339]
- [scsi] aacraid: AIF support for SES device add/remove (Rajinikanth Pandurangan) [1205339]
- [scsi] aacraid: remove deprecated IRQF_DISABLED from aacraid (Rajinikanth Pandurangan) [1205339]
- [scsi] hpsa: Cleanup pci_id entries (Joseph Szczypek) [1181313]
- [scsi] hpsa: Update driver revision to 3.4.4-1-RH4 (Joseph Szczypek) [1181313]
- [scsi] hpsa: correct compiler warnings introduced by hpsa-add-local-workqueue patch (Joseph Szczypek) [1181313]
- [scsi] hpsa: Use local workqueues instead of system workqueues (Joseph Szczypek) [1181313]
- [scsi] hpsa: detect and report failures changing controller transport modes (Joseph Szczypek) [1181313]
- [scsi] hpsa: shorten the wait for the CISS doorbell mode change ack (Joseph Szczypek) [1181313]
- [scsi] hpsa: refactor duplicated scan completion code into a new routine (Joseph Szczypek) [1181313]
- [scsi] hpsa: move SG descriptor set-up out of hpsa_scatter_gather() (Joseph Szczypek) [1181313]
- [scsi] hpsa: do not use function pointers in fast path command submission (Joseph Szczypek) [1181313]
- [scsi] hpsa: print CDBs instead of kernel virtual addresses for uncommon errors (Joseph Szczypek) [1181313]
- [scsi] hpsa: do not use a void pointer for scsi_cmd field of struct CommandList (Joseph Szczypek) [1181313]
- [scsi] hpsa: return failed from device reset/abort handlers (Joseph Szczypek) [1181313]
- [scsi] hpsa: check for ctlr lockup after command allocation in main io path (Joseph Szczypek) [1181313]
- [scsi] hpsa: guard against overflowing raid map array (Joseph Szczypek) [1181313]
- [scsi] hpsa: do not ack controller events on controllers that do not support it (Joseph Szczypek) [1181313]
- [scsi] hpsa: remove incorrect BUG_ONs checking for raid offload enable (Joseph Szczypek) [1181313]
- [scsi] hpsa: do not check for msi(x) in interrupt_pending (Joseph Szczypek) [1181313]
- [scsi] hpsa: slightly optimize SA5_performant_completed (Joseph Szczypek) [1181313]
- [scsi] hpsa: count passthru cmds with atomics, not a spin locked int (Joseph Szczypek) [1181313]
- [scsi] hpsa: optimize cmd_alloc function by remembering last allocation (Joseph Szczypek) [1181313]
- [scsi] hpsa: fix race between abort handler and main i/o path (Joseph Szczypek) [1181313]
- [scsi] hpsa: honor queue depth of physical devices (Joseph Szczypek) [1181313]
- [scsi] hpsa: use workqueue to resubmit failed ioaccel commands (Joseph Szczypek) [1181313]
- [scsi] hpsa: factor out hpsa_ciss_submit function (Joseph Szczypek) [1181313]
- [scsi] hpsa: do not request device rescan on every ioaccel path error (Joseph Szczypek) [1181313]
- [scsi] hpsa: do not queue commands internally in driver (Joseph Szczypek) [1181313]
- [scsi] hpsa: get rid of cmd_special_alloc and cmd_special_free (Joseph Szczypek) [1181313]
- [scsi] hpsa: reserve some commands for use by driver (Joseph Szczypek) [1181313]
- [scsi] hpsa: avoid unneccesary calls to resource freeing functions (Joseph Szczypek) [1181313]
- [scsi] hpsa: fix memory leak in hpsa_alloc_cmd_pool (Joseph Szczypek) [1181313]
- [scsi] hpsa: report allocation failures while allocating SG chain blocks (Joseph Szczypek) [1181313]
- [scsi] hpsa: pass error from pci_set_consistent_dma_mask from hpsa_message (Joseph Szczypek) [1181313]
- [scsi] hpsa: rename hpsa_request_irq to hpsa_request_irqs (Joseph Szczypek) [1181313]
- [scsi] hpsa: report failure to ioremap config table (Joseph Szczypek) [1181313]
- [scsi] hpsa: trivial message and comment clean ups (Joseph Szczypek) [1181313]
- [scsi] hpsa: refactor hpsa_find_board_params() to encapsulate legacy test (Joseph Szczypek) [1181313]
- [scsi] hpsa: downgrade the Waiting for no-op print to dev_info (Joseph Szczypek) [1181313]
- [scsi] hpsa: propagate return value from board ID lookup (Joseph Szczypek) [1181313]
- [scsi] hpsa: propagate hard_reset failures in reset_devices mode (Joseph Szczypek) [1181313]
- [scsi] hpsa: remove 0x from queue depth print which is in decimal (Joseph Szczypek) [1181313]
- [scsi] hpsa: notice all request_irq errors (Joseph Szczypek) [1181313]
- [scsi] hpsa: Fix -Wunused-but-set-variable warning (Joseph Szczypek) [1181313]
- [scsi] hpsa: rename free_irqs to hpsa_free_irqs (Joseph Szczypek) [1181313]
- [scsi] hpsa: adjust RAID-1, RAID-1ADM, and RAID-6 names (Joseph Szczypek) [1181313]
- [scsi] hpsa: change how SA controllers are reset (Joseph Szczypek) [1181313]
- [scsi] hpsa: turn off interrupts when kdump starts (Joseph Szczypek) [1181313]
- [scsi] hpsa: fix memory leak in kdump hard reset (Joseph Szczypek) [1181313]
- [scsi] hpsa: correct endian sparse warnings (Joseph Szczypek) [1181313]
- [scsi] hpsa: remove spin lock around command allocation (Joseph Szczypek) [1181313]
- [scsi] hpsa: always call pci_set_master after pci_enable_device (Joseph Szczypek) [1181313]
- [scsi] hpsa: Convert SCSI LLD ->queuecommand() for host_lock less operation (Joseph Szczypek) [1181313]
- [scsi] hpsa: do not be so noisy about check conditions (Joseph Szczypek) [1181313]
- [scsi] hpsa: use atomics for commands_outstanding (Joseph Szczypek) [1181313]
- [scsi] hpsa: get rid of type/attribute/direction bit field where possible (Joseph Szczypek) [1181313]
- [scsi] hpsa: fix endianness issue with scatter gather elements (Joseph Szczypek) [1181313]
- [scsi] hpsa: fix allocation sizes for CISS_REPORT_LUNs commands (Joseph Szczypek) [1181313]
- [scsi] hpsa: remove 'action required' phrasing (Joseph Szczypek) [1181313]
- [scsi] hpsa: correct off-by-one sizing of chained SG block (Joseph Szczypek) [1181313]
- [scsi] hpsa: fix a couple pci id table mistakes (Joseph Szczypek) [1181313]
- [scsi] hpsa: remove dev_warn prints from RAID-1ADM (Joseph Szczypek) [1181313]
- [scsi] hpsa: Clean up warnings from sparse (Joseph Szczypek) [1181313]
- [scsi] maintainers: change hpsa and cciss maintainer (Joseph Szczypek) [1181313]
- [scsi] hpsa: add missing pci_set_master in kdump path (Joseph Szczypek) [1181313]
- [scsi] hpsa: refine the pci enable/disable handling (Joseph Szczypek) [1181313]
- [scsi] hpsa: Use pci_enable_msix_range() instead of pci_enable_msix() (Joseph Szczypek) [1181313]
- [scsi] hpsa: Fallback to MSI rather than to INTx if MSI-X failed (Joseph Szczypek) [1181313]

* Mon Jun 01 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-258.el7]
- [kvm] avoid page allocation failure in kvm_set_memory_region() (Bandan Das) [1209995]
- [kvm] x86: call irq notifiers with directed EOI (Bandan Das) [1209995]
- [kvm] nvmx: mask unrestricted_guest if disabled on L0 (Bandan Das) [1209995]
- [kvm] svm: fix interrupt injection (apic->isr_count always 0) (Bandan Das) [1209995]
- [kvm] emulate: fix CMPXCHG8B on 32-bit hosts (Bandan Das) [1209995]
- [kvm] add halt_poll_ns module parameter (Bandan Das) [1198205 1209995]
- [kvm] x86: revert "add method to test PIR bitmap vector" (Bandan Das) [1209995]
- [kvm] vmx: Add PML support in VMX (Bandan Das) [1209995]
- [kvm] x86: Add new dirty logging kvm_x86_ops for PML (Bandan Das) [1209995]
- [kvm] x86: Change parameter of kvm_mmu_slot_remove_write_access (Bandan Das) [1209995]
- [kvm] mmu: Explicitly set D-bit for writable spte (Bandan Das) [1209995]
- [kvm] mmu: Add mmu help functions to support PML (Bandan Das) [1209995]
- [kvm] Rename kvm_arch_mmu_write_protect_pt_masked to be more generic for log dirty (Bandan Das) [1209995]
- [kvm] update_memslots: clean flags for invalid memslots (Bandan Das) [1209995]
- [kvm] Remove unused config symbol (Bandan Das) [1209995]
- [kvm] fix "Should it be static?" warnings from sparse (Bandan Das) [1209995]
- [kvm] Optimize TLB flush in kvm_mmu_slot_remove_write_access (Bandan Das) [1209995]
- [kvm] x86: kvm: vmx: Remove some unused functions (Bandan Das) [1209995]
- [kvm] x86: switch to kvm_get_dirty_log_protect (Bandan Das) [1209995]
- [kvm] Add generic support for dirty page logging (Bandan Das) [1209995]
- [kvm] Add architecture-defined TLB flush support (Bandan Das) [1209995]
- [kvm] x86: flush TLB when D bit is manually changed (Bandan Das) [1209995]
- [kvm] x86: allow TSC deadline timer on all hosts (Bandan Das) [1209995]
- [kvm] x86: mmu: replace assertions with MMU_WARN_ON, a conditional WARN_ON (Bandan Das) [1209995]
- [kvm] x86: mmu: remove ASSERT(vcpu) (Bandan Das) [1209995]
- [kvm] x86: mmu: remove argument to kvm_init_shadow_mmu and kvm_init_shadow_ept_mmu (Bandan Das) [1209995]
- [kvm] x86: mmu: do not use return to tail-call functions that return void (Bandan Das) [1209995]
- [kvm] x86: add method to test PIR bitmap vector (Bandan Das) [1209995]
- [kvm] x86: vmx: NULL out hwapic_isr_update() in case of !enable_apicv (Bandan Das) [1209995]
- [kvm] x86: Remove FIXMEs in emulate.c for the function, task_switch_32 (Bandan Das) [1209995]
- [kvm] nvmx: consult PFEC_MASK and PFEC_MATCH when generating #PF VM-exit (Bandan Das) [1209995]
- [kvm] nvmx: Improve nested msr switch checking (Bandan Das) [1209995]
- [kvm] nvmx: Add nested msr load/restore algorithm (Bandan Das) [1209995]
- [kvm] x86: check LAPIC presence when building apic_map (Bandan Das) [1209995]
- [kvm] x86: Fix of previously incomplete fix for CVE-2014-8480 (Bandan Das) [1209995]
- [kvm] warn on more invariant breakage (Bandan Das) [1209995]
- [kvm] fix sorting of memslots with base_gfn == 0 (Bandan Das) [1209995]
- [kvm] x86: drop severity of "generation wraparound" message (Bandan Das) [1209995]
- [kvm] x86: vmx: reorder some msr writing (Bandan Das) [1209995]
- [kvm] move APIC types to arch/x86/ (Bandan Das) [1209995]
- [kvm] x86: em_ret_far overrides cpl (Bandan Das) [1152997 1209995] {CVE-2014-3647}
- [kvm] nvmx: Disable unrestricted mode if ept=0 (Bandan Das) [1209995]
- [kvm] x86: Emulate should check #UD before #GP (Bandan Das) [1209995]
- [kvm] x86: Do not push eflags.vm on pushf (Bandan Das) [1209995]
- [kvm] x86: Remove prefix flag when GP macro is used (Bandan Das) [1209995]
- [kvm] cpuid: recompute CPUID 0xD.0:EBX,ECX (Bandan Das) [1209995]
- [kvm] cpuid: mask more bits in leaf 0xd and subleaves (Bandan Das) [1209995]
- [kvm] cpuid: set CPUID(EAX=0xd, ECX=1).EBX correctly (Bandan Das) [1209995]
- [kvm] x86: use F() macro throughout cpuid.c (Bandan Das) [1209995]
- [kvm] track pid for VCPU only on KVM_RUN ioctl (Bandan Das) [1209995]
- [kvm] don't check for PF_VCPU when yielding (Bandan Das) [1209995]
- [kvm] optimize GFN to memslot lookup with large slots amount (Bandan Das) [1209995]
- [kvm] change memslot sorting rule from size to GFN (Bandan Das) [1209995]
- [kvm] search_memslots: add simple LRU memslot caching (Bandan Das) [1209995]
- [kvm] update_memslots: drop not needed check for the same slot (Bandan Das) [1209995]
- [kvm] update_memslots: drop not needed check for the same number of pages (Bandan Das) [1209995]
- [kvm] x86: allow 256 logical x2APICs again (Bandan Das) [1209995]
- [kvm] x86: check bounds of APIC maps (Bandan Das) [1209995]
- [kvm] x86: fix APIC physical destination wrapping (Bandan Das) [1209995]
- [kvm] x86: deliver phys lowest-prio (Bandan Das) [1209995]
- [kvm] x86: don't retry hopeless APIC delivery (Bandan Das) [1209995]
- [kvm] x86: use MSR_ICR instead of a number (Bandan Das) [1209995]
- [kvm] x86: Fix reserved x2apic registers (Bandan Das) [1209995]
- [kvm] x86: Generate #UD when memory operand is required (Bandan Das) [1209995]
- [kvm] add a memslot flag for incoherent memory regions (Bandan Das) [1209995]
- [kvm] fix kvm_is_mmio_pfn() and rename to kvm_is_reserved_pfn() (Bandan Das) [1209995]
- [kvm] x86: avoid warning about potential shift wrapping bug (Bandan Das) [1209995]
- [kvm] x86: move device assignment out of kvm_host.h (Bandan Das) [1209995]
- [kvm] x86: mask out XSAVES (Bandan Das) [1209995]
- [kvm] x86/xsaves: Detect xsaves/xrstors feature (Bandan Das) [1209995]
- [kvm] x86: move assigned-dev.c and iommu.c to arch/x86/ (Bandan Das) [1209995]
- [kvm] remove IA64 ioctls (Bandan Das) [1209995]
- [kvm] remove CONFIG_X86 #ifdefs from files formerly shared with ia64 (Bandan Das) [1209995]
- [kvm] x86: move ioapic.c and irq_comm.c back to arch/x86/ (Bandan Das) [1209995]
- [kvm] documentation: remove ia64 (Bandan Das) [1209995]
- [kvm] ia64: remove (Bandan Das) [1209995]
- [kvm] x86/kvm/tracing: Use helper function trace_seq_buffer_ptr() (Bandan Das) [1209995]
- [kvm] x86: Remove FIXMEs in emulate.c (Bandan Das) [1209995]
- [kvm] emulator: remove duplicated limit check (Bandan Das) [1209995]
- [kvm] emulator: remove code duplication in register_address{, _increment} (Bandan Das) [1209995]
- [kvm] x86: Move __linearize masking of la into switch (Bandan Das) [1209995]
- [kvm] x86: Non-canonical access using SS should cause #SS (Bandan Das) [1209995]
- [kvm] x86: Perform limit checks when assigning EIP (Bandan Das) [1209995]
- [kvm] x86: Emulator performs privilege checks on __linearize (Bandan Das) [1209995]
- [kvm] x86: Stack size is overridden by __linearize (Bandan Das) [1209995]
- [kvm] x86: Revert NoBigReal patch in the emulator (Bandan Das) [1209995]
- [kvm] x86: vmx: remove MMIO_MAX_GEN (Bandan Das) [1209995]
- [kvm] x86: vmx: cleanup handle_ept_violation (Bandan Das) [1209995]
- [kvm] x86: Fix lost interrupt on irr_pending race (Bandan Das) [1209995]
- [kvm] compute correct map even if all APICs are software disabled (Bandan Das) [1209995]
- [kvm] x86: Software disabled APIC should still deliver NMIs (Bandan Das) [1209995]
- [kvm] simplify update_memslots invocation (Bandan Das) [1209995]
- [kvm] commonize allocation of the new memory slots (Bandan Das) [1209995]
- [kvm] memslots: track id_to_index changes during the insertion sort (Bandan Das) [1209995]
- [kvm] memslots: replace heap sort with an insertion sort pass (Bandan Das) [1209995]
- [kvm] svm: move WARN_ON in svm_adjust_tsc_offset (Bandan Das) [1209995]
- [kvm] x86, kvm, vmx: Don't set LOAD_IA32_EFER when host and guest match (Bandan Das) [1209995]
- [kvm] x86, kvm, vmx: Always use LOAD_IA32_EFER if available (Bandan Das) [1209995]
- [kvm] x86: fix warning on 32-bit compilation (Bandan Das) [1209995]
- [kvm] x86: add trace event for pvclock updates (Bandan Das) [1209995]
- [kvm] x86: Fix kvm clock versioning (Bandan Das) [1209995]
- [kvm] x86: MOVNTI emulation min opsize is not respected (Bandan Das) [1209995]
- [kvm] x86: Return UNHANDLABLE on unsupported SYSENTER (Bandan Das) [1209995]
- [kvm] x86: Warn on APIC base relocation (Bandan Das) [1209995]
- [kvm] x86: Emulator mis-decodes VEX instructions on real-mode (Bandan Das) [1209995]
- [kvm] x86: Remove redundant and incorrect cpl check on task-switch (Bandan Das) [1209995]
- [kvm] x86: Inject #GP when loading system segments with non-canonical base (Bandan Das) [1209995]
- [kvm] x86: Combine the lgdt and lidt emulation logic (Bandan Das) [1209995]
- [kvm] x86: Do not update EFLAGS on faulting emulation (Bandan Das) [1209995]
- [kvm] x86: MOV to CR3 can set bit 63 (Bandan Das) [1209995]
- [kvm] x86: Emulate push sreg as done in Core (Bandan Das) [1209995]
- [kvm] x86: Wrong flags on CMPS and SCAS emulation (Bandan Das) [1209995]
- [kvm] x86: SYSCALL cannot clear eflags[1] (Bandan Das) [1209995]
- [kvm] x86: Emulation of MOV-sreg to memory uses incorrect size (Bandan Das) [1209995]
- [kvm] x86: Breakpoints do not consider CS.base (Bandan Das) [1209995]
- [kvm] x86: Clear DR6[0:3] on #DB during handle_dr (Bandan Das) [1209995]
- [kvm] x86: Emulator should set DR6 upon GD like real CPU (Bandan Das) [1209995]
- [kvm] x86: No error-code on real-mode exceptions (Bandan Das) [1209995]
- [kvm] x86: decode_modrm does not regard modrm correctly (Bandan Das) [1209995]
- [kvm] x86: reset RVI upon system reset (Bandan Das) [1209995]
- [kvm] x86: vmx: avoid returning bool to distinguish success from error (Bandan Das) [1209995]
- [kvm] x86: vmx: move some vmx setting from vmx_init() to hardware_setup() (Bandan Das) [1209995]
- [kvm] x86: vmx: move down hardware_setup() and hardware_unsetup() (Bandan Das) [1209995]
- [kvm] x86: Fix uninitialized op->type for some immediate values (Bandan Das) [1209995]
- [kvm] x86: optimize some accesses to LVTT and SPIV (Bandan Das) [1209995]
- [kvm] trivial fix comment regarding __kvm_set_memory_region (Bandan Das) [1209995]
- [kvm] x86: Enable Intel AVX-512 for guest (Bandan Das) [1178982 1209995]
- [kvm] drop unsupported capabilities, fix documentation (Bandan Das) [1209995]
- [kvm] x86: fix deadline tsc interrupt injection (Bandan Das) [1179067 1209995]
- [kvm] x86: add apic_timer_expired() (Bandan Das) [1209995]
- [kvm] documentation: virtual: kvm: correct one bit description in APF case (Bandan Das) [1209995]
- [kvm] vmx: Unavailable DR4/5 is checked before CPL (Bandan Das) [1209995]
- [kvm] x86: Emulator performs code segment checks on read access (Bandan Das) [1209995]
- [kvm] x86: Clear DR7.LE during task-switch (Bandan Das) [1209995]
- [kvm] x86: Emulator does not calculate address correctly (Bandan Das) [1209995]
- [kvm] x86: DR7.GD should be cleared upon any #DB exception (Bandan Das) [1209995]
- [kvm] x86: some apic broadcast modes does not work (Bandan Das) [1209995]
- [kvm] x86,kvm,vmx: Don't trap writes to CR4.TSD (Bandan Das) [1209995]
- [kvm] x86: Sysexit emulation does not mask RIP/RSP (Bandan Das) [1209995]
- [kvm] x86: Distinguish between stack operation and near branches (Bandan Das) [1209995]
- [kvm] x86: Getting rid of grp45 in emulator (Bandan Das) [1209995]
- [kvm] x86: Use new is_noncanonical_address in _linearize (Bandan Das) [1209995]
- [kvm] emulator: always inline __linearize (Bandan Das) [1209995]
- [kvm] nvmx: Disable preemption while reading from shadow VMCS (Bandan Das) [1209995]
- [kvm] x86: Fix far-jump to non-canonical check (Bandan Das) [1152997 1209995] {CVE-2014-3647}
- [kvm] emulator: fix execution close to the segment limit (Bandan Das) [1209995]
- [kvm] emulator: fix error code for __linearize (Bandan Das) [1209995]
- [kvm] vfio: fix unregister kvm_device_ops of vfio (Bandan Das) [1209995]
- [kvm] x86: Wrong assertion on paging_tmpl.h (Bandan Das) [1209995]
- [kvm] fix excessive pages un-pinning in kvm_iommu_map error path (Bandan Das) [1209995]
- [kvm] x86: PREFETCH and HINT_NOP should have SrcMem flag (Bandan Das) [1209995]
- [kvm] x86: Emulator does not decode clflush well (Bandan Das) [1209995]
- [kvm] emulate: avoid accessing NULL ctxt->memopp (Bandan Das) [1209995]
- [kvm] x86: Decoding guest instructions which cross page boundary may fail (Bandan Das) [1209995]
- [kvm] x86: don't kill guest on unknown exit reason (Bandan Das) [1209995]
- [kvm] x86: Handle errors when RIP is set during far jumps (Bandan Das) [1152997 1209995] {CVE-2014-3647}
- [kvm] x86: Emulator fixes for eip canonical checks on near branches (Bandan Das) [1152997 1209995] {CVE-2014-3647}
- [kvm] x86: Fix wrong masking on relative jump/call (Bandan Das) [1152997 1209995] {CVE-2014-3647}
- [kvm] Fix kvm_get_page_retry_io __gup retval check (Bandan Das) [1209995]
- [kvm] iommu: Convert to use new iommu_capable() API function (Bandan Das) [1209995]
- [kvm] kvm/x86/mmu: Pass gfn and level to rmapp callback (Bandan Das) [1209995]
- [kvm] x86: use macros to compute bank MSRs (Bandan Das) [1209995]
- [kvm] x86: Remove debug assertion of non-PAE reserved bits (Bandan Das) [1209995]
- [kvm] don't take vcpu mutex for obviously invalid vcpu ioctls (Bandan Das) [1209995]
- [kvm] Faults which trigger IO release the mmap_sem (Bandan Das) [1209995]
- [kvm] x86: fix two typos in comment (Bandan Das) [1209995]
- [kvm] vmx: Inject #GP on invalid PAT CR (Bandan Das) [1209995]
- [kvm] x86: emulating descriptor load misses long-mode case (Bandan Das) [1209995]
- [kvm] x86: directly use kvm_make_request again (Bandan Das) [1209995]
- [kvm] x86: count actual tlb flushes (Bandan Das) [1209995]
- [kvm] x86: Don't report guest userspace emulation error to userspace (Bandan Das) [1163766 1209995] {CVE-2010-5313 CVE-2014-7842}
- [kvm] Make init_rmode_tss() return 0 on success (Bandan Das) [1209995]
- [kvm] x86: Warn if guest virtual address space is not 48-bits (Bandan Das) [1209995]
- [kvm] kvm-vfio: do not use module_init (Bandan Das) [1209995]
- [kvm] eventfd: Remove inclusion of irq.h (Bandan Das) [1209995]
- [kvm] correct null pid check in kvm_vcpu_yield_to() (Bandan Das) [1209995]
- [kvm] Make init_rmode_identity_map() return 0 on success (Bandan Das) [1209995]
- [kvm] vfio: register kvm_device_ops dynamically (Bandan Das) [1209995]
- [kvm] device: add simple registration mechanism for kvm_device_ops (Bandan Das) [1209995]
- [kvm] Use PCI device flag helper functions (Bandan Das) [1209995]
- [kvm] x86: Use kvm_make_request when applicable (Bandan Das) [1209995]
- [kvm] mm: export symbol dependencies of is_zero_pfn() (Bandan Das) [1209995]
- [kvm] check for !is_zero_pfn() in kvm_is_mmio_pfn() (Bandan Das) [1209995]
- [kvm] x86: make apic_accept_irq tracepoint more generic (Bandan Das) [1209995]
- [kvm] fix api documentation of KVM_GET_EMULATED_CPUID (Bandan Das) [1209995]
- [kvm] document KVM_SET_GUEST_DEBUG api (Bandan Das) [1209995]
- [kvm] remove redundant assignments in __kvm_set_memory_region (Bandan Das) [1209995]
- [kvm] remove redundant assigment of return value in kvm_dev_ioctl (Bandan Das) [1209995]
- [kvm] remove redundant check of in_spin_loop (Bandan Das) [1209995]
- [kvm] x86: propagate exception from permission checks on the nested page fault (Bandan Das) [1209995]
- [kvm] x86: skip writeback on injection of nested exception (Bandan Das) [1209995]
- [kvm] nsvm: propagate the NPF EXITINFO to the guest (Bandan Das) [1209995]
- [kvm] x86: reserve bit 8 of non-leaf PDPEs and PML4Es in 64-bit mode on AMD (Bandan Das) [1209995]
- [kvm] mmio: cleanup kvm_set_mmio_spte_mask (Bandan Das) [1209995]
- [kvm] x86: fix stale mmio cache bug (Bandan Das) [1209995]
- [kvm] fix potentially corrupt mmio cache (Bandan Das) [1209995]
- [kvm] do not bias the generation number in kvm_current_mmio_generation (Bandan Das) [1209995]
- [kvm] x86: use guest maxphyaddr to check MTRR values (Bandan Das) [1209995]
- [kvm] remove garbage arg to *hardware_{en, dis}able (Bandan Das) [1209995]
- [kvm] forward declare structs in kvm_types.h (Bandan Das) [1209995]
- [kvm] x86: remove Aligned bit from movntps/movntpd (Bandan Das) [1209995]
- [kvm] vmx: VMXOFF emulation in vm86 should cause #UD (Bandan Das) [1209995]
- [kvm] x86: fix some sparse warnings (Bandan Das) [1209995]
- [kvm] nvmx: nested TPR shadow/threshold emulation (Bandan Das) [1209995]
- [kvm] nvmx: introduce nested_get_vmcs12_pages (Bandan Das) [1209995]
- [kvm] Unconditionally export KVM_CAP_USER_NMI (Bandan Das) [1209995]
- [kvm] Unconditionally export KVM_CAP_READONLY_MEM (Bandan Das) [1209995]
- [kvm] Introduce gfn_to_hva_memslot_prot (Bandan Das) [1209995]
- [kvm] x86: fix tracing for 32-bit (Bandan Das) [1209995]
- [kvm] clarify the idea of kvm_dirty_regs (Bandan Das) [1209995]
- [kvm] x86: Replace X86_FEATURE_NX offset with the definition (Bandan Das) [1209995]
- [kvm] avoid unnecessary synchronize_rcu (Bandan Das) [1209995]
- [kvm] emulate: warn on invalid or uninitialized exception numbers (Bandan Das) [1209995]
- [kvm] emulate: do not return X86EMUL_PROPAGATE_FAULT explicitly (Bandan Das) [1209995]
- [kvm] x86: Clarify PMU related features bit manipulation (Bandan Das) [1209995]
- [kvm] vmx: fix ept reserved bits for 1-GByte page (Bandan Das) [1209995]
- [kvm] x86: Clear apic tsc-deadline after deadline (Bandan Das) [1179067 1209995]
- [kvm] x86: #GP when attempts to write reserved bits of Variable Range MTRRs (Bandan Das) [1209995]
- [kvm] x86: fix check legal type of Variable Range MTRRs (Bandan Das) [1209995]
- [kvm] arch/x86: Use RCU_INIT_POINTER(x, NULL) in kvm/vmx.c (Bandan Das) [1209995]
- [kvm] virt/kvm/assigned-dev.c: Set 'dev->irq_source_id' to '-1' after free it (Bandan Das) [1209995]
- [kvm] x86: raise invalid TSS exceptions during a task switch (Bandan Das) [1209995]
- [kvm] x86: drop fpu_activate hook (Bandan Das) [1209995]
- [kvm] x86: do not check CS.DPL against RPL during task switch (Bandan Das) [1209995]
- [kvm] svm: add rdmsr support for AMD event registers (Bandan Das) [1209995]
- [kvm] x86: Avoid emulating instructions on #UD mistakenly (Bandan Das) [1209995]
- [kvm] iommu: fix the third parameter of kvm_iommu_put_pages (CVE-2014-3601) (Bandan Das) [1209995]
- [kvm] nvmx: fix "acknowledge interrupt on exit" when APICv is in use (Bandan Das) [1209995]
- [kvm] nvmx: Fix nested vmexit ack intr before load vmcs01 (Bandan Das) [1209995]
- [kvm] Allow KVM_CHECK_EXTENSION on the vm fd (Bandan Das) [1209995]
- [kvm] Rename and add argument to check_extension (Bandan Das) [1209995]
- [kvm] x86/kvm: Resolve shadow warning from min macro (Bandan Das) [1209995]
- [kvm] Resolve missing-field-initializers warnings (Bandan Das) [1209995]
- [kvm] Replace NR_VMX_MSR with its definition (Bandan Das) [1209995]
- [kvm] x86: Assertions to check no overrun in MSR lists (Bandan Das) [1209995]
- [kvm] x86: set rflags.rf during fault injection (Bandan Das) [1209995]
- [kvm] x86: Setting rflags.rf during rep-string emulation (Bandan Das) [1209995]
- [kvm] x86: kvm: Make kvm_get_time_and_clockread() nanoseconds based (Bandan Das) [1209995]
- [kvm] x86: DR6/7.RTM cannot be written (Bandan Das) [1209995]
- [kvm] nvmx: clean up nested_release_vmcs12 and code around it (Bandan Das) [1209995]
- [kvm] nvmx: fix lifetime issues for vmcs02 (Bandan Das) [1209995 1220461]
- [kvm] x86: emulator injects #DB when RFLAGS.RF is set (Bandan Das) [1209995]
- [kvm] x86: Cleanup of rflags.rf cleaning (Bandan Das) [1209995]
- [kvm] x86: Clear rflags.rf on emulated instructions (Bandan Das) [1209995]
- [kvm] x86: popf emulation should not change RF (Bandan Das) [1209995]
- [kvm] x86: Clearing rflags.rf upon skipped emulated instruction (Bandan Das) [1209995]
- [kvm] nvmx: Fix virtual interrupt delivery injection (Bandan Das) [1209995]
- [kvm] x86: Emulator support for #UD on CPL>0 (Bandan Das) [1209995]
- [kvm] x86: Emulator flag for instruction that only support 16-bit addresses in real mode (Bandan Das) [1209995]
- [kvm] x86: use kvm_read_guest_page for emulator accesses (Bandan Das) [1036792 1209995]
- [kvm] x86: ensure emulator fetches do not span multiple pages (Bandan Das) [1036792 1209995]
- [kvm] emulate: put pointers in the fetch_cache (Bandan Das) [1036792 1209995]
- [kvm] emulate: avoid per-byte copying in instruction fetches (Bandan Das) [1036792 1209995]
- [kvm] emulate: avoid repeated calls to do_insn_fetch_bytes (Bandan Das) [1036792 1209995]
- [kvm] emulate: speed up do_insn_fetch (Bandan Das) [1036792 1209995]
- [kvm] emulate: do not initialize memopp (Bandan Das) [1036792 1209995]
- [kvm] emulate: rework seg_override (Bandan Das) [1036792 1209995]
- [kvm] emulate: clean up initializations in init_decode_cache (Bandan Das) [1036792 1209995]
- [kvm] emulate: cleanup decode_modrm (Bandan Das) [1036792 1209995]
- [kvm] emulate: Remove ctxt->intercept and ctxt->check_perm checks (Bandan Das) [1036792 1209995]
- [kvm] emulate: move init_decode_cache to emulate.c (Bandan Das) [1036792 1209995]
- [kvm] emulate: simplify writeback (Bandan Das) [1036792 1209995]
- [kvm] emulate: speed up emulated moves (Bandan Das) [1036792 1209995]
- [kvm] emulate: protect checks on ctxt->d by a common "if (unlikely())" (Bandan Das) [1036792 1209995]
- [kvm] emulate: move around some checks (Bandan Das) [1036792 1209995]
- [kvm] x86: avoid useless set of KVM_REQ_EVENT after emulation (Bandan Das) [1209995]
- [kvm] x86: return all bits from get_interrupt_shadow (Bandan Das) [1209995]
- [kvm] vmx: speed up emulation of invalid guest state (Bandan Das) [1209995]
- [kvm] svm: writes to MSR_K7_HWCR generates GPE in guest (Bandan Das) [1209995]
- [kvm] x86: Pending interrupt may be delivered after INIT (Bandan Das) [1209995]
- [kvm] Synthesize G bit for all segments (Bandan Das) [1209995]
- [kvm] x86: Fix lapic.c debug prints (Bandan Das) [1209995]
- [kvm] nsvm: Set correct port for IOIO interception evaluation (Bandan Das) [1209995]
- [kvm] nsvm: Fix IOIO size reported on emulation (Bandan Das) [1209995]
- [kvm] nsvm: Fix IOIO bitmap evaluation (Bandan Das) [1209995]
- [kvm] nsvm: Do not report CLTS via SVM_EXIT_WRITE_CR0 to L1 (Bandan Das) [1209995]
- [kvm] tracing: Add trace_seq_buffer_ptr() helper function (Bandan Das) [1209995]
- [kvm] arch: x86: kvm: x86.c: Cleaning up variable is set more than once (Bandan Das) [1209995]
- [kvm] vmx: vmx instructions handling does not consider cs.l (Bandan Das) [1209995]
- [kvm] vmx: handle_cr ignores 32/64-bit mode (Bandan Das) [1209995]
- [kvm] x86: Hypercall handling does not considers opsize correctly (Bandan Das) [1209995]
- [kvm] x86: check DR6/7 high-bits are clear only on long-mode (Bandan Das) [1209995]
- [kvm] nvmx: Fix returned value of MSR_IA32_VMX_VMCS_ENUM (Bandan Das) [1209995]
- [kvm] nvmx: Allow to disable VM_{ENTRY_LOAD, EXIT_SAVE}_DEBUG_CONTROLS (Bandan Das) [1209995]
- [kvm] nvmx: Fix returned value of MSR_IA32_VMX_PROCBASED_CTLS (Bandan Das) [1209995]
- [kvm] nvmx: Allow to disable CR3 access interception (Bandan Das) [1209995]
- [kvm] nvmx: Advertise support for MSR_IA32_VMX_TRUE_*_CTLS (Bandan Das) [1209995]
- [kvm] x86: Fix constant value of VM_{EXIT_SAVE, ENTRY_LOAD}_DEBUG_CONTROLS (Bandan Das) [1209995]
- [kvm] x86: NOP emulation clears (incorrectly) the high 32-bits of RAX (Bandan Das) [1209995]
- [kvm] x86: emulation of dword cmov on long-mode should clear [63:32] (Bandan Das) [1209995]
- [kvm] x86: Inter-privilege level ret emulation is not implemeneted (Bandan Das) [1152997 1209995] {CVE-2014-3647}
- [kvm] x86: Wrong emulation on 'xadd X, X' (Bandan Das) [1209995]
- [kvm] x86: bit-ops emulation ignores offset on 64-bit (Bandan Das) [1209995]
- [kvm] x86: vmx: use PAGE_ALIGNED instead of IS_ALIGNED(..., PAGE_SIZE) (Bandan Das) [1209995]
- [kvm] emulate: fix harmless typo in MMX decoding (Bandan Das) [1209995]
- [kvm] emulate: simplify BitOp handling (Bandan Das) [1209995]
- [kvm] emulate: POP SS triggers a MOV SS shadow too (Bandan Das) [1209995]
- [kvm] x86: smsw emulation is incorrect in 64-bit mode (Bandan Das) [1209995]
- [kvm] x86: Return error on cmpxchg16b emulation (Bandan Das) [1209995]
- [kvm] x86: rdpmc emulation checks the counter incorrectly (Bandan Das) [1209995]
- [kvm] x86: movnti minimum op size of 32-bit is not kept (Bandan Das) [1209995]
- [kvm] x86: cmpxchg emulation should compare in reverse order (Bandan Das) [1209995]
- [kvm] x86: sgdt and sidt are not privilaged (Bandan Das) [1209995]
- [kvm] x86: Loading segments on 64-bit mode may be wrong (Bandan Das) [1152997 1209995] {CVE-2014-3647}
- [kvm] x86: Emulator ignores LDTR/TR extended base on LLDT/LTR (Bandan Das) [1152997 1209995] {CVE-2014-3647}
- [kvm] x86: Mark VEX-prefix instructions emulation as unimplemented (Bandan Das) [1209995]
- [kvm] x86: mmu: flush tlb out of mmu lock when write-protect the sptes (Bandan Das) [1209995]
- [kvm] x86: mmu: flush tlb if the spte can be locklessly modified (Bandan Das) [1209995]
- [kvm] x86: mmu: lazily drop large spte (Bandan Das) [1209995]
- [kvm] x86: mmu: properly check last spte in fast_page_fault() (Bandan Das) [1209995]
- [kvm] x86: optimize out smp_mb after srcu_read_unlock (Bandan Das) [1209995]
- [kernel] srcu: API for barrier after srcu read unlock (Bandan Das) [1209995]

* Thu May 28 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-257.el7]
- [pci] pciehp: Fix pcie_wait_cmd() timeout (Myron Stowe) [1223472]
- [pci] revert "pci: Make sure bus number resources stay within their parents bounds" (Myron Stowe) [1223472]
- [pci] revert "pci: Don't scan random busses in pci_scan_bridge()" (Myron Stowe) [1223472]
- [pci] acpiphp / radeon / nouveau: Remove acpi_bus_no_hotplug() (Myron Stowe) [1223472]
- [pci] Remove "no hotplug settings from platform" warning (Myron Stowe) [1223472]
- [pci] Add pci_ignore_hotplug() to ignore hotplug events for a device (Myron Stowe) [1223472]
- [pci] maintainers: Add Lucas Stach as co-maintainer for i.MX6 PCI driver (Myron Stowe) [1223472]
- [pci] msi: Use irq_get_msi_desc() to simplify code (Myron Stowe) [1223472]
- [pci] msi: Remove unused list access in __pci_restore_msix_state() (Myron Stowe) [1223472]
- [pci] msi: Retrieve first MSI IRQ from msi_desc rather than pci_dev (Myron Stowe) [1223472]
- [pci] msi: Remove unused function msi_remove_pci_irq_vectors() (Myron Stowe) [1223472]
- [pci] msi: Add msi_setup_entry() to clean up MSI initialization (Myron Stowe) [1223472]
- [pci] Configure ASPM when enabling device (Myron Stowe) [1223472]
- [pci] x86: don't exclude low BIOS area when allocating address space for non-PCI c (Myron Stowe) [1223472]
- [pci] Tidy resource assignment messages (Myron Stowe) [1223472]
- [pci] Return conventional error values from pci_revert_fw_address() (Myron Stowe) [1223472]
- [pci] Cleanup control flow (Myron Stowe) [1223472]
- [pci] cpqphp: Remove unnecessary null test before debugfs_remove() (Myron Stowe) [1223472]
- [pci] pciehp: Remove struct controller.no_cmd_complete (Myron Stowe) [1223472]
- [pci] msi: Cache Multiple Message Capable in struct msi_desc (Myron Stowe) [1223472]
- [pci] msi: Remove unused msi_enabled_mask() (Myron Stowe) [1223472]
- [pci] msi: Add internal msix_clear_and_set_ctrl() function (Myron Stowe) [1223472]
- [pci] powerpc: Remove duplicate logic (Myron Stowe) [1223472]
- [pci] Make resetting secondary bus logic common (Myron Stowe) [1223472]
- [pci] pci: Fix sysfs acpi_index and label errors (Myron Stowe) [1223472]
- [pci] portdrv: Remove warning about invalid IRQ for hot-added PCIe ports (Myron Stowe) [1223472]
- [pci] pciehp: Remove assumptions about which commands cause completion events (Myron Stowe) [1223472]
- [pci] pciehp: Compute timeout from hotplug command start time (Myron Stowe) [1223472]
- [pci] pciehp: Wait for hotplug command completion lazily (Myron Stowe) [1223472]
- [pci] pciehp: Make pcie_wait_cmd() self-contained (Myron Stowe) [1223472]
- [pci] label: treat PCI label with index 0 as valid label (Myron Stowe) [1223472]
- [pci] acpi: replace open-coded _DSM code with helper functions (Myron Stowe) [1223472]
- [pci] label: release allocated ACPI object on error recovery path (Myron Stowe) [1223472]
- [pci] acpi: Eliminate the DEVICE_ACPI_HANDLE() macro (Myron Stowe) [1223472]
- [fs] ext4: fix overflow when updating superblock backups after resize (Lukas Czerner) [1220312]
- [fs] ext4: fix growing of tiny filesystems (Lukas Czerner) [1220312]
- [fs] ext4: make fsync to sync parent dir in no-journal for real this time (Lukas Czerner) [1220312]
- [fs] ext4: don't release reserved space for previously allocated cluster (Lukas Czerner) [1220312]
- [fs] ext4: fix loss of delalloc extent info in ext4_zero_range() (Lukas Czerner) [1220312]
- [fs] ext4: remove unnecessary lock/unlock of i_block_reservation_lock (Lukas Czerner) [1220312]
- [fs] ext4: remove useless condition in if statement (Lukas Czerner) [1220312]
- [fs] ext4: fix comments in ext4_can_extents_be_merged() (Lukas Czerner) [1220312]
- [fs] ext4: fix transposition typo in format string (Lukas Czerner) [1220312]
- [fs] ext4: fix bh leak on error paths in ext4_rename() and ext4_cross_rename() (Lukas Czerner) [1220312]
- [fs] ext4: fix indirect punch hole corruption (Lukas Czerner) [1220312]
- [fs] ext4: ignore journal checksum on remount; don't fail (Lukas Czerner) [1220312]
- [fs] ext4: remove duplicate remount check for JOURNAL_CHECKSUM change (Lukas Czerner) [1220312]
- [fs] jbd2: complain about descriptor block checksum errors (Lukas Czerner) [1220312]
- [fs] ext4: remove spurious KERN_INFO from ext4_warning call (Lukas Czerner) [1220312]
- [fs] ext4: prevent online resize with backup superblock (Lukas Czerner) [1220312]
- [fs] move_extent_per_page(): get rid of unused w_flags (Lukas Czerner) [1220312]
- [fs] ext4: ext4_da_convert_inline_data_to_extent drop locked page after error (Lukas Czerner) [1220312]
- [fs] ext4: ext4_inline_data_fiemap should respect callers argument (Lukas Czerner) [1220312]
- [fs] ext4: prevent fsreentrance deadlock for inline_data (Lukas Czerner) [1220312]
- [fs] jbd2: fix regression where we fail to initialize checksum seed when loading (Lukas Czerner) [1220312]
- [fs] ext4: forbid journal_async_commit in data=ordered mode (Lukas Czerner) [1220312]
- [fs] jbd2: remove unnecessary NULL check before iput() (Lukas Czerner) [1220312]
- [fs] ext4: Remove an unnecessary check for NULL before iput() (Lukas Czerner) [1220312]
- [fs] ext4: remove unneeded code in ext4_unlink (Lukas Czerner) [1220312]
- [fs] ext4: remove never taken branch from ext4_ext_shift_path_extents() (Lukas Czerner) [1220312]
- [fs] ext4: create nojournal_checksum mount option (Lukas Czerner) [1220312]
- [fs] ext4: update comments regarding ext4_delete_inode() (Lukas Czerner) [1220312]
- [fs] ext4: cleanup GFP flags inside resize path (Lukas Czerner) [1220312]
- [fs] ext4: cache extent hole in extent status tree for ext4_da_map_blocks() (Lukas Czerner) [1220312]
- [fs] ext4: fix block reservation for bigalloc filesystems (Lukas Czerner) [1220312]
- [fs] ext4: fix end of region partial cluster handling (Lukas Czerner) [1220312]
- [fs] ext4: miscellaneous partial cluster cleanups (Lukas Czerner) [1220312]
- [fs] ext4: fix end of leaf partial cluster handling (Lukas Czerner) [1220312]
- [fs] ext4: fix partial cluster initialization (Lukas Czerner) [1220312]
- [fs] ext4: move_extent improve bh vanishing success factor (Lukas Czerner) [1220312]
- [fs] ext4: make ext4_ext_convert_to_initialized() return proper number of blocks (Lukas Czerner) [1220312]
- [fs] ext4: bail early when clearing inode journal flag fails (Lukas Czerner) [1220312]
- [fs] ext4: bail out from make_indexed_dir() on first error (Lukas Czerner) [1220312]
- [fs] jbd2: use a better hash function for the revoke table (Lukas Czerner) [1220312]
- [fs] ext4: disallow changing journal_csum option during remount (Lukas Czerner) [1220312]
- [fs] ext4: enable journal checksum when metadata checksum feature enabled (Lukas Czerner) [1220312]
- [fs] ext4: fix oops when loading block bitmap failed (Lukas Czerner) [1220312]
- [fs] xfs: allow appending aio writes (Eric Sandeen) [1053615]
- [fs] direct-io: add flag to allow aio writes beyond i_size (Eric Sandeen) [1053615]
- [fs] ext4: fix data corruption caused by unwritten and delayed extents (Lukas Czerner) [1213487]
- [fs] gfs2: Use average srttb value in congestion calculations (Robert S Peterson) [1162821]
- [fs] xfs: disallow ro->rw remount on norecovery mount (Eric Sandeen) [1206220]
- [fs] nfs: Fixing lease renewal (Benjamin Coddington) [1205048]
- [fs] bio: modify __bio_add_page() to accept pages that don't start a new segment (Maurizio Lombardi) [1094392]

* Tue May 26 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-256.el7]
- [perf] probe: Fix segfault if passed with '' (Jiri Olsa) [1222189]
- [perf] report: Fix -T/--threads option to work again (Jiri Olsa) [1222189]
- [perf] bench numa: Fix immediate meeting of convergence condition (Jiri Olsa) [1222189]
- [perf] bench numa: Fixes of --quiet argument (Jiri Olsa) [1222189]
- [perf] bench futex: Fix hung wakeup tasks after requeueing (Jiri Olsa) [1222189]
- [perf] probe: Fix bug with global variables handling (Jiri Olsa) [1222189]
- [perf] top: Fix a segfault when kernel map is restricted (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Fix build failure on 32-bit arch (Jiri Olsa) [1222189]
- [perf] kmem: Fix compiles on RHEL6/OL6 (Jiri Olsa) [1222189]
- [perf] tools lib api: Undefine _FORTIFY_SOURCE before setting it (Jiri Olsa) [1222189]
- [perf] kmem: Consistently use PRIu64 for printing u64 values (Jiri Olsa) [1222189]
- [perf] trace: Disable events and drain events when forked workload ends (Jiri Olsa) [1222189]
- [perf] trace: Enable events when doing system wide tracing and starting a workload (Jiri Olsa) [1222189]
- [perf] probe: Fix segfault when probe with lazy_line to file (Jiri Olsa) [1222189]
- [perf] probe: Find compilation directory path for lazy matching (Jiri Olsa) [1222189]
- [perf] probe: Set retprobe flag when probe in address-based alternative mode (Jiri Olsa) [1222189]
- [perf] kmem: Analyze page allocator events also (Jiri Olsa) [1222189]
- [perf] evlist: Fix type for references to data_head/tail (Jiri Olsa) [1222189]
- [perf] probe: Check the orphaned -x option (Jiri Olsa) [1222189]
- [perf] probe: Support multiple probes on different binaries (Jiri Olsa) [1222189]
- [perf] buildid-list: Fix segfault when show DSOs with hits (Jiri Olsa) [1222189]
- [perf] tools: Fix cross-endian analysis (Jiri Olsa) [1222189]
- [perf] tools: Fix error path to do closedir() when synthesizing threads (Jiri Olsa) [1222189]
- [perf] tools: Fix synthesizing fork_event.ppid for non-main thread (Jiri Olsa) [1222189]
- [perf] tools: Add 'I' event modifier for exclude_idle bit (Jiri Olsa) [1222189]
- [perf] report: Don't call map__kmap if map is NULL (Jiri Olsa) [1222189]
- [perf] probe: Fix ARM 32 building error (Jiri Olsa) [1222189]
- [perf] tools: Merge all perf_event_attr print functions (Jiri Olsa) [1222189]
- [perf] sched replay: Use replay_repeat to calculate the runavg of cpu usage instead of the default value 10 (Jiri Olsa) [1222189]
- [perf] sched replay: Support using -f to override perf.data file ownership (Jiri Olsa) [1222189]
- [perf] sched replay: Fix the EMFILE error caused by the limitation of the maximum open files (Jiri Olsa) [1222189]
- [perf] sched replay: Handle the dead halt of sem_wait when create_tasks() fails for any task (Jiri Olsa) [1222189]
- [perf] sched replay: Fix the segmentation fault problem caused by pr_err in threads (Jiri Olsa) [1222189]
- [perf] sched replay: Realloc the memory of pid_to_task stepwise to adapt to the different pid_max configurations (Jiri Olsa) [1222189]
- [perf] sched replay: Alloc the memory of pid_to_task dynamically to adapt to the unexpected change of pid_max (Jiri Olsa) [1222189]
- [perf] sched replay: Increase the MAX_PID value to fix assertion failure problem (Jiri Olsa) [1222189]
- [perf] sched replay: Use struct task_desc instead of struct task_task for correct meaning (Jiri Olsa) [1222189]
- [perf] kmem: Respect -i option (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Honor operator priority (Jiri Olsa) [1222189]
- [perf] kmaps: Check kmaps to make code more robust (Jiri Olsa) [1222189]
- [perf] evlist: Fix inverted logic in perf_mmap__empty (Jiri Olsa) [1222189]
- [perf] data: Support using -f to override perf.data file ownership for 'convert' (Jiri Olsa) [1222189]
- [perf] trace: Support using -f to override perf.data file ownership (Jiri Olsa) [1222189]
- [perf] timechart: Support using -f to override perf.data file ownership (Jiri Olsa) [1222189]
- [perf] script: Support using -f to override perf.data file ownership (Jiri Olsa) [1222189]
- [perf] mem: Support using -f to override perf.data file ownership (Jiri Olsa) [1222189]
- [perf] lock: Support using -f to override perf.data file ownership (Jiri Olsa) [1222189]
- [perf] kvm: Support using -f to override perf.data.guest file ownership (Jiri Olsa) [1222189]
- [perf] kmem: Support using -f to override perf.data file ownership (Jiri Olsa) [1222189]
- [perf] inject: Support using -f to override perf.data file ownership (Jiri Olsa) [1222189]
- [perf] evlist: Support using -f to override perf.data file ownership (Jiri Olsa) [1222189]
- [perf] probe: Fix to track down unnamed union/structure members (Jiri Olsa) [1222189]
- [perf] db-export: No need to have ->thread twice in struct export_sample (Jiri Olsa) [1222189]
- [perf] db-export: No need to pass thread twice to db_export__sample (Jiri Olsa) [1222189]
- [perf] scripting: No need to pass thread twice to the scripting callbacks (Jiri Olsa) [1222189]
- [perf] script: No need to lookup thread twice (Jiri Olsa) [1222189]
- [perf] ordered_samples: Remove references to perf_{evlist, tool} and machines (Jiri Olsa) [1222189]
- [perf] session: Always initialize ordered_events (Jiri Olsa) [1222189]
- [perf] tools: Fix ppid for synthesized fork events (Jiri Olsa) [1222189]
- [perf] tools: Refactor comm/tgid lookup (Jiri Olsa) [1222189]
- [perf] callchain: Fix kernel symbol resolution by remembering the cpumode (Jiri Olsa) [1222189]
- [perf] build: Disable libbabeltrace check by default (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Zero should not be considered "not found" in eval_flag() (Jiri Olsa) [1222189]
- [perf] trace: Fix syscall enter formatting bug (Jiri Olsa) [1222189]
- [perf] tools: Set JOBS based on CPU or processor (Jiri Olsa) [1222189]
- [perf] Bump max number of cpus to 1024 (Jiri Olsa) [1222189]
- [perf] evlist: Return the first evsel with an invalid filter in apply_filters() (Jiri Olsa) [1222189]
- [perf] timechart: Fix SIBGUS error on sparc64 (Jiri Olsa) [1222189]
- [perf] tools: Add pid/tid filtering to report and script commands (Jiri Olsa) [1222189]
- [perf] diff: Add kallsyms option (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Add support for __print_array() (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Free filter tokens in process_filter() (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Add way to find sub buffer boundary (Jiri Olsa) [1222189]
- [perf] tools lib traceevent kbuffer: Remove extra update to data pointer in PADDING (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Make plugin options either string or boolean (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Add pevent_data_pid_from_comm() (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Handle z in bprint format (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Copy trace_clock and free it (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Handle NULL comm name (Jiri Olsa) [1222189]
- [perf] symbols: Save DSO loading errno to better report errors (Jiri Olsa) [1222189]
- [perf] target: Simplify handling of strerror_r return (Jiri Olsa) [1222189]
- [perf] tools: Work around lack of sched_getcpu in glibc < 2.6 (Jiri Olsa) [1222189]
- [perf] kmem: Print big numbers using thousands' group (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Factor out allocating and processing args (Jiri Olsa) [1222189]
- [perf] probe: Fix to get ummapped symbol address on kernel (Jiri Olsa) [1222189]
- [perf] tools: Remove (null) value of "Sort order" for perf mem report (Jiri Olsa) [1222189]
- [perf] annotate: Allow annotation for decompressed kernel modules (Jiri Olsa) [1222189]
- [perf] tools: Try to lookup kernel module map before creating one (Jiri Olsa) [1222189]
- [perf] tools: Remove is_kmodule_extension function (Jiri Olsa) [1222189]
- [perf] tools: Remove compressed argument from is_kernel_module (Jiri Olsa) [1222189]
- [perf] tools: Use kmod_path__parse in is_kernel_module (Jiri Olsa) [1222189]
- [perf] tools: Use kmod_path__parse in decompress_kmodule (Jiri Olsa) [1222189]
- [perf] tools: Use kmod_path__parse in map_groups__set_modules_path_dir (Jiri Olsa) [1222189]
- [perf] tools: Use kmod_path__parse for machine__new_dso (Jiri Olsa) [1222189]
- [perf] tools: Add machine__module_dso function (Jiri Olsa) [1222189]
- [perf] tools: Add dsos__addnew function (Jiri Olsa) [1222189]
- [perf] tools: Add kmod_path__parse function (Jiri Olsa) [1222189]
- [perf] tools: Add lzma decompression support for kernel module (Jiri Olsa) [1222189]
- [perf] tools build: Add feature check for lzma library (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Add destructor for format_field (Jiri Olsa) [1222189]
- [perf] hists browser: Indicate which callchain entries are annotated (Jiri Olsa) [1222189]
- [perf] trace: Handle legacy syscalls tracepoints (Jiri Olsa) [1222189]
- [perf] build: Move feature checks code under tools/build (Jiri Olsa) [1222189]
- [perf] build: Make features checks directory configurable (Jiri Olsa) [1222189]
- [perf] build: Separate feature make support into config/Makefile.feature (Jiri Olsa) [1222189]
- [perf] build: Fix feature_check name clash (Jiri Olsa) [1222189]
- [perf] trace: Fix summary_only option (Jiri Olsa) [1222189]
- [perf] probe: Fix failure to add multiple probes without debuginfo (Jiri Olsa) [1222189]
- [perf] build: Add config/feature-checks/*.output to the .gitignore file (Jiri Olsa) [1222189]
- [perf] build: Use FEATURE-DUMP instead of PERF-FEATURES in the .gitignore file (Jiri Olsa) [1222189]
- [perf] tools: Don't allow empty argument for field-separator (Jiri Olsa) [1222189]
- [perf] report: Don't allow empty argument for '-t' (Jiri Olsa) [1222189]
- [perf] callchain: Separate eh/debug frame offset cache (Jiri Olsa) [1222189]
- [perf] tools: Avoid confusion with preloaded bash function for perf bash completion (Jiri Olsa) [1222189]
- [perf] tools: Add the bash completion for listing subsubcommands of perf trace (Jiri Olsa) [1222189]
- [perf] tools: Add the bash completion for listing subsubcommands of perf timechart (Jiri Olsa) [1222189]
- [perf] tools: Add the bash completion for listing subsubcommands of perf test (Jiri Olsa) [1222189]
- [perf] tools: Add the bash completion for listing subsubcommands of perf script (Jiri Olsa) [1222189]
- [perf] tools: Add the bash completion for listing subsubcommands of perf help (Jiri Olsa) [1222189]
- [perf] tools: Add the bash completion for listing subsubcommands of perf data (Jiri Olsa) [1222189]
- [perf] tools: Fix the bash completion for listing subcommands of perf (Jiri Olsa) [1222189]
- [perf] tools: Fix the bash completion to support listing events for --event (Jiri Olsa) [1222189]
- [perf] tools: Fix the bash completion for listing events of perf subcommand record|stat|top -e (Jiri Olsa) [1222189]
- [perf] tools: Provide the right bash completion for listing options of perf subcommand subsubcommand (Jiri Olsa) [1222189]
- [perf] tools: Fix the bash completion for listing subsubcommands of perf subcommand (Jiri Olsa) [1222189]
- [perf] tools: Fix the bash completion for listing options of perf subcommand (Jiri Olsa) [1222189]
- [perf] tools: Fix perf-read-vdsox32 not building and lib64 install dir (Jiri Olsa) [1222189]
- [perf] build: Rename feature_print_var_code to print_var_code (Jiri Olsa) [1222189]
- [perf] build: Rename PERF-FEATURES into FEATURE-DUMP (Jiri Olsa) [1222189]
- [perf] build: Rename display_vf to feature_verbose (Jiri Olsa) [1222189]
- [perf] build: Rename display_lib into feature_display (Jiri Olsa) [1222189]
- [perf] build: Get rid of VF_FEATURE_TESTS (Jiri Olsa) [1222189]
- [perf] build: Rename CORE_FEATURE_TESTS to FEATURE_TESTS (Jiri Olsa) [1222189]
- [perf] build: Get rid of LIB_INCLUDE variable (Jiri Olsa) [1222189]
- [perf] build: Fix pthread-attr-setaffinity-np include in test-all (Jiri Olsa) [1222189]
- [perf] build: Move features build output under features directory (Jiri Olsa) [1222189]
- [perf] build: Disable default check for libbabeltrace (Jiri Olsa) [1222189]
- [perf] tools: Fix building error for arm64 (Jiri Olsa) [1222189]
- [perf] hists browser: Allow annotating entries in callchains (Jiri Olsa) [1222189]
- [perf] hists: Remove hist_entry->used, not used anymore (Jiri Olsa) [1222189]
- [perf] hists browser: Fix up some branch alignment (Jiri Olsa) [1222189]
- [perf] hists browser: Simplify symbol annotation menu setup (Jiri Olsa) [1222189]
- [perf] data: Add tracepoint events fields CTF conversion support (Jiri Olsa) [1222189]
- [perf] kmem: Fix alignment of slab result table (Jiri Olsa) [1222189]
- [perf] kmem: Allow -v option (Jiri Olsa) [1222189]
- [perf] kmem: Fix segfault when invalid sort key is given (Jiri Olsa) [1222189]
- [perf] stat: Always correctly indent ratio column (Jiri Olsa) [1222189]
- [perf] stat: Fix IPC and other formulas with -A (Jiri Olsa) [1222189]
- [perf] stat: Output running time and run/enabled ratio in CSV mode (Jiri Olsa) [1222189]
- [perf] hists browser: Fix UI bug after fold/unfold (Jiri Olsa) [1222189]
- [perf] probe: Fix compiles due to declarations using perf_probe_point (Jiri Olsa) [1222189]
- [perf] hists browser: Fix UI bug after zoom into thread/dso/symbol (Jiri Olsa) [1222189]
- [perf] probe: Fix possible double free on error (Jiri Olsa) [1222189]
- [perf] tools: Output feature detection's gcc output to a file (Jiri Olsa) [1222189]
- [perf] build: Fix libbabeltrace detection (Jiri Olsa) [1222189]
- [perf] probe: Allow weak symbols to be probed (Jiri Olsa) [1222189]
- [perf] symbols: Allow symbol alias when loading map for symbol name (Jiri Olsa) [1222189]
- [perf] revert "perf probe: Fix to fall back to find probe point in symbols" (Jiri Olsa) [1222189]
- [perf] probe: Fix --line to handle aliased symbols in glibc (Jiri Olsa) [1222189]
- [perf] probe: Fix to handle aliased symbols in glibc (Jiri Olsa) [1222189]
- [perf] ordered_events: Adopt queue() method (Jiri Olsa) [1222189]
- [perf] tools: Remove superfluous thread->comm_set setting (Jiri Olsa) [1222189]
- [perf] tools: tool->finished_round() doesn't need perf_session (Jiri Olsa) [1222189]
- [perf] ordered_events: Allow tools to specify a deliver method (Jiri Olsa) [1222189]
- [perf] ordered_events: Shorten function signatures (Jiri Olsa) [1222189]
- [perf] ordered_events: Untangle from perf_session (Jiri Olsa) [1222189]
- [perf] sched: No need to keep the session around (Jiri Olsa) [1222189]
- [perf] tools: Reference count struct thread (Jiri Olsa) [1222189]
- [perf] tools: Initialize cpu set in pthread_attr_setaffinity_np feature test (Jiri Olsa) [1222189]
- [perf] probe: Remove bias offset to find probe point by address (Jiri Olsa) [1222189]
- [perf] probe: Warn if given uprobe event accesses memory on older kernel (Jiri Olsa) [1222189]
- [perf] tools: Improve 'libbabel' feature check failure message (Jiri Olsa) [1222189]
- [perf] tools: Improve feature test debuggability (Jiri Olsa) [1222189]
- [perf] tools: Improve libbfd detection message (Jiri Olsa) [1222189]
- [perf] tools: Improve libperl detection message (Jiri Olsa) [1222189]
- [perf] tools: Improve Python feature detection messages (Jiri Olsa) [1222189]
- [perf] tools: Remove annoying extra message from the features build (Jiri Olsa) [1222189]
- [perf] tools: Add PERF-FEATURES to the .gitignore file (Jiri Olsa) [1222189]
- [perf] record: Document --group option (Jiri Olsa) [1222189]
- [perf] record: Get rid of -l option from Documentation (Jiri Olsa) [1222189]
- [perf] tools: Fix build error on ARCH=i386/x86_64/sparc64 (Jiri Olsa) [1222189]
- [perf] tools: Fix FORK after COMM when synthesizing records for pre-existing threads (Jiri Olsa) [1222189]
- [perf] stat: Report unsupported events properly (Jiri Olsa) [1222189]
- [perf] tools: Compare JOBS to 0 after grep (Jiri Olsa) [1222189]
- [perf] tools: Only include tsc file for x86 (Jiri Olsa) [1222189]
- [perf] report: Fix branch stack mode cannot be set (Jiri Olsa) [1222189]
- [perf] buildid-cache: Show usage with incorrect params (Jiri Olsa) [1222189]
- [perf] buildid-cache: Use pr_debug instead of verbose && pr_info (Jiri Olsa) [1222189]
- [perf] buildid-cache: Add --purge FILE to remove all caches of FILE (Jiri Olsa) [1222189]
- [perf] tools: Fix the bash completion problem of 'perf --*' (Jiri Olsa) [1222189]
- [perf] list: Extend raw-dump to certain kind of events (Jiri Olsa) [1222189]
- [perf] list: Clean up the printing functions of hardware/software events (Jiri Olsa) [1222189]
- [perf] tools: Remove the '--(null)' long_name for --list-opts (Jiri Olsa) [1222189]
- [perf] list: Avoid confusion of perf output and the next command prompt (Jiri Olsa) [1222189]
- [perf] list: Allow listing events with 'tracepoint' prefix (Jiri Olsa) [1222189]
- [perf] list: Sort the output of 'perf list' to view more clearly (Jiri Olsa) [1222189]
- [perf] data: Fix sentinel setting for data_cmds array (Jiri Olsa) [1222189]
- [perf] probe: Fix a precedence bug (Jiri Olsa) [1222189]
- [perf] diff: Support for different binaries (Jiri Olsa) [1222189]
- [perf] buildid-cache: Add new buildid cache if update target is not cached (Jiri Olsa) [1222189]
- [perf] probe: Handle strdup() failure (Jiri Olsa) [1222189]
- [perf] probe: Fix get_real_path to free allocated memory in error path (Jiri Olsa) [1222189]
- [perf] probe: Check kprobes blacklist when adding new events (Jiri Olsa) [1222189]
- [perf] trace: Fix SIGBUS failures due to misaligned accesses (Jiri Olsa) [1222189]
- [perf] data: Add a 'perf' prefix to the generic fields (Jiri Olsa) [1222189]
- [perf] data: Add perf data to CTF conversion support (Jiri Olsa) [1222189]
- [perf] tools: Add new 'perf data' command (Jiri Olsa) [1222189]
- [perf] tools: Add feature check for libbabeltrace (Jiri Olsa) [1222189]
- [perf] record: Support recording running/enabled time (Jiri Olsa) [1222189]
- [perf] tools: Print the thread's tid on PERF_RECORD_COMM events when -D is asked (Jiri Olsa) [1222189]
- [perf] trace: Dump stack on segfaults (Jiri Olsa) [1222189]
- [perf] tools: Introduce dump_stack signal helper (Jiri Olsa) [1222189]
- [perf] ordered_events: Stop using tool->ordered_events (Jiri Olsa) [1222189]
- [perf] session: Remove perf_session from dump_event (Jiri Olsa) [1222189]
- [perf] session: Remove perf_session from some deliver event routines (Jiri Olsa) [1222189]
- [perf] session: Remove perf_session from warn_errors signature (Jiri Olsa) [1222189]
- [perf] evlist: Adopt events_stats from perf_session (Jiri Olsa) [1222189]
- [perf] session: Remove wrappers to machines__find (Jiri Olsa) [1222189]
- [perf] trace: Separate routine that handles an event from the one that reads it (Jiri Olsa) [1222189]
- [perf] trace: Add man page entry for --event (Jiri Olsa) [1222189]
- [perf] trace: Introduce --filter-pids (Jiri Olsa) [1222189]
- [perf] evlist: Introduce set_filter_pids method (Jiri Olsa) [1222189]
- [perf] trace: Filter out the trace pid when no threads are specified (Jiri Olsa) [1222189]
- [perf] evlist: Introduce set_filter_pid method (Jiri Olsa) [1222189]
- [perf] trace: Only insert blank duration bracket when tracing syscalls (Jiri Olsa) [1222189]
- [perf] trace: Support --events foo:bar --no-syscalls (Jiri Olsa) [1222189]
- [perf] trace: Allow mixing with other events (Jiri Olsa) [1222189]
- [perf] trace: Handle multiple threads better wrt syscalls being intermixed (Jiri Olsa) [1222189]
- [perf] trace: Print thread info when following children (Jiri Olsa) [1222189]
- [perf] list: Place the header text in its right position (Jiri Olsa) [1222189]
- [perf] tools: Fix a bug of segmentation fault (Jiri Olsa) [1222189]
- [perf] build: Display make commands on V=1 (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Use tools build framework (Jiri Olsa) [1222189]
- [perf] tools lib api: Rename libapikfs.a to libapi.a (Jiri Olsa) [1222189]
- [perf] tools lib api: Use tools build framework (Jiri Olsa) [1222189]
- [perf] build: Add build documentation (Jiri Olsa) [1222189]
- [perf] build: Remove PERF-CFLAGS file (Jiri Olsa) [1222189]
- [perf] build: Remove uneeded variables (Jiri Olsa) [1222189]
- [perf] build: Remove directory dependency rules (Jiri Olsa) [1222189]
- [perf] build: Add single target build framework support (Jiri Olsa) [1222189]
- [perf] build: Add arch sparc objects building (Jiri Olsa) [1222189]
- [perf] build: Add arch sh objects building (Jiri Olsa) [1222189]
- [perf] build: Add arch s390 objects building (Jiri Olsa) [1222189]
- [perf] build: Add arch powerpc objects building (Jiri Olsa) [1222189]
- [perf] build: Add arch arm64 objects building (Jiri Olsa) [1222189]
- [perf] build: Add arch arm objects building (Jiri Olsa) [1222189]
- [perf] build: Add arch x86 objects building (Jiri Olsa) [1222189]
- [perf] build: Add perf.o object building (Jiri Olsa) [1222189]
- [perf] build: Add zlib objects building (Jiri Olsa) [1222189]
- [perf] build: Add perf regs objects building (Jiri Olsa) [1222189]
- [perf] build: Add scripts objects building (Jiri Olsa) [1222189]
- [perf] build: Add gtk objects building (Jiri Olsa) [1222189]
- [perf] build: Add slang objects building (Jiri Olsa) [1222189]
- [perf] build: Add ui objects building (Jiri Olsa) [1222189]
- [perf] build: Add dwarf unwind objects building (Jiri Olsa) [1222189]
- [perf] build: Add dwarf objects building (Jiri Olsa) [1222189]
- [perf] build: Add probe objects building (Jiri Olsa) [1222189]
- [perf] build: Add libperf objects building (Jiri Olsa) [1222189]
- [perf] build: Add builtin objects building (Jiri Olsa) [1222189]
- [perf] build: Add tests objects building (Jiri Olsa) [1222189]
- [perf] build: Add bench objects building (Jiri Olsa) [1222189]
- [perf] build: Disable make's built-in rules (Jiri Olsa) [1222189]
- [perf] tools: Remove api fs object from python build (Jiri Olsa) [1222189]
- [perf] tools build: Add subdir support (Jiri Olsa) [1222189]
- [perf] tools build: Add detected config support (Jiri Olsa) [1222189]
- [perf] tools build: Add new build support (Jiri Olsa) [1222189]
- [perf] buildid-cache: Consolidate .build-id cache path generators (Jiri Olsa) [1222189]
- [perf] buildid-cache: Remove unneeded debugdir parameters (Jiri Olsa) [1222189]
- [perf] symbols: Define STT_GNU_IFUNC for glibc 2.9 and older (Jiri Olsa) [1222189]
- [perf] tools: Make perf aware of tracefs (Jiri Olsa) [1222189]
- [perf] tools lib api fs: Add {tracefs, debugfs}_configured() functions (Jiri Olsa) [1222189]
- [perf] tools lib api debugfs: Add DEBUGFS_DEFAULT_PATH macro (Jiri Olsa) [1222189]
- [perf] tools lib api fs: Add tracefs mount helper functions (Jiri Olsa) [1222189]
- [perf] tools lib fs: Add helper to find mounted file systems (Jiri Olsa) [1222189]
- [perf] tools: Do not check debugfs MAGIC for tracing files (Jiri Olsa) [1222189]
- [perf] evlist: Fix typo in comment (Jiri Olsa) [1222189]
- [perf] trace: No need to enable evsels for workload started from perf (Jiri Olsa) [1222189]
- [perf] tools: Introduce event_format__fprintf method (Jiri Olsa) [1222189]
- [perf] tools lib traceevent: Introduce trace_seq_do_fprintf function (Jiri Olsa) [1222189]
- [perf] symbols: debuglink should take symfs option into account (Jiri Olsa) [1222189]
- [perf] symbols: Ignore mapping symbols on aarch64 (Jiri Olsa) [1222189]
- [perf] probe: Update man page (Jiri Olsa) [1222189]
- [perf] probe: Fix to handle optimized not-inlined functions (Jiri Olsa) [1222189]
- [perf] tools: Fix a dso open fail message (Jiri Olsa) [1222189]
- [perf] tests: Do not rely on dso__data_read_offset() to open dso (Jiri Olsa) [1222189]
- [perf] test: Fix dso cache testcase (Jiri Olsa) [1222189]
- [perf] tools: Construct LBR call chain (Jiri Olsa) [1222189]
- [perf] tools: Enable LBR call stack support (Jiri Olsa) [1222189]
- [perf] treewide: Fix typo in printk messages (Jiri Olsa) [1222189]
- [perf] annotate: Fix fallback to unparsed disassembler line (Jiri Olsa) [1222189]
- [perf] bench: Add -r all so that you can run all mem* routines (Jiri Olsa) [1222189]
- [perf] bench: Carve out mem routine benchmarking (Jiri Olsa) [1222189]
- [perf] x86/intel/uncore: Move PCI IDs for IMC to uncore driver (Jiri Olsa) [1222189]
- [perf] x86/intel/uncore: Add support for Intel Haswell ULT (lower power Mobile Processor) IMC uncore PMUs (Jiri Olsa) [1222189]
- [perf] x86/intel: Add cpu_(prepare|starting|dying) for core_pmu (Jiri Olsa) [1222189]
- [perf] x86/intel: Add Broadwell support for the LBR callstack (Jiri Olsa) [1222189]
- [perf] x86/intel/rapl: Fix energy counter measurements but supporing per domain energy units (Jiri Olsa) [1222189]
- [perf] x86/intel: Fix Core2, Atom, NHM, WSM cycles:pp events (Jiri Olsa) [1222189]
- [perf] Fix racy group access (Jiri Olsa) [1222189]
- [perf] x86: Remove redundant calls to perf_pmu_{dis|en}able() (Jiri Olsa) [1222189]
- [perf] Remove type specific target pointers (Jiri Olsa) [1222189]
- [perf] x86/intel: Support task events with Intel CQM (Jiri Olsa) [1222189]
- [perf] x86/intel: Add Intel Cache QoS Monitoring support (Jiri Olsa) [1222189]
- [perf] Move cgroup init before PMU ->event_init() (Jiri Olsa) [1222189]
- [perf] Add ->count() function to read per-package counters (Jiri Olsa) [1222189]
- [perf] Make perf_cgroup_from_task() global (Jiri Olsa) [1222189]
- [perf]  powerpc: Fix up flush_branch_stack() users (Jiri Olsa) [1222189]
- [perf] x86/intel: Expose LBR callstack to user space tooling (Jiri Olsa) [1222189]
- [perf] x86/intel: Discard zero length call entries in LBR call stack (Jiri Olsa) [1222189]
- [perf] x86/intel: Disable FREEZE_LBRS_ON_PMI when LBR operates in callstack mode (Jiri Olsa) [1222189]
- [perf] x86/intel: Re-organize code that implicitly enables LBR/PEBS (Jiri Olsa) [1222189]
- [perf] Simplify the branch stack check (Jiri Olsa) [1222189]
- [perf] x86/intel: Save/restore LBR stack during context switch (Jiri Olsa) [1222189]
- [perf] x86/intel: Track number of events that use the LBR callstack (Jiri Olsa) [1222189]
- [perf] x86/intel: Allocate space for storing LBR stack (Jiri Olsa) [1222189]
- [perf] Always switch pmu specific data during context switch (Jiri Olsa) [1222189]
- [perf] Add pmu specific data for perf task context (Jiri Olsa) [1222189]
- [perf] x86/intel: Add basic Haswell LBR call stack support (Jiri Olsa) [1222189]
- [perf] x86/intel: Use context switch callback to flush LBR stack (Jiri Olsa) [1222189]
- [perf] Introduce pmu context switch callback (Jiri Olsa) [1222189]
- [perf] x86/intel: Reduce lbr_sel_map[] size (Jiri Olsa) [1222189]
- [perf] x86/amd/ibs: Convert force_ibs_eilvt_setup() to void (Jiri Olsa) [1222189]
- [perf] Update userspace page info for software event (Jiri Olsa) [1222189]
- [perf] Update shadow timestamp before add event (Jiri Olsa) [1222189]
- [perf] x86/asm/entry: Explicitly optimize vm86 handling in code_segment_base() (Jiri Olsa) [1222189]
- [perf] Fix context leak in put_event() (Jiri Olsa) [1222189]
- [perf] x86/asm/entry: Fix incorrect TIF_IA32 check in code_segment_base() (Jiri Olsa) [1222189]

* Tue May 26 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-255.el7]
- [pci] Keep original resource if we fail to expand it (Myron Stowe) [1221057]
- [x86] Mark Intel Broadwell-EP processor as supported (Steve Best) [1131674]
- [s390] pci: reenable per default (Hendrik Brueckner) [1200410]
- [kernel] ftrace: Have control op function callback only trace when RCU is watching (Jiri Olsa) [1197062]
- [kernel] rcu: Do not trace rcu_is_watching() functions (Jiri Olsa) [1197062]
- [kernel] rcu: Consistent rcu_is_watching() naming (Jiri Olsa) [1197062]
- [kernel] rcu: Is it safe to enter an RCU read-side critical section? (Jiri Olsa) [1197062]
- [kernel] time: Revert to calling clock_was_set_delayed() while in irq context (Prarit Bhargava) [1222767]
- [kernel] tracing: Disable tracing on warning (Josh Poimboeuf) [1149340]
- [netdrv] xen-netfront: use correct linear area after linearizing an skb (Vitaly Kuznetsov) [1144931]
- [netdrv] xen-netfront: Remove BUGs on paged skb data which crosses a page boundary (Vitaly Kuznetsov) [1144931]
- [netdrv] xen-netfront: Fix handling packets on compound pages with skb_linearize (Vitaly Kuznetsov) [1144931]
- [powercap] rapl: add IDs for future Xeon CPUs (Steve Best) [1179961]
- [thermal] powerclamp: add ids for future xeon cpus (Steve Best) [1179953]
- [powerpc] powernv: Use _GLOBAL_TOC for opal wrappers (Steve Best) [1223481]
- [powerpc] pseries: Simplify check for suspendability during suspend/migration (Gustavo Duarte) [1207295]
- [powerpc] pseries: Introduce api_version to migration sysfs interface (Gustavo Duarte) [1207295]
- [powerpc] pseries: Little endian fixes for post mobility device tree update (Gustavo Duarte) [1207295]
- [powerpc] book3s: Fix partial invalidation of TLBs in MCE code (Steve Best) [1221090]
- [powerpc] book3s: Fix the MCE code to use CONFIG_KVM_BOOK3S_64_HANDLER (Steve Best) [1221090]
- [powerpc] powernv: Separate function for OPAL IRQ setup (Steve Best) [1221071]
- [powerpc] powernv: Remove "opal" prefix from pr_xxx()s (Steve Best) [1221071]
- [powerpc] powernv: Support OPAL requested heartbeat (Steve Best) [1221071]

* Wed May 20 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-254.el7]
- [fs] aio: Skip timer for io_getevents if timeout=0 (Carlos Maiolino) [1161535]
- [fs] proc: fix page_size limit of proc pid cmdline fix (Jarod Wilson) [1193998]
- [fs] proc: fix PAGE_SIZE limit of /proc/$PID/cmdline (Jarod Wilson) [1193998]
- [hv] remove the per-channel workqueue (Vitaly Kuznetsov) [1203682]
- [hv] don't schedule new works in vmbus_onoffer()/vmbus_onoffer_rescind() (Vitaly Kuznetsov) [1203682]
- [hv] run non-blocking message handlers in the dispatch tasklet (Vitaly Kuznetsov) [1203682]
- [hv] vmbus: Fix a bug in rescind processing in vmbus_close_internal() (Vitaly Kuznetsov) [1203682]
- [hv] vmbus: Cleanup vmbus_close_internal() (Vitaly Kuznetsov) [1203682]
- [hv] vmbus: missing curly braces in vmbus_process_offer() (Vitaly Kuznetsov) [1203682]
- [hv] vmbus: Perform device register in the per-channel work element (Vitaly Kuznetsov) [1203682]
- [hv] util: On device remove, close the channel after de-initializing the service (Vitaly Kuznetsov) [1203682]
- [hv] vmbus: Remove the channel from the channel list(s) on failure (Vitaly Kuznetsov) [1203682]
- [hv] vmbus: Handle both rescind and offer messages in the same context (Vitaly Kuznetsov) [1203682]
- [hv] vmbus: Introduce a function to remove a rescinded offer (Vitaly Kuznetsov) [1203682]
- [hv] vmbus: Properly handle child device remove (Vitaly Kuznetsov) [1203682]
- [hv] vmbus: serialize Offer and Rescind offer (Vitaly Kuznetsov) [1203682]
- [hv] net: Add support for vNIC hot removal (Vitaly Kuznetsov) [1203682]
- [hv] rename sc_lock to the more generic lock (Vitaly Kuznetsov) [1203682]
- [hv] check vmbus_device_create() return value in vmbus_process_offer() (Vitaly Kuznetsov) [1203682]
- [hv] vmbus: Fix a race condition when unregistering a device (Vitaly Kuznetsov) [1203682]
- [hv] vmbus: prevent cpu offlining on newer hypervisors (Vitaly Kuznetsov) [1167380]
- [netdrv] qlge: Fix qlge_update_hw_vlan_features to handle if interface is down (Chad Dupuis) [1164114]
- [libata] fixup oops in ata_eh_link_report() (Ewan Milne) [1220144]
- [kernel] watchdog: update watchdog_thresh properly (Ulrich Obergfell) [1216074]
- [kernel] watchdog: update watchdog attributes atomically (Ulrich Obergfell) [1216074]
- [cpufreq] powernv: Report cpu frequency throttling (Gustavo Duarte) [1218970]
- [powerpc] powernv: Fix the overflow of OPAL message notifiers head array (Steve Best) [1221089]
- [powerpc] powernv: Add OPAL message notifier unregister function (Steve Best) [1221089]
- [powerpc] powernv: Add pstore support on powernv (Steve Best) [1220165]
- [powerpc] pstore: Add pstore type id for PPC64 opal nvram partition (Steve Best) [1220165]
- [powerpc] nvram: Move generic code for nvram and pstore (Steve Best) [1220165]
- [powerpc] powernv: Handle compound PE in config accessors (Steve Best) [1211946]
- [powerpc] powernv: Handle compound PE for EEH (Steve Best) [1211946]
- [powerpc] powernv: Handle compound PE (Steve Best) [1211946]
- [powerpc] powernv: Split ioda_eeh_get_state() (Steve Best) [1211946]
- [powerpc] powernv: Allow to freeze PE (Steve Best) [1211946]
- [powerpc] powernv: Enable M64 aperatus for PHB3 (Steve Best) [1211946]
- [infiniband] qib: Add blank line after declaration (Doug Ledford) [1185097 1188513]
- [infiniband] qib: Fix checkpatch warnings (Doug Ledford) [1185097 1188513]
- [infiniband] qib: Fix potential NULL d_inode dereference (Doug Ledford) [1185097 1188513]
- [infiniband] qib: Fix sizeof checkpatch warnings (Doug Ledford) [1185097 1188513]
- [infiniband] qib: Add support for the new QMH7360 card (Doug Ledford) [1185097 1188513]
- [infiniband] qib: Do not write EEPROM (Doug Ledford) [1185097 1188513]
- [infiniband] ipoib: drop mcast_mutex usage (Doug Ledford) [1183881]
- [infiniband] ipoib: deserialize multicast joins (Doug Ledford) [1183881]
- [infiniband] ipoib: fix MCAST_FLAG_BUSY usage (Doug Ledford) [1183881]
- [infiniband] ipoib: No longer use flush as a parameter (Doug Ledford) [1183881]
- [infiniband] ipoib: Use dedicated workqueues per interface (Doug Ledford) [1183881]
- [infiniband] ipoib: Make the carrier_on_task race aware (Doug Ledford) [1183881]
- [infiniband] ipoib: Consolidate rtnl_lock tasks in workqueue (Doug Ledford) [1183881]
- [infiniband] ipoib: change init sequence ordering (Doug Ledford) [1183881]
- [infiniband] ipoib: factor out ah flushing (Doug Ledford) [1183881]
- [infiniband] ipoib: Remove unnecessary port query (Doug Ledford) [1183881]

* Fri May 15 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-253.el7]
- [block] scsi-mq: fix requests that use a separate CDB buffer (Jeff Moyer) [1209624]
- [block] Fix bug in blk_rq_merge_ok (Jeff Moyer) [1209624]
- [block] blkmq: Fix NULL pointer deref when all reserved tags in (Jeff Moyer) [1209624]
- [block] blk-mq: fix double-free in error path (Jeff Moyer) [1209624]
- [block] prevent request-to-request merging with gaps if not allowed (Jeff Moyer) [1209624]
- [block] blk-mq: fix false negative out-of-tags condition (Jeff Moyer) [1209624]
- [block] blk-mq: get rid of ->cmd_size in the hardware queue (Jeff Moyer) [1209624]
- [block] revert "blk-mq: Micro-optimize bt_get()" (Jeff Moyer) [1209624]
- [block] blk-mq: Use all available hardware queues (Jeff Moyer) [1209624]
- [block] blk-mq: Micro-optimize bt_get() (Jeff Moyer) [1209624]
- [block] blk-mq: Fix a race between bt_clear_tag() and bt_get() (Jeff Moyer) [1209624]
- [block] blk-mq: Avoid that __bt_get_word() wraps multiple times (Jeff Moyer) [1209624]
- [block] blk-mq: re-check for available tags after running the hardware queue (Jeff Moyer) [1209624]
- [block] blk-mq: fix hang in bt_get() (Jeff Moyer) [1209624]
- [block] blk-mq: cleanup tag free handling (Jeff Moyer) [1209624]
- [block] blk-mq: use 'nr_cpu_ids' as highest CPU ID count for hwq <-> cpu map (Jeff Moyer) [1209624]
- [block] Fix computation of merged request priority (Jeff Moyer) [1209624]
- [block] Return short read or 0 at end of a raw device, not EIO (Jeff Moyer) [1209624]
- [block] revert "block: all blk-mq requests are tagged" (Jeff Moyer) [1209624]
- [block] fix wrong error return in elevator_init() (Jeff Moyer) [1209624]
- [block] scsi: Fix error handling in SCSI_IOCTL_SEND_COMMAND (Jeff Moyer) [1209624]
- [block] remove artifical max_hw_sectors cap (Jeff Moyer) [1209624]
- [block] include func name in __get_request prints (Jeff Moyer) [1209624]
- [block] make blk_update_request print prefix match ratelimited prefix (Jeff Moyer) [1209624]
- [block] include/linux/blkdev.h: use NULL instead of zero (Jeff Moyer) [1209624]
- [block] block_dev: implement readpages() to optimize sequential read (Jeff Moyer) [1209624]
- [block] blk-mq: Make bt_clear_tag() easier to read (Jeff Moyer) [1209624]
- [block] blk-mq: fix potential hang if rolling wakeup depth is too high (Jeff Moyer) [1209624]
- [block] misplaced rq_complete tracepoint (Jeff Moyer) [1209624]
- [block] bdi: reimplement bdev_inode_switch_bdi() (Jeff Moyer) [1209624]
- [block] bsg: fix potential error pointer dereference (Jeff Moyer) [1209624]
- [block] blk-mq: add BLK_MQ_F_DEFER_ISSUE support flag (Jeff Moyer) [1209624]
- [block] blk-mq: put blk_queue_rq_timeout together in blk_mq_init_queue() (Jeff Moyer) [1209624]
- [block] remove redundant check about 'set->nr_hw_queues' in blk_mq_alloc_tag_set() (Jeff Moyer) [1209624]
- [block] blk-mq: release mq's kobjects in blk_release_queue() (Jeff Moyer) [1209624]
- [block] blk-mq: End unstarted requests on a dying queue (Jeff Moyer) [1209624]
- [block] blk-mq: Allow requests to never expire (Jeff Moyer) [1209624]
- [block] blk-mq: Add helper to abort requeued requests (Jeff Moyer) [1209624]
- [block] blk-mq: Let drivers cancel requeue_work (Jeff Moyer) [1209624]
- [block] blk-mq: Export if requests were started (Jeff Moyer) [1209624]
- [block] blk-mq: Wake tasks entering queue on dying (Jeff Moyer) [1209624]
- [block] blk-mq: export blk_mq_freeze_queue() (Jeff Moyer) [1209624]
- [block] wake up waiters when a queue is marked dying (Jeff Moyer) [1209624]
- [block] blk-mq: Export freeze_unfreeze functions (Jeff Moyer) [1209624]
- [block] blk-mq: Exit queue on alloc failure (Jeff Moyer) [1209624]
- [block] blk-mq: prevent unmapped hw queue from being scheduled (Jeff Moyer) [1209624]
- [block] blk-mq: move the kdump check to blk_mq_alloc_tag_set (Jeff Moyer) [1209624]
- [block] blk-mq: handle the single queue case in blk_mq_hctx_next_cpu (Jeff Moyer) [1209624]
- [block] blk-mq: add blk_mq_free_hctx_request() (Jeff Moyer) [1209624]
- [block] blk-mq: export blk_mq_free_request() (Jeff Moyer) [1209624]
- [block] blk-mq: add blk_mq_unique_tag() (Jeff Moyer) [1209624]
- [block] blk-mq: add a 'list' parameter to ->queue_rq() (Jeff Moyer) [1209624]
- [block] blk-mq: allocate cpumask on the home node (Jeff Moyer) [1209624]
- [block] blk-mq: don't wait in blk_mq_queue_enter() if __GFP_WAIT isn't set (Jeff Moyer) [1209624]
- [block] block, scsi: fixup blk_get_request dead queue scenarios (Jeff Moyer) [1209624]
- [block] blk-mq: export blk_mq_run_hw_queues (Jeff Moyer) [1209624]
- [block] blk-mq: make blk_mq_run_queues() static (Jeff Moyer) [1209624]
- [block] blk-mq: use get_cpu/put_cpu instead of preempt_disable_preempt_enable (Jeff Moyer) [1209624]
- [block] blk-mq: call preempt_disable/enable in blk_mq_run_hw_queue, and only if needed (Jeff Moyer) [1209624]
- [block] blk-mq: add blk_mq_init_allocated_queue and export blk_mq_register_disk (Jeff Moyer) [1209624]
- [block] blk-mq: fix use of incorrect goto label in blk_mq_init_queue error path (Jeff Moyer) [1209624]
- [block] blk-mq: support per-distpatch_queue flush machinery (Jeff Moyer) [1209624]
- [block] introduce 'blk_mq_ctx' parameter to blk_get_flush_queue (Jeff Moyer) [1209624]
- [block] flush: avoid to figure out flush queue unnecessarily (Jeff Moyer) [1209624]
- [block] remove blk_init_flush() and its pair (Jeff Moyer) [1209624]
- [block] introduce blk_flush_queue to drive flush machinery (Jeff Moyer) [1209624]
- [block] avoid to use q->flush_rq directly (Jeff Moyer) [1209624]
- [block] move flush initialization to blk_flush_init (Jeff Moyer) [1209624]
- [block] introduce blk_init_flush and its pair (Jeff Moyer) [1209624]
- [block] blk-mq: allocate flush_rq in blk_mq_init_flush() (Jeff Moyer) [1209624]
- [block] blk-mq: handle failure path for initializing hctx (Jeff Moyer) [1209624]
- [block] blk-mq: make mq_queue_reinit_notify() freeze queues in parallel (Jeff Moyer) [1209624]
- [block] blk-mq, percpu-ref: start q->mq_usage_counter in atomic mode (Jeff Moyer) [1209624]
- [block] blk-mq: blk_mq_freeze_queue() should allow nesting (Jeff Moyer) [1209624]
- [lib] percpu-refcount: implement percpu_ref_is_dying() (Jeff Moyer) [1209624]
- [lib] percpu-refcount: remove unnecessary ACCESS_ONCE() in percpu_ref_tryget_live() (Jeff Moyer) [1209624]
- [lib] percpu-refcount: fix DEAD flag contamination of percpu pointer (Jeff Moyer) [1209624]
- [lib] percpu-refcount: Replace smp_read_barrier_depends() with lockless_dereference() (Jeff Moyer) [1209624]
- [lib] percpu-refcount: make INIT_ATOMIC and switch_to_atomic() sticky (Jeff Moyer) [1209624]
- [lib] percpu-refcount: add PERCPU_REF_INIT_* flags (Jeff Moyer) [1209624]
- [lib] percpu-refcount: decouple switching to percpu mode and reinit (Jeff Moyer) [1209624]
- [lib] percpu-refcount: decouple switching to atomic mode and killing (Jeff Moyer) [1209624]
- [lib] percpu-refcount: add PCPU_REF_DEAD (Jeff Moyer) [1209624]
- [lib] percpu-refcount: rename things to prepare for decoupling percpu_atomic mode switch (Jeff Moyer) [1209624]
- [lib] percpu-refcount: replace pcpu_ prefix with percpu_ (Jeff Moyer) [1209624]
- [lib] percpu-refcount: minor code and comment updates (Jeff Moyer) [1209624]
- [lib] percpu-refcount: relocate percpu_ref_reinit() (Jeff Moyer) [1209624]
- [lib] percpu-refcount: make percpu_ref based on longs instead of ints (Jeff Moyer) [1209624]
- [lib] percpu-refcount: add @gfp to percpu_ref_init() (Jeff Moyer) [1209624]
- [block] blk-mq: use percpu_ref for mq usage count (Jeff Moyer) [1209624]
- [lib] percpu-counter: add @gfp to percpu_counter_init() (Jeff Moyer) [1209624]
- [lib] percpu-counter: make percpu_counters_lock irq-safe (Jeff Moyer) [1209624]
- [mm] percpu: implement asynchronous chunk population (Jeff Moyer) [1209624]
- [mm] percpu: rename pcpu_reclaim_work to pcpu_balance_work (Jeff Moyer) [1209624]
- [mm] percpu: implmeent pcpu_nr_empty_pop_pages and chunk->nr_populated (Jeff Moyer) [1209624]
- [mm] percpu: make sure chunk->map array has available space (Jeff Moyer) [1209624]
- [mm] percpu: implement [__]alloc_percpu_gfp() (Jeff Moyer) [1209624]
- [mm] percpu: indent the population block in pcpu_alloc() (Jeff Moyer) [1209624]
- [mm] percpu: make pcpu_alloc_area() capable of allocating only from populated areas (Jeff Moyer) [1209624]
- [mm] percpu: restructure locking (Jeff Moyer) [1209624]
- [mm] percpu: make percpu-km set chunk->populated bitmap properly (Jeff Moyer) [1209624]
- [mm] percpu: move region iterations out of pcpu_[de]populate_chunk() (Jeff Moyer) [1209624]
- [mm] percpu: move common parts out of pcpu_[de]populate_chunk() (Jeff Moyer) [1209624]
- [mm] percpu: remove @may_alloc from pcpu_get_pages() (Jeff Moyer) [1209624]
- [mm] percpu: remove the usage of separate populated bitmap in percpu-vm (Jeff Moyer) [1209624]
- [mm] percpu: perform tlb flush after pcpu_map_pages() failure (Jeff Moyer) [1209624]
- [mm] percpu: fix pcpu_alloc_pages() failure path (Jeff Moyer) [1209624]
- [mm] percpu: Use ALIGN macro instead of hand coding alignment calculation (Jeff Moyer) [1209624]
- [mm] percpu: make pcpu_alloc_chunk() use pcpu_mem_free() instead of kfree() (Jeff Moyer) [1209624]
- [mm] percpu: renew the max_contig if we merge the head and previous block (Jeff Moyer) [1209624]
- [mm] percpu: allocation size should be even (Jeff Moyer) [1209624]
- [mm] percpu: speed alloc_pcpu_area() up (Jeff Moyer) [1209624]
- [mm] percpu: store offsets instead of lengths in ->map[] (Jeff Moyer) [1209624]
- [mm] percpu: fold pcpu_split_block() into the only caller (Jeff Moyer) [1209624]
- [mm] revert "percpu scalability fixes" (Jeff Moyer) [1209624]
- [lib] percpu-refcount: improve WARN messages (Jeff Moyer) [1209624]
- [lib] percpu-refcount: fix synchronize_rcu() in comments (Jeff Moyer) [1209624]
- [lib] percpu-refcount: implement percpu_ref_reinit() and percpu_ref_is_zero() (Jeff Moyer) [1209624]
- [lib] percpu-refcount: require percpu_ref to be exited explicitly (Jeff Moyer) [1209624]
- [lib] percpu-refcount: use unsigned long for pcpu_count pointer (Jeff Moyer) [1209624]
- [lib] percpu-refcount: add helpers for ->percpu_count accesses (Jeff Moyer) [1209624]
- [lib] percpu-refcount: one bit is enough for REF_STATUS (Jeff Moyer) [1209624]
- [lib] percpu-refcount: fix usage of this_cpu_ops (Jeff Moyer) [1209624]
- [lib] percpu-refcount: implement percpu_ref_tryget() (Jeff Moyer) [1209624]
- [lib] percpu-refcount: rename percpu_ref_tryget() to percpu_ref_tryget_live() (Jeff Moyer) [1209624]
- [lib] percpu-refcount: Add a WARN() for ref going negative (Jeff Moyer) [1209624]
- [lib] percpu-refcount: export symbols (Jeff Moyer) [1209624]
- [lib] percpu-refcount: use RCU-sched insted of normal RCU (Jeff Moyer) [1209624]
- [lib] percpu-refcount: implement percpu_tryget() along with percpu_ref_kill_and_confirm() (Jeff Moyer) [1209624]
- [lib] percpu-refcount: implement percpu_ref_cancel_init() (Jeff Moyer) [1209624]
- [lib] percpu-refcount: add __must_check to percpu_ref_init() and don't use ACCESS_ONCE() in percpu_ref_kill_rcu() (Jeff Moyer) [1209624]
- [lib] percpu-refcount: cosmetic updates (Jeff Moyer) [1209624]
- [lib] percpu-refcount: consistently use plain (non-sched) RCU (Jeff Moyer) [1209624]
- [lib] percpu-refcount: Don't use silly cmpxchg() (Jeff Moyer) [1209624]
- [lib] percpu: implement generic percpu refcounting (Jeff Moyer) [1209624]

* Thu May 14 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-252.el7]
- [powercap] rapl: Add support for Intel Skylake processors (Steve Best) [1169598]
- [tools] turbostat: support additional Broadwell model (Steve Best) [1189945]
- [x86] kernel: execution in the early microcode loader (Jacob Tanenbaum) [1206830] {CVE-2015-2666}
- [x86] kernel: Update the UV APIC HUB check (Frank Ramsay) [1215695]
- [x86] kernel: Update the UV APIC driver check (Frank Ramsay) [1215695]
- [x86] kernel: Update the APIC UV OEM check (Frank Ramsay) [1215695]
- [mfd] rtsx: Clear hardware PFM mode in rtl8411b (Jarod Wilson) [1220506]
- [mfd] rtsx: Using pcr_dbg replace dev_dbg (Jarod Wilson) [1220506]
- [mfd] rtsx: Add support for rts525A (Jarod Wilson) [1220506]
- [mfd] rtsx: Add support for rts524A (Jarod Wilson) [1220506]
- [mfd] rtsx: Remove LCTLR defination (Jarod Wilson) [1220506]
- [mfd] rtsx: Update phy register (Jarod Wilson) [1220506]
- [mfd] rtsx: Update driving settings (Jarod Wilson) [1220506]
- [mfd] rtsx: Update PETXCFG address (Jarod Wilson) [1220506]
- [mfd] rtsx: Place register address and values togather (Jarod Wilson) [1220506]
- [mfd] rtsx: Replace TAB by SPC after #define (Jarod Wilson) [1220506]
- [mfd] rtsx: Add func to split u32 into register (Jarod Wilson) [1220506]
- [mfd] rtsx: Fix PM suspend for 5227 & 5249 (Jarod Wilson) [1220506]
- [mfd] rtsx: Fix build warnings for !PM (Jarod Wilson) [1220506]
- [mfd] rtsx_pcr: Fix MSI enable error handling (Jarod Wilson) [1220506]
- [mfd] rtsx: Add dma transfer function (Jarod Wilson) [1220506]
- [mfd] rtsx: modify phase searching method for tuning (Jarod Wilson) [1220506]
- [mfd] rtsx: Add support for card reader rtl8402 (Jarod Wilson) [1220506]
- [mfd] rtsx: Add set pull control macro and simplify rtl8411 (Jarod Wilson) [1220506]
- [mfd] rtsx_pcr: Disable interrupts before cancelling delayed works (Jarod Wilson) [1220506]
- [mfd] mc12xx-i2c: rtsx_pcr: ti-ssp: Remove redundant dev_set_drvdata (Jarod Wilson) [1220506]
- [mfd] rtsx: Modify rts5249_optimize_phy (Jarod Wilson) [1220506]
- [acpi] lpss: add LPSS device for Wildcat Point PCH (Prarit Bhargava) [1208093]
- [acpi] lpss: provide con_id for the clkdev (Prarit Bhargava) [1178891]
- [acpi] lpss: check the result of ioremap() (Prarit Bhargava) [1178891]
- [acpi] lpss: allow to use specific PM domain during ->probe() (Prarit Bhargava) [1178891]
- [acpi] lpss: add all LPSS devices to the specific power domain (Prarit Bhargava) [1178891]
- [acpi] lpss: not using UART RTS override with Auto Flow Control (Prarit Bhargava) [1178891]
- [acpi] lpss: disable async suspend/resume of LPSS devices (Prarit Bhargava) [1178891]
- [acpi] clk: fractional-divider: cast parent_rate to u64 before multiplying (Prarit Bhargava) [1178891]
- [acpi] lpss: complete PM entries for LPSS power domain (Prarit Bhargava) [1178891]
- [acpi] lpss: drop clkdev_name member from lpss_device_desc (Prarit Bhargava) [1178891]
- [acpi] lpss: introduce flags (Prarit Bhargava) [1178891]
- [acpi] lpss: remove struct lpss_shared_clock (Prarit Bhargava) [1178891]
- [acpi] lpss: Take I2C host controllers out of reset (Prarit Bhargava) [1178891]
- [acpi] scan: always register ACPI LPSS scan handler (Prarit Bhargava) [1178891]
- [acpi] lpss: support for fractional divider clock (Prarit Bhargava) [1178891]
- [acpi] clk: new basic clk type for fractional divider (Prarit Bhargava) [1178891]
- [acpi] clk: wrap I/O access for improved portability (Prarit Bhargava) [1178891]
- [acpi] lpss: custom power domain for LPSS (Prarit Bhargava) [1178891]
- [acpi] lpss: Enable async suspend/resume of LPSS devices (Prarit Bhargava) [1178891]
- [acpi] lpss: Support for device latency tolerance PM QoS (Prarit Bhargava) [1178891]
- [acpi] scan: Add bind/unbind callbacks to struct acpi_scan_handler (Prarit Bhargava) [1178891]
- [acpi] pm: qos: Introcuce latency tolerance device PM QoS type (Prarit Bhargava) [1178891]
- [acpi] lpss: fix UART Auto Flow Control (Prarit Bhargava) [1178891]
- [acpi] enable CONFIG_X86_INTEL_LPSS (Prarit Bhargava) [1178891]
- [security] selinux/nlmsg: add a build time check for rtnl/xfrm cmds (Alexander Duyck) [1210224]
- [security] selinux/nlmsg: add XFRM_MSG_MAPPING (Alexander Duyck) [1210224]
- [security] selinux/nlmsg: add XFRM_MSG_MIGRATE (Alexander Duyck) [1210224]
- [security] selinux/nlmsg: add XFRM_MSG_REPORT (Alexander Duyck) [1210224]
- [security] selinux/nlmsg: add XFRM_MSG_[NEW|GET]SADINFO (Alexander Duyck) [1210224]
- [security] selinux/nlmsg: add XFRM_MSG_GETSPDINFO (Alexander Duyck) [1210224]
- [security] selinux/nlmsg: add XFRM_MSG_NEWSPDINFO (Alexander Duyck) [1210224]

* Mon May 11 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-251.el7]
- [x86] perf: Add INST_RETIRED.ALL workarounds (Jiri Olsa) [1086843]
- [x86] perf: Add Broadwell core support (Jiri Olsa) [1086843]
- [x86] perf: Add new cache events table for Haswell (Jiri Olsa) [1086843]
- [x86] perf/uncore: Delete an unnecessary check before pci_dev_put() call (Jiri Olsa) [1176340]
- [x86] perf/uncore/hsw-ep: Handle systems with only two SBOXes (Jiri Olsa) [1176340]
- [x86] perf/uncore: Add scaling units to the EP iMC events (Jiri Olsa) [1176340]
- [x86] perf/uncore: Fix boot crash on SBOX PMU on Haswell-EP (Jiri Olsa) [1176340]
- [x86] perf/uncore: Fix IRP uncore register offsets on Haswell EP (Jiri Olsa) [1176340]
- [x86] perf/uncore: Fix minor race in box set up (Jiri Olsa) [1176340]
- [x86] perf/uncore: Update support for client uncore IMC PMU (Jiri Olsa) [1176340]
- [x86] perf/uncore: Fix PCU filter setup for Sandy/Ivy/Haswell EP (Jiri Olsa) [1176340]
- [x86] perf/uncore: Add missing cbox filter flags on IvyBridge-EP uncore driver (Jiri Olsa) [1176340]
- [x86] perf/uncore: Register the PMU only if the uncore pci device exists (Jiri Olsa) [1176340]
- [x86] perf/uncore: Add Haswell-EP uncore support (Jiri Olsa) [1176340]
- [x86] perf/uncore: Rename IvyTown to IvyBridge-EP (Jiri Olsa) [1176340]
- [x86] perf/uncore: Export basic memory events for IVT IMC PMU (Jiri Olsa) [1176340]
- [x86] perf/uncore: Fix coccinelle warnings (Jiri Olsa) [1176340]
- [x86] perf/uncore: move NHM-EX/WSM-EX specific code to seperate file (Jiri Olsa) [1176340]
- [x86] perf/uncore: Move SNB/IVB-EP specific code to seperate file (Jiri Olsa) [1176340]
- [x86] perf/uncore: Move NHM/SNB/IVB specific code to seperate file (Jiri Olsa) [1176340]
- [x86] perf/uncore: Declare some functions and variables (Jiri Olsa) [1176340]
- [x86] perf/uncore: Fix SNB-EP/IVT Cbox filter mappings (Jiri Olsa) [1176340]
- [x86] perf/uncore: Fix missing end markers for SNB/IVB/HSW IMC PMU (Jiri Olsa) [1176340]
- [x86] perf/uncore: Fix compilation warning in snb_uncore_imc_init_box() (Jiri Olsa) [1176340]
- [x86] perf/uncore: Add __init for uncore_cpumask_init() (Jiri Olsa) [1176340]
- [x86] perf/uncore: use MiB unit for events for SNB/IVB/HSW IMC (Jiri Olsa) [1176340]
- [x86] perf/uncore: add hrtimer to SNB uncore IMC PMU (Jiri Olsa) [1176340]
- [x86] perf/uncore: add SNB/IVB/HSW client uncore memory controller support (Jiri Olsa) [1176340]
- [x86] perf/uncore: move uncore_event_to_box() and uncore_pmu_to_box() (Jiri Olsa) [1176340]
- [x86] perf/uncore: make hrtimer timeout configurable per box (Jiri Olsa) [1176340]
- [x86] perf/uncore: add PCI ids for SNB/IVB/HSW IMC (Jiri Olsa) [1176340]
- [x86] perf/uncore: add ability to customize pmu callbacks (Jiri Olsa) [1176340]
- [x86] perf/uncore: fix initialization of cpumask (Jiri Olsa) [1176340]
- [x86] perf: Add Ivy Bridge-EP uncore IRP box support (Jiri Olsa) [1176340]
- [x86] perf/uncore: Add filter support for IvyBridge-EP QPI boxes (Jiri Olsa) [1176340]
- [x86] perf/uncore: Don't use smp_processor_id() in validate_group() (Jiri Olsa) [1176340]
- [x86] perf: Fix uncore PCI fixed counter handling (Jiri Olsa) [1176340]
- [x86] perf: Convert kmalloc_node(...GFP_ZERO...) to kzalloc_node() (Jiri Olsa) [1176340]
- [x86] perf/uncore: Enable EV_SEL_EXT bit for PCU (Jiri Olsa) [1176340]
- [x86] perf/uncore: Add filter support for QPI boxes (Jiri Olsa) [1176340]
- [x86] perf/uncore: Add auxiliary pci device support (Jiri Olsa) [1176340]
- [x86] perf: Fix sparse warning (Jiri Olsa) [1176340]
- [x86] perf: Reduce stack usage of x86_schedule_events() (Jiri Olsa) [1176340]
- [x86] perf: Prevent some shift wrapping bugs in the Intel uncore driver (Jiri Olsa) [1176340]
- [perf] tools: Make sparc64 arch point to sparc (Jiri Olsa) [1209607]
- [perf] symbols: Define EM_AARCH64 for older OSes (Jiri Olsa) [1209607]
- [perf] top: Fix SIGBUS on sparc64 (Jiri Olsa) [1209607]
- [perf] tools: Fix probing for PERF_FLAG_FD_CLOEXEC flag (Jiri Olsa) [1209607]
- [perf] tools: Fix pthread_attr_setaffinity_np build error (Jiri Olsa) [1209607]
- [perf] tools: Define _GNU_SOURCE on pthread_attr_setaffinity_np feature check (Jiri Olsa) [1209607]
- [perf] bench: Fix order of arguments to memcpy_alloc_mem (Jiri Olsa) [1209607]
- [perf] symbols: Convert lseek + read to pread (Jiri Olsa) [1209607]
- [perf] tools: Use perf_data_file__fd() consistently (Jiri Olsa) [1209607]
- [perf] symbols: Support to read compressed module from build-id cache (Jiri Olsa) [1209607]
- [perf] evsel: Set attr.task bit for a tracking event (Jiri Olsa) [1209607]
- [perf] header: Set header version correctly (Jiri Olsa) [1209607]
- [perf] record: Show precise number of samples (Jiri Olsa) [1209607]
- [perf] tools: Do not use __perf_session__process_events() directly (Jiri Olsa) [1209607]
- [perf] callchain: Cache eh/debug frame offset for dwarf unwind (Jiri Olsa) [1209607]
- [perf] tools: Provide stub for missing pthread_attr_setaffinity_np (Jiri Olsa) [1209607]
- [perf] evsel: Don't rely on malloc working for sz 0 (Jiri Olsa) [1209607]
- [perf] tools: add hardware breakpoint bp_len test cases (Jiri Olsa) [1209607]
- [perf] tools: allow user to specify hardware breakpoint bp_len (Jiri Olsa) [1209607]
- [perf] tools lib traceevent: Add support for IP address formats (Jiri Olsa) [1209607]
- [perf] ui/tui: Show fatal error message only if exists (Jiri Olsa) [1209607]
- [perf] tests: Fix typo in sample-parsing.c (Jiri Olsa) [1209607]
- [perf] tools lib fs debugfs: Check if debugfs is mounted when handling ENOENT (Jiri Olsa) [1209607]
- [perf] tools lib fs debugfs: Introduce debugfs__strerror_open_tp (Jiri Olsa) [1209607]
- [perf] trace: Fix error reporting for evsel pgfault constructor (Jiri Olsa) [1209607]
- [perf] tools lib fs: Pass filename to debugfs__strerror_open (Jiri Olsa) [1209607]
- [perf] tools lib fs: Adopt debugfs open strerrno method (Jiri Olsa) [1209607]
- [perf] diff: Fix -o/--order option behavior (Jiri Olsa) [1209607]
- [perf] diff: Fix output ordering to honor next column (Jiri Olsa) [1209607]
- [perf] tools: Pass struct perf_hpp_fmt to its callbacks (Jiri Olsa) [1209607]
- [perf] diff: Introduce fmt_to_data_file() helper (Jiri Olsa) [1209607]
- [perf] diff: Print diff result more precisely (Jiri Olsa) [1209607]
- [perf] diff: Get rid of hists__compute_resort() (Jiri Olsa) [1209607]
- [perf] tools: Allow use of an exclusive option more than once (Jiri Olsa) [1209607]
- [perf] tools: Document parameterized and symbolic events (Jiri Olsa) [1209607]
- [perf] tools: Extend format_alias() to include event parameters (Jiri Olsa) [1209607]
- [perf] tools: Support parsing parameterized events (Jiri Olsa) [1209607]
- [perf] tools: Remove some unused functions from color.c (Jiri Olsa) [1209607]
- [perf] report: Get rid of report__inc_stat() (Jiri Olsa) [1209607]
- [perf] hists: Introduce function for deleting/removing hist_entry (Jiri Olsa) [1209607]
- [perf] hists: Rename hist_entry__free to __delete (Jiri Olsa) [1209607]
- [perf] tools: Remove EOL whitespaces (Jiri Olsa) [1209607]
- [perf] mem: Move the mem_operations global to struct perf_mem (Jiri Olsa) [1209607]
- [perf] mem: Enable sampling loads and stores simultaneously (Jiri Olsa) [1209607]
- [perf] probe: Fix probing kretprobes (Jiri Olsa) [1209607]
- [perf] symbols: Introduce 'for' method to iterate over the symbols with a given name (Jiri Olsa) [1209607]
- [perf] probe: Do not rely on map__load() filter to find symbols (Jiri Olsa) [1209607]
- [perf] symbols: Introduce method to iterate symbols ordered by name (Jiri Olsa) [1209607]
- [perf] symbols: Return the first entry with a given name in find_by_name method (Jiri Olsa) [1209607]
- [perf] annotate: Fix memory leaks in LOCK handling (Jiri Olsa) [1209607]
- [perf] annotate: Handle ins parsing failures (Jiri Olsa) [1209607]
- [perf] scripting perl: Force to use stdbool (Jiri Olsa) [1209607]
- [perf] evlist: Remove extraneous 'was' on error message (Jiri Olsa) [1209607]
- [perf] tools: Fix segfault for symbol annotation on TUI (Jiri Olsa) [1209607]
- [perf] test: Fix dwarf unwind using libunwind (Jiri Olsa) [1209607]
- [perf] tools: Avoid build splat for syscall numbers with uclibc (Jiri Olsa) [1209607]
- [perf] tools: Elide strlcpy warning with uclibc (Jiri Olsa) [1209607]
- [perf] tools: Fix statfs.f_type data type mismatch build error with uclibc (Jiri Olsa) [1209607]
- [perf] machine: Fix __machine__findnew_thread() error path (Jiri Olsa) [1209607]
- [perf] tools: Fix building error in x86_64 when dwarf unwind is on (Jiri Olsa) [1209607]
- [perf] probe: Propagate error code when write(2) failed (Jiri Olsa) [1209607]
- [perf] hists browser: Fix segfault when showing callchain (Jiri Olsa) [1209607]
- [perf] callchain: Free callchains when hist entries are deleted (Jiri Olsa) [1209607]
- [perf] hists: Fix children sort key behavior (Jiri Olsa) [1209607]
- [perf] diff: Fix to sort by baseline field by default (Jiri Olsa) [1209607]
- [perf] list: Fix --raw-dump option (Jiri Olsa) [1209607]
- [perf] probe: Fix crash in dwarf_getcfi_elf (Jiri Olsa) [1209607]
- [perf] probe: Fix to fall back to find probe point in symbols (Jiri Olsa) [1209607]
- [perf] callchain: Append callchains only when requested (Jiri Olsa) [1209607]
- [perf] ui/tui: Print backtrace symbols when segfault occurs (Jiri Olsa) [1209607]
- [perf] report: Show progress bar for output resorting (Jiri Olsa) [1209607]
- [perf] Fix building warning on ARM 32 (Jiri Olsa) [1209607]
- [perf] symbols: Fix use after free in filename__read_build_id (Jiri Olsa) [1209607]
- [perf] evlist: Use roundup_pow_of_two (Jiri Olsa) [1209607]
- [perf] tools: Make the mmap length autotuning more robust (Jiri Olsa) [1209607]
- [perf] bitops: Fix signedness of compile-time hweight implementations (Jiri Olsa) [1209607]
- [perf] tools: Remove bitops/hweight usage of bits in tools/perf (Jiri Olsa) [1209607]
- [perf] tools: Adopt roundup_pow_of_two (Jiri Olsa) [1209607]
- [perf] tools: Adopt rounddown_pow_of_two and deps (Jiri Olsa) [1209607]
- [perf] tools: Adopt fls_long and deps (Jiri Olsa) [1209607]
- [perf] tools: Move bitops.h from tools/perf/util to tools/ (Jiri Olsa) [1209607]
- [perf] tools: Introduce asm-generic/bitops.h (Jiri Olsa) [1209607]
- [perf] tools lib: Move asm-generic/bitops/find.h code to tools/include and tools/lib (Jiri Olsa) [1209607]
- [perf] tools: Whitespace prep patches for moving bitops.h (Jiri Olsa) [1209607]
- [perf] tools: Move code originally from asm-generic/atomic.h into tools/include/asm-generic/ (Jiri Olsa) [1209607]
- [perf] tools: Move code originally from linux/log2.h to tools/include/linux/ (Jiri Olsa) [1209607]
- [perf] tools: Move __ffs implementation to tools/include/asm-generic/bitops/__ffs.h (Jiri Olsa) [1209607]
- [perf] evlist: Do not use hard coded value for a mmap_pages default (Jiri Olsa) [1209607]
- [perf] trace: Let the perf_evlist__mmap autosize the number of pages to use (Jiri Olsa) [1209607]
- [perf] evlist: Improve the strerror_mmap method (Jiri Olsa) [1209607]
- [perf] evlist: Clarify sterror_mmap variable names (Jiri Olsa) [1209607]
- [perf] evlist: Fixup brown paper bag on "hint" for --mmap-pages cmdline arg (Jiri Olsa) [1209607]
- [perf] trace: Provide a better explanation when mmap fails (Jiri Olsa) [1209607]
- [perf] evlist: Introduce strerror_mmap method (Jiri Olsa) [1209607]
- [perf] tools: Use sysctl__read_int instead of ad-hoc copies (Jiri Olsa) [1209607]
- [perf] tools lib fs: Add sysctl__read_int helper (Jiri Olsa) [1209607]
- [perf] tools lib fs: Adopt filename__read_int from tools/perf/ (Jiri Olsa) [1209607]
- [perf] kvm stat live: Mark events as (x86 only) in help output (Jiri Olsa) [1209607]
- [perf] tests: Fix attr tests size values to cope with machine state on interrupt ABI changes (Jiri Olsa) [1209607]
- [perf] calloc/xcalloc: Fix argument order (Jiri Olsa) [1209607]
- [perf] callchain: Move cpumode resolve code to add_callchain_ip (Jiri Olsa) [1209607]
- [perf] callchain: Fixup parameter handling error message (Jiri Olsa) [1209607]
- [perf] tools: Add --buildid-dir option to set cache directory (Jiri Olsa) [1209607]
- [perf] buildid cache: Fix -a segfault related to kcore handling (Jiri Olsa) [1209607]
- [perf] buildid-cache: Remove extra debugdir variables (Jiri Olsa) [1209607]
- [perf] tools: Use single strcmp call instead of two (Jiri Olsa) [1209607]
- [perf] hists browser: Change print format from lu to PRIu64 (Jiri Olsa) [1209607]
- [perf] bench: Fix memcpy/memset output (Jiri Olsa) [1209607]
- [perf] bench: Merge memset into memcpy (Jiri Olsa) [1209607]
- [perf] bench: Prepare memcpy for merge (Jiri Olsa) [1209607]
- [perf] session: Do not fail on processing out of order event (Jiri Olsa) [1209607]
- [perf] report: In branch stack mode use address history sorting (Jiri Olsa) [1209607]
- [perf] report: Add --branch-history option (Jiri Olsa) [1209607]
- [perf] callchain: Support handling complete branch stacks as histograms (Jiri Olsa) [1209607]
- [perf] stat: Add support for snapshot counters (Jiri Olsa) [1209607]
- [perf] stat: Add support for per-pkg counters (Jiri Olsa) [1209607]
- [perf] tools: Remove perf_evsel__read interface (Jiri Olsa) [1209607]
- [perf] stat: Use read_counter in read_counter_aggr (Jiri Olsa) [1209607]
- [perf] stat: Make read_counter work over the thread dimension (Jiri Olsa) [1209607]
- [perf] stat: Use perf_evsel__read_cb in read_counter (Jiri Olsa) [1209607]
- [perf] tools: Add snapshot format file parsing (Jiri Olsa) [1209607]
- [perf] tools: Add per-pkg format file parsing (Jiri Olsa) [1209607]
- [perf] evsel: Introduce perf_evsel__read_cb function (Jiri Olsa) [1209607]
- [perf] evsel: Introduce perf_counts_values__scale function (Jiri Olsa) [1209607]
- [perf] evsel: Introduce perf_evsel__compute_deltas function (Jiri Olsa) [1209607]
- [perf] tools: Allow to force redirect pr_debug to stderr (Jiri Olsa) [1209607]
- [perf] tools: Fix segfault due to invalid kernel dso access (Jiri Olsa) [1209607]
- [perf] callchain: Make get_srcline fall back to sym+offset (Jiri Olsa) [1209607]
- [perf] symbols: Move bfd_demangle stubbing to its only user (Jiri Olsa) [1209607]
- [perf] callchain: Enable printing the srcline in the history (Jiri Olsa) [1209607]
- [perf] tools: Collapse first level callchain entry if it has sibling (Jiri Olsa) [1209607]
- [perf] hists browser: Print overhead percent value for first-level callchain (Jiri Olsa) [1209607]
- [perf] tools: Only override the default :tid comm entry (Jiri Olsa) [1209607]
- [perf] tools: Add perf-read-vdso32 and perf-read-vdsox32 to .gitignore (Jiri Olsa) [1209607]
- [perf] evlist: Do not poll events that use the system_wide flag (Jiri Olsa) [1209607]
- [perf] evsel: Fix ftrace:function event recording (Jiri Olsa) [1209607]
- [perf] diff: Add missing handler for PERF_RECORD_MMAP2 events (Jiri Olsa) [1209607]
- [perf] hists: Fix up srcline histogram key formatting (Jiri Olsa) [1209607]
- [perf] annotate: Support source line numbers in annotate (Jiri Olsa) [1209607]
- [perf] tools: Only print base source file for srcline (Jiri Olsa) [1209607]
- [perf] callchain: Use a common function to resolve symbol or name (Jiri Olsa) [1209607]
- [perf] callchain: Use al.addr to set up call chain (Jiri Olsa) [1209607]
- [perf] callchain: Factor out adding new call chain entries (Jiri Olsa) [1209607]
- [perf] tools: Fix annotation with kcore (Jiri Olsa) [1209607]
- [perf] test: fix typo in python test (Jiri Olsa) [1209607]
- [perf] symbols: Fallback to kallsyms when using the minimal 'ELF' loader (Jiri Olsa) [1209607]
- [perf] tools: Clean up libelf feature support code (Jiri Olsa) [1209607]
- [perf] build-id: Move disable_buildid_cache() to util/build-id.c (Jiri Olsa) [1209607]
- [perf] record: Add new -I option to sample interrupted machine state (Jiri Olsa) [1209607]
- [perf] tests: Add interrupted state sample parsing test (Jiri Olsa) [1209607]
- [perf] tools: Add core support for sampling intr machine state regs (Jiri Olsa) [1209607]
- [perf] evsel: Do not call pevent_free_format when deleting tracepoint (Jiri Olsa) [1209607]
- [perf] script python: Removing event cache as it's no longer needed (Jiri Olsa) [1209607]
- [perf] script perl: Removing event cache as it's no longer needed (Jiri Olsa) [1209607]
- [perf] tools: Add test_and_set_bit function (Jiri Olsa) [1209607]
- [perf] tools: Make vmlinux short name more like kallsyms short name (Jiri Olsa) [1209607]
- [perf] tools: Fix build-id matching on vmlinux (Jiri Olsa) [1209607]
- [perf] record: Do not save pathname in ./debug/.build-id directory for vmlinux (Jiri Olsa) [1209607]
- [perf] build-id: Move build-id related functions to util/build-id.c (Jiri Olsa) [1209607]
- [perf] build-id: Rename dsos__write_buildid_table() (Jiri Olsa) [1209607]
- [perf] tools: Add gzip decompression support for kernel module (Jiri Olsa) [1209607]
- [perf] symbols: Preparation for compressed kernel module support (Jiri Olsa) [1209607]
- [perf] tools: Defer export of comms that were not 'set' (Jiri Olsa) [1209607]
- [perf] tools: Add call information to Python export (Jiri Olsa) [1209607]
- [perf] tools: Add call information to the database export API (Jiri Olsa) [1209607]
- [perf] tools: Add branch_type and in_tx to Python export (Jiri Olsa) [1209607]
- [perf] tools: Add branch type to db export (Jiri Olsa) [1209607]
- [perf] tools: Enhance the thread stack to output call/return data (Jiri Olsa) [1209607]
- [perf] tools: Add a thread stack for synthesizing call chains (Jiri Olsa) [1209607]
- [perf] session: Add perf_session__deliver_synth_event() (Jiri Olsa) [1209607]
- [perf] tools: Use evlist__for_each in a few remaining places (Jiri Olsa) [1209607]
- [perf] tools: Add id index (Jiri Olsa) [1209607]
- [perf] probe: Add --quiet option to suppress output result message (Jiri Olsa) [1209607]
- [perf] script: Add Python script to export to postgresql (Jiri Olsa) [1209607]
- [perf] scripting python: Extend interface to export data in a database-friendly way (Jiri Olsa) [1209607]
- [perf] tools: Add facility to export data in database-friendly way (Jiri Olsa) [1209607]
- [perf] pmu: Add proper error handling to print_pmu_events() (Jiri Olsa) [1209607]
- [perf] tools: Do not attempt to run perf-read-vdso32 if it wasn't built (Jiri Olsa) [1209607]
- [perf] tools: Add support for 32-bit compatibility VDSOs (Jiri Olsa) [1209607]
- [perf] tools: Build programs to copy 32-bit compatibility (Jiri Olsa) [1209607]
- [perf] pmu: Let pmu's with no events show up on perf list (Jiri Olsa) [1209607]
- [perf] tools: Ensure return negative value when write header error (Jiri Olsa) [1209607]
- [perf] probe: Use PARSE_OPT_EXCLUSIVE flag (Jiri Olsa) [1209607]
- [perf] tools: Add support for exclusive option (Jiri Olsa) [1209607]
- [perf] kvm: Print kvm specific --help output (Jiri Olsa) [1209607]
- [perf] tools: Export usage string and option table of perf record (Jiri Olsa) [1209607]
- [perf] tools: Add PARSE_OPT_DISABLED flag (Jiri Olsa) [1209607]
- [perf] tests: Use thread->mg->machine (Jiri Olsa) [1209607]
- [perf] tests: Remove misplaced __maybe_unused (Jiri Olsa) [1209607]
- [perf] callchains: Use thread->mg->machine (Jiri Olsa) [1209607]
- [perf] thread: Adopt resolve_callchain method from machine (Jiri Olsa) [1209607]
- [perf] tools: A thread's machine can be found via thread->mg->machine (Jiri Olsa) [1209607]
- [perf] tools: Set thread->mg.machine in all places (Jiri Olsa) [1209607]
- [perf] x86: Fix Haswell CYCLE_ACTIVITY.* counter constraints (Jiri Olsa) [1209607]
- [perf] x86: Filter branches for PEBS event (Jiri Olsa) [1209607]
- [perf] Fix irq_work 'tail' recursion (Jiri Olsa) [1209607]
- [perf] add PMU_EVENT_ATTR_STRING() helper (Jiri Olsa) [1209607]
- [perf] provide sysfs_show for struct perf_pmu_events_attr (Jiri Olsa) [1209607]
- [perf] Decouple unthrottling and rotating (Jiri Olsa) [1209607]
- [perf] Drop module reference on event init failure (Jiri Olsa) [1209607]
- [perf] Use POLLIN instead of POLL_IN for perf poll data in flag (Jiri Olsa) [1209607]
- [perf] Fix put_event() ctx lock (Jiri Olsa) [1209607]
- [perf] Fix move_group() order (Jiri Olsa) [1209607]
- [perf] Fix event->ctx locking (Jiri Olsa) [1209607]
- [perf] Add a bit of paranoia (Jiri Olsa) [1209607]
- [perf] Tighten (and fix) the grouping condition (Jiri Olsa) [1209607]
- [perf] x86: Add model number for Airmont (Jiri Olsa) [1209607]
- [perf] x86: Fix bug for "cycles:p" and "cycles:pp" on SLM (Jiri Olsa) [1209607]
- [perf] rapl: Fix sysfs_show() initialization for RAPL PMU (Jiri Olsa) [1209607]
- [perf] Avoid horrible stack usage (Jiri Olsa) [1209607]
- [perf] Move task_pt_regs sampling into arch code (Jiri Olsa) [1209607]
- [perf] Improve the perf_sample_data struct layout (Jiri Olsa) [1209607]
- [perf] x86: Disallow flags for most Core2/Atom/Nehalem/Westmere events (Jiri Olsa) [1209607]
- [perf] x86: Use INTEL_FLAGS_UEVENT_CONSTRAINT for PRECDIST (Jiri Olsa) [1209607]
- [perf] x86: Add INTEL_FLAGS_UEVENT_CONSTRAINT (Jiri Olsa) [1209607]
- [perf] x86: Add support for sampling PEBS machine state registers (Jiri Olsa) [1209607]
- [perf] Add ability to sample machine state on interrupt (Jiri Olsa) [1209607]
- [perf] list: introduce list_last_entry(), use list_{first, last}_entry() (Jiri Olsa) [1209607]

* Fri May 08 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-250.el7]
- [powercap] rapl: add ID for Broadwell server (Steve Best) [1169551]
- [powerpc] powernv: Restore LPCR with LPCR_PECE1 cleared (Gustavo Duarte) [1193516]
- [kernel] clockevents: Fix cpu_down() race for hrtimer based broadcasting (Gustavo Duarte) [1193516]
- [tty] vt: don't set font mappings on vc not supporting this (Jarod Wilson) [1192395 1213538]
- [x86] kernel: Remove a bogus 'ret_from_fork' optimization (Mateusz Guzik) [1209235] {CVE-2015-2830}
- [x86] mm: Linux stack ASLR implementation (Jacob Tanenbaum) [1195685] {CVE-2015-1593}
- [char] redhat/configs: Kconfig settings for new TPM drivers/support (Jarod Wilson) [1182709]
- [char] tpm: fix call order in tpm-chip.c (Jarod Wilson) [1182709]
- [char] tpm: Additional LE support for tpm_ibmvtpm_send (Jarod Wilson) [1182709]
- [char] tpm, tpm_tis: fix TPM 2.0 probing (Jarod Wilson) [1182709]
- [char] tpm: fix suspend/resume paths for TPM 2.0 (Jarod Wilson) [1182709]
- [char] tpm/tpm_tis: Add missing ifdef CONFIG_ACPI for pnp_acpi_device (Jarod Wilson) [1182709]
- [char] tpm: fix format string error in tpm-chip.c (Jarod Wilson) [1182709]
- [char] char/tpm/tpm_crb: fix build error (Jarod Wilson) [1182709]
- [char] tpm: fixed white spaces coding style issues (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Change tpm_i2c_stm_st33.h to tpm_stm_st33.h (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Replace remaining r by ret (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Sanity cleanup (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Remove sparse spaces (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Add status check when reading data on the FIFO (Jarod Wilson) [1182709]
- [char] tpm: TPM 2.0 FIFO Interface (Jarod Wilson) [1182709]
- [char] tpm: TPM 2.0 CRB Interface (Jarod Wilson) [1182709]
- [char] tpm: TPM 2.0 baseline support (Jarod Wilson) [1182709]
- [char] tpm: device class for tpm (Jarod Wilson) [1182709]
- [char] tpm: rename chip->dev to chip->pdev (Jarod Wilson) [1182709]
- [char] tpm: fix raciness of PPI interface lookup (Jarod Wilson) [1182709]
- [char] tpm: two-phase chip management functions (Jarod Wilson) [1182709]
- [char] tpm: merge duplicate transmit_cmd() functions (Jarod Wilson) [1182709]
- [char] tpm: Update email address in maintainers list and ibmvtpm driver (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Fix coccinelle warnings. Possible NULL pointer dereference (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Increment driver version to 1.2.1 (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Remove useless i2c read on interrupt registers (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Interrupt management improvement (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Few code cleanup (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Add devicetree structure (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Replace tpm_st33_* function with tpm_stm_* (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Replace err/rc/ret by ret for a function return code (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Remove reference to io_serirq (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Add new tpm_stm_dev structure and remove tpm_i2c_buffer[0], [1] buffer (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Move tpm registers to tpm_i2c_stm_st33.c (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Fix few coding style error reported by scripts/checkpatch.pl (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Change License header to have up to date address information (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Update Kconfig in order to be inline to other similar product (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Fix potential bug in tpm_stm_i2c_send (Jarod Wilson) [1182709]
- [char] tpm: Deletion of unnecessary checks before the function call "tpm_dev_vendor_release" (Jarod Wilson) [1182709]
- [char] tpm: remove unnecessary sizeof(u8) (Jarod Wilson) [1182709]
- [char] tpm_tis: verify interrupt during init (Jarod Wilson) [1182709]
- [char] tpm: Add missing error check for devm_kzalloc (Jarod Wilson) [1182709]
- [char] tpm: Add new TPMs to the tail of the list to prevent inadvertent change of dev (Jarod Wilson) [1182709]
- [char] tpm: drop owner assignment from platform_drivers (Jarod Wilson) [1182709]
- [char] tpm: simplify code by using *phN specifier (Jarod Wilson) [1182709]
- [char] tpm: Provide a generic means to override the chip returned timeouts (Jarod Wilson) [1182709]
- [char] tpm: missing tpm_chip_put in tpm_get_random() (Jarod Wilson) [1182709]
- [char] tpm: Properly clean sysfs entries in error path (Jarod Wilson) [1182709]
- [char] tpm: Add missing tpm_do_selftest to ST33 I2C driver (Jarod Wilson) [1182709]
- [char] tpm: Fix resume regression on Chromebooks (Jarod Wilson) [1182709]
- [char] drivers/char: delete non-required instances of include <linux/init.h> (Jarod Wilson) [1182709]
- [char] tpm/tpm-sysfs: active_show() can be static (Jarod Wilson) [1182709]
- [char] tpm: tpm_tis: Fix compile problems with CONFIG_PM_SLEEP/CONFIG_PNP (Jarod Wilson) [1182709]
- [char] tpm: Make tpm-dev allocate a per-file structure (Jarod Wilson) [1182709]
- [char] tpm: Use the ops structure instead of a copy in tpm_vendor_specific (Jarod Wilson) [1182709]
- [char] tpm: Create a tpm_class_ops structure and use it in the drivers (Jarod Wilson) [1182709]
- [char] tpm: Pull all driver sysfs code into tpm-sysfs.c (Jarod Wilson) [1182709]
- [char] tpm: Move sysfs functions from tpm-interface to tpm-sysfs (Jarod Wilson) [1182709]
- [char] tpm: Pull everything related to /dev/tpmX into tpm-dev.c (Jarod Wilson) [1182709]
- [char] tpm: nuvoton: remove unused variable (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_atmel: fix coccinelle warnings (Jarod Wilson) [1182709]
- [char] tpm: fix unreachable code warning (smatch warning) (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_stm_st33: Check return code of get_burstcount (Jarod Wilson) [1182709]
- [char] tpm: detect PPI features by checking availability of _DSM functions (Jarod Wilson) [1182709]
- [char] tpm: replace open-coded _DSM code with helper functions (Jarod Wilson) [1182709]
- [char] acpi: introduce helper interfaces for _DSM method (Jarod Wilson) [1182709]
- [char] tpm: match node name instead of full path when searching for TPM device (Jarod Wilson) [1182709]
- [char] tpm: fix memory leak when walking ACPI namespace (Jarod Wilson) [1182709]
- [char] xen/pvhvm: If xen_platform_pci=0 is set don't blow up (v4) (Jarod Wilson) [1182709]
- [char] acpi: Clean up inclusions of ACPI header files (Jarod Wilson) [1182709]
- [char] tpm: use tabs instead of whitespaces in Kconfig (Jarod Wilson) [1182709]
- [char] tpm: Fix module name description in Kconfig for tpm_i2c_infineon (Jarod Wilson) [1182709]
- [char] tpm: Add support for Atmel I2C TPMs (Jarod Wilson) [1182709]
- [char] tpm: Add support for the Nuvoton NPCT501 I2C TPM (Jarod Wilson) [1182709]
- [char] tpm: Merge the tpm-bios module with tpm.o (Jarod Wilson) [1182709]
- [char] tpm: Rename tpm.c to tpm-interface.c (Jarod Wilson) [1182709]
- [char] tpm: cleanup checkpatch warnings (Jarod Wilson) [1182709]
- [char] tpm: Remove tpm_show_caps_1_2 (Jarod Wilson) [1182709]
- [char] tpm: st33: Remove chip->data_buffer access from this driver (Jarod Wilson) [1182709]
- [char] tpm: Remove redundant dev_set_drvdata (Jarod Wilson) [1182709]
- [char] tpm: Use container_of to locate the tpm_chip in tpm_open (Jarod Wilson) [1182709]
- [char] tpm: Store devname in the tpm_chip (Jarod Wilson) [1182709]
- [char] tpm: atmel: Call request_region with the correct base (Jarod Wilson) [1182709]
- [char] tpm: Use zd formatting for size_t format arguments (Jarod Wilson) [1182709]
- [char] tpm: xen-tpmfront: fix missing declaration of xen_domain (Jarod Wilson) [1182709]
- [char] tpm: xen-tpmfront: Remove the locality sysfs attribute (Jarod Wilson) [1182709]
- [char] tpm: xen-tpmfront: Fix default durations (Jarod Wilson) [1182709]
- [char] tpm: convert tpm_tis driver to use dev_pm_ops from legacy pm_ops (Jarod Wilson) [1182709]
- [char] drivers/xen-tpmfront: Fix compile issue with missing option (Jarod Wilson) [1182709]
- [char] tpm: add xen tpmfront interface (Jarod Wilson) [1182709]
- [char] tpm/tpm_i2c_infineon: Remove unused header file (Jarod Wilson) [1182709]
- [char] tpm: tpm_i2c_infinion: Don't modify i2c_client->driver (Jarod Wilson) [1182709]
- [char] tpm: fix regression caused by section type conflict of tpm_dev_release() in ppc builds (Jarod Wilson) [1182709]
- [char] tpm: move TPM_DIGEST_SIZE defintion (Jarod Wilson) [1182709]
- [char] tpm_tis: missing platform_driver_unregister() on error in init_tis() (Jarod Wilson) [1182709]
- [enclosure] fix WARN_ON removing an adapter in multi-path devices (Maurizio Lombardi) [1204955]
- [scsi] scsi_sysfs: make unpriv_sgio queue attribute accessible for non-block devices (Ewan Milne) [1072734]
- [scsi] increase max_scsi_report_luns from 511 to 16k-1 (Rob Evers) [874231]
- [scsi] trim initial allocation in report_luns if limited by max_report_luns (Rob Evers) [874231]
- [scsi] re-implement 'max_report_luns' merged with latest report_luns code (Rob Evers) [874231]
- [scsi] re-introduce 'max_report_luns' parameter (Rob Evers) [874231]
- [scsi] retry report-luns when reported LU count requires more memory (Rob Evers) [874231]
- [scsi] use set/get_unaligned_be32 in report_luns (Rob Evers) [874231]
- [scsi] avoid unnecessary GFP_ATOMIC allocation in scsi_report_lun_scan (Rob Evers) [874231]
- [scsi] be2iscsi: Bump the driver version (Rob Evers) [1183800]
- [scsi] be2iscsi: Logout of FW Boot Session (Rob Evers) [1183800]
- [scsi] be2iscsi: Update the copyright year (Rob Evers) [1183800]
- [scsi] be2iscsi: Fix memory check before unmapping (Rob Evers) [1183800]
- [scsi] be2iscsi: Fix memory leak in the unload path (Rob Evers) [1183800]
- [scsi] be2iscsi: Fix the PCI request region reserving (Rob Evers) [1183800]
- [scsi] be2iscsi: Fix the retry count for boot targets (Rob Evers) [1183800]
- [scsi] be2iscsi: Fix kernel panic when device initialization fails (Rob Evers) [1183800]
- [scsi] be2iscsi: treewide: Fix typo in printk messages (Rob Evers) [1183800]
- [scsi] be2iscsi: fixed invalid assignment of 64bit mask to host dma_boundary for scatter gather segment boundary limit (Rob Evers) [1183800]
- [scsi] be2iscsi: check ip buffer before copying (Rob Evers) [1183800]
- [scsi] be2iscsi: Fix kernel panic during reboot/shutdown (Rob Evers) [1183800]
- [scsi] fix regression in scsi_send_eh_cmnd() (Ewan Milne) [1167454]
- [scsi] fnic: IOMMU Fault occurs when IO and abort IO is out of order (Maurizio Lombardi) [1159398]
- [scsi] fnic: Fnic Driver crashed with NULL pointer reference (Maurizio Lombardi) [1159398]
- [scsi] fnic: For Standalone C series, "sending VLAN request" message seen even if the link is down (Maurizio Lombardi) [1159398]
- [scsi] fnic: Improper resue of exchange Ids (Maurizio Lombardi) [1159398]
- [scsi] fnic: Memcopy only mimumum of data or trace buffer (Maurizio Lombardi) [1159398]
- [scsi] fnic: Not probing all the vNICS via fnic_probe on boot (Maurizio Lombardi) [1159398]
- [scsi] fnic: assign FIP_ALL_FCF_MACS to fcoe_all_fcfs (Maurizio Lombardi) [1159398]
- [scsi] fnic: fnic Control Path Trace Utility (Maurizio Lombardi) [1159398]
- [scsi] bnx2fc: do not add shared skbs to the fcoe_rx_list (Maurizio Lombardi) [1087796]
- [scsi] do not display kernel pointer in message logs (Ewan Milne) [1124082]
- [scsi] Do not display buffer pointers in scsi_log_send() (Ewan Milne) [1124082]
- [scsi] Conditionally compile in constants.c (Ewan Milne) [1124082]
- [scsi] use per-cpu buffer for formatting scsi_print_result() (Ewan Milne) [1124082]
- [scsi] use per-cpu buffer for formatting sense (Ewan Milne) [1124082]
- [ata] libata: use __scsi_format_command() (Ewan Milne) [1124082]
- [scsi] use external buffer for command logging (Ewan Milne) [1124082]
- [scsi] log request tag for scmd_printk() (Ewan Milne) [1124082]
- [scsi] Implement per-cpu logging buffer (Ewan Milne) [1124082]
- [scsi] set fmt to NULL scsi_extd_sense_format() by default (Ewan Milne) [1124082]
- [scsi] ratelimit I/O error messages (Ewan Milne) [1124082]
- [scsi] correct return values for .eh_abort_handler implementations (Ewan Milne) [1124082]
- [scsi] document scsi_try_to_abort_cmd (Ewan Milne) [1124082]
- [scsi] use shost argument in scsi_eh_prt_fail_stats (Ewan Milne) [1124082]
- [scsi] fixup logging messages in scsi_error.c (Ewan Milne) [1124082]
- [scsi] simplify scsi_log_(send|completion) (Ewan Milne) [1124082]
- [scsi] scsi_lib: Revert "rate-limit the error message from failing commands" (Ewan Milne) [1124082]
- [scsi] remove scsi_show_result() (Ewan Milne) [1124082]
- [scsi] separate out scsi_(host|driver)byte_string() (Ewan Milne) [1124082]
- [scsi] Remove scsi_print_command when calling abort (Ewan Milne) [1124082]
- [scsi] repurpose the last argument from print_opcode_name() (Ewan Milne) [1124082]
- [scsi] consolidate opcode lookup in scsi_opcode_sa_name() (Ewan Milne) [1124082]
- [scsi] merge print_opcode_name() (Ewan Milne) [1124082]
- [scsi] implement scsi_opcode_sa_name (Ewan Milne) [1124082]
- [scsi] remove scsi_print_status() (Ewan Milne) [1124082]
- [scsi] use 'bool' as return value for scsi_normalize_sense() (Ewan Milne) [1124082]
- [scsi] do not decode sense extras (Ewan Milne) [1124082]
- [scsi] stop decoding if scsi_normalize_sense() fails (Ewan Milne) [1124082]
- [scsi] 53c700: remove scsi_print_sense() usage (Ewan Milne) [1124082]
- [scsi] fas216: update logging messages (Ewan Milne) [1124082]
- [scsi] fas216: return DID_ERROR for incomplete data transfer (Ewan Milne) [1124082]
- [scsi] acornscsi: use scsi_print_command() (Ewan Milne) [1124082]
- [scsi] use sdev as argument for sense code printing (Ewan Milne) [1124082]
- [scsi] introduce sdev_prefix_printk() (Ewan Milne) [1124082]
- [scsi] aha152x: debug output update and whitespace cleanup (Ewan Milne) [1124082]
- [scsi] sd: remove scsi_print_sense() in sd_done() (Ewan Milne) [1124082]
- [scsi] remove scsi_cmd_print_sense_hdr() (Ewan Milne) [1124082]
- [scsi] st: add a debug_flag module parameter request (Maurizio Lombardi) [1156041]

* Thu May 07 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-249.el7]
- [cpuidle] powernv: Read target_residency value of idle states from DT if available (Gustavo Duarte) [1199939]
- [cpuidle] powernv: Populate cpuidle state details by querying the device-tree (Gustavo Duarte) [1199939]
- [kernel] timers/tick/broadcast-hrtimer: Fix suspicious RCU usage in idle loop (Gustavo Duarte) [1199939]
- [scsi] ipr: Driver version 2.6.1 (Gustavo Duarte) [1182037]
- [scsi] ipr: AF DASD raw mode implementation in ipr driver (Gustavo Duarte) [1182037]
- [scsi] ipr: Fix possible error path oops during initialization (Gustavo Duarte) [1182037]
- [scsi] ipr: Reset in task context (Gustavo Duarte) [1182037]
- [scsi] ipr: Reboot speed improvements (Gustavo Duarte) [1182037]
- [scsi] ipr: set scsi_level correctly for disk arrays (Gustavo Duarte) [1182037]
- [scsi] ipr: add support for async scanning to speed up boot (Gustavo Duarte) [1182037]
- [ata] libata: Blacklist queued TRIM on Samsung SSD 850 Pro (David Milburn) [1217179]
- [ata] libata: Update Crucial/Micron blacklist (David Milburn) [1217179]
- [ata] libata: prevent HSM state change race between ISR and PIO (David Milburn) [1217179]
- [ata] libata: allow sata_sil24 to opt-out of tag ordered submission (David Milburn) [1217179]
- [ata] ata: libata-core: Remove unused function (David Milburn) [1217179]
- [ata] ahci: Use dev_info() to inform about the lack of Device Sleep support (David Milburn) [1217179]
- [ata] libata: Whitelist SSDs that are known to properly return zeroes after TRIM (David Milburn) [1217179]
- [ata] libata: Remove FIXME comment in atapi_eh_request_sense (David Milburn) [1217179]
- [ata] libata: s/ata_id_removeable()/ata_id_removable()/ (David Milburn) [1217179]
- [ata] libata: Remove FIXME comment in atapi_request_sense() (David Milburn) [1217179]
- [ata] ahci: disable MSI instead of NCQ on Samsung pci-e SSDs on macbooks (David Milburn) [1217179]
- [ata] revert "ahci: Optimize single IRQ interrupt processing" (David Milburn) [1217179]
- [ata] revert "ahci: Do not acquire ata_host::lock from single IRQ handler" (David Milburn) [1217179]
- [ata] ahci: Do not acquire ata_host::lock from single IRQ handler (David Milburn) [1217179]
- [ata] ahci: Optimize single IRQ interrupt processing (David Milburn) [1217179]
- [ata] ahci: Do not read HOST_IRQ_STAT reg in multi-MSI mode (David Milburn) [1217179]
- [ata] ahci: Make few function names more descriptive (David Milburn) [1217179]
- [ata] ahci: Move host activation code into ahci_host_activate() (David Milburn) [1217179]
- [ata] ahci: Move ahci_host_activate() function to libahci.c (David Milburn) [1217179]
- [ata] ahci: Pass SCSI host template as arg to ahci_host_activate() (David Milburn) [1217179]
- [ata] ahci: Cleanup checking of multiple MSIs/SLM modes (David Milburn) [1217179]
- [ata] libata-sff: Fix controllers with no ctl port (David Milburn) [1217179]
- [ata] libata: change ata_<foo>_printk routines to return void (David Milburn) [1217179]
- [ata] ahci: add pcid for Marvel 0x9182 controller (David Milburn) [1217179]
- [ata] ata: Disabling the async PM for JMicron chip 363/361 (David Milburn) [1217179]
- [ata] libata: Use dev_name() for request_irq() to distinguish devices (David Milburn) [1217179]
- [ata] libata: widen Crucial M550 blacklist matching (David Milburn) [1217179]
- [ata] sata_sil24: Identify which card suffered IRQ status error (David Milburn) [1217179]
- [ata] libata: introduce ata_host->n_tags to avoid oops on SAS controllers (David Milburn) [1217179]
- [ata] libata: EH should handle AMNF error condition as a media error (David Milburn) [1217179]
- [ata] libata: support the ata host which implements a queue depth less than 32 (David Milburn) [1217179]
- [ata] libahci: export ahci_qc_issue() and ahci_start_fix_rx() (David Milburn) [1217179]
- [ata] libata: Blacklist queued trim for Crucial M500 (David Milburn) [1217179]
- [ata] ahci: add PCI ID for Marvell 88SE91A0 SATA Controller (David Milburn) [1217179]
- [ata] ata: ahci: append new hflag AHCI_HFLAG_NO_FBS (David Milburn) [1217179]
- [ata] ata: SATL compliance for Inquiry Product Revision (David Milburn) [1217179]
- [ata] ahci: Use pci_enable_msi_exact() instead of pci_enable_msi_range() (David Milburn) [1217179]
- [ata] ahci: Ensure "MSI Revert to Single Message" mode is not enforced (David Milburn) [1217179]
- [ata] libata: Update queued trim blacklist for M5x0 drives (David Milburn) [1217179]
- [ata] libata: use wider match for blacklisting Crucial M500 (David Milburn) [1217179]
- [ata] libata: async resume (David Milburn) [1217179]
- [ata] libata, libsas: kill pm_result and related cleanup (David Milburn) [1217179]
- [ata] libata: end the r-word (David Milburn) [1217179]
- [ata] libata: add ATA_HORKAGE_BROKEN_FPDMA_AA quirk for Seagate Momentus SpinPoint M8 (2BA30001) (David Milburn) [1217179]
- [ata] libata: disable queued TRIM for Crucial M500 mSATA SSDs (David Milburn) [1217179]
- [ata] ata: libahci: replace obsolete simple_strtoul() with kstrtouint() (David Milburn) [1217179]
- [ata] ata: libahci: make ahci_pmp_retry_softreset() as static (David Milburn) [1217179]
- [ata] ata: CONFIG_ATA is libata (David Milburn) [1217179]
- [ata] ahci: disable NCQ on Samsung pci-e SSDs on macbooks (David Milburn) [1217179]
- [ata] ata: delete non-required instances of include <linux/init.h> (David Milburn) [1217179]
- [ata] sata_sil: apply MOD15WRITE quirk to TOSHIBA MK2561GSYN (David Milburn) [1217179]
- [ata] ata: enable quirk from jmicron JMB350 for JMB394 (David Milburn) [1217179]
- [ata] libata: disable LPM for some WD SATA-I devices (David Milburn) [1217179]
- [ata] ahci: add PCI ID for Marvell 88SE9170 SATA controller (David Milburn) [1217179]
- [ata] libata: implement ATA_HORKAGE_NO_NCQ_TRIM and apply it to Micro M500 SSDs (David Milburn) [1217179]
- [ata] libata: disable a disk via libata.force params (David Milburn) [1217179]
- [ata] ahci: bail out on ICH6 before using AHCI BAR (David Milburn) [1217179]
- [ata] drivers: ata: Mark the function as static in libahci.c (David Milburn) [1217179]
- [ata] libata: add ATA_HORKAGE_BROKEN_FPDMA_AA quirk for Seagate Momentus SpinPoint M8 (David Milburn) [1217179]
- [ata] ata: libata-eh: Remove unnecessary snprintf arithmetic (David Milburn) [1217179]
- [ata] libata: Add some missing command descriptions (David Milburn) [1217179]
- [ata] ahci_platform: use dev_info() instead of printk() (David Milburn) [1217179]
- [ata] ahci: use dev_info() instead of printk() (David Milburn) [1217179]
- [ata] ahci: Changing two module params with static and __read_mostly (David Milburn) [1217179]
- [ata] libata: bugfix: Remove __le32 in ata_tf_to_fis() (David Milburn) [1217179]
- [ata] libata: Add support for queued DSM TRIM (David Milburn) [1217179]
- [ata] libata: Add support for SEND/RECEIVE FPDMA QUEUED (David Milburn) [1217179]
- [ata] libata: Add H2D FIS "auxiliary" port flag (David Milburn) [1217179]
- [ata] libata: Populate host-to-device FIS "auxiliary" field (David Milburn) [1217179]
- [ata] ata: pata_arasan: Staticize local symbols (David Milburn) [1217179]
- [ata] sata_mv: Remove unneeded CONFIG_HAVE_CLK ifdefs (David Milburn) [1217179]
- [ata] sata_mv: Remove unneeded forward declaration (David Milburn) [1217179]
- [ata] ata: use dev_get_platdata() (David Milburn) [1217179]
- [ata] ahci: use ATA_BUSY (David Milburn) [1217179]
- [ata] libata: move 'struct ata_taskfile' and friends from ata.h to libata.h (David Milburn) [1217179]
- [ata] libata: cleanup SAT error translation (David Milburn) [1217179]
- [ata] ahci: make ahci_transmit_led_message into a function pointer (David Milburn) [1217179]
- [ata] libata: Add atapi_dmadir force flag (David Milburn) [1217179]
- [virtio] defer config changed notifications (David Gibson) [1196009]
- [virtio] unify config_changed handling (David Gibson) [1196009]
- [netdrv] ibmveth: Fix off-by-one error in ibmveth_change_mtu() (David Gibson) [1209310]
- [scripts] checkpatch: fix code broken by backport (Jerry Snitselaar) [1218494]
- [powerpc] powernv: Check image loaded or not before calling flash (Steve Best) [1182056]
- [security] keys: memory corruption or panic during key garbage collection (Jacob Tanenbaum) [1179852] {CVE-2014-9529}

* Wed May 06 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-248.el7]
- [cpufreq] intel_pstate: remove MSR test (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: provide option to only use intel_pstate with HWP (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: Add num_pstates to sysfs (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: honor user space min_perf_pct override on resume (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: respect cpufreq policy request (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: expose turbo range to sysfs (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: Add a few comments (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: add kernel parameter to force loading (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: skip this driver if Sun server has _PPC method (Prarit Bhargava) [1214335]
- [x86] intel_pstate: Add support for HWP (Prarit Bhargava) [1214335]
- [x86] Add support for Intel HWP feature detection (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: Correct BYT VID values (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: Don't lose sysfs settings during cpu offline (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: Fix BYT frequency reporting (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: Reflect current no_turbo state correctly (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: Fix setting max_perf_pct in performance policy (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: Remove unneeded variable (Prarit Bhargava) [1214335]
- [cpufreq] intel_pstate: Turn per cpu printk into pr_debug (Prarit Bhargava) [1214335]
- [cpufreq] Documentation, add cpu-freq/intel-pstate.txt (Prarit Bhargava) [1214335]
- [pci] Support BAR sizes up to 128GB (Myron Stowe) [1211947]
- [x86] mce: Fix warning about indented braces (Prarit Bhargava) [1217770]
- [x86] mce: Define mce_severity function pointer (Prarit Bhargava) [1217770]
- [x86] mce: Add an AMD severities-grading function (Prarit Bhargava) [1217770]
- [x86] mce: Reindent __mcheck_cpu_apply_quirks() properly (Prarit Bhargava) [1217770]
- [x86] mce: Use safe MSR accesses for AMD quirk (Prarit Bhargava) [1217770]
- [x86] Add another set of MSR accessor functions (Prarit Bhargava) [1217770]
- [x86] mce: Enable thresholding interrupts by default if supported (Prarit Bhargava) [1217770]
- [x86] mce: Make mce_panic() fatal machine check msg in the same pattern (Prarit Bhargava) [1217770]
- [x86] mce: Cleanup CMCI storm logic (Prarit Bhargava) [1217770]
- [x86] mce: Drop bogus const modifier from AMD's bank4_names() (Prarit Bhargava) [1217770]
- [x86] mce: Get rid of TIF_MCE_NOTIFY and associated mce tricks (Prarit Bhargava) [1217770]
- [x86] mce: Fix sparse errors (Prarit Bhargava) [1217770]
- [x86] mce: Improve timeout error messages (Prarit Bhargava) [1217770]
- [x86] mce: Extend the the mce_severity mechanism to handle UCNA/DEFERRED error (Prarit Bhargava) [1217770]
- [x86] mce: Assign interrupt handler only when bank supports it (Prarit Bhargava) [1217770]
- [x86] mce: Drop software-defined bank in error thresholding (Prarit Bhargava) [1217770]
- [x86] mce: Move invariant code out from loop body (Prarit Bhargava) [1217770]
- [x86] mce: Correct thresholding error logging (Prarit Bhargava) [1217770]
- [x86] mce: Use macros to compute bank MSRs (Prarit Bhargava) [1217770]
- [x86] mce: Avoid showing repetitive message from intel_init_thermal() (Prarit Bhargava) [1217770]
- [x86] replace strict_strto calls (Prarit Bhargava) [1217770]
- [x86] mce: Robustify mcheck_init_device (Prarit Bhargava) [1217770]
- [x86] msr-index: define MSR_TURBO_RATIO_LIMIT, 1, 2 (Prarit Bhargava) [1187329]
- [tools] turbostat: correct dumped pkg-cstate-limit value (Prarit Bhargava) [1187329]
- [tools] turbostat: calculate TSC frequency from CPUID(0x15) on SKL (Prarit Bhargava) [1187329]
- [tools] turbostat: correct DRAM RAPL units on recent Xeon processors (Prarit Bhargava) [1187329]
- [tools] turbostat: Use $(CURDIR) instead of $(PWD) and add support for O= option in Makefile (Prarit Bhargava) [1187329]
- [tools] turbostat: modprobe msr, if needed (Prarit Bhargava) [1187329]
- [tools] turbostat: Initial Skylake support (Prarit Bhargava) [1187329]
- [tools] turbostat: dump MSR_TURBO_RATIO_LIMIT2 (Prarit Bhargava) [1187329]
- [tools] turbostat: use new MSR_TURBO_RATIO_LIMIT names (Prarit Bhargava) [1187329]
- [tools] turbostat: update PERF_LIMIT_REASONS decoding (Prarit Bhargava) [1187329]
- [tools] turbostat: label base frequency (Prarit Bhargava) [1187329]
- [tools] turbostat: simplify default output (Prarit Bhargava) [1187329]
- [tools] turbostat: support additional Broadwell model (Prarit Bhargava) [1187329]
- [tools] turbostat: update parameters, documentation (Prarit Bhargava) [1187329]
- [tools] turbostat: Skip printing disabled package C-states (Prarit Bhargava) [1187329]
- [tools] turbostat: relax dependency on APERF_MSR (Prarit Bhargava) [1187329]
- [tools] turbostat: relax dependency on invariant TSC (Prarit Bhargava) [1187329]
- [tools] turbostat: decode MSR_*_PERF_LIMIT_REASONS (Prarit Bhargava) [1187329]
- [tools] turbostat: relax dependency on root permission (Prarit Bhargava) [1187329]
- [hwmon] k10temp: Convert to devm_hwmon_device_register_with_groups (Jarod Wilson) [1135029]
- [hwmon] k10temp: Add support for F15h M60h (Jarod Wilson) [1135029]
- [pci] Add include guard to include/linux/pci_ids.h (Jarod Wilson) [1135029]
- [hwmon] k10temp: Add support for AMD F16 M30h processor (Jarod Wilson) [1135029]
- [hwmon] Do not accept invalid name attributes (Jarod Wilson) [1135029]
- [hwmon] k10temp: Add support for Kaveri CPUs (Jarod Wilson) [1135029]
- [kernel] pci_ids: Add PCI device IDs for F15h M60h (Jarod Wilson) [1135029]
- [kernel] pci_ids: add AMD F16h M30h device IDs (Jarod Wilson) [1135029]
- [hwmon] Provide managed hwmon registration (Jarod Wilson) [1135029]
- [hwmon] Introduce hwmon_device_register_with_groups (Jarod Wilson) [1135029]
- [hwmon] k10temp: remove unnecessary pci_set_drvdata() (Jarod Wilson) [1135029]
- [firmware] dmi_scan: Prevent dmi_num integer overflow (Jarod Wilson) [853192]
- [firmware] dmi_scan: Fix dmi_len type (Jarod Wilson) [853192]
- [firmware] dmi_scan: Fix dmi scan to handle "End of Table" structure (Jarod Wilson) [853192]
- [firmware] dmi: add support for SMBIOS 3.0 64-bit entry point (Jarod Wilson) [853192]
- [firmware] efi: dmi: add support for SMBIOS 3.0 UEFI configuration table (Jarod Wilson) [853192]
- [firmware] dmi_scan: generalize for use by other archs (Jarod Wilson) [853192]
- [firmware] dmi_scan: constify strings (Jarod Wilson) [853192]
- [firmware] dmi_scan: drop OOM messages (Jarod Wilson) [853192]
- [firmware] dmi_scan: fix most checkpatch errors and warnings (Jarod Wilson) [853192]
- [firmware] dmi_scan: drop obsolete comment (Jarod Wilson) [853192]
- [firmware] dmi_scan: add comments on dmi_present() and the loop in dmi_scan_machine() (Jarod Wilson) [853192]

* Tue May 05 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-247.el7]
- [powerpc] eeh: Aux PE data for error log (Steve Best) [1211945]
- [powerpc] eeh: Make diag-data not endian dependent (Steve Best) [1211945]
- [powerpc] eeh: Replace pr_warning() with pr_warn() (Steve Best) [1211945]
- [powerpc] eeh: Reduce lines of log dump (Steve Best) [1211945]
- [powerpc] eeh: Selectively enable IO for error log (Steve Best) [1211945]
- [powerpc] eeh: Refactor EEH flag accessors (Steve Best) [1211945]
- [powerpc] eeh: Fetch IOMMU table in reliable way (Steve Best) [1211945]
- [powerpc] powernv: Fix IOMMU table for VFIO dev (Steve Best) [1211945]
- [powerpc] eeh: sysfs entries lost (Steve Best) [1211945]
- [powerpc] eeh: EEH support for VFIO PCI device (Steve Best) [1211945]
- [powerpc] eeh: Avoid event on passed PE (Steve Best) [1211945]
- [powerpc] powernv: Switch powernv drivers to use machine_xxx_initcall() (Steve Best) [1211945]
- [powerpc] Add machine_early_initcall() (Steve Best) [1211945]
- [powerpc] perf: Cap 64bit userspace backtraces to PERF_MAX_STACK_DEPTH (Steve Best) [1213950]
- [powerpc] kvm: Implement H_LOGICAL_CI_{LOAD,STORE} in KVM (David Gibson) [1184290]
- [mm] zbud: avoid accessing last unused freelist (Seth Jennings) [1141434]
- [mm] zsmalloc: simplify init_zspage free obj linking (Seth Jennings) [1141434]
- [mm] zsmalloc: correct comment for fullness group computation (Seth Jennings) [1141434]
- [mm] zsmalloc: move pages_allocated to zs_pool (Seth Jennings) [1141434]
- [mm] zpool: use prefixed module loading (Seth Jennings) [1141434]
- [mm] zswap: add __init to zswap_entry_cache_destroy() (Seth Jennings) [1141434]
- [mm] zpool: update zswap to use zpool (Seth Jennings) [1141434]
- [mm] zpool: zbud/zsmalloc implement zpool (Seth Jennings) [1141434]
- [mm] zpool: implement common zpool api to zbud/zsmalloc (Seth Jennings) [1141434]
- [mm] zbud: change zbud_alloc size type to size_t (Seth Jennings) [1141434]
- [mm] zswap: NUMA aware allocation for zswap_dstmem (Seth Jennings) [1141434]
- [mm] zsmalloc: make zsmalloc module-buildable (Seth Jennings) [1141434]
- [mm] zsmalloc: fixup trivial zs size classes value in comments (Seth Jennings) [1141434]
- [mm] zbud: make size unsigned like unique callsite (Seth Jennings) [1141434]
- [Documentation] MAINTAINERS: change zswap/zbud maintainer email address (Seth Jennings) [1141434]
- [mm] zswap: remove unnecessary parentheses (Seth Jennings) [1141434]
- [mm] zswap: support multiple swap devices (Seth Jennings) [1141434]
- [mm] zswap: update zsmalloc in comment to zbud (Seth Jennings) [1141434]
- [mm] zswap: fix trivial typo and arrange indentation (Seth Jennings) [1141434]
- [mm] zsmalloc: Fix CPU hotplug callback registration (Seth Jennings) [1141434]
- [mm] Kconfig: fix URL for zsmalloc benchmark (Seth Jennings) [1141434]
- [mm] zsmalloc: add maintainers (Seth Jennings) [1141434]
- [mm] zsmalloc: add copyright (Seth Jennings) [1141434]
- [mm] zsmalloc: move it under mm (Seth Jennings) [1141434]
- [mm] zswap: change params from hidden to ro (Seth Jennings) [1141434]
- [mm] zsmalloc: add more comment (Seth Jennings) [1141434]
- [mm] zsmalloc: add Kconfig for enabling page table method (Seth Jennings) [1141434]
- [mm] zswap: refactor the get/put routines (Seth Jennings) [1141434]
- [mm] zswap: fix memory leak when invalidate and reclaim occur concurrently (Seth Jennings) [1141434]
- [mm] zswap: avoid unnecessary page scanning (Seth Jennings) [1141434]
- [Documentation] zswap: fix typos (Seth Jennings) [1141434]
- [mm] zswap: fix memory leak when re-swapon (Seth Jennings) [1141434]
- [mm] zsmalloc: Fix map_vm_area undefined reference errors (Seth Jennings) [1141434]
- [mm] zswap: use postorder iteration when destroying rbtree (Seth Jennings) [1141434]
- [lib] rbtree: fix rbtree_postorder_for_each_entry_safe() iterator (Seth Jennings) [1141434]
- [lib] rbtree: add rbtree_postorder_for_each_entry_safe() helper (Seth Jennings) [1141434]
- [lib] rbtree: add postorder iteration functions (Seth Jennings) [1141434]
- [mm] zbud: fix some trivial typos in comments (Seth Jennings) [1141434]
- [mm] zswap: get swapper address_space by using macro (Seth Jennings) [1141434]
- [mm] zsmalloc: access page->private by using page_private macro (Seth Jennings) [1141434]
- [mm] zsmalloc: Fixed up incorrect formatted comments (Seth Jennings) [1141434]
- [mm] zsmalloc: Fixes string split across lines in zsmalloc zsmalloc-main (Seth Jennings) [1141434]
- [s390] zfcp: auto port scan resiliency (Hendrik Brueckner) [1182316]
- [s390] zfcp: bring back unit sysfs attributes for automatic LUN scan (Hendrik Brueckner) [1182314]
- [tools] perf: Fix race in build_id_cache__add_s() (Milos Vyletel) [1204077]
- [kernel] sched/rt/nohz: Stop scheduler tick if running realtime task (Rik van Riel) [1193629]
- [kernel] sched: rt: Reduce rq lock contention by eliminating locking of non-feasible target (Larry Woodman) [1195521]

* Fri May 01 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-246.el7]
- [kernel] audit: convert status version to a feature bitmap (Richard Guy Briggs) [1155589]
- [kernel] audit: use define's for audit version (Richard Guy Briggs) [1155589]
- [kernel] audit: clean up AUDIT_GET/SET local variables and future-proof API (Richard Guy Briggs) [1155589]
- [kernel] audit: use memset instead of trying to initialize field by field (Richard Guy Briggs) [1155589]
- [net] libceph: tcp_nodelay support (Sage Weil) [1197952]
- [net] pppoe: Use workqueue to die properly when a PADT is received (Beniamino Galvani) [1025871]
- [net] tcp: restore 1.5x per RTT limit to CUBIC cwnd growth in congestion avoidance (Florian Westphal) [1191260]
- [net] tcp: fix tcp_cong_avoid_ai() credit accumulation bug with decreases in w (Florian Westphal) [1191260]
- [net] tcp: fix timing issue in CUBIC slope calculation (Florian Westphal) [1191260]
- [net] tcp: fix stretch ACK bugs in CUBIC (Florian Westphal) [1191260]
- [net] tcp: fix stretch ACK bugs in Reno (Florian Westphal) [1191260]
- [net] tcp: fix the timid additive increase on stretch ACKs (Florian Westphal) [1191260]
- [net] tcp: stretch ACK fixes prep (Florian Westphal) [1191260]
- [net] tcp_cubic: refine Hystart delay threshold (Florian Westphal) [1191260]
- [net] tcp_cubic: add SNMP counters to track how effective is Hystart (Florian Westphal) [1191260]
- [net] inet_diag: fix access to tcp cc information (Florian Westphal) [1212624]
- [net] inet_diag: fix possible overflow in inet_diag_dump_one_icsk() (Florian Westphal) [1212624]
- [net] inet_diag: zero out uninitialized idiag_{src, dst} fields (Florian Westphal) [1212624]
- [net] tcp: add per route congestion control (Florian Westphal) [1212624]
- [net] tcp: add RTAX_CC_ALGO fib handling (Florian Westphal) [1212624]
- [net] tcp: add key management to congestion control (Florian Westphal) [1212624]
- [net] tcp: refactor reinitialization of congestion control (Florian Westphal) [1212624]
- [net] fib6: convert cfg metric to u32 outside of table write lock (Florian Westphal) [1212624]
- [net] fib6: fib6_commit_metrics: fix potential NULL pointer dereference (Florian Westphal) [1212624]
- [net] ipv6: do not overwrite inetpeer metrics prematurely (Florian Westphal) [1212624]
- [net] dctcp: loosen requirement to assert ECT(0) during 3WHS (Florian Westphal) [1212624]
- [net] tcp: allow setting ecn via routing table (Florian Westphal) [1212624]
- [net] tcp: move TCP_ECN_create_request out of header (Florian Westphal) [1212624]
- [net] syncookies: split cookie_check_timestamp() into two functions (Florian Westphal) [1212624]
- [net] syncookies: avoid magic values and document which-bit-is-what-option (Florian Westphal) [1212624]
- [net] fib_trie: Fix regression in handling of inflate/halve failure (Alexander Duyck) [1205277]
- [net] fib_trie: Address possible NULL pointer dereference in resize (Alexander Duyck) [1205277]
- [net] fib_trie: Correctly handle case of key == 0 in leaf_walk_rcu (Alexander Duyck) [1205277]
- [net] fib_trie: Add key vector to root, return parent key_vector in resize (Alexander Duyck) [1205277]
- [net] fib_trie: Move parent from key_vector to tnode (Alexander Duyck) [1205277]
- [net] fib_trie: Pull empty_children and full_children into tnode (Alexander Duyck) [1205277]
- [net] fib_trie: Move rcu from key_vector to tnode, add accessors. (Alexander Duyck) [1205277]
- [net] fib_trie: Add tnode struct as a container for fields not needed in key_vector (Alexander Duyck) [1205277]
- [net] fib_trie: Rename tnode_child_length to child_length (Alexander Duyck) [1205277]
- [net] fib_trie: replace tnode_get_child functions with get_child macros (Alexander Duyck) [1205277]
- [net] fib_trie: Rename tnode to key_vector (Alexander Duyck) [1205277]
- [net] fib_trie: Make fib_table rcu safe (Alexander Duyck) [1205277]
- [net] fib_trie: Return pointer to tnode pointer in resize/inflate/halve (Alexander Duyck) [1205277]
- [net] fib_trie: Fix RCU bug and merge similar bits of inflate/halve (Alexander Duyck) [1205277]
- [net] fib_trie: Prevent allocating tnode if bits is too big for size_t (Alexander Duyck) [1205277]
- [net] fib_trie: Update last spot w/ idx >> n->bits code and explanation (Alexander Duyck) [1205277]
- [net] fib_trie: move leaf and tnode to occupy the same spot in the key vector (Alexander Duyck) [1205277]
- [net] fib_trie: Update insert and delete to make use of tp from find_node (Alexander Duyck) [1205277]
- [net] fib_trie: Fib find node should return parent (Alexander Duyck) [1205277]
- [net] fib_trie: Fib walk rcu should take a tnode and key instead of a trie and a leaf (Alexander Duyck) [1205277]
- [net] fib_trie: Only resize tnodes once instead of on each leaf removal in fib_table_flush (Alexander Duyck) [1205277]
- [net] fib_trie: Remove leaf_info (Alexander Duyck) [1205277]
- [net] fib_trie: Add slen to fib alias (Alexander Duyck) [1205277]
- [net] fib_trie: Replace plen with slen in leaf_info (Alexander Duyck) [1205277]
- [net] fib_trie: Convert fib_alias to hlist from list (Alexander Duyck) [1205277]
- [net] fib_trie: Various clean-ups for handling slen (Alexander Duyck) [1205277]
- [net] fib_trie: Move fib_find_alias to file where it is used (Alexander Duyck) [1205277]
- [net] fib_trie: Use empty_children instead of counting empty nodes in stats collection (Alexander Duyck) [1205277]
- [net] fib_trie: Add collapse() and should_collapse() to resize (Alexander Duyck) [1205277]
- [net] fib_trie: Fall back to slen update on inflate/halve failure (Alexander Duyck) [1205277]
- [net] fib_trie: Use index & (~0ul << n->bits) instead of index >> n->bits (Alexander Duyck) [1205277]
- [net] fib_trie: Add tracking value for suffix length (Alexander Duyck) [1205277]
- [net] fib_trie: Remove checks for index >= tnode_child_length from tnode_get_child (Alexander Duyck) [1205277]
- [net] fib_trie: inflate/halve nodes in a more RCU friendly way (Alexander Duyck) [1205277]
- [net] fib_trie: Push tnode flushing down to inflate/halve (Alexander Duyck) [1205277]
- [net] fib_trie: Push assignment of child to parent down into inflate/halve (Alexander Duyck) [1205277]
- [net] fib_trie: Add functions should_inflate and should_halve (Alexander Duyck) [1205277]
- [net] fib_trie: Move resize to after inflate/halve (Alexander Duyck) [1205277]
- [net] fib_trie: Push rcu_read_lock/unlock to callers (Alexander Duyck) [1205277]
- [net] fib_trie: Use unsigned long for anything dealing with a shift by bits (Alexander Duyck) [1205277]
- [net] fib_trie: Update meaning of pos to represent unchecked bits (Alexander Duyck) [1205277]
- [net] fib_trie: Optimize fib_table_insert (Alexander Duyck) [1205277]
- [net] fib_trie: Optimize fib_find_node (Alexander Duyck) [1205277]
- [net] fib_trie: Optimize fib_table_lookup to avoid wasting time on loops/variables (Alexander Duyck) [1205277]
- [net] fib_trie: Merge leaf into tnode (Alexander Duyck) [1205277]
- [net] fib_trie: Merge tnode_free and leaf_free into node_free (Alexander Duyck) [1205277]
- [net] fib_trie: Make leaf and tnode more uniform (Alexander Duyck) [1205277]
- [net] fib_trie: Update usage stats to be percpu instead of global variables (Alexander Duyck) [1205277]
- [net] fib_trie: Fix trie balancing issue if new node pushes down existing node (Alexander Duyck) [1205277]
- [net] fib_trie: only calc for the un-first node (Alexander Duyck) [1205277]
- [net] fib_trie: avoid a redundant bit judgement in inflate (Alexander Duyck) [1205277]
- [net] fib_trie: Fix /proc/net/fib_trie when CONFIG_IP_MULTIPLE_TABLES is not defined (Alexander Duyck) [1205277]
- [net] ipv6: gre: add x-netns support (Hannes Frederic Sowa) [1210346 1210390]
- [net] gre: add x-netns support (Hannes Frederic Sowa) [1210346 1210390]
- [net] ip6_gre: fix flowi6_proto value in xmit path (Hannes Frederic Sowa) [1210346 1210390]
- [net] ipv6: Initialize ip6_tnl.hlen in gre tunnel even if no route is found (Hannes Frederic Sowa) [1210346 1210390]
- [net] ipv6: protect skb->sk accesses from recursive dereference inside the stack (Hannes Frederic Sowa) [1129707]
- [net] ip_tunnel: Change __skb_push back to skb_push (Florian Westphal) [1187739]
- [net] ip_tunnel: fix possible rtable leak (Florian Westphal) [1187739]
- [net] ip_tunnel: clear IPCB in ip_tunnel_xmit() in case dst_link_failure() is called (Florian Westphal) [1187739]
- [net] ipv4: be friend with drop monitor (Florian Westphal) [1187739]
- [net] ip_tunnel: Fix a memory corruption in ip_tunnel_xmit (Florian Westphal) [1187739]
- [net] ip_tunnel: Do not use stale inner_iph pointer (Florian Westphal) [1187739]

* Thu Apr 30 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-245.el7]
- [mm] memcg: use proper memcg in limit bypass (Johannes Weiner) [1213903] {CVE-2014-8171}
- [mm] memcg: do not allow task about to OOM kill to bypass the limit (Johannes Weiner) [1213903] {CVE-2014-8171}
- [mm] memcg: do not declare OOM from __GFP_NOFAIL allocations (Johannes Weiner) [1213903] {CVE-2014-8171}
- [fs] buffer: move allocation failure loop into the allocator (Johannes Weiner) [1213903] {CVE-2014-8171}
- [mm] memcg: handle non-error OOM situations more gracefully (Johannes Weiner) [1213903] {CVE-2014-8171}
- [mm] memcg: do not trap chargers with full callstack on OOM (Johannes Weiner) [1213903] {CVE-2014-8171}
- [mm] memcg: rework and document OOM waiting and wakeup (Johannes Weiner) [1213903] {CVE-2014-8171}
- [mm] memcg: enable memcg OOM killer only for user faults (Johannes Weiner) [1213903] {CVE-2014-8171}
- [x86] finish user fault error path with fatal signal (Johannes Weiner) [1213903] {CVE-2014-8171}
- [arch] mm: pass userspace fault flag to generic fault handler (Johannes Weiner) [1213903] {CVE-2014-8171}
- [block] cfq-iosched: handle failure of cfq group allocation (Vivek Goyal) [1190716]
- [crypto] qat - do not duplicate string containing firmware name (Nikolay Aleksandrov) [1173791]
- [crypto] qat - fix double release_firmware on error path (Nikolay Aleksandrov) [1173791]
- [crypto] qat - print ring name in debug output (Nikolay Aleksandrov) [1173791]
- [crypto] qat - fix checkpatch CODE_INDENT issue (Nikolay Aleksandrov) [1173791]
- [crypto] qat - fix checkpatch COMPARISON_TO_NULL issue (Nikolay Aleksandrov) [1173791]
- [crypto] qat - fix checkpatch BIT_MACRO issues (Nikolay Aleksandrov) [1173791]
- [crypto] qat - fix checkpatch CONCATENATED_STRING issues (Nikolay Aleksandrov) [1173791]
- [crypto] qat - checkpatch PARENTHESIS_ALIGNMENT and LOGICAL_CONTINUATIONS (Nikolay Aleksandrov) [1173791]
- [crypto] qat - fix checkpatch CHECK_SPACING issues (Nikolay Aleksandrov) [1173791]
- [crypto] qat - fix typo (Nikolay Aleksandrov) [1173791]
- [crypto] qat - make error and info log messages more descriptive (Nikolay Aleksandrov) [1173791]
- [crypto] qat - fix typo in string (Nikolay Aleksandrov) [1173791]
- [crypto] qat - remove duplicate definition of Intel PCI vendor id (Nikolay Aleksandrov) [1173791]
- [crypto] qat - remove incorrect __exit markup (Nikolay Aleksandrov) [1173791]
- [crypto] qat - don't need qat_auth_state struct (Nikolay Aleksandrov) [1173791]
- [crypto] qat - Ensure ipad and opad are zeroed (Nikolay Aleksandrov) [1173791]
- [crypto] qat - remove unnecessary include of atomic.h header file (Nikolay Aleksandrov) [1173791]
- [crypto] qat - use pci_wait_for_pending_transaction() (Nikolay Aleksandrov) [1173791]
- [crypto] qat - adf_ae_stop() is never called (Nikolay Aleksandrov) [1173791]
- [crypto] qat - correctly type a boolean (Nikolay Aleksandrov) [1173791]
- [crypto] qat - fix device reset flow (Nikolay Aleksandrov) [1173791]
- [crypto] qat - Fix incorrect uses of memzero_explicit (Nikolay Aleksandrov) [1173791]
- [crypto] qat - add support for cbc(aes) ablkcipher (Nikolay Aleksandrov) [1173791]
- [crypto] qat - Fix assumption that sg in and out will have the same nents (Nikolay Aleksandrov) [1173791]
- [crypto] qat - fix problem with coalescing enable logic (Nikolay Aleksandrov) [1173791]
- [crypto] qat - Fix 64 bytes requests (Nikolay Aleksandrov) [1173791]
- [crypto] qat - Use memzero_explicit (Nikolay Aleksandrov) [1173791]
- [crypto] qat - Move BAR definitions to device specific module (Nikolay Aleksandrov) [1173791]
- [crypto] qat - misspelling typo - "reseting" should be "resetting" (Nikolay Aleksandrov) [1173791]
- [crypto] qat - cleanup unnecessary break checkpatch warning (Nikolay Aleksandrov) [1173791]
- [crypto] qat - cleanup coccicheck warning - NULL check before freeing functions (Nikolay Aleksandrov) [1173791]
- [crypto] qat - fix bad unlock balance (Nikolay Aleksandrov) [1173791]
- [crypto] llvmlinux: Remove VLAIS from crypto/.../qat_algs.c (Nikolay Aleksandrov) [1173791]
- [crypto] llvmlinux: Add macro to remove use of VLAIS in crypto code (Nikolay Aleksandrov) [1173791]
- [crypto] qat - Removed unneeded partial state (Nikolay Aleksandrov) [1173791]
- [crypto] qat - Fix typo in name of tasklet_struct (Nikolay Aleksandrov) [1173791]
- [crypto] treewide: fix errors in printk (Nikolay Aleksandrov) [1173791]
- [netdrv] netxen: Fix trivial typos in comments (Tony Camuso) [1187294]
- [netdrv] netxen: Use eth_<foo>_addr instead of memset (Tony Camuso) [1187294]
- [netdrv] netxen: Fix typo in printk (Tony Camuso) [1187294]
- [netdrv] netxen: Delete an unnecessary check before the function call "kfree" (Tony Camuso) [1187294]
- [netdrv] netxen: fix netxen_nic_poll() logic (Tony Camuso) [1187294]
- [netdrv] netxen: Fix link event handling (Tony Camuso) [1187294]
- [netdrv] netxen: Fix bug in Tx completion path (Tony Camuso) [1187294]
- [netdrv] netxen: Fix BUG "sleeping function called from invalid context" (Tony Camuso) [1187294]
- [netdrv] netxen: Convert remaining uses of pr_warning to pr_warn (Tony Camuso) [1187294]
- [kernel] time: More core infrastructure for timespec64 (Prarit Bhargava) [1215108]
- [kernel] time64: Add time64.h header and define struct timespec64 (Prarit Bhargava) [1215108]

* Wed Apr 29 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-244.el7]
- [kernel] timers: Reduce future __run_timers() latency for first add to empty list (Rik van Riel) [1193625]
- [kernel] subject timers: Reduce future __run_timers() latency for newly emptied list (Rik van Riel) [1193625]
- [kernel] timers: Reduce __run_timers() latency for empty list (Rik van Riel) [1193625]
- [kernel] timers: Track total number of timers in list (Rik van Riel) [1193625]
- [misc] genwqe: remove unnecessary version.h inclusion (Steve Best) [1182052]
- [misc] assorted conversions to p[dD] (Steve Best) [1182052]
- [misc] genwqe: check for error from get_user_pages_fast() (Steve Best) [1182052]
- [misc] genwqe: Support blocking when DDCB queue is busy (Steve Best) [1182052]
- [misc] genwqe: Fix checkpatch complaints (Steve Best) [1182052]
- [misc] genwqe: Check return code of pci_sriov_enable (Steve Best) [1182052]
- [misc] genwqe: Do not modify return code of genwqe_set_interrupt_capability (Steve Best) [1182052]
- [misc] genwqe: Update author information (Steve Best) [1182052]
- [misc] genwqe: Remove sysfs entry for driver version (Steve Best) [1182052]
- [misc] genwqe: Check pci_get_totalvfs return code (Steve Best) [1182052]
- [misc] genwqe: fix pci_enable_msi usage (Steve Best) [1182052]
- [s390] dasd: fix inability to set a DASD device offline (Hendrik Brueckner) [1213888]
- [s390] dasd: Fix unresumed device after suspend/resume having no paths (Hendrik Brueckner) [1213889]
- [s390] af_iucv: fix AF_IUCV sendmsg() errno (Hendrik Brueckner) [1213885]
- [s390] dasd: fix unresumed device after suspend/resume (Hendrik Brueckner) [1213884]
- [scsi] megaraid_sas: revert: Add release date and update driver version (Tomas Henzl) [1207175]
- [pci] Fix RHEL7 specific possible Null pointer dereference (Myron Stowe) [1215237]
- [x86] mce: Fix regression. All error records should report via /dev/mcelog (Seth Jennings) [1183957]
- [fs] isofs: Fix unchecked printing of ER records (Mateusz Guzik) [1180483] {CVE-2014-9584}
- [fs] isofs: infinite loop in CE record entries (Jacob Tanenbaum) [1175248] {CVE-2014-9420}

* Mon Apr 27 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-243.el7]
- [fs] xfs: fix behaviour of XFS_IOC_FSSETXATTR on directories (Brian Foster) [1200652]
- [fs] xfs: factor projid hint checking out of xfs_ioctl_setattr (Brian Foster) [1200652]
- [fs] xfs: factor extsize hint checking out of xfs_ioctl_setattr (Brian Foster) [1200652]
- [fs] xfs: XFS_IOCTL_SETXATTR can run in user namespaces (Brian Foster) [1200652]
- [fs] xfs: kill xfs_ioctl_setattr behaviour mask (Brian Foster) [1200652]
- [fs] xfs: disaggregate xfs_ioctl_setattr (Brian Foster) [1200652]
- [fs] xfs: factor out xfs_ioctl_setattr transaciton preamble (Brian Foster) [1200652]
- [fs] xfs: separate xflags from xfs_ioctl_setattr (Brian Foster) [1200652]
- [fs] xfs: FSX_NONBLOCK is not used (Brian Foster) [1200652]
- [fs] xfs: split metadata and log buffer completion to separate workqueues (Brian Foster) [1184177]
- [fs] xfs: check xfs_buf_read_uncached returns correctly (Brian Foster) [1184177]
- [fs] xfs: introduce xfs_buf_submit[_wait] (Brian Foster) [1184177]
- [fs] xfs: kill xfs_bioerror_relse (Brian Foster) [1184177]
- [fs] xfs: xfs_bioerror can die (Brian Foster) [1184177]
- [fs] xfs: kill xfs_bdstrat_cb (Brian Foster) [1184177]
- [fs] xfs: rework xfs_buf_bio_endio error handling (Brian Foster) [1184177]
- [fs] xfs: xfs_buf_ioend and xfs_buf_iodone_work duplicate functionality (Brian Foster) [1184177]
- [fs] xfs: synchronous buffer IO needs a reference (Brian Foster) [1184177]
- [fs] xfs: Keep sb_bad_features2 consistent with sb_features2 (Brian Foster) [1184177]
- [fs] xfs: fix set-but-unused warnings (Brian Foster) [1184177]
- [fs] xfs: move type conversion functions to xfs_dir.h (Brian Foster) [1184177]
- [fs] xfs: move ftype conversion functions to libxfs (Brian Foster) [1184177]
- [fs] xfs: active inodes stat is broken (Brian Foster) [1184177]
- [fs] xfs: cleanup xfs_bmse_merge returns (Brian Foster) [1184177]
- [fs] xfs: cleanup xfs_bmse_shift_one goto mess (Brian Foster) [1184177]
- [fs] xfs: fix premature enospc on inode allocation (Brian Foster) [1184177]
- [fs] xfs: overflow in xfs_iomap_eof_align_last_fsb (Brian Foster) [1184177]
- [fs] xfs: fix simple_return.cocci warning in xfs_bmse_shift_one (Brian Foster) [1184177]
- [fs] xfs: fix simple_return.cocci warning in xfs_file_readdir (Brian Foster) [1184177]
- [fs] libxfs: fix simple_return.cocci warnings (Brian Foster) [1184177]
- [fs] xfs: remove unnecessary null checks (Brian Foster) [1184177]
- [fs] xfs: merge xfs_inum.h into xfs_format.h (Brian Foster) [1184177]
- [fs] xfs: move most of xfs_sb.h to xfs_format.h (Brian Foster) [1184177]
- [fs] xfs: merge xfs_ag.h into xfs_format.h (Brian Foster) [1184177]
- [fs] xfs: move acl structures to xfs_format.h (Brian Foster) [1184177]
- [fs] xfs: merge xfs_dinode.h into xfs_format.h (Brian Foster) [1184177]
- [fs] xfs: allow lazy sb counter sync during filesystem freeze sequence (Brian Foster) [1184177]
- [fs] xfs: fix error handling in xfs_qm_log_quotaoff() (Brian Foster) [1184177]
- [fs] xfs: replace on-stack xfs_trans_res with pointer in xfs_create() (Brian Foster) [1184177]
- [fs] xfs: track bulkstat progress by agino (Brian Foster) [1184177]
- [fs] xfs: bulkstat error handling is broken (Brian Foster) [1184177]
- [fs] xfs: bulkstat main loop logic is a mess (Brian Foster) [1184177]
- [fs] xfs: bulkstat chunk-formatter has issues (Brian Foster) [1184177]
- [fs] xfs: bulkstat chunk formatting cursor is broken (Brian Foster) [1184177]
- [fs] xfs: bulkstat btree walk doesn't terminate (Brian Foster) [1184177]
- [fs] xfs: rework zero range to prevent invalid i_size updates (Brian Foster) [1184177]
- [fs] xfs: Check error during inode btree iteration in xfs_bulkstat() (Brian Foster) [1184177]
- [fs] xfs: bulkstat doesn't release AGI buffer on error (Brian Foster) [1184177]
- [fs] xfs: fix agno increment in xfs_inumbers() loop (Brian Foster) [1184177]
- [fs] xfs: xfs_iflush_done checks the wrong log item callback (Brian Foster) [1184177]
- [fs] xfs: check for null dquot in xfs_quota_calc_throttle() (Brian Foster) [1184177]
- [fs] xfs: fix crc field handling in xfs_sb_to/from_disk (Brian Foster) [1184177]
- [fs] xfs: don't send null bp to xfs_trans_brelse() (Brian Foster) [1184177]
- [fs] xfs: check for inode size overflow in xfs_new_eof() (Brian Foster) [1184177]
- [fs] xfs: kill time.h (Brian Foster) [1184177]
- [fs] xfs: compat_xfs_bstat does not have forkoff (Brian Foster) [1184177]
- [fs] xfs: Don't use xfs_buf_iowait in the delwri buffer code (Brian Foster) [1184177]
- [fs] xfs: force the log before shutting down (Brian Foster) [1184177]
- [fs] xfs: annotate user variables passed as void (Brian Foster) [1184177]
- [fs] xfs: xfs_kset should be static (Brian Foster) [1184177]
- [fs] xfs: fix use of agi_newino in finobt lookup (Brian Foster) [1184177]
- [fs] xfs: refactor recovery transaction start handling (Brian Foster) [1184177]
- [fs] xfs: reorganise transaction recovery item code (Brian Foster) [1184177]
- [fs] xfs: fix double free in xlog_recover_commit_trans (Brian Foster) [1184177]
- [fs] xfs: recovery of XLOG_UNMOUNT_TRANS leaks memory (Brian Foster) [1184177]
- [fs] xfs: refactor xlog_recover_process_data() (Brian Foster) [1184177]
- [fs] xfs: flush entire last page of old EOF on truncate up (Brian Foster) [1184177]
- [fs] xfs: xfs_swap_extent_flush can be static (Brian Foster) [1184177]
- [fs] xfs: xfs_buf_write_fail_rl_state can be static (Brian Foster) [1184177]
- [fs] xfs: xfs_rtget_summary can be static (Brian Foster) [1184177]
- [fs] xfs: remove second xfs_quota.h inclusion in xfs_icache.c (Brian Foster) [1184177]
- [fs] xfs: don't ASSERT on corrupt ftype (Brian Foster) [1184177]
- [fs] xfs: xlog_cil_force_lsn doesn't always wait correctly (Brian Foster) [1184177]
- [fs] xfs: only writeback and truncate pages for the freed range (Brian Foster) [1184177]
- [fs] xfs: writeback and inval. file range to be shifted by collapse (Brian Foster) [1184177]
- [fs] xfs: refactor single extent shift into xfs_bmse_shift_one() helper (Brian Foster) [1184177]
- [fs] xfs: refactor shift-by-merge into xfs_bmse_merge() helper (Brian Foster) [1184177]
- [fs] xfs: track collapse via file offset rather than extent index (Brian Foster) [1184177]
- [fs] xfs: ensure WB_SYNC_ALL writeback handles partial pages correctly (Brian Foster) [1184177]
- [fs] xfs: remove rbpp check from xfs_rtmodify_summary_int (Brian Foster) [1184177]
- [fs] xfs: combine xfs_rtmodify_summary and xfs_rtget_summary (Brian Foster) [1184177]
- [fs] xfs: combine xfs_dir_canenter into xfs_dir_createname (Brian Foster) [1184177]
- [fs] xfs: check resblks before calling xfs_dir_canenter (Brian Foster) [1184177]
- [fs] xfs: deduplicate xlog_do_recovery_pass() (Brian Foster) [1184177]
- [fs] xfs: lseek: the "whence" argument is called "whence" (Brian Foster) [1184177]
- [fs] xfs: combine xfs_seek_hole & xfs_seek_data (Brian Foster) [1184177]
- [fs] xfs: export log_recovery_delay to delay mount time log recovery (Brian Foster) [1184177]
- [fs] xfs: add debug sysfs attribute set (Brian Foster) [1184177]
- [fs] xfs: trim eofblocks before collapse range (Brian Foster) [1184177]
- [fs] xfs: xfs_file_collapse_range is delalloc challenged (Brian Foster) [1184177]
- [fs] xfs: don't log inode unless extent shift makes extent modifications (Brian Foster) [1184177]
- [fs] xfs: kill xfs_vnode.h (Brian Foster) [1184177]
- [fs] xfs: kill VN_MAPPED (Brian Foster) [1184177]
- [fs] xfs: kill VN_CACHED (Brian Foster) [1184177]
- [fs] xfs: kill VN_DIRTY() (Brian Foster) [1184177]
- [fs] xfs: introduce xfs_bulkstat_ag_ichunk (Brian Foster) [1184177]
- [fs] xfs: require 64-bit sector_t (Brian Foster) [1184177]
- [fs] xfs: remove XFS_IS_OQUOTA_ON macros (Brian Foster) [1184177]
- [fs] xfs: tidy up xfs_set_inode32 (Brian Foster) [1184177]
- [fs] xfs: mark xfs_qm_quotacheck as static (Brian Foster) [1184177]
- [fs] xfs: introduce xfs_bulkstat_grab_ichunk (Brian Foster) [1184177]
- [fs] xfs: introduce xfs_bulkstat_ichunk_ra (Brian Foster) [1184177]
- [fs] xfs: fix error handling at xfs_bulkstat (Brian Foster) [1184177]
- [fs] xfs: remove redundant user buffer count checks at xfs_bulkstat (Brian Foster) [1184177]
- [fs] xfs: fix error handling at xfs_inumbers (Brian Foster) [1184177]
- [fs] xfs: consolidate xfs_inumbers (Brian Foster) [1184177]
- [fs] xfs: remove xfs_bulkstat_single (Brian Foster) [1184177]
- [fs] xfs: remove redundant stat assignment in xfs_bulkstat_one_int (Brian Foster) [1184177]
- [fs] xfs: add log attributes for log lsn and grant head data (Brian Foster) [1184177]
- [fs] xfs: add xlog sysfs kobject and attribute handlers (Brian Foster) [1184177]
- [fs] xfs: add xfs_mount sysfs kobject (Brian Foster) [1184177]
- [fs] xfs: add a sysfs kset (Brian Foster) [1184177]
- [fs] xfs: global error sign conversion (Brian Foster) [1184177]
- [fs] libxfs: move source files (Brian Foster) [1184177]
- [fs] libxfs: move header files (Brian Foster) [1184177]
- [fs] xfs: create libxfs infrastructure (Brian Foster) [1184177]
- [fs] xfs: Nuke XFS_ERROR macro (Brian Foster) [1184177]
- [fs] xfs: return is not a function (Brian Foster) [1184177]
- [fs] xfs: fix xfs_da_args sparse warning in xfs_readdir (Brian Foster) [1184177]
- [fs] xfs: small cleanup in xfs_lowbit64() (Brian Foster) [1184177]
- [fs] xfs: kill xfs_buf_geterror() (Brian Foster) [1184177]
- [fs] xfs: remove redundant geometry information from xfs_da_state (Brian Foster) [1184177]
- [fs] xfs: replace attr LBSIZE with xfs_da_geometry (Brian Foster) [1184177]
- [fs] xfs: pass xfs_da_args to xfs_attr_leaf_newentsize (Brian Foster) [1184177]
- [fs] xfs: use xfs_da_geometry for block size in attr code (Brian Foster) [1184177]
- [fs] xfs: remove mp->m_dir_geo from directory logging (Brian Foster) [1184177]
- [fs] xfs: reduce direct usage of mp->m_dir_geo (Brian Foster) [1184177]
- [fs] xfs: move node entry counts to xfs_da_geometry (Brian Foster) [1184177]
- [fs] xfs: convert dir/attr btree threshold to xfs_da_geometry (Brian Foster) [1184177]
- [fs] xfs: convert m_dirblksize to xfs_da_geometry (Brian Foster) [1184177]
- [fs] xfs: convert m_dirblkfsbs to xfs_da_geometry (Brian Foster) [1184177]
- [fs] xfs: convert directory segment limits to xfs_da_geometry (Brian Foster) [1184177]
- [fs] xfs: convert directory db conversion to xfs_da_geometry (Brian Foster) [1184177]
- [fs] xfs: convert directory dablk conversion to xfs_da_geometry (Brian Foster) [1184177]
- [fs] xfs: convert dir byte/off conversion to xfs_da_geometry (Brian Foster) [1184177]
- [fs] xfs: kill XFS_DIR2...FIRSTDB macros (Brian Foster) [1184177]
- [fs] xfs: move directory block translatiosn to xfs_dir2_priv.h (Brian Foster) [1184177]
- [fs] xfs: introduce directory geometry structure (Brian Foster) [1184177]
- [fs] xfs: fix compile error when libxfs header used in C++ code (Brian Foster) [1184177]
- [fs] xfs: fix infinite loop at xfs_vm_writepage on 32bit system (Brian Foster) [1184177]
- [fs] xfs: remove XFS_TRANS_RESERVE in collapse range (Brian Foster) [1184177]
- [fs] xfs: remove shared supberlock feature checking (Brian Foster) [1184177]
- [fs] xfs: don't need dirv2 checks anymore (Brian Foster) [1184177]
- [fs] xfs: turn NLINK feature on by default (Brian Foster) [1184177]
- [fs] xfs: make superblock version checks reflect reality (Brian Foster) [1184177]
- [fs] xfs: pass struct da_args to xfs_attr_calc_size (Brian Foster) [1184177]
- [fs] xfs: simplify attr name setup (Brian Foster) [1184177]
- [fs] xfs: fold xfs_attr_remove_int into xfs_attr_remove (Brian Foster) [1184177]
- [fs] xfs: fold xfs_attr_get_int into xfs_attr_get (Brian Foster) [1184177]
- [fs] xfs: fold xfs_attr_set_int into xfs_attr_set (Brian Foster) [1184177]
- [fs] xfs: remove dquot hints (Brian Foster) [1184177]
- [fs] xfs: enable the finobt feature on v5 superblocks (Brian Foster) [1184177]
- [fs] xfs: report finobt status in fs geometry (Brian Foster) [1184177]
- [fs] xfs: add finobt support to growfs (Brian Foster) [1184177]
- [fs] xfs: update the finobt on inode free (Brian Foster) [1184177]
- [fs] xfs: refactor xfs_difree() inobt bits into xfs_difree_inobt() helper (Brian Foster) [1184177]
- [fs] xfs: use and update the finobt on inode allocation (Brian Foster) [1184177]
- [fs] xfs: insert newly allocated inode chunks into the finobt (Brian Foster) [1184177]
- [fs] xfs: update inode allocation/free transaction reservations for finobt (Brian Foster) [1184177]
- [fs] xfs: support the XFS_BTNUM_FINOBT free inode btree type (Brian Foster) [1184177]
- [fs] xfs: reserve v5 superblock read-only compat. feature bit for finobt (Brian Foster) [1184177]
- [fs] xfs: refactor xfs_ialloc_btree.c to support multiple inobt numbers (Brian Foster) [1184177]
- [fs] xfs: add filestream allocator tracepoints (Brian Foster) [1184177]
- [fs] xfs: remove xfs_filestream_associate (Brian Foster) [1184177]
- [fs] xfs: don't create a slab cache for filestream items (Brian Foster) [1184177]
- [fs] xfs: rewrite the filestream allocator using the dentry cache (Brian Foster) [1184177]
- [fs] xfs: remove XFS_IFILESTREAM (Brian Foster) [1184177]
- [fs] xfs: embedd mru_elem into parent structure (Brian Foster) [1184177]
- [fs] xfs: handle duplicate entries in xfs_mru_cache_insert (Brian Foster) [1184177]
- [fs] xfs: split xfs_bmap_btalloc_nullfb (Brian Foster) [1184177]
- [fs] xfs: don't try to use the filestream allocator for metadata allocations (Brian Foster) [1184177]
- [fs] xfs: remove unused calculation in xfs_dir2_sf_addname() (Brian Foster) [1184177]
- [fs] xfs: remove pointless pointer increment in xfs_dir2_block_compact() (Brian Foster) [1184177]
- [fs] xfs: remove unused trans pointer arg from xlog_recover_unmount_trans() (Brian Foster) [1184177]
- [fs] xfs: remove unused ail pointer arg from xfs_trans_ail_cursor_done() (Brian Foster) [1184177]
- [fs] xfs: remove unused xfs_mount arg from xfs_symlink_hdr_ok() (Brian Foster) [1184177]
- [fs] xfs: remove unused bp arg from xfs_iflush_fork() (Brian Foster) [1184177]
- [fs] xfs: remove unused pag ptr arg from iterator execute functions (Brian Foster) [1184177]
- [fs] xfs: remove unused length arg from alloc_block ops (Brian Foster) [1184177]
- [fs] xfs: remove unused mp arg from xfs_calc_dquots_per_chunk() (Brian Foster) [1184177]
- [fs] xfs: remove unused mp arg from xfs_dir2 dataptr/byte functions (Brian Foster) [1184177]
- [fs] xfs: remove unused tp arg from xfs_da_reada_buf & callers (Brian Foster) [1184177]
- [fs] xfs: remove unused bip arg from xfs_buf_item_log_segment() (Brian Foster) [1184177]
- [fs] xfs: remove unused flags arg from _xfs_buf_get_pages() (Brian Foster) [1184177]
- [fs] xfs: remove unused args from xfs_alloc_buftarg() (Brian Foster) [1184177]
- [fs] xfs: remove unused blocksize arg from xfs_setsize_buftarg() (Brian Foster) [1184177]
- [fs] xfs: remove unused level arg from xfs_btree_read_buf_block() (Brian Foster) [1184177]
- [fs] xfs: remove unused mp arg from xfs_bmap_forkoff_reset() (Brian Foster) [1184177]
- [fs] xfs: remove unused mp arg from xfs_bmdr_maxrecs() (Brian Foster) [1184177]
- [fs] xfs: remove unused mp arg from xfs_attr3_rmt_hdr_ok() (Brian Foster) [1184177]
- [fs] xfs: remove unused tp arg from xfs_bmap_last_offset() and callers (Brian Foster) [1184177]
- [fs] xfs: correct error sign on COLLAPSE_RANGE errors (Brian Foster) [1184177]
- [fs] xfs: collapse range is delalloc challenged (Brian Foster) [1184177]
- [fs] xfs: move falloc collapse range check into the filesystem methods (Brian Foster) [1184177]
- [fs] xfs: Add support for FALLOC_FL_ZERO_RANGE (Brian Foster) [1184177]
- [fs] xfs: use NOIO contexts for vm_map_ram (Brian Foster) [1184177]
- [fs] xfs: fix directory inode iolock lockdep false positive (Brian Foster) [1184177]
- [fs] xfs: allocate xfs_da_args to reduce stack footprint (Brian Foster) [1184177]
- [fs] xfs: Add support FALLOC_FL_COLLAPSE_RANGE for fallocate (Brian Foster) [1184177]
- [fs] xfs: always use unwritten extents for direct I/O writes (Brian Foster) [1184177]
- [fs] xfs: factor prid related codes into xfs_get_initial_prid() (Brian Foster) [1184177]

* Thu Apr 23 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-242.el7]
- [netdrv] hyperv: Add processing of MTU reduced by the host (Vitaly Kuznetsov) [1196420]
- [x86] crypto: aesni - fix memory usage in GCM decryption (Kurt Stutsman) [1212178] {CVE-2015-3331}
- [usb] fix use-after-free bug in usb_hcd_unlink_urb() (Don Zickus) [1187256]
- [pci] Mark RTL8110SC INTx masking as broken (Myron Stowe) [1205911]
- [powerpc] pci: Clip bridge windows to fit in upstream windows (Myron Stowe) [1110898]
- [x86] pci: Clip bridge windows to fit in upstream windows (Myron Stowe) [1110898]
- [pci] Add pci_claim_bridge_resource() to clip window if necessary (Myron Stowe) [1110898]
- [pci] Add pci_bus_clip_resource() to clip to fit upstream window (Myron Stowe) [1110898]
- [pci] Pass bridge device, not bus, when updating bridge windows (Myron Stowe) [1110898]
- [pci] Add missing MEM_64 mask in pci_assign_unassigned_bridge_resources() (Myron Stowe) [1110898]
- [pci] maintainers: Update mx6 PCI driver maintainer's email (Myron Stowe) [1110898]
- [pci] Add function 1 DMA alias quirk for HighPoint RocketRaid 642L (Myron Stowe) [1110898]
- [pci] msi: Fix memory leak in free_msi_irqs() (Myron Stowe) [1110898]
- [pci] Merge multi-line quoted strings (Myron Stowe) [1110898]
- [pci] Whitespace cleanup (Myron Stowe) [1110898]
- [pci] Move EXPORT_SYMBOL so it immediately follows function/variable (Myron Stowe) [1110898]
- [pci] Make pci_bus_add_device() void (Myron Stowe) [1110898]
- [pci] Introduce new device binding path using pci_dev.driver_override (Myron Stowe) [1110898]
- [pci] cpqphp: Fix possible null pointer dereference (Myron Stowe) [1110898]
- [pci] Fix return value from pci_user_{read, write}_config_*() (Myron Stowe) [1110898]
- [pci] Turn pcibios_penalize_isa_irq() into a weak function (Myron Stowe) [1110898]
- [pci] pcmcia: Use pci_is_bridge() to simplify code (Myron Stowe) [1110898]
- [pci] pciehp: Use pci_is_bridge() to simplify code (Myron Stowe) [1110898]
- [pci] acpiphp: Use pci_is_bridge() to simplify code (Myron Stowe) [1110898]
- [pci] cpcihp: Use pci_is_bridge() to simplify code (Myron Stowe) [1110898]
- [pci] shpchp: Use pci_is_bridge() to simplify code (Myron Stowe) [1110898]
- [pci] rpaphp: Use pci_is_bridge() to simplify code (Myron Stowe) [1110898]
- [x86] pci: Use pci_is_bridge() to simplify code (Myron Stowe) [1110898]
- [pci] Use pci_is_bridge() to simplify code (Myron Stowe) [1110898]
- [pci] nvme: Implement PCIe reset notification callback (Myron Stowe) [1110898]
- [pci] Notify driver before and after device reset (Myron Stowe) [1110898]
- [x86] pci: Clean up and mark early_root_info_init() as deprecated (Myron Stowe) [1110898]
- [pci] dma-api: Update dma_pool_create ()and dma_pool_alloc() descriptions (Myron Stowe) [1110898]
- [pci] dma-api: Fix duplicated word in DMA-API-HOWTO.txt (Myron Stowe) [1110898]
- [pci] dma-api: Capitalize "CPU" consistently (Myron Stowe) [1110898]
- [pci] Add resource allocation comments (Myron Stowe) [1110898]
- [pci] Simplify __pci_assign_resource() coding style (Myron Stowe) [1110898]
- [pci] Change pbus_size_mem() return values to be more conventional (Myron Stowe) [1110898]
- [pci] Restrict 64-bit prefetchable bridge windows to 64-bit resources (Myron Stowe) [1110898]
- [pci] Support BAR sizes up to 8GB (Myron Stowe) [1110898]
- [x86] gart: Tidy messages and add bridge device info (Myron Stowe) [1110898]
- [x86] gart: Replace printk() with pr_info() (Myron Stowe) [1110898]
- [x86] pci: Move pcibios_assign_resources() annotation to definition (Myron Stowe) [1110898]
- [pci] Remove pcibios_add_platform_entries() (Myron Stowe) [1110898]
- [s390] pci: use pdev->dev.groups for attribute creation (Myron Stowe) [1110898]
- [x86] pci: Work around AMD Fam15h BIOSes that fail to provide _PXM (Myron Stowe) [1110898]
- [x86] pci: Warn if we have to "guess" host bridge node information (Myron Stowe) [1110898]
- [pci] dma-api: Change dma_declare_coherent_memory() CPU address to phys_addr_t (Myron Stowe) [1110898]
- [pci] dma-api: Clarify physical/bus address distinction (Myron Stowe) [1110898]
- [pci] msi: Remove pci_enable_msi_block() (Myron Stowe) [1110898]
- [pci] Move Open Firmware devspec attribute to PCI common code (Myron Stowe) [1110898]
- [pci] Fix use of uninitialized MPS value (Myron Stowe) [1110898]
- [pci] Remove dead code (Myron Stowe) [1110898]
- [pci] maintainers: Add arch/x86/kernel/quirks.c to PCI file patterns (Myron Stowe) [1110898]
- [pci] Remove unnecessary __ref annotations (Myron Stowe) [1110898]
- [pci] Add new ID for Intel GPU "spurious interrupt" quirk (Myron Stowe) [1110898]
- [pci] genwqe: Use pci_enable_msi_exact() instead of pci_enable_msi_block() (Myron Stowe) [1110898]
- [pci] Fix incorrect vgaarb conditional in WARN_ON() (Myron Stowe) [1110898]
- [x86] pci: Mark ATI SBx00 HPET BAR as IORESOURCE_PCI_FIXED (Myron Stowe) [1110898]
- [x86] pci: Don't try to move IORESOURCE_PCI_FIXED resources (Myron Stowe) [1110898]
- [x86] pci: Fix Broadcom CNB20LE unintended sign extension (Myron Stowe) [1110898]
- [pci] Use designated initialization in PCI_VDEVICE (Myron Stowe) [1110898]
- [pci] Allow hotplug service drivers to operate in polling mode (Myron Stowe) [1110898]
- [pci] pciehp: Acknowledge spurious "cmd completed" event (Myron Stowe) [1110898]
- [pci] Remove old serial device IDs (Myron Stowe) [1110898]
- [pci] Remove unnecessary includes of <linux/init.h> (Myron Stowe) [1110898]
- [pci] pciehp: Use PCI_EXP_SLTCAP_PSN define (Myron Stowe) [1110898]
- [pci] hotplug: Remove unnecessary "dev->bus" test (Myron Stowe) [1110898]
- [pci] msi: Simplify populate_msi_sysfs() (Myron Stowe) [1110898]
- [pci] portdrv: Use pci_enable_msix_exact() instead of pci_enable_msix() (Myron Stowe) [1110898]
- [powerpc] kvm: ppc: book3s hv: Enable for little endian hosts (David Gibson) [1193257]
- [powerpc] kvm: ppc: book3s hv: Fix ABIv2 on LE (David Gibson) [1193257]
- [powerpc] kvm: ppc: book3s hv: Access XICS in BE (David Gibson) [1193257]
- [powerpc] kvm: ppc: book3s hv: Access host lppaca and shadow slb in BE (David Gibson) [1193257]
- [powerpc] kvm: ppc: book3s hv: Access guest VPA in BE (David Gibson) [1193257]
- [powerpc] kvm: ppc: book3s hv: Make HTAB code LE host aware (David Gibson) [1193257]
- [powerpc] Add asm helpers for BE 32bit load/store (David Gibson) [1193257]
- [powerpc] kvm: ppc: Assembly functions exported to modules need _GLOBAL_TOC() (David Gibson) [1193257]
- [powerpc] kvm: ppc: rtas: Do byte swaps explicitly (David Gibson) [1193257]
- [powerpc] kvm: ppc: book3s pr: Fix ABIv2 on LE (David Gibson) [1193257]
- [powerpc] kvm: ppc: book3s hv: Fix ABIv2 indirect branch issue (David Gibson) [1193257]
- [powerpc] perf: add missing put_cpu_var in power_pmu_event_init (Jan Stancek) [1202283]
- [s390] watchdog: support for KVM hypervisors and delete pr_info messages (Hendrik Brueckner) [1182310]
- [s390] watchdog: enable KEEPALIVE for /dev/watchdog (Hendrik Brueckner) [1182310]
- [s390] kernel: Update /proc/sysinfo file with Extended Name and UUID (Hendrik Brueckner) [1182311]
- [s390] qeth: Display adjacent switch attributes (Hendrik Brueckner) [1182287]
- [x86] kvm: vmx: fix oops with explicit flexpriority=0 option (Radim Krcmar) [1185276]

* Tue Apr 21 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-241.el7]
- [hv] hv_fcopy: drop the obsolete message on transfer failure (Vitaly Kuznetsov) [1162100]
- [virtio] virtio_ring: Update weak barriers to use dma_wmb/rmb (Alexander Duyck) [1205268]
- [arch] Add lightweight memory barriers dma_rmb() and dma_wmb() (Alexander Duyck) [1205268]
- [arch] Cleanup read_barrier_depends() and comments (Alexander Duyck) [1205268]
- [arch] Clean up asm/barrier.h implementations using asm-generic/barrier.h (Alexander Duyck) [1205268]
- [x86] kernel: Remove CONFIG_X86_OOSTORE (Alexander Duyck) [1205268]
- [kernel] sched/idle: Optimize try-to-wake-up IPI (Rik van Riel) [1197889]
- [kernel] sched, trace: Add a tracepoint for IPI-less remote wakeups (Rik van Riel) [1197889]
- [kernel] sched/idle: Avoid spurious wakeup IPIs (Rik van Riel) [1197889]
- [kernel] sched/idle: Clear polling before descheduling the idle thread (Rik van Riel) [1197889]
- [x86] sched/idle: Switch from TS_POLLING to TIF_POLLING_NRFLAG (Rik van Riel) [1197889]
- [hv] vss: Fast propagation of userspace communication failure (Vitaly Kuznetsov) [1092780]
- [hv] vss: Introduce timeout for communication with userspace (Vitaly Kuznetsov) [1092780]
- [pci] Increase IBM ipr SAS Crocodile BARs to at least system page size (Steve Best) [1211951]
- [thermal] intel_powerclamp: add id for broadwell server (Steve Best) [1169554]
- [powerpc] Fail remap_4k_pfn() if PFN doesn't fit inside PTE (Steve Best) [1211954]
- [kernel] perf: Fix events installation during moving group (Jiri Olsa) [1066402]
- [x86] perf_event_intel_uncore: Make sure only uncore events are collected (Jiri Olsa) [1066402]
- [kernel] futex: Mention key referencing differences between shared and private futexes (Larry Woodman) [1205862]
- [kernel] futex: Ensure get_futex_key_refs() always implies a barrier (Larry Woodman) [1205862]
- [scripts] kconfig: Fix warning "'jump' may be used uninitialized" (Prarit Bhargava) [1184972]
- [netdrv] bnx2x: fix encapsulation features on 57710/57711 (Michal Schmidt) [1164997]
- [netdrv] be2net: use PCI MMIO read instead of config read for errors (Ivan Vecera) [1171839]
- [netdrv] be2net: Fix TX rate limiting on Lancer/Skyhawk-R VFs (Ivan Vecera) [1186613]
- [netdrv] be2net: fail VF link config change via ndo_set_vf_link_state() on BE3/Lancer (Ivan Vecera) [1186607]
- [pci] Add ACS quirk for Emulex NICs (Ivan Vecera) [1183443]
- [pci] Test for std config alias when testing extended config space (Myron Stowe) [1205915]
- [hv] hv_balloon: correctly handle num_pages>INT_MAX case (Vitaly Kuznetsov) [1203790]
- [hv] hv_balloon: correctly handle val.freeram<num_pages case (Vitaly Kuznetsov) [1203790]
- [hv] hv_balloon: survive ballooning request with num_pages=0 (Vitaly Kuznetsov) [1203790]
- [hv] hv_balloon: eliminate jumps in piecewiese linear floor function (Vitaly Kuznetsov) [1203790]
- [hv] hv_balloon: keep locks balanced on add_memory() failure (Vitaly Kuznetsov) [1203790]
- [hv] hv_balloon: refuse to balloon below the floor (Vitaly Kuznetsov) [1203790]
- [hv] hv_balloon: report offline pages as being used (Vitaly Kuznetsov) [1203790]
- [hv] hv_balloon: eliminate the trylock path in acquire/release_region_mutex (Vitaly Kuznetsov) [1203790]
- [hv] hv_balloon: Don't post pressure status from interrupt context (Vitaly Kuznetsov) [1203790]
- [hv] hv_balloon: Fix a locking bug in the balloon driver (Vitaly Kuznetsov) [1203790]
- [hv] hv_balloon: Make adjustments in computing the floor (Vitaly Kuznetsov) [1203790]
- [hv] hv_balloon: avoid memory leak on alloc_error of 2MB memory block (Vitaly Kuznetsov) [1203790]
- [vfio] Rework offsetofend() (Alex Williamson) [1206275]
- [vfio] always select ANON_INODES (Alex Williamson) [1206275]
- [vfio] vfio-pci: Fix the check on pci device type in vfio_pci_probe() (Alex Williamson) [1206275]
- [vfio] vfio-pci: Fix wrong MSI interrupt count (Alex Williamson) [1206275]
- [vfio] vfio-pci: Add missing break to enable VFIO_PCI_ERR_IRQ_INDEX (Alex Williamson) [1206275]
- [vfio] vfio-pci: Add device request interface (Alex Williamson) [1206275]
- [vfio] vfio-pci: Generalize setup of simple eventfds (Alex Williamson) [1206275]
- [vfio] Add and use device request op for vfio bus drivers (Alex Williamson) [1206275]
- [vfio] Tie IOMMU group reference to vfio group (Alex Williamson) [1206275]
- [vfio] Add device tracking during unbind (Alex Williamson) [1206275]
- [vfio] iommu_type1: Add conditional rescheduling (Alex Williamson) [1206275]
- [vfio] iommu_type1: Chunk contiguous reserved/invalid page mappings (Alex Williamson) [1206275]
- [vfio] iommu_type1: DMA unmap chunking (Alex Williamson) [1206275]
- [vfio] vfio-pci: Fix remove path locking (Alex Williamson) [1206275]
- [vfio] vfio-pci: Attempt bus/slot reset on release (Alex Williamson) [1206275]
- [vfio] vfio-pci: Use mutex around open, release, and remove (Alex Williamson) [1206275]
- [vfio] vfio-pci: Release devices with BusMaster disabled (Alex Williamson) [1206275]
- [vfio] iommu_type1: Avoid overflow (Alex Williamson) [1206275]
- [vfio] vfio-pci: Fix unchecked return value (Alex Williamson) [1206275]
- [vfio] vfio-pci: Fix sizing of DPA and THP express capabilities (Alex Williamson) [1206275]
- [vfio] fio: Support for DMA coherent IOMMUs (Alex Williamson) [1206275]
- [vfio] Add external user check extension interface (Alex Williamson) [1206275]
- [vfio] iommu_type1: Add extension to test DMA cache coherence of IOMMU (Alex Williamson) [1206275]
- [vfio] iommu_type1: Multi-IOMMU domain support (Alex Williamson) [1206275]
- [acpi] processor: Convert apic_id to phys_id to make it arch agnostic (Prarit Bhargava) [1201167]
- [acpi] processor: Make it possible to get local x2apic id via _MAT (Prarit Bhargava) [1201167]
- [acpi] scan: bail out early if failed to parse APIC ID for CPU (Prarit Bhargava) [1201167]
- [acpi] processor: use apic_id and remove duplicated _MAT evaluation (Prarit Bhargava) [1201167]

* Wed Apr 15 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-240.el7]
- [net] neigh: Netlink notification for administrative NUD state change (Jiri Pirko) [1210373]
- [net] netfilter: nf_tables: fix flush ruleset chain dependencies (Jiri Pirko) [1192881] {CVE-2015-1573}
- [net] pktgen: disable xmit_clone on virtual devices (Alexander Duyck) [1205266]
- [net] packet: fix packet_direct_xmit for BQL enabled drivers (Alexander Duyck) [1205266]
- [net] pktgen: packet bursting via skb->xmit_more (Alexander Duyck) [1205266]
- [net] pktgen: add flag NO_TIMESTAMP to disable timestamping (Alexander Duyck) [1205266]
- [net] qdisc: dequeue bulking also pickup GSO/TSO packets (Alexander Duyck) [1205266]
- [net] qdisc: bulk dequeue support for qdiscs with TCQ_F_ONETXQUEUE (Alexander Duyck) [1205266]
- [net] qdisc: validate frames going through the direct_xmit path (Alexander Duyck) [1205266]
- [net] qdisc: exit case fixes for skb list handling in qdisc layer (Alexander Duyck) [1205266]
- [net] qdisc: adjustments for API allowing skb list xmits (Alexander Duyck) [1205266]
- [net] xmit_list() becomes dev_hard_start_xmit() (Alexander Duyck) [1205266]
- [net] Don't keep around original SKB when we software segment GSO frames (Alexander Duyck) [1205266]
- [net] Validate xmit SKBs right when we pull them out of the qdisc (Alexander Duyck) [1205266]
- [net] Separate out SKB validation logic from transmit path (Alexander Duyck) [1205266]
- [net] Have xmit_list() signal more==true when appropriate (Alexander Duyck) [1205266]
- [net] Pass a "more" indication down into netdev_start_xmit() code paths (Alexander Duyck) [1205266]
- [net] Move main gso loop out of dev_hard_start_xmit() into helper (Alexander Duyck) [1205266]
- [net] Create xmit_one() helper for dev_hard_start_xmit() (Alexander Duyck) [1205266]
- [net] move inline skb_needs_linearize helper to header (Alexander Duyck) [1205266]
- [net] Do txq_trans_update() in netdev_start_xmit() (Alexander Duyck) [1205266]
- [netdrv] virtio_net: flush when in xmit_more mode and under descriptor pressure (Alexander Duyck) [1205266]
- [netdrv] igb: flush when in xmit_more mode and under descriptor pressure (Alexander Duyck) [1205266]
- [netdrv] ixgbe: flush when in xmit_more mode and under descriptor pressure (Alexander Duyck) [1205266]
- [netdrv] ixgbe: support skb->xmit_more in netdev_ops->ndo_start_xmit() (Alexander Duyck) [1205266]
- [net] Remove ndo_xmit_flush netdev operation, use signalling instead (Alexander Duyck) [1205266]
- [net] Add ops->ndo_xmit_flush() (Alexander Duyck) [1205266]
- [net] add skb_get_tx_queue() helper (Alexander Duyck) [1205266]
- [net] netpoll: Only call ndo_start_xmit from a single place (Alexander Duyck) [1205266]
- [net] Pull out core bits of __netdev_alloc_skb and add __napi_alloc_skb (Alexander Duyck) [1205273]
- [net] Split netdev_alloc_frag into __alloc_page_frag and add __napi_alloc_frag (Alexander Duyck) [1205273]
- [net] nf_conntrack: reserve two bytes for nf_ct_ext->len (Marcelo Leitner) [1206164] {CVE-2014-9715}
- [net] ipv6: Partial checksum only UDP packets (Vlad Yasevich) [1105064]
- [net] ipv6: Allow for partial checksums on non-ufo packets (Vlad Yasevich) [1105064]
- [net] udpv6: Add lockless sendmsg() support (Vlad Yasevich) [1105064]
- [net] ipv6: Introduce udpv6_send_skb() (Vlad Yasevich) [1105064]
- [net] ipv6: introduce ipv6_make_skb (Vlad Yasevich) [1105064]
- [net] ipv6: Append sending data to arbitrary queue (Vlad Yasevich) [1105064]
- [net] ipv6: pull cork initialization into its own function (Vlad Yasevich) [1105064]
- [net] do not enable tx-nocache-copy by default (Alexander Duyck) [1205271]
- [net] tcp: add DCTCP congestion control algorithm (Florian Westphal) [970613]
- [net] tcp: more detailed ACK events and events for CE marked packets (Florian Westphal) [970613]
- [net] tcp: split ack slow/fast events from cwnd_event (Florian Westphal) [970613]
- [net] tcp: add flag for ca to indicate that ECN is required (Florian Westphal) [970613]
- [net] tcp: assign tcp cong_ops when tcp sk is created (Florian Westphal) [970613]
- [net] tcp: don't include Fast Open option in SYN-ACK on pure SYN-data (Florian Westphal) [1151756]
- [net] tcp: abort orphan sockets stalling on zero window probes (Florian Westphal) [1151756]
- [net] tcp: fix more NULL deref after prequeue changes (Florian Westphal) [1151756]
- [net] tcp: fix possible NULL dereference in tcp_vX_send_reset() (Florian Westphal) [1151756]
- [net] skb_fclone_busy() needs to detect orphaned skb (Florian Westphal) [1151756]
- [net] cleanup and document skb fclone layout (Florian Westphal) [1151756]
- [net] tcp: md5: do not use alloc_percpu() (Florian Westphal) [1151756]
- [net] tcp: tcp_conn_request: fix build error when IPv6 is disabled (Florian Westphal) [1151756]
- [net] introduce __skb_header_release() (Florian Westphal) [1151756]
- [net] tcp: add coalescing attempt in tcp_ofo_queue() (Florian Westphal) [1151756]
- [net] tcp: avoid possible arithmetic overflows (Florian Westphal) [1151756]
- [net] tcp: do not fake tcp headers in tcp_send_rcvq() (Florian Westphal) [1151756]
- [net] tcp: do not copy headers in tcp_collapse() (Florian Westphal) [1151756]
- [net] tcp: allow segment with FIN in tcp_try_coalesce() (Florian Westphal) [1151756]
- [net] tcp: use tcp_flags in tcp_data_queue() (Florian Westphal) [1151756]
- [net] tcp: use TCP_SKB_CB(skb)->tcp_flags in input path (Florian Westphal) [1151756]
- [net] tcp: remove dst refcount false sharing for prequeue mode (Florian Westphal) [1151756]
- [net] tcp: remove obsolete comment about TCP_SKB_CB(skb)->when in tcp_fragment() (Florian Westphal) [1151756]
- [net] tcp: remove TCP_SKB_CB(skb)->when (Florian Westphal) [1151756]
- [net] tcp: introduce TCP_SKB_CB(skb)->tcp_tw_isn (Florian Westphal) [1151756]
- [net] tcp: whitespace fixes (Florian Westphal) [1151756]
- [net] tcp: improve undo on timeout (Florian Westphal) [1151756]
- [net] tcp: fix ssthresh and undo for consecutive short FRTO episodes (Florian Westphal) [1151756]
- [net] tcp: don't allow syn packets without timestamps to pass tcp_tw_recycle logic (Florian Westphal) [1151756]
- [net] tcp: fix tcp_release_cb() to dispatch via address family for mtu_reduced() (Florian Westphal) [1151756]
- [net] tcp: don't use timestamp from repaired skb-s to calculate RTT (v2) (Florian Westphal) [1151756]
- [net] tcp: md5: check md5 signature without socket lock (Florian Westphal) [1151756]
- [net] tcp: reduce spurious retransmits due to transient SACK reneging (Florian Westphal) [1151756]
- [net] tcp: md5: remove unneeded check in tcp_v4_parse_md5_keys (Florian Westphal) [1151756]
- [net] tcp: Fix integer-overflow in TCP vegas (Florian Westphal) [1151756]
- [net] tcp: Fix integer-overflows in TCP veno (Florian Westphal) [1151756]
- [net] tcp: Remove unnecessary arg from tcp_enter_cwr and tcp_init_cwnd_reduction (Florian Westphal) [1151756]
- [net] tcp: fix false undo corner cases (Florian Westphal) [1151756]
- [net] tcp: switch snt_synack back to measuring transmit time of first SYNACK (Florian Westphal) [1151756]
- [net] tcp: Fix divide by zero when pushing during tcp-repair (Florian Westphal) [1151756]
- [net] tcp: add tcp_conn_request (Florian Westphal) [1151756]
- [net] tcp: add queue_add_hash to tcp_request_sock_ops (Florian Westphal) [1151756]
- [net] tcp: add mss_clamp to tcp_request_sock_ops (Florian Westphal) [1151756]
- [net] tcp: unify tcp_v4_rtx_synack and tcp_v6_rtx_synack (Florian Westphal) [1151756]
- [net] tcp: add send_synack method to tcp_request_sock_ops (Florian Westphal) [1151756]
- [net] ipv6: cleanup for tcp_ipv6.c (Florian Westphal) [1151756]
- [net] tcp: add init_seq method to tcp_request_sock_ops (Florian Westphal) [1151756]
- [net] tcp: move around a few calls in tcp_v6_conn_request (Florian Westphal) [1151756]
- [net] tcp: add route_req method to tcp_request_sock_ops (Florian Westphal) [1151756]
- [net] tcp: add init_cookie_seq method to tcp_request_sock_ops (Florian Westphal) [1151756]
- [net] tcp: add init_req method to tcp_request_sock_ops (Florian Westphal) [1151756]
- [net] remove inet6_reqsk_alloc (Florian Westphal) [1151756]
- [net] tcp: tcp_v[46]_conn_request: fix snt_synack initialization (Florian Westphal) [1151756]
- [net] tcp: cookie_v4_init_sequence: skb should be const (Florian Westphal) [1151756]
- [net] tcp: fix tcp_match_skb_to_sack() for unaligned SACK at end of an skb (Florian Westphal) [1151756]
- [net] tcp: fixing TLP's FIN recovery (Florian Westphal) [1151756]
- [net] tcp: fix cwnd undo on DSACK in F-RTO (Florian Westphal) [1151756]
- [net] tcp: make cwnd-limited checks measurement-based, and gentler (Florian Westphal) [1151756]
- [net] tcp: IPv6 support for fastopen server (Florian Westphal) [1151756]
- [net] net: ipv6: Fix oif in TCP SYN+ACK route lookup. (Florian Westphal) [1151756]
- [net] ipv6: tcp_ipv6 policy route issue (Florian Westphal) [1151756]
- [net] ipv6: reuse rt6_need_strict (Florian Westphal) [1151756]
- [net] tcp: improve fastopen icmp handling (Florian Westphal) [1151756]
- [net] tcp: use tcp_v4_send_synack on first SYN-ACK (Florian Westphal) [1151756]
- [net] tcp: simplify fast open cookie processing (Florian Westphal) [1151756]
- [net] tcp: move fastopen functions to tcp_fastopen.c (Florian Westphal) [1151756]
- [net] tcp: remove in_flight parameter from cong_avoid() methods (Florian Westphal) [1151756]
- [net] tcp: fix cwnd limited checking to improve congestion control (Florian Westphal) [1151756]
- [net] tcp_cubic: fix the range of delayed_ack (Florian Westphal) [1151756]
- [net] tcp: increment retransmit counters in tlp and fast open (Florian Westphal) [1151756]
- [net] tcp: avoid retransmits of TCP packets hanging in host queues (Florian Westphal) [1151756]
- [net] tcp: make tcp_cwnd_application_limited() static (Florian Westphal) [1151756]
- [net] ipv6: tcp_ipv6 do some cleanup (Florian Westphal) [1151756]
- [net] tcp: fix get_timewait4_sock() delay computation on 64bit (Florian Westphal) [1151756]
- [net] tcp: tcp_make_synack() minor changes (Florian Westphal) [1151756]
- [net] tcp: delete unused parameter in tcp_nagle_check() (Florian Westphal) [1151756]
- [net] tcp: tcp_release_cb() should release socket ownership (Florian Westphal) [1151756]
- [net] tcp: timestamp SYN+DATA messages (Florian Westphal) [1151756]
- [net] tcp: do not leak non zero tstamp in output packets (Florian Westphal) [1151756]
- [net] tcp: Use NET_ADD_STATS instead of NET_ADD_STATS_BH in tcp_event_new_data_sent() (Florian Westphal) [1151756]
- [net] tcp: snmp stats for Fast Open, SYN rtx, and data pkts (Florian Westphal) [1151756]
- [net] tcp: fix bogus RTT on special retransmission (Florian Westphal) [1151756]
- [net] tcp: switch rtt estimations to usec resolution (Florian Westphal) [1151756]
- [net] kabi: don't make kabi-check trip over sk_buff change (Florian Westphal) [1151756]
- [net] add skb_mstamp infrastructure (Florian Westphal) [1151756]
- [net] tcp: add mib counters to track zero window transitions (Florian Westphal) [1151756]
- [net] tcp: use zero-window when free_space is low (Florian Westphal) [1151756]
- [net] tcp: reduce the bloat caused by tcp_is_cwnd_limited() (Florian Westphal) [1151756]
- [net] tcp: fastopen: fix high order allocations (Florian Westphal) [1151756]
- [net] tcp: remove unused min_cwnd member of tcp_congestion_ops (Florian Westphal) [1151756]
- [net] tcp: remove 1ms offset in srtt computation (Florian Westphal) [1151756]
- [net] tcp: delete redundant calls of tcp_mtup_init() (Florian Westphal) [1151756]
- [net] ipv6: tcp: fix flowlabel value in ACK messages send from TIME_WAIT (Florian Westphal) [1151756]
- [net] tcp: initialize passive-side sk_pacing_rate after 3WHS (Florian Westphal) [1151756]
- [net] tcp: tcp_transmit_skb() optimizations (Florian Westphal) [1151756]
- [net] tcp: metrics: Handle v6/v4-mapped sockets in tcp-metrics (Florian Westphal) [1151756]
- [net] tcp: metrics: Fix rcu-race when deleting multiple entries (Florian Westphal) [1151756]
- [net] tcp: metrics: Avoid duplicate entries with the same destination-IP (Florian Westphal) [1151756]
- [net] tcp: metrics: Allow selective get/del of tcp-metrics based on src IP (Florian Westphal) [1151756]
- [net] tcp: metrics: Delete all entries matching a certain destination (Florian Westphal) [1151756]
- [net] tcp: metrics: New netlink attribute for src IP and dumped in netlink reply (Florian Westphal) [1151756]
- [net] tcp: metrics: Add source-address to tcp-metrics (Florian Westphal) [1151756]
- [net] tcp: metrics: rename tcpm_addr to tcpm_daddr (Florian Westphal) [1151756]
- [net] tcp: out_of_order_queue do not use its lock (Florian Westphal) [1151756]
- [net] tcp: make local functions static (Florian Westphal) [1151756]
- [net] tcp: autocork should not hold first packet in write queue (Florian Westphal) [1151756]
- [net] tcp: refine TSO splits (Florian Westphal) [1151756]
- [net] tcp: auto corking (Florian Westphal) [1151756]
- [net] tcp: optimize some skb_shinfo(skb) uses (Florian Westphal) [1151756]
- [net] tcp: properly handle stretch acks in slow start (Florian Westphal) [1151756]
- [net] tcp: temporarily disable Fast Open on SYN timeout (Florian Westphal) [1151756]
- [net] tcp: do not rearm RTO when future data are sacked (Florian Westphal) [1151756]
- [net] tcp: only take RTT from timestamps if new data is acked (Florian Westphal) [1151756]
- [net] tcp: fix SYNACK RTT estimation in Fast Open (Florian Westphal) [1151756]
- [net] tcp: remove redundant code in __tcp_retransmit_skb() (Florian Westphal) [1151756]
- [net] ipv4: shrink rt_cache_stat (Florian Westphal) [1151756]
- [net] tcp: sndbuf autotuning improvements (Florian Westphal) [1151756]
- [net] tcp: Always set options to 0 before calling tcp_established_options (Florian Westphal) [1151756]
- [net] tcp: fix dynamic right sizing (Florian Westphal) [1151756]
- [net] tcp: Remove extern from function prototypes (Florian Westphal) [1151756]
- [net] tcp: fix RTO calculated from cached RTT (Florian Westphal) [1151756]
- [net] tcp: properly increase rcv_ssthresh for ofo packets (Florian Westphal) [1151756]
- [net] tcp: fix no cwnd growth after timeout (Florian Westphal) [1151756]
- [net] tcp: better comments for RTO initiallization (Florian Westphal) [1151756]
- [net] tcp: Change return value of tcp_rcv_established() (Florian Westphal) [1151756]
- [net] tcp: do not use cached RTT for RTT estimation (Florian Westphal) [1151756]
- [net] tcp: increase throughput when reordering is high (Florian Westphal) [1151756]
- [net] tcp: trivial: Remove nocache argument from tcp_v4_send_synack (Florian Westphal) [1151756]
- [net] tcp: reset reordering est. selectively on timeout (Florian Westphal) [1151756]
- [net] tcp: add server ip to encrypt cookie in fast open (Florian Westphal) [1151756]
- [net] ip: add SNMP counters tracking incoming ECN bits (Florian Westphal) [1151756]
- [net] tcp: Remove unused tcpct declarations and comments (Florian Westphal) [1151756]
- [net] tcp: TCP_NOTSENT_LOWAT socket option (Florian Westphal) [1151756]
- [net] add sk_stream_is_writeable() helper (Florian Westphal) [1151756]
- [net] fib_trie: potential out of bounds access in trie_show_stats() (Florian Westphal) [1151756]
- [net] tcp: use RTT from SACK for RTO (Florian Westphal) [1151756]
- [net] tcp: measure RTT from new SACK (Florian Westphal) [1151756]
- [net] tcp: prefer packet timing to TS-ECR for RTT (Florian Westphal) [1151756]
- [net] tcp: consolidate SYNACK RTT sampling (Florian Westphal) [1151756]
- [net] tcp: account all retransmit failures (Florian Westphal) [1151756]
- [net] ipv4: fix spacing in assignment (Florian Westphal) [1151756]
- [net] net: sock: fix TCP_SKB_MIN_TRUESIZE (Florian Westphal) [1151756]
- [net] tcp: remove invalid __rcu annotation (Florian Westphal) [1151756]
- [net] ipv6: remove a useless pr_info() in addrconf_gre_config() (Florian Westphal) [1151756]
- [net] inet_fragment: remove an empty ifdef (Florian Westphal) [1151756]
- [net] tcp: typo unset should be unsent (Florian Westphal) [1151756]
- [net] net: sock: adapt SOCK_MIN_RCVBUF and SOCK_MIN_SNDBUF (Florian Westphal) [1151756]
- [net] tcp: properly send new data in fast recovery in first RTT (Florian Westphal) [1151756]
- [net] udp: fix two sparse errors (Florian Westphal) [1151756]
- [net] ipv4: Update RFS target at poll for tcp/udp (Florian Westphal) [1151756]
- [net] tcp: undo on DSACK during recovery (Florian Westphal) [1151756]
- [net] tcp: fix undo on partial ack in recovery (Florian Westphal) [1151756]
- [net] tcp: refactor undo functions (Florian Westphal) [1151756]
- [net] tcp: consolidate PRR packet accounting (Florian Westphal) [1151756]
- [net] tcp: Remove 2 indentation levels in tcp_rcv_state_process (Florian Westphal) [1151756]
- [net] tcp: Remove another indentation level in tcp_rcv_state_process (Florian Westphal) [1151756]
- [net] tcp: remove one indentation level in tcp_rcv_state_process (Florian Westphal) [1151756]
- [net] tcp: md5: remove spinlock usage in fast path (Florian Westphal) [1151756]
- [net] tcp: remove bad timeout logic in fast recovery (Florian Westphal) [1151756]
- [net] tcp: speedup tcp_fixup_rcvbuf() (Florian Westphal) [1151756]

* Tue Apr 14 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-239.el7]
- [fs] proc/task_mmu: bump kernelpagesize_kB to EOL in /proc/pid/numa_maps (Petr Holasek) [1071987]
- [Documentation] filesystems/proc.txt: add /proc/pid/numa_maps interface explanation snippet (Petr Holasek) [1071987]
- [fs] proc/task_mmu: show page size in /proc/<pid>/numa_maps (Petr Holasek) [1071987]
- [mm] vmscan: use proportional scanning during direct reclaim and full scan at DEF_PRIORITY (Larry Woodman) [1178988]
- [fs] superblock: avoid locking counting inodes and dentries before reclaiming them (Larry Woodman) [1178988]
- [fs] superblock: unregister sb shrinker before ->kill_sb() (Larry Woodman) [1178988]
- [mm] vmstat: Reduce time interval to stat update on idle cpu (Larry Woodman) [1157802]
- [mm] vmstat: do not use deferrable delayed work for vmstat_update (Larry Woodman) [1157802]
- [mm] vmstat: on-demand vmstat workers V8 (Larry Woodman) [1157802]
- [mm] vmstat: use this_cpu() to avoid irqon/off sequence in refresh_cpu_vm_stats (Larry Woodman) [1157802]
- [mm] vmstat: create fold_diff (Larry Woodman) [1157802]
- [mm] vmstat: create separate function to fold per cpu diffs into local counters (Larry Woodman) [1157802]
- [mm] msync: fix incorrect fstart calculation (Larry Woodman) [1172896]
- [mm] msync: sync only the requested range in msync() (Larry Woodman) [1172896]
- [drm] Missed clflushopt in drm_clflush_virt_range (Steve Best) [1170846]
- [x86] cpufeature: If we disable CLFLUSH, we should disable CLFLUSHOPT (Steve Best) [1170846]
- [x86] Use clflushopt in drm_clflush_virt_range (Steve Best) [1170846]
- [x86] Use clflushopt in drm_clflush_page (Steve Best) [1170846]
- [x86] Use clflushopt in clflush_cache_range (Steve Best) [1170846]
- [x86] Add support for the clflushopt instruction (Steve Best) [1170846]
- [x86] mm: register 1G page size if we can allocate them at runtime (Petr Holasek) [1197899]
- [x86] kvm: insufficient sysenter emulation when invoked from 16-bit code (Jacob Tanenbaum) [1186452] {CVE-2015-0239}
- [kernel] module: Clean up ro/nx after early module load failures (Pratyush Anand) [1202866]
- [kernel] panic: add TAINT_SOFTLOCKUP (Aaron Tomlin) [1194353]
- [kernel] watchdog: print traces for all cpus on lockup detection (Aaron Tomlin) [1194353]
- [x86] nmi: provide the option to issue an NMI back trace to every cpu but current (Aaron Tomlin) [1194353]
- [kernel] Use 'E' instead of 'X' for unsigned module taint flag (Jiri Olsa) [1179759]
- [kernel] fix module signature vs tracepoints add new TAINT_UNSIGNED_MODULE (Jiri Olsa) [1179759]
- [kernel] kvm: rcu: nohz: use RCU extended quiescent state when running KVM guest (Rik van Riel) [1194681]
- [kernel] context_tracking: Export context_tracking_user_enter/exit (Rik van Riel) [1194681]
- [kernel] context_tracking: Run vtime_user_enter/exit only when state == CONTEXT_USER (Rik van Riel) [1194681]
- [kernel] context_tracking: Add stub context_tracking_is_enabled (Rik van Riel) [1194681]
- [kernel] context_tracking: Generalize context tracking APIs to support user and guest (Rik van Riel) [1194681]
- [kernel] context_tracking: Rename context symbols to prepare for transition state (Rik van Riel) [1194681]
- [kernel] context_tracking: Restore previous state in schedule_user (Rik van Riel) [1194681]
- [powerpc] Remove unused cpp symbols in kvm headers (Rik van Riel) [1194681]
- [kernel] context_tracking: Rename context_tracking_active() to context_tracking_cpu_is_enabled() (Rik van Riel) [1194681]
- [kernel] context_tracking: Wrap static key check into more intuitive function name (Rik van Riel) [1194681]
- [kernel] arm: Fix build error with context tracking calls (Rik van Riel) [1194681]
- [kernel] irq_work: Remove BUG_ON in irq_work_run() (Jan Stancek) [1210986]
- [kernel] rcu: Remove "Experimental" flags (Prarit Bhargava) [1182093]

* Fri Apr 10 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-238.el7]
- [md] dm-snapshot: suspend merging snapshot when doing exception handover (Mike Snitzer) [1205955]
- [md] dm-snapshot: suspend origin when doing exception handover (Mike Snitzer) [1205955]
- [md] dm-snapshot: allocate a per-target structure for snapshot-origin target (Mike Snitzer) [1205955]
- [md] dm-crypt: sort writes (Mike Snitzer) [1205955 752438]
- [md] dm-crypt: add 'submit_from_crypt_cpus' option (Mike Snitzer) [1205955 752438]
- [md] dm-crypt: offload writes to thread (Mike Snitzer) [1205955 752438]
- [md] dm-crypt: remove unused io_pool and _crypt_io_pool (Mike Snitzer) [1205955 752438]
- [md] dm-crypt: avoid deadlock in mempools (Mike Snitzer) [1205955 752438]
- [md] dm-crypt: don't allocate pages for a partial request (Mike Snitzer) [1205955 752438]
- [md] dm-crypt: use unbound workqueue for request processing (Mike Snitzer) [1205955 752438]
- [md] dm: fix add_disk() NULL pointer due to race with free_dev() (Mike Snitzer) [1205955]
- [md] dm-io: deal with wandering queue limits when handling REQ_DISCARD and REQ_WRITE_SAME (Mike Snitzer) [1205955]
- [md] dm: hold suspend_lock while suspending device during device deletion (Mike Snitzer) [1205955]
- [md] dm-thin: fix to consistently zero-fill reads to unprovisioned blocks (Mike Snitzer) [1205955]
- [md] dm-snapshot: fix a possible invalid memory access on unload (Mike Snitzer) [1205955]
- [md] dm: fix a race condition in dm_get_md (Mike Snitzer) [1205955]
- [md] dm-io: reject unsupported DISCARD requests with EOPNOTSUPP (Mike Snitzer) [1205955]
- [md] dm-mirror: do not degrade the mirror on discard error (Mike Snitzer) [1205955]
- [md] dm-space-map-disk: fix sm_disk_count_is_more_than_one() (Mike Snitzer) [1205955]
- [md] dm: inherit QUEUE_FLAG_SG_GAPS flags from underlying queues (Mike Snitzer) [1205955]
- [md] dm-snapshot: remove unnecessary NULL checks before vfree() calls (Mike Snitzer) [1205955]
- [md] dm-mpath: simplify failure path of dm_multipath_init() (Mike Snitzer) [1205955]
- [md] dm-thin-metadata: remove unused dm_pool_get_data_block_size() (Mike Snitzer) [1205955]
- [md] dm-ioctl: fix stale comment above dm_get_inactive_table() (Mike Snitzer) [1205955]
- [md] dm-crypt: update url in CONFIG_DM_CRYPT help text (Mike Snitzer) [1205955]
- [md] dm-bufio: fix time comparison to use time_after_eq() (Mike Snitzer) [1205955]
- [md] dm: use time_in_range() and time_after() (Mike Snitzer) [1205955]
- [md] dm-raid: fix a couple integer overflows (Mike Snitzer) [1205955]
- [md] dm-table: train hybrid target type detection to select blk-mq if appropriate (Mike Snitzer) [1205955]
- [md] dm: allocate requests in target when stacking on blk-mq devices (Mike Snitzer) [1205955]
- [md] dm: prepare for allocating blk-mq clone requests in target (Mike Snitzer) [1205955]
- [md] dm: submit stacked requests in irq enabled context (Mike Snitzer) [1205955]
- [md] dm: split request structure out from dm_rq_target_io structure (Mike Snitzer) [1205955]
- [md] dm: remove exports for request-based interfaces without external callers (Mike Snitzer) [1205955]
- [md] block: mark blk-mq devices as stackable (Mike Snitzer) [1205955]
- [md] block: keep established cmd_flags when cloning into a blk-mq request (Mike Snitzer) [1205955]
- [md] block: add blk-mq support to blk_insert_cloned_request() (Mike Snitzer) [1205955]
- [md] dm: fix multipath regression due to initializing wrong request (Mike Snitzer) [1205955]
- [md] block: require blk_rq_prep_clone() be given an initialized clone request (Mike Snitzer) [1205955]
- [md] dm: fix handling of multiple internal suspends (Mike Snitzer) [1205955]
- [md] dm: fix missed error code if .end_io isn't implemented by target_type (Mike Snitzer) [1205955]
- [md] dm-crypt: use memzero_explicit for on-stack buffer (Mike Snitzer) [1205955]
- [md] lib: memzero_explicit: add comment for its usage (Mike Snitzer) [1205955]
- [md] random: add and use memzero_explicit() for clearing data (Mike Snitzer) [1205955]
- [md] crypto: define OPTIMIZER_HIDE_VAR for future use in memzero_explicit (Mike Snitzer) [1205955]
- [md] dm-space-map-metadata: fix sm_bootstrap_get_count() (Mike Snitzer) [1205955]
- [md] dm-space-map-metadata: fix sm_bootstrap_get_nr_blocks() (Mike Snitzer) [1205955]
- [md] dm-stripe: fix potential for leak in stripe_ctr error path (Mike Snitzer) [1205955]
- [md] dm-log-userspace: fix memory leak in dm_ulog_tfr_init failure path (Mike Snitzer) [1205955]
- [md] dm-raid: fix inaccessible superblocks causing oops in configure_discard_support (Mike Snitzer) [1205955]
- [md] dm-raid: add discard support for RAID levels 4, 5 and 6 (Mike Snitzer) [1205955]
- [md] dm-raid: add discard support for RAID levels 1 and 10 (Mike Snitzer) [1205955]
- [md] dm-switch: efficiently support repetitive patterns (Mike Snitzer) [1205955]
- [md] dm-switch: factor out switch_region_table_read (Mike Snitzer) [1205955]
- [md] dm-table: fix RHEL7 inconsistency with location of dm_table_run_md_queue_async (Mike Snitzer) [1205955]
- [md] dm-mpath: fix stalls when handling invalid ioctls (Mike Snitzer) [1205955]
- [tty] fix kABI broken by introduction of ldisc_sem (Aristeu Rozanski) [1183479]
- [tty] Fix hang at ldsem_down_read() (Aristeu Rozanski) [1183479]
- [tty] Replace ldisc locking with ldisc_sem (Aristeu Rozanski) [1183479]
- [tty] Add lock/unlock ldisc pair functions (Aristeu Rozanski) [1183479]
- [tty] Fix tty_ldisc_lock name collision (Aristeu Rozanski) [1183479]
- [tty] n_tty: Buffer work should not reschedule itself (Aristeu Rozanski) [1183479]
- [tty] n_tty: Fix unsafe update of available buffer space (Aristeu Rozanski) [1183479]
- [tty] n_tty: Untangle read completion variables (Aristeu Rozanski) [1183479]
- [tty] n_tty: Encapsulate minimum_to_wake within N_TTY (Aristeu Rozanski) [1183479]
- [tty] Add timed, writer-prioritized rw semaphore (Aristeu Rozanski) [1183479]
- [tty] Remove TTY_HW_COOK_IN/OUT (Aristeu Rozanski) [1183479]
- [char] random: account for entropy loss due to overwrites (Herbert Xu) [1110044]
- [char] random: allow fractional bits to be tracked (Herbert Xu) [1110044]
- [char] random: statically compute poolbitshift, poolbytes, poolbits (Herbert Xu) [1110044]
- [kernel] jiffies: Fix timeval conversion to jiffies (George Beshers) [1182693]
- [kernel] timekeeping: Update timekeeper before updating vsyscall and pvclock (George Beshers) [1182693]
- [kernel] timekeeping: Provide internal ktime_t based data (George Beshers) [1182693]
- [kernel] irq_work: Force raised irq work to run on irq work interrupt (George Beshers) [1182693]
- [kernel] irq_work: Introduce arch_irq_work_has_interrupt() (George Beshers) [1182693]
- [kernel] nohz: Restore NMI safe local irq work for local nohz kick (George Beshers) [1182693]
- [kernel] nohz: Avoid tick's double reprogramming in highres mode (George Beshers) [1182693]
- [kernel] nohz: Fix spurious periodic tick behaviour in low-res dynticks mode (George Beshers) [1182693]
- [kernel] nohz: Support nohz full remote kick (George Beshers) [1182693]
- [kernel] irq_work: Implement remote queueing (George Beshers) [1182693]
- [kernel] irq_work: Split raised and lazy lists (George Beshers) [1182693]
- [kernel] tick-sched: Check tick_nohz_enabled in tick_nohz_switch_to_nohz() (George Beshers) [1182693]
- [kernel] tick-sched: Don't call update_wall_time() when delta is lesser than tick_period (George Beshers) [1182693]
- [kernel] nohz: Get timekeeping max deferment outside jiffies_lock (George Beshers) [1182693]
- [kernel] sched/clock, x86: Avoid a runtime condition in native_sched_clock() (George Beshers) [1182693]
- [kernel] nohz_full: fix code style issue of tick_nohz_full_stop_tick (George Beshers) [1182693]
- [kernel] sched/clock, x86: Use a static_key for sched_clock_stable (George Beshers) [1182693]
- [kernel] sched/clock: Remove local_irq_disable() from the clocks (George Beshers) [1182693]
- [x86] perf: Clean up cap_user_time setting (George Beshers) [1182693]
- [kernel] timekeeping: Call update_wall_time outside the jiffies lock (George Beshers) [1182693]
- [kernel] timekeeping: Avoid possible deadlock from clock_was_set_delayed (George Beshers) [1182693]
- [kernel] timekeeping: Fix lost updates to tai adjustment (George Beshers) [1182693]
- [kernel] timekeeping: Fix potential lost pv notification of time change (George Beshers) [1182693]
- [kernel] timekeeping: Indicate that clock was set in the pvclock gtod notifier (George Beshers) [1182693]
- [kernel] timekeeping: Pass flags instead of multiple bools to timekeeping_update() (George Beshers) [1182693]
- [kernel] nohz: Convert a few places to use local per cpu accesses (George Beshers) [1182693]
- [kernel] nohz: Check for nohz active instead of nohz enabled (George Beshers) [1182693]
- [crypto] sha-mb: sha1_mb_alg_state can be static (Herbert Xu) [1173756]
- [crypto] mcryptd: mcryptd_flist can be static (Herbert Xu) [1173756]
- [crypto] sha-mb: SHA1 multibuffer job manager and glue code (Herbert Xu) [1173756]
- [crypto] sha-mb: SHA1 multibuffer crypto computation (x8 AVX2) (Herbert Xu) [1173756]
- [crypto] sha-mb: SHA1 multibuffer submit and flush routines for AVX2 (Herbert Xu) [1173756]
- [crypto] sha-mb: SHA1 multibuffer algorithm data structures (Herbert Xu) [1173756]
- [crypto] sha-mb: multibuffer crypto infrastructure (Herbert Xu) [1173756]
- [kernel] sched: Add function single_task_running to let a task check if it is the only task running on a cpu (Herbert Xu) [1173756]
- [crypto] ahash: initialize entry len for null input in crypto hash sg list walk (Herbert Xu) [1173756]
- [crypto] ahash: Add real ahash walk interface (Herbert Xu) [1173756]
- [crypto] x86: sha256_ssse3 - also test for BMI2 (Herbert Xu) [1201563]
- [crypto] x86: sha1 - reduce size of the AVX2 asm implementation (Herbert Xu) [1177968]
- [crypto] x86: sha1 - fix stack alignment of AVX2 variant (Herbert Xu) [1177968]
- [crypto] x86: sha1 - re-enable the AVX variant (Herbert Xu) [1177968]
- [crypto] sha: SHA1 transform x86_64 AVX2 (Herbert Xu) [1177968]
- [crypto] testmgr: fix RNG return code enforcement (Herbert Xu) [1198978]

* Tue Apr 07 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-237.el7]
- [fs] btrfs: simplify insert_orphan_item (Eric Sandeen) [1205873]
- [fs] btrfs: __add_inode_ref out of bounds memory read when looking for extended ref (Eric Sandeen) [1205873]
- [fs] btrfs: fix data loss in the fast fsync path (Eric Sandeen) [1205873]
- [fs] btrfs: fix lost return value due to variable shadowing (Eric Sandeen) [1205873]
- [fs] btrfs: fix fsync race leading to ordered extent memory leaks (Eric Sandeen) [1205873]
- [fs] btrfs: fix fsync data loss after adding hard link to inode (Eric Sandeen) [1205873]
- [fs] btrfs: fix leak of path in btrfs_find_item (Eric Sandeen) [1205873]
- [fs] btrfs: set proper message level for skinny metadata (Eric Sandeen) [1205873]
- [fs] btrfs: add missing blk_finish_plug in btrfs_sync_log() (Eric Sandeen) [1205873]
- [fs] btrfs: fix raid56 scrub failed in xfstests btrfs/072 (Eric Sandeen) [1205873]
- [fs] btrfs: Don't call btrfs_start_transaction() on frozen fs to avoid deadlock (Eric Sandeen) [1205873]
- [fs] btrfs: Fix the bug that fs_info->pending_changes is never cleared (Eric Sandeen) [1205873]
- [fs] btrfs: fix state->private cast on 32 bit machines (Eric Sandeen) [1205873]
- [fs] btrfs: fix race deleting block group from space_info->ro_bgs list (Eric Sandeen) [1205873]
- [fs] btrfs: fix incorrect freeing in scrub_stripe (Eric Sandeen) [1205873]
- [fs] btrfs: sync ioctl, handle errors after transaction start (Eric Sandeen) [1205873]
- [fs] btrfs: don't delay inode ref updates during log replay (Eric Sandeen) [1205873]
- [fs] btrfs: correctly get tree level in tree_backref_for_extent (Eric Sandeen) [1205873]
- [fs] btrfs: call inode_dec_link_count() on mkdir error path (Eric Sandeen) [1205873]
- [fs] btrfs: abort transaction if we don't find the block group (Eric Sandeen) [1205873]
- [fs] btrfs, scrub: uninitialized variable in scrub_extent_for_parity() (Eric Sandeen) [1205873]
- [fs] btrfs: filp_open() returns ERR_PTR() on failure, not NULL (Eric Sandeen) [1205873]
- [fs] btrfs: remove non-sense btrfs_error_discard_extent() function (Eric Sandeen) [1205873]
- [fs] btrfs: fix fs corruption on transaction abort if device supports discard (Eric Sandeen) [1205873]
- [fs] btrfs: always clear a block group node when removing it from the tree (Eric Sandeen) [1205873]
- [fs] btrfs: ensure deletion from pinned_chunks list is protected (Eric Sandeen) [1205873]
- [fs] btrfs: make get_caching_control unconditionally return the ctl (Eric Sandeen) [1205873]
- [fs] btrfs: fix unprotected deletion from pending_chunks list (Eric Sandeen) [1205873]
- [fs] btrfs: fix fs mapping extent map leak (Eric Sandeen) [1205873]
- [fs] btrfs: fix memory leak after block remove + trimming (Eric Sandeen) [1205873]
- [fs] btrfs: make btrfs_abort_transaction consider existence of new block groups (Eric Sandeen) [1205873]
- [fs] btrfs: fix race between writing free space cache and trimming (Eric Sandeen) [1205873]
- [fs] btrfs: fix race between fs trimming and block group remove/allocation (Eric Sandeen) [1205873]
- [fs] btrfs, replace: enable dev-replace for raid56 (Eric Sandeen) [1205873]
- [fs] btrfs: fix freeing used extents after removing empty block group (Eric Sandeen) [1205873]
- [fs] btrfs: fix crash caused by block group removal (Eric Sandeen) [1205873]
- [fs] btrfs: fix invalid block group rbtree access after bg is removed (Eric Sandeen) [1205873]
- [fs] btrfs, raid56: fix use-after-free problem in the final device replace procedure on raid56 (Eric Sandeen) [1205873]
- [fs] btrfs, replace: write raid56 parity into the replace target device (Eric Sandeen) [1205873]
- [fs] btrfs, replace: write dirty pages into the replace target device (Eric Sandeen) [1205873]
- [fs] btrfs, raid56: support parity scrub on raid56 (Eric Sandeen) [1205873]
- [fs] btrfs, raid56: use a variant to record the operation type (Eric Sandeen) [1205873]
- [fs] btrfs, scrub: repair the common data on RAID5/6 if it is corrupted (Eric Sandeen) [1205873]
- [fs] btrfs, raid56: don't change bbio and raid_map (Eric Sandeen) [1205873]
- [fs] btrfs: remove unnecessary code of stripe_index assignment in __btrfs_map_block (Eric Sandeen) [1205873]
- [fs] btrfs: remove noused bbio_ret in __btrfs_map_block in condition (Eric Sandeen) [1205873]
- [fs] btrfs: zero out left over bytes after processing compression streams (Eric Sandeen) [1205873]
- [fs] btrfs: fix snapshot inconsistency after a file write followed by truncate (Eric Sandeen) [1205873]
- [fs] Add wait_on_atomic_t() and wake_up_atomic_t() (Eric Sandeen) [1205873]
- [fs] btrfs: ensure send always works on roots without orphans (Eric Sandeen) [1205873]
- [fs] btrfs: fix freeing used extent after removing empty block group (Eric Sandeen) [1205873]
- [fs] btrfs: include vmalloc.h in check-integrity.c (Eric Sandeen) [1205873]
- [fs] btrfs: Fix a lockdep warning when running xfstest (Eric Sandeen) [1205873]
- [fs] btrfs: ensure ordered extent errors aren't missed on fsync (Eric Sandeen) [1205873]
- [fs] btrfs: collect only the necessary ordered extents on ranged fsync (Eric Sandeen) [1205873]
- [fs] btrfs: don't ignore log btree writeback errors (Eric Sandeen) [1205873]
- [fs] btrfs: do not move em to modified list when unpinning (Eric Sandeen) [1205873]
- [fs] btrfs: make sure logged extents complete in the current transaction V3 (Eric Sandeen) [1205873]
- [fs] btrfs: make sure we wait on logged extents when fsycning two subvols (Eric Sandeen) [1205873]
- [fs] btrfs: fix wrong accounting of raid1 data profile in statfs (Eric Sandeen) [1205873]
- [fs] btrfs: fix dead lock while running replace and defrag concurrently (Eric Sandeen) [1205873]
- [fs] btrfs: make xattr replace operations atomic (Eric Sandeen) [1205873]
- [fs] btrfs: avoid premature -ENOMEM in clear_extent_bit() (Eric Sandeen) [1205873]
- [fs] btrfs: don't take the chunk_mutex/dev_list mutex in statfs V2 (Eric Sandeen) [1205873]
- [fs] btrfs: move read only block groups onto their own list V2 (Eric Sandeen) [1205873]
- [fs] btrfs: fix typos in btrfs_check_super_valid (Eric Sandeen) [1205873]
- [fs] btrfs: check-int: don't complain about balanced blocks (Eric Sandeen) [1205873]
- [fs] btrfs: check_int: use the known block location (Eric Sandeen) [1205873]
- [fs] btrfs: avoid returning -ENOMEM in convert_extent_bit() too early (Eric Sandeen) [1205873]
- [fs] btrfs: make find_first_extent_bit be able to cache any state (Eric Sandeen) [1205873]
- [fs] btrfs: deal with convert_extent_bit errors to avoid fs corruption (Eric Sandeen) [1205873]
- [fs] btrfs: return failure if btrfs_dev_replace_finishing() failed (Eric Sandeen) [1205873]
- [fs] btrfs: fix allocationg memory failure for btrfsic_state structure (Eric Sandeen) [1205873]
- [fs] btrfs: report error after failure inlining extent in compressed write path (Eric Sandeen) [1205873]
- [fs] btrfs: add helper btrfs_fdatawrite_range (Eric Sandeen) [1205873]
- [fs] btrfs: correctly flush compressed data before/after direct IO (Eric Sandeen) [1205873]
- [fs] btrfs: make inode.c:compress_file_range() return void (Eric Sandeen) [1205873]
- [fs] btrfs: fix incorrect compression ratio detection (Eric Sandeen) [1205873]
- [fs] btrfs: don't ignore compressed bio write errors (Eric Sandeen) [1205873]
- [fs] btrfs: make inode.c:submit_compressed_extents() return void (Eric Sandeen) [1205873]
- [fs] btrfs: process all async extents on compressed write failure (Eric Sandeen) [1205873]
- [fs] btrfs: don't leak pages and memory on compressed write error (Eric Sandeen) [1205873]
- [fs] btrfs: fix hang on compressed write error (Eric Sandeen) [1205873]
- [fs] btrfs: set page and mapping error on compressed write failure (Eric Sandeen) [1205873]
- [fs] btrfs: fix lockups from btrfs_clear_path_blocking (Eric Sandeen) [1205873]
- [fs] btrfs: get rid of f_dentry use (Eric Sandeen) [1205873]
- [fs] btrfs: move commit out of sysfs when changing label (Eric Sandeen) [1205873]
- [fs] btrfs: move commit out of sysfs when changing features (Eric Sandeen) [1205873]
- [fs] btrfs: introduce pending action: commit (Eric Sandeen) [1205873]
- [fs] btrfs: switch inode_cache option handling to pending changes (Eric Sandeen) [1205873]
- [fs] btrfs: do commit in sync_fs if there are pending changes (Eric Sandeen) [1205873]
- [fs] btrfs: add support for processing pending changes (Eric Sandeen) [1205873]
- [fs] btrfs: fix kfree on list_head in btrfs_lookup_csums_range error cleanup (Eric Sandeen) [1205873]
- [fs] btrfs: fix race that makes btrfs_lookup_extent_info miss skinny extent items (Eric Sandeen) [1205873]
- [fs] btrfs: properly clean up btrfs_end_io_wq_cache (Eric Sandeen) [1205873]
- [fs] btrfs: fix invalid leaf slot access in btrfs_lookup_extent() (Eric Sandeen) [1205873]
- [fs] btrfs: use macro accessors in superblock validation checks (Eric Sandeen) [1205873]
- [fs] revert "btrfs: race free update of commit root for ro snapshots" (Eric Sandeen) [1205873]
- [fs] btrfs: Fix compile error when CONFIG_SECURITY is not set (Eric Sandeen) [1205873]
- [fs] btrfs: Make btrfs handle security mount options internally to avoid losing security label (Eric Sandeen) [1205873]
- [fs] btrfs: send, don't delay dir move if there's a new parent inode (Eric Sandeen) [1205873]
- [fs] btrfs: add more superblock checks (Eric Sandeen) [1205873]
- [fs] btrfs: fix race in WAIT_SYNC ioctl (Eric Sandeen) [1205873]
- [fs] btrfs: be aware of btree inode write errors to avoid fs corruption (Eric Sandeen) [1205873]
- [fs] btrfs: remove redundant btrfs_verify_qgroup_counts declaration (Eric Sandeen) [1205873]
- [fs] btrfs: fix shadow warning on cmp (Eric Sandeen) [1205873]
- [fs] btrfs: fix compilation errors under DEBUG (Eric Sandeen) [1205873]
- [fs] btrfs: fix crash of btrfs_release_extent_buffer_page (Eric Sandeen) [1205873]
- [fs] btrfs: add missing end_page_writeback on submit_extent_page failure (Eric Sandeen) [1205873]
- [fs] btrfs: Fix the wrong condition judgment about subset extent map (Eric Sandeen) [1205873]
- [fs] btrfs: fix build_backref_tree issue with multiple shared blocks (Eric Sandeen) [1205873]
- [fs] btrfs: cleanup error handling in build_backref_tree (Eric Sandeen) [1205873]
- [fs] btrfs: move checks for DUMMY_ROOT into a helper (Eric Sandeen) [1205873]
- [fs] btrfs: new define for the inline extent data start (Eric Sandeen) [1205873]
- [fs] btrfs: kill extent_buffer_page helper (Eric Sandeen) [1205873]
- [fs] btrfs: drop constant param from btrfs_release_extent_buffer_page (Eric Sandeen) [1205873]
- [fs] btrfs: hide typecast to definition of BTRFS_SEND_TRANS_STUB (Eric Sandeen) [1205873]
- [fs] btrfs: let merge_reloc_roots return void (Eric Sandeen) [1205873]
- [fs] btrfs: remove unused members from struct scrub_warning (Eric Sandeen) [1205873]
- [fs] btrfs: use slab for end_io_wq structures (Eric Sandeen) [1205873]
- [fs] btrfs: fix error labels in init_btrfs_fs (Eric Sandeen) [1205873]
- [fs] btrfs: use enum for wq endio metadata type (Eric Sandeen) [1205873]
- [fs] btrfs: remove unused extent state bits (Eric Sandeen) [1205873]
- [fs] btrfs: set default max_inline to 8KiB instead of 8MiB (Eric Sandeen) [1205873]
- [fs] btrfs: remove blocksize from btrfs_alloc_free_block and rename (Eric Sandeen) [1205873]
- [fs] btrfs: remove unused parameter blocksize from btrfs_find_tree_block (Eric Sandeen) [1205873]
- [fs] btrfs: remove parameter blocksize from read_tree_block (Eric Sandeen) [1205873]
- [fs] btrfs: inline code of reada_tree_block and remove it (Eric Sandeen) [1205873]
- [fs] btrfs: return void from readahead_tree_block (Eric Sandeen) [1205873]
- [fs] btrfs: remove unused parameter from readahead_tree_block (Eric Sandeen) [1205873]
- [fs] btrfs: remove unlikely from data-dependent branches and slow paths (Eric Sandeen) [1205873]
- [fs] btrfs: remove unlikely from NULL checks (Eric Sandeen) [1205873]
- [fs] btrfs: remove unused variable from btrfs_parse_options (Eric Sandeen) [1205873]
- [fs] btrfs: defrag, use unsigned type for extent thresh (Eric Sandeen) [1205873]
- [fs] btrfs: try not to ENOSPC on log replay (Eric Sandeen) [1205873]
- [fs] btrfs: don't do async reclaim during log replay (Eric Sandeen) [1205873]
- [fs] btrfs: remove empty block groups automatically (Eric Sandeen) [1205873]
- [fs] btrfs: fix data corruption after fast fsync and writeback error (Eric Sandeen) [1205873]
- [fs] btrfs: fix fsync race leading to invalid data after log replay (Eric Sandeen) [1205873]
- [fs] revert "btrfs: device_list_add() should not update list when mounted" (Eric Sandeen) [1205873]
- [fs] btrfs: Fix and enhance merge_extent_mapping() to insert best fitted extent map (Eric Sandeen) [1205873]
- [fs] btrfs: fix up bounds checking in lseek (Eric Sandeen) [1205873]
- [fs] btrfs: cleanup the read failure record after write or when the inode is freeing (Eric Sandeen) [1205873]
- [fs] btrfs: implement repair function when direct read fails (Eric Sandeen) [1205873]
- [fs] btrfs: Set real mirror number for read operation on RAID0/5/6 (Eric Sandeen) [1205873]
- [fs] btrfs: modify clean_io_failure and make it suit direct io (Eric Sandeen) [1205873]
- [fs] btrfs: modify repair_io_failure and make it suit direct io (Eric Sandeen) [1205873]
- [fs] btrfs: split bio_readpage_error into several functions (Eric Sandeen) [1205873]
- [fs] btrfs: Cleanup unused variant and argument of IO failure handlers (Eric Sandeen) [1205873]
- [fs] btrfs: fix missing error handler if submiting re-read bio fails (Eric Sandeen) [1205873]
- [fs] btrfs: do file data check by sub-bio's self (Eric Sandeen) [1205873]
- [fs] btrfs: cleanup similar code of the buffered data data check and dio read data check (Eric Sandeen) [1205873]
- [fs] btrfs: Convert various code to bio_for_each_segment() (Eric Sandeen) [1205873]
- [fs] btrfs: load checksum data once when submitting a direct read io (Eric Sandeen) [1205873]
- [fs] btrfs: modify rw_devices counter under chunk_mutex context (Eric Sandeen) [1205873]
- [fs] btrfs: move the missing device to its own fs device list (Eric Sandeen) [1205873]
- [fs] btrfs: stop mounting the fs if the non-ENOENT errors happen when opening seed fs (Eric Sandeen) [1205873]
- [fs] btrfs: make the logic of source device removing more clear (Eric Sandeen) [1205873]
- [fs] btrfs: fix use-after-free problem of the device during device replace (Eric Sandeen) [1205873]
- [fs] btrfs: fix unprotected device list access when cloning fs devices (Eric Sandeen) [1205873]
- [fs] btrfs: Fix misuse of chunk mutex (Eric Sandeen) [1205873]
- [fs] btrfs: fix unprotected device list access when getting the fs information (Eric Sandeen) [1205873]
- [fs] btrfs: fix unprotected system chunk array insertion (Eric Sandeen) [1205873]
- [fs] btrfs: fix unprotected device's variants on 32bits machine (Eric Sandeen) [1205873]
- [fs] btrfs: update free_chunk_space during allocting a new chunk (Eric Sandeen) [1205873]
- [fs] btrfs: fix unprotected device->bytes_used update (Eric Sandeen) [1205873]
- [fs] btrfs: Fix wrong free_chunk_space assignment during removing a device (Eric Sandeen) [1205873]
- [fs] btrfs: fix wrong device bytes_used in the super block (Eric Sandeen) [1205873]
- [fs] btrfs: fix wrong disk size when writing super blocks (Eric Sandeen) [1205873]
- [fs] btrfs: fix unprotected assignment of the target device (Eric Sandeen) [1205873]
- [fs] btrfs: cleanup double assignment of device->bytes_used when device replace finishes (Eric Sandeen) [1205873]
- [fs] btrfs: cleanup unused num_can_discard in fs_devices (Eric Sandeen) [1205873]
- [fs] btrfs: remove the wrong comments (Eric Sandeen) [1205873]
- [fs] btrfs: fix directory recovery from fsync log (Eric Sandeen) [1205873]
- [fs] btrfs: fix loop writing of async reclaim (Eric Sandeen) [1205873]
- [fs] btrfs: make fiemap not blow when you have lots of snapshots (Eric Sandeen) [1205873]
- [fs] btrfs: add missing compression property remove in btrfs_ioctl_setflags (Eric Sandeen) [1205873]
- [fs] btrfs: Fix a deadlock in btrfs_dev_replace_finishing() (Eric Sandeen) [1205873]
- [fs] btrfs: cleanup the same name in end_bio_extent_readpage (Eric Sandeen) [1205873]
- [fs] btrfs: don't go readonly on existing qgroup items (Eric Sandeen) [1205873]
- [fs] btrfs: shrink further sizeof(struct extent_buffer) (Eric Sandeen) [1205873]
- [fs] btrfs: send, lower mem requirements for processing xattrs (Eric Sandeen) [1205873]
- [fs] btrfs: remove stale define after removing ordered operations (Eric Sandeen) [1205873]
- [fs] btrfs: improve free space cache management and space allocation (Eric Sandeen) [1205873]
- [fs] btrfs: rename total_bytes to avoid confusion (Eric Sandeen) [1205873]
- [fs] btrfs: fix typo in the log message (Eric Sandeen) [1205873]
- [fs] btrfs: rw_devices shouldn't be incremented for seed fs in btrfs_rm_dev_replace_srcdev() (Eric Sandeen) [1205873]
- [fs] btrfs: fix memory leak when there is no more seed device (Eric Sandeen) [1205873]
- [fs] btrfs: update sprout seed pointer when seed fs is relinquished (Eric Sandeen) [1205873]
- [fs] btrfs: fix rw_devices miss match after seed replace (Eric Sandeen) [1205873]
- [fs] btrfs: replace seed device followed by unmount causes kernel WARNING (Eric Sandeen) [1205873]
- [fs] btrfs: preparatory to make btrfs_rm_dev_replace_srcdev() seed aware (Eric Sandeen) [1205873]
- [fs] btrfs: Drop stray check of fixup_workers creation (Eric Sandeen) [1205873]
- [fs] btrfs: make btrfs_search_forward return with nodes unlocked (Eric Sandeen) [1205873]
- [fs] btrfs: sysfs label interface should check for read only FS (Eric Sandeen) [1205873]
- [fs] btrfs: code optimize: BTRFS_ATTR_RW could set the mode (Eric Sandeen) [1205873]
- [fs] btrfs: code optimize: BTRFS_ATTR could handle the mode (Eric Sandeen) [1205873]
- [fs] btrfs: use BTRFS_ATTR instead of btrfs_no_store() (Eric Sandeen) [1205873]
- [fs] btrfs: avoid unnecessary switch of path locks to blocking mode (Eric Sandeen) [1205873]
- [fs] btrfs: unlock nodes earlier when inserting items in a btree (Eric Sandeen) [1205873]
- [fs] btrfs: use IS_ALIGNED() for assertion in btrfs_lookup_csums_range() for simplicity (Eric Sandeen) [1205873]
- [fs] btrfs: add trace for qgroup accounting (Eric Sandeen) [1205873]
- [fs] btrfs: cleanup unused latest_devid and latest_trans in fs_devices (Eric Sandeen) [1205873]
- [fs] btrfs: update the comment of total_bytes and disk_total_bytes of btrfs_devie (Eric Sandeen) [1205873]
- [fs] btrfs: Fix the problem that the dirty flag of dev stats is cleared (Eric Sandeen) [1205873]
- [fs] btrfs: make the device lock and its protected data in the same cacheline (Eric Sandeen) [1205873]
- [fs] btrfs: fix wrong generation check of super block on a seed device (Eric Sandeen) [1205873]
- [fs] btrfs: fix wrong fsid check of scrub (Eric Sandeen) [1205873]
- [fs] btrfs: wake up transaction thread from SYNC_FS ioctl (Eric Sandeen) [1205873]
- [fs] btrfs: fix wrong max inline data size limit (Eric Sandeen) [1205873]
- [fs] btrfs: fix off-by-one in cow_file_range_inline() (Eric Sandeen) [1205873]
- [fs] btrfs: fall into nocompression codes quickly if possible (Eric Sandeen) [1205873]
- [fs] btrfs: fix wrong skipping compression for an inode (Eric Sandeen) [1205873]
- [fs] btrfs: fix sparse warning (Eric Sandeen) [1205873]
- [fs] btrfs: use BUG_ON (Eric Sandeen) [1205873]
- [fs] btrfs compression: merge inflate and deflate z_streams (Eric Sandeen) [1205873]
- [fs] btrfs: set error return value in btrfs_get_blocks_direct (Eric Sandeen) [1205873]
- [fs] btrfs: reduce size of struct extent_state (Eric Sandeen) [1205873]
- [fs] btrfs: use PTR_ERR_OR_ZERO (Eric Sandeen) [1205873]
- [fs] btrfs: print btrfs specific info for some fatal error cases (Eric Sandeen) [1205873]
- [fs] btrfs: fix writing data into the seed filesystem (Eric Sandeen) [1205873]
- [fs] btrfs: make defragment work with nodatacow option (Eric Sandeen) [1205873]
- [fs] btrfs: label should not contain return char (Eric Sandeen) [1205873]
- [fs] btrfs: device delete must be sysloged (Eric Sandeen) [1205873]
- [fs] btrfs: device add must be sysloged (Eric Sandeen) [1205873]
- [fs] btrfs: clear compress-force when remounting with compress option (Eric Sandeen) [1205873]
- [fs] btrfs: use DIV_ROUND_UP instead of open-coded variants (Eric Sandeen) [1205873]
- [fs] btrfs: clean away stripe_align helper (Eric Sandeen) [1205873]
- [fs] btrfs: use nodesize everywhere, kill leafsize (Eric Sandeen) [1205873]
- [fs] btrfs: kill the key type accessor helpers (Eric Sandeen) [1205873]
- [fs] btrfs: make close_ctree return void (Eric Sandeen) [1205873]
- [fs] btrfs: cleanup ino cache members of btrfs_root (Eric Sandeen) [1205873]
- [fs] btrfs: clenaup: don't call btrfs_release_path before free_path (Eric Sandeen) [1205873]
- [fs] btrfs: remove obsolete comment in btrfs_clean_one_deleted_snapshot (Eric Sandeen) [1205873]
- [fs] btrfs: set inode's logged_trans/last_log_commit after ranged fsync (Eric Sandeen) [1205873]
- [fs] btrfs: use insert_inode_locked4 for inode creation (Eric Sandeen) [1205873]
- [fs] btrfs: fix fsync data loss after a ranged fsync (Eric Sandeen) [1205873]
- [fs] btrfs: kfree()ing ERR_PTRs (Eric Sandeen) [1205873]
- [fs] btrfs: fix crash while doing a ranged fsync (Eric Sandeen) [1205873]
- [fs] btrfs: fix corruption after write/fsync failure + fsync + log recovery (Eric Sandeen) [1205873]
- [fs] btrfs: fix autodefrag with compression (Eric Sandeen) [1205873]
- [fs] fs/btrfs/tree-log.c: Fix closing brace followed by if (Eric Sandeen) [1205873]
- [fs] btrfs: fix task hang under heavy compressed write (Eric Sandeen) [1205873]
- [fs] btrfs: fix filemap_flush call in btrfs_file_release (Eric Sandeen) [1205873]
- [fs] btrfs: fix crash on endio of reading corrupted block (Eric Sandeen) [1205873]
- [fs] btrfs: fix leak in qgroup_subtree_accounting() error path (Eric Sandeen) [1205873]
- [fs] btrfs: Use right extent length when inserting overlap extent map (Eric Sandeen) [1205873]
- [fs] btrfs: clone, don't create invalid hole extent map (Eric Sandeen) [1205873]
- [fs] btrfs: don't monopolize a core when evicting inode (Eric Sandeen) [1205873]
- [fs] btrfs: fix hole detection during file fsync (Eric Sandeen) [1205873]
- [fs] btrfs: race free update of commit root for ro snapshots (Eric Sandeen) [1205873]
- [fs] btrfs: don't consider the missing device when allocating new chunks (Eric Sandeen) [1205873]
- [fs] btrfs: Fix wrong device size when we are resizing the device (Eric Sandeen) [1205873]
- [fs] btrfs: don't write any data into a readonly device when scrub (Eric Sandeen) [1205873]
- [fs] btrfs: Fix the problem that the replace destroys the seed filesystem (Eric Sandeen) [1205873]
- [fs] btrfs: Return right extent when fiemap gives unaligned offset and len (Eric Sandeen) [1205873]
- [fs] btrfs: fix wrong extent mapping for DirectIO (Eric Sandeen) [1205873]
- [fs] btrfs: fix wrong write range for filemap_fdatawrite_range() (Eric Sandeen) [1205873]
- [fs] btrfs: fix wrong missing device counter decrease (Eric Sandeen) [1205873]
- [fs] btrfs: fix unzeroed members in fs_devices when creating a fs from seed fs (Eric Sandeen) [1205873]
- [fs] btrfs: check generation as replace duplicates devid+uuid (Eric Sandeen) [1205873]
- [fs] btrfs: device_list_add() should not update list when mounted (Eric Sandeen) [1205873]
- [fs] btrfs: fill_holes: Fix slot number passed to hole_mergeable() call (Eric Sandeen) [1205873]
- [fs] btrfs: fix put dio bio twice when we submit dio bio fail (Eric Sandeen) [1205873]
- [fs] btrfs: disable strict file flushes for renames and truncates (Eric Sandeen) [1205873]
- [fs] btrfs: fix csum tree corruption, duplicate and outdated checksums (Eric Sandeen) [1205873]
- [fs] btrfs: Fix memory corruption by ulist_add_merge() on 32bit arch (Eric Sandeen) [1205873]
- [fs] btrfs: fix compressed write corruption on enospc (Eric Sandeen) [1205873]
- [fs] btrfs: correctly handle return from ulist_add (Eric Sandeen) [1205873]
- [fs] btrfs: qgroup: account shared subtrees during snapshot delete (Eric Sandeen) [1205873]
- [fs] btrfs: read lock extent buffer while walking backrefs (Eric Sandeen) [1205873]
- [fs] btrfs: __btrfs_mod_ref should always use no_quota (Eric Sandeen) [1205873]
- [fs] btrfs: adjust statfs calculations according to raid profiles (Eric Sandeen) [1205873]
- [fs] sunrpc: fix sleeping under rcu_read_lock in gss_stringify_acceptor (Steve Dickson) [1111712]
- [fs] nfs: Fix use of uninitialized variable in nfs_getattr() (Steve Dickson) [1111712]
- [fs] nfs: Remove bogus assignment (Steve Dickson) [1111712]
- [fs] nfs: remove spurious WARN_ON_ONCE in write path (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: serialize GETDEVICEINFO calls (Steve Dickson) [1111712]
- [fs] nfs: fix pnfs direct write memory leak (Steve Dickson) [1111712]
- [fs] revert "nfs: nfs4_do_open should add negative results to the dcache." (Steve Dickson) [1111712]
- [fs] revert "nfs: remove BUG possibility in nfs4_open_and_get_state" (Steve Dickson) [1111712]
- [fs] nfsv4: Ensure nfs_atomic_open set the dentry verifier on ENOENT (Steve Dickson) [1111712]
- [fs] nfsv4.1/pnfs: replace broken pnfs_put_lseg_async (Steve Dickson) [1111712]
- [fs] nfsv4: Remove dead prototype for nfs4_insert_deviceid_node() (Steve Dickson) [1111712]
- [fs] svcrdma: advertise the correct max payload (Steve Dickson) [1111712]
- [fs] nfsd: introduce nfsd4_callback_ops (Steve Dickson) [1111712]
- [fs] nfsd: split nfsd4_callback initialization and use (Steve Dickson) [1111712]
- [fs] nfsd: introduce a generic nfsd4_cb (Steve Dickson) [1111712]
- [fs] nfsd: remove nfsd4_callback.cb_op (Steve Dickson) [1111712]
- [fs] nfsd: do not clear rpc_resp in nfsd4_cb_done_sequence (Steve Dickson) [1111712]
- [fs] nfsd: fix nfsd4_cb_recall_done error handling (Steve Dickson) [1111712]
- [fs] nfsd4: clarify how grace period ends (Steve Dickson) [1111712]
- [fs] nfsd4: stop grace_time update at end of grace period (Steve Dickson) [1111712]
- [fs] nfsd: skip subsequent UMH "create" operations after the first one for v4.0 clients (Steve Dickson) [1111712]
- [fs] nfsd: set and test NFSD4_CLIENT_STABLE bit to reduce nfsdcltrack upcalls (Steve Dickson) [1111712]
- [fs] nfsd: serialize nfsdcltrack upcalls for a particular client (Steve Dickson) [1111712]
- [fs] nfsd: pass extra info in env vars to upcalls to allow for early grace period end (Steve Dickson) [1111712]
- [fs] nfsd: add a v4_end_grace file to /proc/fs/nfsd (Steve Dickson) [1111712]
- [fs] lockd: add a /proc/fs/lockd/nlm_end_grace file (Steve Dickson) [1111712]
- [fs] nfsd: reject reclaim request when client has already sent RECLAIM_COMPLETE (Steve Dickson) [1111712]
- [fs] nfsd: remove redundant boot_time parm from grace_done client tracking op (Steve Dickson) [1111712]
- [fs] lockd: move lockd's grace period handling into its own module (Steve Dickson) [1111712]
- [fs] nfsd: Put export if prepare_creds() fail (Steve Dickson) [1111712]
- [fs] nfsd: Full checking of authentication name (Steve Dickson) [1111712]
- [fs] nfsd: Fix bad using of return value from qword_get (Steve Dickson) [1111712]
- [fs] nfsd: Fix a memory leak if nfsd4_recdir_load fail (Steve Dickson) [1111712]
- [fs] nfsd: Reset creds after mnt_want_write_file() fail (Steve Dickson) [1111712]
- [fs] nfsd: Put file after ima_file_check fail in nfsd_open() (Steve Dickson) [1111712]
- [fs] nfs: do not start the callback thread until we set rqstp->rq_task (Steve Dickson) [1111712]
- [fs] lockd: Do not start the lockd thread before we've set nlmsvc_rqst->rq_task (Steve Dickson) [1111712]
- [fs] nfsd4: remove labeled NFS warning from config help (Steve Dickson) [1111712]
- [fs] sunrpc: fix byte-swapping of displayed XID (Steve Dickson) [1111712]
- [fs] nfsd: Update some as-yet unused 4.2 error codes (Steve Dickson) [1111712]
- [fs] nfsd: Remove duplicate initialization of file_lock (Steve Dickson) [1111712]
- [fs] sunrpc: Fix compile on non-x86 (Steve Dickson) [1111712]
- [fs] nfsd4: reserve adequate space for LOCK op (Steve Dickson) [1111712]
- [fs] nfsd4: remove obsolete comment (Steve Dickson) [1111712]
- [fs] nfsd3: Check write permission after checking existence (Steve Dickson) [1111712]
- [fs] nfsd: call nfs4_put_deleg_lease outside of state_lock (Steve Dickson) [1111712]
- [fs] nfsd: protect lease-related nfs4_file fields with fi_lock (Steve Dickson) [1111712]
- [fs] nfsd: Reorder nfsd_cache_match to check more powerful discriminators first (Steve Dickson) [1111712]
- [fs] nfsd: split DRC global spinlock into per-bucket locks (Steve Dickson) [1111712]
- [fs] nfsd: convert num_drc_entries to an atomic_t (Steve Dickson) [1111712]
- [fs] nfsd: Remove the cache_hash list (Steve Dickson) [1111712]
- [fs] nfsd: convert the lru list into a per-bucket thing (Steve Dickson) [1111712]
- [fs] nfsd: Clean up drc cache in preparation for global spinlock elimination (Steve Dickson) [1111712]
- [fs] sunrpc: Optimise away svc_recv_available (Steve Dickson) [1111712]
- [fs] sunrpc: More optimisations of svc_xprt_enqueue() (Steve Dickson) [1111712]
- [fs] sunrpc: Fix broken kthread_should_stop test in svc_get_next_xprt (Steve Dickson) [1111712]
- [fs] sunrpc: get rid of the request wait queue (Steve Dickson) [1111712]
- [fs] sunrpc: Do not grab pool->sp_lock unnecessarily in svc_get_next_xprt (Steve Dickson) [1111712]
- [fs] nfs: Ensure that nfs_callback_start_svc sets the server rq_task (Steve Dickson) [1111712]
- [fs] lockd: Ensure that lockd_start_svc sets the server rq_task (Steve Dickson) [1111712]
- [fs] sunrpc: Do not override wspace tests in svc_handle_xprt (Steve Dickson) [1111712]
- [fs] nfsv4.1: Fix an NFSv4.1 state renewal regression (Steve Dickson) [1111712]
- [fs] nfsv4: fix open/lock state recovery error handling (Steve Dickson) [1111712]
- [fs] nfsv4: Fix lock recovery when CREATE_SESSION/SETCLIENTID_CONFIRM fails (Steve Dickson) [1111712]
- [fs] nfs: Fabricate fscache server index key correctly (Steve Dickson) [1111712]
- [fs] sunrpc: Add missing support for RPC_CLNT_CREATE_NO_RETRANS_TIMEOUT (Steve Dickson) [1111712]
- [fs] nfsv3: Fix missing includes of nfs3_fs.h (Steve Dickson) [1111712]
- [fs] nfs: don't use STABLE writes during writeback (Steve Dickson) [1111712]
- [fs] nfsv4: use exponential retry on NFS4ERR_DELAY for async requests (Steve Dickson) [1111712]
- [fs] rpc: Add -EPERM processing for xs_udp_send_request() (Steve Dickson) [1111712]
- [fs] rpc: return sent and err from xs_sendpages() (Steve Dickson) [1111712]
- [fs] Fixing lease renewal (Steve Dickson) [1111712]
- [fs] nfs: fix duplicate proc entries (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: Fix a 64-bit division/remainder issue in bl_map_stripe (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: include vmalloc.h for __vmalloc (Steve Dickson) [1111712]
- [fs] nfs41: change PNFS_LAYOUTRET_ON_SETATTR to only return on truncation to smaller size (Steve Dickson) [1111712]
- [fs] nfs: Move NFS v3 acl functions to nfs3_fs.h (Steve Dickson) [1111712]
- [fs] nfs: Remove v3 not compiled check from validate_mount_data() (Steve Dickson) [1111712]
- [fs] nfs: Move v3 declarations out of internal.h (Steve Dickson) [1111712]
- [fs] nfs: Unconditionally enable commit code (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: Remove a couple of unused variables (Steve Dickson) [1111712]
- [fs] pnfs: enable CB_NOTIFY_DEVICEID support (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: in-kernel GETDEVICEINFO XDR parsing (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: move all rpc_pipefs related code into a single file (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: refactor extent processing (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: move extent processing to blocklayout.c (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: allocate separate pages for the layoutcommit payload (Steve Dickson) [1111712]
- [fs] pnfs: remove GETDEVICELIST implementation (Steve Dickson) [1111712]
- [fs] pnfs/objlayout: fix endianess annotation in objio_alloc_deviceid_node (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: remove some debugging (Steve Dickson) [1111712]
- [fs] nfs: add __acquires and __releases annotations to seqfile start/stop routines (Steve Dickson) [1111712]
- [fs] nfs: fix RCU cl_xprt handling in nfs_swap_activate/deactivate (Steve Dickson) [1111712]
- [fs] nfs: setattr can only change regular file sizes (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: use the device id cache (Steve Dickson) [1111712]
- [fs] pnfs: add a nfs4_get_deviceid helper (Steve Dickson) [1111712]
- [fs] pnfs: add a common GETDEVICELIST implementation (Steve Dickson) [1111712]
- [fs] pnfs: factor GETDEVICEINFO implementations (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: return layouts on setattr (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: implement the return_range method (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: rewrite extent tracking (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: don't set pages uptodate (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: remove read-modify-write handling in bl_write_pagelist (Steve Dickson) [1111712]
- [fs] pnfs: add return_range method (Steve Dickson) [1111712]
- [fs] pnfs: add flag to force read-modify-write in ->write_begin (Steve Dickson) [1111712]
- [fs] pnfs: force a layout commit when encountering busy segments during recall (Steve Dickson) [1111712]
- [fs] nfs: Fix a compile warning when !(CONFIG_NFS_V3 || CONFIG_NFS_V4) (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: correctly decrement extent length (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: plug block queues (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: improve GETDEVICEINFO error reporting (Steve Dickson) [1111712]
- [fs] pnfs/blocklayout: reject pnfs blocksize larger than page size (Steve Dickson) [1111712]
- [fs] pnfs: allow splicing pre-encoded pages into the layoutcommit args (Steve Dickson) [1111712]
- [fs] pnfs: avoid using stale stateids after layoutreturn (Steve Dickson) [1111712]
- [fs] pnfs: retry after a bad stateid error from layoutget (Steve Dickson) [1111712]
- [fs] pnfs: don't check sequence on new stateids in layoutget (Steve Dickson) [1111712]
- [fs] pnfs: do not pass uninitialized lsegs to ->free_lseg (Steve Dickson) [1111712]
- [fs] nfs: cap request size to fit a kmalloced page array (Steve Dickson) [1111712]
- [fs] nfs/filelayout: set layoutcommit depending on write verifier (Steve Dickson) [1111712]
- [fs] nfs41: add a helper function to set layoutcommit after commit (Steve Dickson) [1111712]
- [fs] nfs: Clear up state owner lock usage (Steve Dickson) [1111712]
- [fs] rpc: xs_bind - do not bind when requesting a random ephemeral port (Steve Dickson) [1111712]

* Mon Apr 06 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-236.el7]
- [documentation] cpuset: isolcpus: document relationship between cpusets & isolcpus (Rik van Riel) [1194687]
- [kernel] cpusets: isolcpus: exclude isolcpus from load balancing in cpusets (Rik van Riel) [1194687]
- [kernel] sched: isolcpu: make cpu_isolated_map visible outside scheduler (Rik van Riel) [1194687]
- [powerpc] fix memory corruption by pnv_alloc_idle_core_states (Jan Stancek) [1205856]
- [kernel] trace: Check if tracing is enabled in trace_puts() (Luiz Capitulino) [1198836]
- [net] ipvs: allow rescheduling of new connections when port reuse is detected (Marcelo Leitner) [1196781]
- [net] ipv6: gre: fix wrong skb->protocol in WCCP (Hannes Frederic Sowa) [1196478]
- [net] ipv6: mld: fix add_grhead skb_over_panic for devs with large MTUs (Hannes Frederic Sowa) [1194694]
- [net] team: don't traverse port list using rcu in team_set_mac_address (Jiri Pirko) [1182208]
- [net] ipv6: replacing a rt6_info needs to purge possible propagated rt6_infos too (Jiri Pirko) [1198402]
- [net] team: allow TSO being set on master (Jiri Pirko) [1189844]
- [net] ipv6: addrconf: validate new MTU before applying it (Marcelo Leitner) [1194011]
- [net] netfilter: conntrack: adjust nf_conntrack_buckets default value (Marcelo Leitner) [1176947]
- [net] ipv6: fix possible deadlock in ip6_fl_purge / ip6_fl_gc (Jan Stancek) [1191411]
- [netdrv] ppp: deflate: never return len larger than output buffer (Florian Westphal) [1187574]
- [net] ipv4: kABI fix for 0bbf87d backport (Aristeu Rozanski) [1184764]
- [net] ipv4: Convert ipv4.ip_local_port_range to be per netns (Aristeu Rozanski) [1184764]
- [net] xfrm: Fix crash with ipv6 IPsec tunnel and NAT (Hannes Frederic Sowa) [1162395]
- [net] bonding: implement bond_poll_controller() (Nikolay Aleksandrov) [1166647]
- [net] bonding: Implement port churn-machine (AD standard 43.4.17) (Nikolay Aleksandrov) [1166647]
- [net] bonding: Verify RX LACPDU has proper dest mac-addr (Nikolay Aleksandrov) [1166647]
- [net] bonding: simple code refactor (Nikolay Aleksandrov) [1166647]
- [net] bonding: Move slave state changes to a helper function (Nikolay Aleksandrov) [1166647]
- [net] bonding: cleanup and remove dead code (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix LACP PDU not sent on slave port sometimes (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix incorrect lacp mux state when agg not active (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix bond_open() don't always set slave active flag (Nikolay Aleksandrov) [1166647]
- [net] bonding: update bond carrier state when min_links option changes (Nikolay Aleksandrov) [1166647]
- [net] bonding: cleanup bond_opts array (Nikolay Aleksandrov) [1166647]
- [net] bonding: change error message to debug message in __bond_release_one() (Nikolay Aleksandrov) [1166647]
- [net] bonding: Check length of IFLA_BOND_ARP_IP_TARGET attributes (Nikolay Aleksandrov) [1166647]
- [net] bonding: Introduce 4 AD link speed to fix agg_bandwidth (Nikolay Aleksandrov) [1166647]
- [net] bonding: change AD_LINK_SPEED_BITMASK to enum to suport more speed (Nikolay Aleksandrov) [1166647]
- [net] bonding: squash a warning (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix curr_active_slave/carrier with loadbalance arp monitoring (Nikolay Aleksandrov) [1166647]
- [net] bonding: Move bonding headers under include/net (Nikolay Aleksandrov) [1166647]
- [net] bonding: add bond_tx_drop() helper (Nikolay Aleksandrov) [1166647]
- [net] bonding: Simplify the xmit function for modes that use xmit_hash (Nikolay Aleksandrov) [1166647]
- [net] bonding: display xmit_hash_policy for non-dynamic-tlb mode (Nikolay Aleksandrov) [1166647]
- [net] bonding: make global bonding stats more reliable (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove the unnecessary notes for bond_xmit_broadcast() (Nikolay Aleksandrov) [1166647]
- [net] bonding: slight optimization for bond_xmit_roundrobin() (Nikolay Aleksandrov) [1166647]
- [net] bonding: consolidate ASSERT_RTNL()s and remove the unnecessary (Nikolay Aleksandrov) [1166647]
- [net] bonding: trivial: style and comment fixes (Nikolay Aleksandrov) [1166647]
- [net] bonding: consolidate the two rlb_next_rx_slave functions into one (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix div by zero while enslaving and transmitting (Nikolay Aleksandrov) [1166647]
- [net] bonding: adjust locking comments (Nikolay Aleksandrov) [1166647]
- [net] bonding: 3ad: convert to bond->mode_lock (Nikolay Aleksandrov) [1166647]
- [net] bonding: alb: convert to bond->mode_lock (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert curr_slave_lock to a spinlock and rename it (Nikolay Aleksandrov) [1166647]
- [net] bonding: clean curr_slave_lock use (Nikolay Aleksandrov) [1166647]
- [net] bonding: alb: remove curr_slave_lock (Nikolay Aleksandrov) [1166647]
- [net] bonding: 3ad: clean up curr_slave_lock usage (Nikolay Aleksandrov) [1166647]
- [net] bonding: Add missing space in bonding driver parameter description (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove last users of bond->lock and bond->lock itself (Nikolay Aleksandrov) [1166647]
- [net] bonding: options: remove bond->lock usage (Nikolay Aleksandrov) [1166647]
- [net] bonding: procfs: clean bond->lock usage and use RCU (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert primary_slave to use RCU (Nikolay Aleksandrov) [1166647]
- [net] bonding: alb: clean bond->lock (Nikolay Aleksandrov) [1166647]
- [net] bonding: 3ad: use curr_slave_lock instead of bond->lock (Nikolay Aleksandrov) [1166647]
- [netdrv] cxgb4: remove bond->lock (Nikolay Aleksandrov) [1166647]
- [net] bonding: Fix typo in printk (Nikolay Aleksandrov) [1166647]
- [net] bonding: create netlink event when bonding option is changed (Nikolay Aleksandrov) [1166647]
- [net] bonding: Replace rcu_dereference() with rcu_access_pointer() (Nikolay Aleksandrov) [1166647]
- [net] bonding: use kobject_put instead of _del after kobject_add (Nikolay Aleksandrov) [1166647]
- [net] bonding: destroy proc directory only after all bonds are gone (Nikolay Aleksandrov) [1166647]
- [net] bonding: use rtnl_deref in bond_change_rx_flags() (Nikolay Aleksandrov) [1166647]
- [net] bonding: enhance L2 hash helper with packet type (Nikolay Aleksandrov) [1166647]
- [net] bonding: Do not try to send packets over dead link in TLB mode (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove pr_fmt from bond_options.c (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert bond_options.c to use netdev_printk instead of pr_ (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert bond_procfs.c to use netdev_printk instead of pr_ (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove pr_fmt from bond_netlink.c (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert bond_netlink.c to use netdev_printk instead of pr_ (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert bond_debugfs.c to use netdev_printk instead of pr_ (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove pr_fmt from bond_alb.c (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert bond_alb.c to use netdev_printk instead of pr_ (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove pr_fmt from bond_3ad.c (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert bond_3ad.c to use netdev_printk instead of pr_ (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove pr_fmt from bond_main.c (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert bond_main.c to use netdev_printk instead of pr_ (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix bond_option_mode_set warning (Nikolay Aleksandrov) [1166647]
- [net] bonding: permit enslaving interfaces without set_mac support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add proper __rcu annotation for current_arp_slave (Nikolay Aleksandrov) [1166647]
- [net] bonding: add proper __rcu annotation for curr_active_slave (Nikolay Aleksandrov) [1166647]
- [net] bonding: use rcu_access_pointer() in bonding_show_mii_status() (Nikolay Aleksandrov) [1166647]
- [net] bonding: get rid of bond_option_active_slave_get() (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix ad_select module param check (Nikolay Aleksandrov) [1166647]
- [net] bonding: Advertize vxlan offload features when supported (Nikolay Aleksandrov) [1166647]
- [net] bonding: Turn on IFF_UNICAST_FLT on bond devices (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove NULL verification from bond_get_bond_by_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: populate essential new_slave->bond/dev early (Nikolay Aleksandrov) [1166647]
- [net] bonding: Don't assume 802.1Q when sending alb learning packets (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix vlan_features computing (Nikolay Aleksandrov) [1166647]
- [net] bonding: replace SLAVE_IS_OK() with bond_slave_can_tx() (Nikolay Aleksandrov) [1166647]
- [net] bonding: rename {, bond_}slave_can_tx and clean it up (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert IS_UP(slave->dev) to inline function (Nikolay Aleksandrov) [1166647]
- [net] bonding: make IS_IP_TARGET_UNUSABLE_ADDRESS an inline function (Nikolay Aleksandrov) [1166647]
- [net] bonding: create a macro for bond mode and use it (Nikolay Aleksandrov) [1166647]
- [net] bonding: make USES_PRIMARY inline functions (Nikolay Aleksandrov) [1166647]
- [net] bonding: make BOND_NO_USES_ARP an inline function (Nikolay Aleksandrov) [1166647]
- [net] bonding: make TX_QUEUE_OVERRIDE() macro an inline function (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove BOND_MODE_IS_LB macro (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix out of range parameters for bond_intmax_tbl (Nikolay Aleksandrov) [1166647]
- [net] bonding: alloc the structure ad_info dynamically in per slave (Nikolay Aleksandrov) [1166647]
- [net] bonding: make a generic sysfs option store and fix comments (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove the unused macro (Nikolay Aleksandrov) [1166647]
- [net] bonding: simplify the slave_do_arp_validate_only() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove the unnecessary struct bond_net (Nikolay Aleksandrov) [1166647]
- [net] bonding: Fix format string mismatch in bond_sysfs.c (Nikolay Aleksandrov) [1166647]
- [net] bonding: Add tlb_dynamic_lb parameter for tlb mode (Nikolay Aleksandrov) [1166647]
- [net] bonding: Added bond_tlb_xmit() for tlb mode (Nikolay Aleksandrov) [1166647]
- [net] bonding: Reorg bond_alb_xmit code (Nikolay Aleksandrov) [1166647]
- [net] bonding: Changed hashing function to just provide hash (Nikolay Aleksandrov) [1166647]
- [net] bonding: Remove debug_fs files when module init fails (Nikolay Aleksandrov) [1166647]
- [net] bonding: Inactive slaves should keep inactive flag's value (Nikolay Aleksandrov) [1166647]
- [net] bonding: Use RCU_INIT_POINTER(x, NULL) in bonding/bond_options.c (Nikolay Aleksandrov) [1166647]
- [net] bonding: add net_ratelimt to avoid spam in arp interval (Nikolay Aleksandrov) [1166647]
- [net] bonding: support QinQ for bond arp interval (Nikolay Aleksandrov) [1166647]
- [net] vlan: make a new function vlan_dev_vlan_proto() and export (Nikolay Aleksandrov) [1166647]
- [net] bonding: ratelimit pr_err() for bond xmit broadcast (Nikolay Aleksandrov) [1166647]
- [net] bonding: slight optimization for bond xmit path (Nikolay Aleksandrov) [1166647]
- [net] bonding: ratelimit pr_warn()s in 802.3ad mode (Nikolay Aleksandrov) [1166647]
- [net] bonding: use the correct ether type for alb (Nikolay Aleksandrov) [1166647]
- [net] ether: add loopback type ETH_P_LOOPBACK (Nikolay Aleksandrov) [1166647]
- [net] bonding: set correct vlan id for alb xmit path (Nikolay Aleksandrov) [1166647]
- [net] bonding: Call dev_kfree_skby_any instead of kfree_skb (Nikolay Aleksandrov) [1166647]
- [net] bonding: force cast of IP address in options (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix const in options processing (Nikolay Aleksandrov) [1166647]
- [net] bonding: correctly handle out of range parameters for lp_interval (Nikolay Aleksandrov) [1166647]
- [net] bonding: options handling cleanup (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove dead code (Nikolay Aleksandrov) [1166647]
- [net] bonding: make slave status notifications GFP_ATOMIC (Nikolay Aleksandrov) [1166647]
- [net] bonding: send arp requests even if there's no route to them (Nikolay Aleksandrov) [1166647]
- [net] bonding: disallow enslaving a bond to itself (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix a div error caused by the slave release path (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix rtnl: assertion failed at net/core/rtnetlink.c for ab arp monitor (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix rtnl: assertion failed at net/core/rtnetlink.c for 802.3ad mode (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove no longer needed lock for bond_xxx_info_query() (Nikolay Aleksandrov) [1166647]
- [net] bonding: use rcu_dereference() to access curr_active_slave (Nikolay Aleksandrov) [1166647]
- [net] bonding: netpoll: remove unwanted slave_dev_support_netpoll() (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix bond_arp_rcv() race of curr_active_slave (Nikolay Aleksandrov) [1166647]
- [net] bonding: Invert test (Nikolay Aleksandrov) [1166647]
- [net] bonding: Remove unnecessary else (Nikolay Aleksandrov) [1166647]
- [net] bonding: More use of ether_addr_copy (Nikolay Aleksandrov) [1166647]
- [net] bonding: rename last_arp_rx to last_rx (Nikolay Aleksandrov) [1166647]
- [net] bonding: trivial: rename slave->jiffies to ->last_link_up (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove useless updating of slave->dev->last_rx (Nikolay Aleksandrov) [1166647]
- [net] bonding: use last_arp_rx in bond_loadbalance_arp_mon() (Nikolay Aleksandrov) [1166647]
- [net] bonding: use last_arp_rx in slave_last_rx() (Nikolay Aleksandrov) [1166647]
- [net] bonding: use the new options to correctly set last_arp_rx (Nikolay Aleksandrov) [1166647]
- [net] bonding: extend arp_validate to be able to receive unvalidated arp-only traffic (Nikolay Aleksandrov) [1166647]
- [net] bonding: always set recv_probe to bond_arp_rcv in arp monitor (Nikolay Aleksandrov) [1166647]
- [net] bonding: always update last_arp_rx on packet recieve (Nikolay Aleksandrov) [1166647]
- [net] bonding: permit using arp_validate with non-ab modes (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove bond->lock from bond_arp_rcv (Nikolay Aleksandrov) [1166647]
- [net] bonding: 802.3ad: make aggregator_identifier bond-private (Nikolay Aleksandrov) [1166647]
- [net] bonding: Convert memcpy(foo, bar, ETH_ALEN) to ether_addr_copy(foo, bar) (Nikolay Aleksandrov) [1166647]
- [net] bonding: Convert c99 comments (Nikolay Aleksandrov) [1166647]
- [net] bonding: Neaten pr_<level> (Nikolay Aleksandrov) [1166647]
- [net] bonding: Convert pr_warning to pr_warn, neatening (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix checkpatch warnings braces {} (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix checkpatch warnings braces {} (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix checkpatch warnings braces {} (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix checkpatch warnings braces {} (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix checkpatch errors comments and space (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix checkpatch errors with foo* bar|foo * bar (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix bond_options.c direct rwlock.h include (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove the redundant judgements for bond_option_queue_id_set() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove the redundant judgements for bond_set_mac_address() (Nikolay Aleksandrov) [1166647]
- [net] bonding: Fix deadlock in bonding driver when using netpoll (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove unwanted bond lock for enslave processing (Nikolay Aleksandrov) [1166647]
- [net] bonding: fail_over_mac should only affect AB mode in bond_set_mac_address() (Nikolay Aleksandrov) [1166647]
- [net] bonding: fail_over_mac should only affect AB mode at enslave and removal processing (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix locking in bond_loadbalance_arp_mon() (Nikolay Aleksandrov) [1166647]
- [net] bonding: restructure locking of bond_ab_arp_probe() (Nikolay Aleksandrov) [1166647]
- [net] bonding: RCUify bond_ab_arp_probe (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix u64 division (Nikolay Aleksandrov) [1166647]
- [net] bonding: Don't allow bond devices to change network namespaces (Nikolay Aleksandrov) [1166647]
- [net] bonding: change name of sysfs dir for bonding slaves (Nikolay Aleksandrov) [1166647]
- [net] bonding: clean the primary slave if there is no slave matching new primary (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert slaves to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert lp_interval to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert resend_igmp to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert all_slaves_active to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert queue_id to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert active_slave to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert use_carrier to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert primary_reselect to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert primary to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert miimon to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert num_peer_notif to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert ad_select to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert min_links to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert lacp_rate to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert updelay to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert downdelay to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert arp_ip_target to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert arp_interval to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert fail_over_mac to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert arp_all_targets to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert arp_validate to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert xmit_hash_policy to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert packets_per_slave to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert mode setting to use the new option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: add infrastructure for an option API (Nikolay Aleksandrov) [1166647]
- [net] bonding: reciprocal_divide: update/correction of the algorithm (Nikolay Aleksandrov) [1166647]
- [net] bonding: make slave_sysfs_ops static (Nikolay Aleksandrov) [1166647]
- [net] bonding: add sysfs /slave dir for bond slave devices (Nikolay Aleksandrov) [1166647]
- [net] bonding: handle slave's name change with primary_slave logic (Nikolay Aleksandrov) [1166647]
- [net] bonding: use __dev_get_by_name instead of dev_get_by_name to find interface (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix __get_active_agg() RCU logic (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix __get_first_agg RCU usage (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix bond_3ad_set_carrier() RCU usage (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove dead code from 3ad (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert 3ad to use pr_warn instead of pr_warning (Nikolay Aleksandrov) [1166647]
- [net] bonding: clean up style for bond_3ad.c (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix kstrtou8() return value verification in num_peer_notif (Nikolay Aleksandrov) [1166647]
- [net] bonding: add bounds checking for tbl params (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix netlink msg size (Nikolay Aleksandrov) [1166647]
- [net] bonding: add ad_info attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add ad_select attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add lacp_rate attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: make more functions static (Nikolay Aleksandrov) [1166647]
- [net] bonding: use ether_addr_equal_64bits to instead of ether_addr_equal (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove the return value for bond_3ad_bind_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove unwanted return value for bond_dev_queue_xmit() (Nikolay Aleksandrov) [1166647]
- [net] bonding: slight optimizztion for bond_slave_override() (Nikolay Aleksandrov) [1166647]
- [net] bonding: slight optimization for bond_alb_xmit() (Nikolay Aleksandrov) [1166647]
- [net] bonding: slight optimization for bond_3ad_xmit_xor() (Nikolay Aleksandrov) [1166647]
- [net] bonding: use ether_addr_equal_unaligned for bond addr compare (Nikolay Aleksandrov) [1166647]
- [net] bonding: ust micro BOND_NO_USE_ARP to simplify the mode check (Nikolay Aleksandrov) [1166647]
- [net] bonding: add option lp_interval for loading module (Nikolay Aleksandrov) [1166647]
- [net] bonding: make local function static (Nikolay Aleksandrov) [1166647]
- [net] bonding: add packets_per_slave attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add lp_interval attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add min_links attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add all_slaves_active attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add num_grat_arp attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: protect port for bond_3ad_handle_link_change() (Nikolay Aleksandrov) [1166647]
- [net] bonding: protect port for bond_3ad_adapter_duplex_changed() (Nikolay Aleksandrov) [1166647]
- [net] bonding: protect port for bond_3ad_adapter_speed_changed() (Nikolay Aleksandrov) [1166647]
- [net] bonding: add resend_igmp attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add xmit_hash_policy attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add fail_over_mac attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add primary_select attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add primary attribute netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: use be32 nla put/get for be32 values (Nikolay Aleksandrov) [1166647]
- [net] bonding: rebuild the bond_resend_igmp_join_requests_delayed() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove unwanted lock for bond_store_primaryxxx() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove unwanted lock for bond_option_active_slave_set() (Nikolay Aleksandrov) [1166647]
- [net] bonding: add RCU for bond_3ad_state_machine_handler() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove unwanted lock for bond enslave and release (Nikolay Aleksandrov) [1166647]
- [net] bonding: rebuild the lock use for bond_activebackup_arp_mon() (Nikolay Aleksandrov) [1166647]
- [net] bonding: create bond_first_slave_rcu() (Nikolay Aleksandrov) [1166647]
- [net] bonding: rebuild the lock use for bond_loadbalance_arp_mon() (Nikolay Aleksandrov) [1166647]
- [net] bonding: rebuild the lock use for bond_alb_monitor() (Nikolay Aleksandrov) [1166647]
- [net] bonding: rebuild the lock use for bond_mii_monitor() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove the no effect lock for bond_select_active_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: add arp_all_targets netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add arp_validate netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add arp_ip_target netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add arp_interval netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add use_carrier netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add downdelay netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add updelay netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: add miimon netlink support (Nikolay Aleksandrov) [1166647]
- [net] bonding: Use RCU_INIT_POINTER() for better overhead and for sparse (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix packets_per_slave showing (Nikolay Aleksandrov) [1166647]
- [net] bonding: Fix FSF address in file headers (Nikolay Aleksandrov) [1166647]
- [net] bonding: add arp_ip_target checks when install the module (Nikolay Aleksandrov) [1166647]
- [net] bonding: disable arp and enable mii monitoring when bond change to no uses arp mode (Nikolay Aleksandrov) [1166647]
- [net] bonding: add ip checks when store ip target (Nikolay Aleksandrov) [1166647]
- [net] bonding: extend round-robin mode with packets_per_slave (Nikolay Aleksandrov) [1166647]
- [net] bonding: bond_get_size() returns wrong size (Nikolay Aleksandrov) [1166647]
- [net] Revert "Merge branch 'bonding_monitor_locking'" (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove bond read lock for bond_3ad_state_machine_handler() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove bond read lock for bond_activebackup_arp_mon() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove bond read lock for bond_loadbalance_arp_mon() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove bond read lock for bond_alb_monitor() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove bond read lock for bond_mii_monitor() (Nikolay Aleksandrov) [1166647]
- [net] bonding: move bond-specific init after enslave happens (Nikolay Aleksandrov) [1166647]
- [net] bonding: Remove __exit tag from bond_netlink_fini() (Nikolay Aleksandrov) [1166647]
- [net] bonding: add Netlink support active_slave option (Nikolay Aleksandrov) [1166647]
- [net] bonding: add Netlink support mode option (Nikolay Aleksandrov) [1166647]
- [net] bonding: move active_slave getting into separate function (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove bond_ioctl_change_active() (Nikolay Aleksandrov) [1166647]
- [net] bonding: move active_slave setting into separate function (Nikolay Aleksandrov) [1166647]
- [net] bonding: move mode setting into separate function (Nikolay Aleksandrov) [1166647]
- [net] bonding: push Netlink bits into separate file (Nikolay Aleksandrov) [1166647]
- [net] bonding: add rtnl lock and remove read lock for bond sysfs (Nikolay Aleksandrov) [1166647]
- [net] bonding: use RCU protection for alb xmit path (Nikolay Aleksandrov) [1166647]
- [net] bonding: use RCU protection for 3ad xmit path (Nikolay Aleksandrov) [1166647]
- [net] bonding: modify the old and add new xmit hash policies (Nikolay Aleksandrov) [1166647]
- [net] flow_dissector: factor out the ports extraction in skb_flow_get_ports (Nikolay Aleksandrov) [1166647]
- [net] flow: Remove extern from function prototypes (Nikolay Aleksandrov) [1166647]
- [net] bonding: RCUify bond_set_rx_mode() (Nikolay Aleksandrov) [1166647]
- [net] bonding: trivial: remove forgotten bond_next_vlan() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove bond_next_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: don't use bond_next_slave() in bond_info_seq_next() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove unused __get_next_agg() (Nikolay Aleksandrov) [1166647]
- [net] bonding: make bond_3ad_unbind_slave() use bond_for_each_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: make ad_agg_selection_logic() use bond_for_each_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: make __get_active_agg() use bond_for_each_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: make ad_port_selection_logic() use bond_for_each_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove __get_first_port() (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove __get_next_port() (Nikolay Aleksandrov) [1166647]
- [net] bonding: verify if we still have slaves in bond_3ad_unbind_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: correctly verify for the first slave in bond_enslave (Nikolay Aleksandrov) [1166647]
- [net] bonding: move bond_attach/detach_slave in the proper position (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove bond_prev_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: add bond_has_slaves() and use it (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove unused bond_for_each_slave_from() (Nikolay Aleksandrov) [1166647]
- [net] bonding: rework bond_ab_arp_probe() to use bond_for_each_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: rework bond_find_best_slave() to use bond_for_each_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: rework rlb_next_rx_slave() to use bond_for_each_slave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: rework bond_3ad_xmit_xor() to use bond_for_each_slave() only (Nikolay Aleksandrov) [1166647]
- [net] bonding: use bond_for_each_slave() in bond_uninit() (Nikolay Aleksandrov) [1166647]
- [net] bonding: make bond_for_each_slave() use lower neighbour's private (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove bond_for_each_slave_continue_reverse() (Nikolay Aleksandrov) [1166647]
- [net] bonding: populate neighbour's private on enslave (Nikolay Aleksandrov) [1166647]
- [net] bonding: Make alb learning packet interval configurable (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix bond_arp_rcv setting and arp validate desync state (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix store_arp_validate race with mode change (Nikolay Aleksandrov) [1166647]
- [net] bonding: drop read_lock in bond_compute_features (Nikolay Aleksandrov) [1166647]
- [net] bonding: drop read_lock in bond_fix_features (Nikolay Aleksandrov) [1166647]
- [net] bonding: simplify bond_3ad_update_lacp_rate and use RTNL for sync (Nikolay Aleksandrov) [1166647]
- [net] bonding: trivial: remove outdated comment and braces (Nikolay Aleksandrov) [1166647]
- [net] bonding: simplify and fix peer notification (Nikolay Aleksandrov) [1166647]
- [net] bonding: use rlb_client_info->vlan_id instead of ->tag (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove bond_vlan_used() (Nikolay Aleksandrov) [1166647]
- [net] bonding: pr_debug instead of pr_warn in bond_arp_send_all (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove vlan_list/current_alb_vlan (Nikolay Aleksandrov) [1166647]
- [net] bonding: make alb_send_learning_packets() use upper dev list (Nikolay Aleksandrov) [1166647]
- [net] bonding: split alb_send_learning_packets() (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert bond_has_this_ip() to use upper devices (Nikolay Aleksandrov) [1166647]
- [net] bonding: make bond_arp_send_all use upper device list (Nikolay Aleksandrov) [1166647]
- [net] bonding: use netdev_upper list in bond_vlan_used (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix error return code in bond_enslave() (Nikolay Aleksandrov) [1166647]
- [net] bonding: unwind on bond_add_vlan failure (Nikolay Aleksandrov) [1166647]
- [net] bonding: change the bond's vlan syncing functions with the standard ones (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove locking from bond_set_rx_mode() (Nikolay Aleksandrov) [1166647]
- [net] bonding: add bond_time_in_interval() and use it for time comparison (Nikolay Aleksandrov) [1166647]
- [net] bonding: call slave_last_rx() only once per slave (Nikolay Aleksandrov) [1166647]
- [net] bonding: initial RCU conversion (Nikolay Aleksandrov) [1166647]
- [net] bonding: factor out slave id tx code and simplify xmit paths (Nikolay Aleksandrov) [1166647]
- [net] bonding: simplify broadcast_xmit function (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove unnecessary read_locks of curr_slave_lock (Nikolay Aleksandrov) [1166647]
- [net] bonding: convert to list API and replace bond's custom list (Nikolay Aleksandrov) [1166647]
- [net] bonding: fix system hang due to fast igmp timer rescheduling (Nikolay Aleksandrov) [1166647]
- [net] bond: cleanup netpoll code (Nikolay Aleksandrov) [1166647]
- [net] bonding: use pre-defined macro in bond_mode_name instead of magic number 0 (Nikolay Aleksandrov) [1166647]
- [net] bonding: Fixed up a error "do not initialise statics to 0 or NULL" in bond_main.c (Nikolay Aleksandrov) [1166647]
- [net] bonding: add rtnl protection for bonding_store_fail_over_mac (Nikolay Aleksandrov) [1166647]
- [net] bonding: bond_sysfs.c checkpatch cleanup (Nikolay Aleksandrov) [1166647]
- [net] bonding: don't call slave_xxx_netpoll under spinlocks (Nikolay Aleksandrov) [1166647]
- [net] bonding: remove unnecessary setup_by_slave member (Nikolay Aleksandrov) [1166647]
- [net] bonding: add an option to fail when any of arp_ip_target is inaccessible (Nikolay Aleksandrov) [1166647]
- [net] bonding: don't trust arp requests unless active slave really works (Nikolay Aleksandrov) [1166647]
- [net] bonding: don't validate arp if we don't have to (Nikolay Aleksandrov) [1166647]
- [net] bonding: don't add duplicate targets to arp_ip_target (Nikolay Aleksandrov) [1166647]
- [net] bonding: add helper function bond_get_targets_ip(targets, ip) (Nikolay Aleksandrov) [1166647]
- [net] bonding: trivial: make alb use bond_slave_has_mac() (Nikolay Aleksandrov) [1166647]
- [net] bonding: don't call alb_set_slave_mac_addr() while atomic (Nikolay Aleksandrov) [1166647]
- [net] bonding: disallow change of MAC if fail_over_mac enabled (Nikolay Aleksandrov) [1166647]
- [net] bonding: Convert hw addr handling to sync/unsync, support ucast addresses (Nikolay Aleksandrov) [1166647]
- [net] bonding: trivial: update the comments to reflect the reality (Nikolay Aleksandrov) [1166647]
- [net] bonding: trivial: remove unused parameter from alb_swap_mac_addr() (Nikolay Aleksandrov) [1166647]
- [net] bonding: allow xmit hash policy change while bond dev is up (Nikolay Aleksandrov) [1166647]
- [net] nf_conntrack: allow server to become a client in TW handling (Marcelo Leitner) [1160431]

* Fri Apr 03 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-235.el7]
- [crypto] add missing crypto module aliases (Denys Vlasenko) [1190631] {CVE-2013-7421 CVE-2014-9644}
- [crypto] include crypto- module prefix in template (Denys Vlasenko) [1190631] {CVE-2013-7421 CVE-2014-9644}
- [crypto] prefix module autoloading with "crypto-" (Denys Vlasenko) [1190631] {CVE-2013-7421 CVE-2014-9644}
- [hv] vmbus: introduce vmbus_acpi_remove (Vitaly Kuznetsov) [1201889]
- [hv] vmbus: Teardown synthetic interrupt controllers on module unload (Vitaly Kuznetsov) [1201889]
- [hv] vmbus: teardown hv_vmbus_con workqueue and vmbus_connection pages on shutdown (Vitaly Kuznetsov) [1201889]
- [hv] vmbus: avoid double kfree for device_obj (Vitaly Kuznetsov) [1201889]
- [hv] vmbus: rename channel work queues (Vitaly Kuznetsov) [1201889]
- [hv] use correct order when freeing monitor_pages (Vitaly Kuznetsov) [1201889]
- [x86] hyperv: Fixup the (brain) damage caused by the irq cleanup (Vitaly Kuznetsov) [1201889]
- [x86] hyperv: Fix brown paperbag typos reported by Fenguangs build robot (Vitaly Kuznetsov) [1201889]
- [x86] hyperv: Make it build with CONFIG_HYPERV=m again (Vitaly Kuznetsov) [1201889]
- [x86] hyperv: Cleanup the irq mess (Vitaly Kuznetsov) [1201889]
- [hv] move ringbuffer bus attributes to dev_groups (Vitaly Kuznetsov) [1201889]
- [hv] delete struct hv_dev_port_info (Vitaly Kuznetsov) [1201889]
- [hv] delete vmbus_get_debug_info() (Vitaly Kuznetsov) [1201889]
- [hv] move "client/server_monitor_conn_id" bus attributes to dev_groups (Vitaly Kuznetsov) [1201889]
- [hv] move "client/server_monitor_latency" bus attributes to dev_groups (Vitaly Kuznetsov) [1201889]
- [hv] move "client/server_monitor_pending" bus attributes to dev_groups (Vitaly Kuznetsov) [1201889]
- [hv] make "monitor_pages" a "real" pointer array (Vitaly Kuznetsov) [1201889]
- [hv] move "device_id" bus attribute to dev_groups (Vitaly Kuznetsov) [1201889]
- [hv] move "class_id" bus attribute to dev_groups (Vitaly Kuznetsov) [1201889]
- [hv] move "modalias" bus attribute to dev_groups (Vitaly Kuznetsov) [1201889]
- [hv] move "monitor_id" bus attribute to dev_groups (Vitaly Kuznetsov) [1201889]
- [hv] move "state" bus attribute to dev_groups (Vitaly Kuznetsov) [1201889]
- [hv] use dev_groups for device attributes (Vitaly Kuznetsov) [1201889]
- [drm] radeon: fix kernel segfault in hwmonitor (Jerome Glisse) [1187817]
- [pci] Remove DEFINE_PCI_DEVICE_TABLE macro use (Prarit Bhargava) [1198151]
- [scsi] storvsc: get rid of overly verbose warning messages (Vitaly Kuznetsov) [1035213 1206437]
- [scsi] storvsc: force discovery of LUNs that may have been removed (Vitaly Kuznetsov) [1035213 1206437]
- [scsi] storvsc: in responce to a scan event, scan the host (Vitaly Kuznetsov) [1035213 1206437]
- [scsi] storvsc: NULL pointer dereference fix (Vitaly Kuznetsov) [1035213 1206437]
- [netdrv] bnx2: disable toggling of rxvlan if necessary (Ivan Vecera) [1190094]
- [netdrv] tg3: move init/deinit from open/close to probe/remove (Ivan Vecera) [1172960]
- [netdrv] mlx4_en: tx_info->ts_requested was not cleared (Doug Ledford) [1178070]
- [input] serio: hyperv-keyboard - register as a wakeup source (Vitaly Kuznetsov) [1086100]
- [hid] hyperv: register as a wakeup source (Vitaly Kuznetsov) [1086100]
- [hid] hyperv: make sure input buffer is big enough (Vitaly Kuznetsov) [1086100]
- [edac] sb_edac: Fix typo computing number of banks (Seth Jennings) [1165448]
- [edac] sb_edac: Add support for Broadwell-DE processor (Seth Jennings) [1165448]
- [edac] sb_edac: Fix discovery of top-of-low-memory for Haswell (Seth Jennings) [1158624]
- [perf] powerpc: Use dwfl_report_elf() instead of offline (Gustavo Duarte) [1113736]
- [perf] powerpc: Cache the DWARF debug info (Gustavo Duarte) [1113736]
- [kernel] ring-buffer: Check if buffer exists before polling (Gustavo Duarte) [1199699]
- [powerpc] mm: thp: Add tracepoints to track hugepage invalidate (Gustavo Duarte) [1199016]
- [powerpc] mm: Use read barrier when creating real_pte (Gustavo Duarte) [1199016]
- [powerpc] mm: thp: Use ACCESS_ONCE when loading pmdp (Gustavo Duarte) [1199016]
- [powerpc] mm: thp: Invalidate with vpn in loop (Gustavo Duarte) [1199016]
- [powerpc] mm: thp: Handle combo pages in invalidate (Gustavo Duarte) [1199016]
- [powerpc] mm: thp: Invalidate old 64K based hash page mapping before insert of 4k pte (Gustavo Duarte) [1199016]
- [powerpc] mm: thp: Don't recompute vsid and ssize in loop on invalidate (Gustavo Duarte) [1199016]
- [powerpc] mm: thp: Add write barrier after updating the valid bit (Gustavo Duarte) [1199016]
- [cpufreq] powernv: Set the cpus to nominal frequency during reboot/kexec (Gustavo Duarte) [1182062]
- [cpufreq] powernv: Set the pstate of the last hotplugged out cpu in policy->cpus to minimum (Gustavo Duarte) [1182062]
- [cpufreq] Allow stop CPU callback to be used by all cpufreq drivers (Gustavo Duarte) [1182062]
- [i2c] i801: Add DeviceIDs for SunrisePoint LP (David Milburn) [1129470]
- [sound] alsa: hda_intel: Add DeviceIDs for Sunrise Point-LP (David Milburn) [1129470]
- [ata] ahci: Add DeviceIDs for Sunrise Point-LP SATA controller (David Milburn) [1129470]
- [ata] ahci: Remove Device ID for Intel Sunrise Point PCH (David Milburn) [1082114]
- [i2c] i801: Check if interrupts are disabled (David Milburn) [1082114]
- [i2c] i801: Fallback to polling if request_irq() fails (David Milburn) [1082114]
- [i2c] i801: Use wait_event_timeout to wait for interrupts (David Milburn) [1082114]
- [ata] ahci: Add Device IDs for Intel Sunrise Point PCH (David Milburn) [1082114]
- [i2c] i801: Add Device IDs for Intel Sunrise Point PCH (David Milburn) [1082114]
- [sound] alsa: hda_intel: Add Device IDs for Intel Sunrise Point PCH (David Milburn) [1082114]

* Mon Mar 23 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-234.el7]
- [tools] perf/probe: Trivial typo fix for --demangle (Jiri Olsa) [1169436]
- [tools] perf: Fix report -F dso_from for data without branch info (Jiri Olsa) [1169436]
- [tools] perf: Fix report -F dso_to for data without branch info (Jiri Olsa) [1169436]
- [tools] perf: Fix report -F symbol_from for data without branch info (Jiri Olsa) [1169436]
- [tools] perf: Fix report -F symbol_to for data without branch info (Jiri Olsa) [1169436]
- [tools] perf: Fix report -F mispredict for data without branch info (Jiri Olsa) [1169436]
- [tools] perf: Fix report -F in_tx for data without branch info (Jiri Olsa) [1169436]
- [tools] perf: Fix report -F abort for data without branch info (Jiri Olsa) [1169436]
- [tools] perf: Make CPUINFO_PROC an array to support different kernel versions (Jiri Olsa) [1169436]
- [tools] perf/callchain: Use global caching provided by libunwind (Jiri Olsa) [1169436]
- [tools] perf/diff: Add missing hists__init() call at tool start (Jiri Olsa) [1169436]
- [tools] perf/script: Add period as a default output column (Jiri Olsa) [1169436]
- [tools] perf/script: Add period data column (Jiri Olsa) [1169436]
- [tools] perf/evsel: No need to drag util/cgroup.h (Jiri Olsa) [1169436]
- [tools] perf/evlist: Add missing 'struct option' forward declaration (Jiri Olsa) [1169436]
- [tools] perf/evsel: Move exit stuff from __delete to __exit (Jiri Olsa) [1169436]
- [tools] perf/kvm/stat/live: Enable events copying (Jiri Olsa) [1169436]
- [tools] perf/session: Add option to copy events when queueing (Jiri Olsa) [1169436]
- [tools] perf/Documentation: Fix typos in perf/Documentation (Jiri Olsa) [1169436]
- [tools] perf/trace: Use thread_{, _set}_priv helpers (Jiri Olsa) [1169436]
- [tools] perf/kvm: Use thread_{, _set}_priv helpers (Jiri Olsa) [1169436]
- [tools] perf/callchain: Create an address space per thread (Jiri Olsa) [1169436]
- [tools] perf/report: Set callchain_param.record_mode for future use (Jiri Olsa) [1169436]
- [tools] perf/evlist: Fix for double free in tools/perf stat (Jiri Olsa) [1169436]
- [tools] perf/test: Add test case for pmu event new style format (Jiri Olsa) [1169436]
- [tools] perf: Add support to new style format of kernel PMU event (Jiri Olsa) [1169436]
- [tools] perf: Parse the pmu event prefix and suffix (Jiri Olsa) [1169436]
- [tools] Revert: perf: Default to cpu// for events v5 (Jiri Olsa) [1169436]
- [tools] perf/top: Add a visual cue for toggle zeroing of samples (Jiri Olsa) [1169436]
- [tools] perf/symbols: Make sym->end be the first address after the symbol range (Jiri Olsa) [1169436]
- [tools] perf/symbols: Fix map->end fixup (Jiri Olsa) [1169436]
- [tools] perf: Fixup off-by-one comparision in maps__find (Jiri Olsa) [1169436]
- [tools] perf: fix off-by-one error in maps (Jiri Olsa) [1169436]
- [tools] perf/machine: Add missing dsos->root rbtree root initialization (Jiri Olsa) [1169436]
- [tools] perf/evsel: Make some exit routines static (Jiri Olsa) [1169436]
- [tools] perf/evsel: Add missing 'target' struct forward declaration (Jiri Olsa) [1169436]
- [tools] perf/evlist: Default to syswide target when no thread/cpu maps set (Jiri Olsa) [1169436]
- [tools] perf/evlist: Check that there is a thread_map when preparing a workload (Jiri Olsa) [1169436]
- [tools] perf/thread_map: Create dummy constructor out of open coded equivalent (Jiri Olsa) [1169436]
- [tools] perf: Remove hists from evsel (Jiri Olsa) [1169436]
- [tools] perf/callchain: Move the callchain_param extern to callchain.h (Jiri Olsa) [1169436]
- [tools] perf/evsel: Subclassing (Jiri Olsa) [1169436]
- [tools] perf/session: Remove last reference to hists struct (Jiri Olsa) [1169436]
- [tools] perf/ui/browsers: Add missing include (Jiri Olsa) [1169436]
- [tools] perf: Move events_stats struct to event.h (Jiri Olsa) [1169436]
- [tools] perf/session: Don't count per evsel events (Jiri Olsa) [1169436]
- [tools] perf/evsel: Add hists helper (Jiri Olsa) [1169436]
- [tools] perf/script: Stop updating hists stats, not used (Jiri Olsa) [1169436]
- [tools] perf/sched: Stop updating hists stats, not used (Jiri Olsa) [1169436]
- [tools] perf/callchain: Move callchain_param to util object in to fix python test (Jiri Olsa) [1169436]
- [tools] perf/kvm/stat/live: Use fdarray object instead of pollfd (Jiri Olsa) [1169436]
- [tools] perf/kvm/stat/live: Use perf_evlist__add_pollfd return fd position (Jiri Olsa) [1169436]
- [tools] perf/kvm/stat/live: Fix perf_evlist__add_pollfd error handling (Jiri Olsa) [1169436]
- [tools] perf/record: Fix error message for --filter option not coming after tracepoint (Jiri Olsa) [1169436]
- [tools] perf: Fix build breakage on arm64 targets (Jiri Olsa) [1169436]
- [tools] perf/symbols: Improve DSO long names lookup speed with rbtree (Jiri Olsa) [1169436]
- [tools] perf/symbols: Encapsulate dsos list head into struct dsos (Jiri Olsa) [1169436]
- [tools] perf/bench/futex: Sanitize -q option in requeue (Jiri Olsa) [1169436]
- [tools] perf/bench/futex: Support operations for shared futexes (Jiri Olsa) [1169436]
- [tools] perf/trace: Fix mmap return address truncation to 32-bit (Jiri Olsa) [1169436]
- [tools] perf: Refactor unit and scale function parameters (Jiri Olsa) [1169436]
- [tools] perf: Fix line number in the config file error message (Jiri Olsa) [1169436]
- [tools] perf: Convert {record, top}.call-graph option to call-graph.record-mode (Jiri Olsa) [1169436]
- [tools] perf: Introduce perf_callchain_config() (Jiri Olsa) [1169436]
- [tools] perf/callchain: Move some parser functions to callchain.c (Jiri Olsa) [1169436]
- [tools] perf: Move callchain config from record_opts to callchain_param (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Fix callchain print bug on TUI (Jiri Olsa) [1169436]
- [tools] perf: Use ACCESS_ONCE() instead of volatile cast (Jiri Olsa) [1169436]
- [tools] perf: Modify error code for when perf_session__new() fails (Jiri Olsa) [1169436]
- [tools] perf: Fix perf record as non root with kptr_restrict == 1 (Jiri Olsa) [1169436]
- [tools] perf/stat: Fix --per-core on multi socket systems (Jiri Olsa) [1169436]
- [tools] perf/trace: Filter out POLLHUP'ed file descriptors (Jiri Olsa) [1169436]
- [tools] perf/record: Filter out POLLHUP'ed file descriptors (Jiri Olsa) [1169436]
- [tools] perf/evlist: Unmap when all refcounts to fd are gone and events drained (Jiri Olsa) [1169436]
- [tools] lib/fd/array: Allow associating an integer cookie with each entry (Jiri Olsa) [1169436]
- [tools] perf/evlist: Refcount mmaps (Jiri Olsa) [1169436]
- [tools] lib/api: Adopt fdarray class from perf's evlist (Jiri Olsa) [1169436]
- [tools] perf/evlist: Introduce poll method for common code idiom (Jiri Olsa) [1169436]
- [tools] perf/kvm/stat/live: Use perf_evlist__add_pollfd() instead of local equivalent (Jiri Olsa) [1169436]
- [tools] perf/tests: Add pollfd growing test (Jiri Olsa) [1169436]
- [tools] perf/evlist: Allow growing pollfd on add method (Jiri Olsa) [1169436]
- [tools] perf/evlist: We need to poll all event file descriptors (Jiri Olsa) [1169436]
- [tools] perf/evlist: Monitor POLLERR and POLLHUP events too (Jiri Olsa) [1169436]
- [tools] perf/tests: Add test for perf_evlist__filter_pollfd() (Jiri Olsa) [1169436]
- [tools] perf/evlist: Introduce perf_evlist__filter_pollfd method (Jiri Olsa) [1169436]
- [tools] perf/record: Use ring buffer consume method to look like other tools (Jiri Olsa) [1169436]
- [tools] perf/probe: Do not use dwfl_module_addrsym if dwarf_diename finds symbol name (Jiri Olsa) [1169436]
- [tools] perf/probe: Do not access kallsyms when analyzing user binaries (Jiri Olsa) [1169436]
- [tools] perf/symbols: Add path to Ubuntu kernel debuginfo file (Jiri Olsa) [1169436]
- [tools] perf/symbols: Ignore stripped vmlinux and fallback to kallsyms (Jiri Olsa) [1169436]
- [tools] perf: define _DEFAULT_SOURCE for glibc_2.20 (Jiri Olsa) [1169436]
- [tools] perf: Don't include sys/poll.h directly (Jiri Olsa) [1169436]
- [tools] perf: Fix GNU-only grep usage in Makefile (Jiri Olsa) [1169436]
- [tools] perf/tool: fix compilation for ARM (Jiri Olsa) [1169436]
- [tools] perf: Add perf_pmu__scan_file() (Jiri Olsa) [1169436]
- [tools] perf: Let default config be defined for a PMU (Jiri Olsa) [1169436]
- [tools] perf: Add perf-with-kcore script (Jiri Olsa) [1169436]
- [tools] perf: Let a user specify a PMU event without any config terms (Jiri Olsa) [1169436]
- [tools] perf/kvm/stat/report: Unify the title bar output (Jiri Olsa) [1169436]
- [tools] perf/kvm/stat/report: Enable the target.system_wide flag (Jiri Olsa) [1169436]
- [tools] perf/kvm/stat/report: Save pid string in opts.target.pid (Jiri Olsa) [1169436]
- [tools] perf/powerpc: Fix build issue when DWARF support is disabled (Jiri Olsa) [1169436]
- [tools] perf: Add +field argument support for --sort option (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Consolidate callchain print functions in TUI (Jiri Olsa) [1169436]
- [tools] perf: Add +field argument support for --field option (Jiri Olsa) [1169436]
- [tools] perf/top: Use set_term_quiet() instead of open coded equivalent (Jiri Olsa) [1169436]
- [tools] perf/machine: Fallback to MAP__FUNCTION if daddr maps are NULL (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Cleanup callchain print functions (Jiri Olsa) [1169436]
- [tools] perf: Add machine__kernel_ip() (Jiri Olsa) [1169436]
- [tools] perf/machine: Rename machine__get_kernel_start_addr() method (Jiri Olsa) [1169436]
- [tools] perf/scripting: Add 'flush' callback to scripting API (Jiri Olsa) [1169436]
- [tools] perf/tests: Add a test for tracking with sched_switch (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Factor out hist_browser__show_callchain_entry() (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Fix children overhead dump (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Get rid of unused 'remaining' variable (Jiri Olsa) [1169436]
- [tools] perf/powerpc: Explicitly include util/debug.h (Jiri Olsa) [1169436]
- [tools] perf/symbols: Don't try to find DSOs in SYSV maps (Jiri Olsa) [1169436]
- [tools] perf/stat: Use strerror_r instead of strerror (Jiri Olsa) [1169436]
- [tools] perf/help: Use strerror_r instead of strerror (Jiri Olsa) [1169436]
- [tools] perf/kvm: Use strerror_r instead of strerror (Jiri Olsa) [1169436]
- [tools] perf/buildid-cache: Use strerror_r instead of strerror (Jiri Olsa) [1169436]
- [tools] perf/sched: Use strerror_r instead of strerror (Jiri Olsa) [1169436]
- [tools] perf/test: Use strerror_r instead of strerror (Jiri Olsa) [1169436]
- [tools] perf/record: Use strerror_r instead of strerror (Jiri Olsa) [1169436]
- [tools] perf/trace: Use strerror_r instead of strerror (Jiri Olsa) [1169436]
- [tools] perf/top: Use strerror_r instead of strerror (Jiri Olsa) [1169436]
- [tools] perf/util: Replace strerror with strerror_r for thread-safety (Jiri Olsa) [1169436]
- [tools] perf/probe: Make error messages thread-safe (Jiri Olsa) [1169436]
- [tools] perf: Use strerror_r instead of strerror (Jiri Olsa) [1169436]
- [tools] perf/probe: Don't use strerror if strlist__add failed (Jiri Olsa) [1169436]
- [tools] perf/report: Relax -g option parsing not to limit the option order (Jiri Olsa) [1169436]
- [tools] perf: Annotate PMU related list_head members with type info (Jiri Olsa) [1169436]
- [tools] perf: Add arm64 triplets (Jiri Olsa) [1169436]
- [tools] perf/annotate: Don't truncate Intel style addresses (Jiri Olsa) [1169436]
- [tools] perf/probe: Warn user to rebuild target with debuginfo (Jiri Olsa) [1169436]
- [tools] perf/evlist: Add perf_evlist__enable_event_idx() (Jiri Olsa) [1169436]
- [tools] perf: Add flags and insn_len to struct sample (Jiri Olsa) [1169436]
- [tools] perf/machine: Add machine__thread_exec_comm() (Jiri Olsa) [1169436]
- [tools] perf: Identify which comms are from exec (Jiri Olsa) [1169436]
- [tools] perf/script/python: Add helpers for calling Python objects (Jiri Olsa) [1169436]
- [tools] perf/script: Allow callchains if any event samples them (Jiri Olsa) [1169436]
- [tools] perf/session: Add perf_session__peek_event() (Jiri Olsa) [1169436]
- [tools] perf/evlist: Add perf_evlist__set_tracking_event() (Jiri Olsa) [1169436]
- [tools] perf/evlist: Add 'system_wide' option (Jiri Olsa) [1169436]
- [tools] perf/symbols: Fix missing label symbols (Jiri Olsa) [1169436]
- [tools] perf/top: Handle 'z' key for toggle zeroing samples in TUI (Jiri Olsa) [1169436]
- [tools] perf/top: Fix -z option behavior (Jiri Olsa) [1169436]
- [tools] perf/report: Set proper sort__mode for the branch option (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Fix a small callchain display bug (Jiri Olsa) [1169436]
- [tools] perf: Check recorded kernel version when finding vmlinux (Jiri Olsa) [1169436]
- [tools] perf/trace: Move call to symbol__init() after creating session (Jiri Olsa) [1169436]
- [tools] perf/timechart: Move call to symbol__init() after creating session (Jiri Olsa) [1169436]
- [tools] perf/script: Move call to symbol__init() after creating session (Jiri Olsa) [1169436]
- [tools] perf/sched: Move call to symbol__init() after creating session (Jiri Olsa) [1169436]
- [tools] perf/lock: Move call to symbol__init() after creating session (Jiri Olsa) [1169436]
- [tools] perf/kvm: Move call to symbol__init() after creating session (Jiri Olsa) [1169436]
- [tools] perf/kmem: Move session handling out of __cmd_kmem() (Jiri Olsa) [1169436]
- [tools] perf/inject: Move session handling out of __cmd_inject() (Jiri Olsa) [1169436]
- [tools] perf/buildid-cache: Move session handling into cmd_buildid_cache() (Jiri Olsa) [1169436]
- [tools] perf/annotate: Move session handling out of __cmd_annotate() (Jiri Olsa) [1169436]
- [tools] perf/symbols: Fix a memory leak in vmlinux_path__init() (Jiri Olsa) [1169436]
- [tools] perf/script: Fix possible memory leaks (Jiri Olsa) [1169436]
- [tools] perf: Prefer to use a cpu-wide event for probing CLOEXEC (Jiri Olsa) [1169436]
- [tools] perf: Fix probing the kernel API with cpu-wide events (Jiri Olsa) [1169436]
- [tools] perf: Fix one of the probe events to exclude kernel (Jiri Olsa) [1169436]
- [tools] perf: Fix CLOEXEC probe for perf_event_paranoid == 2 (Jiri Olsa) [1169436]
- [tools] perf/trace: Add beautifier for mremap flags param (Jiri Olsa) [1169436]
- [tools] perf/probe: Fix --del option to delete events only with uprobe events (Jiri Olsa) [1169436]
- [tools] perf/probe: Fix --list option to show events only with uprobe events (Jiri Olsa) [1169436]
- [tools] perf/kvm: Fix stdin handling for 'kvm stat live' command (Jiri Olsa) [1169436]
- [tools] perf/top: Setup signals for terminal output (Jiri Olsa) [1169436]
- [tools] perf: Introduce set_term_quiet_input helper function (Jiri Olsa) [1169436]
- [tools] perf/top: Join the display thread on exit (Jiri Olsa) [1169436]
- [tools] perf: Add cpu_startup_entry to the list of kernel idle symbols (Jiri Olsa) [1169436]
- [tools] perf/top: Don't look for kernel idle symbols in all DSOs (Jiri Olsa) [1169436]
- [tools] perf: Default to python version 2 (Jiri Olsa) [1169436]
- [tools] perf: Fix PERF_FLAG_FD_CLOEXEC flag probing event type open counters due to EBUSY error (Jiri Olsa) [1169436]
- [tools] perf: Fix column alignment when headers aren't shown on TUI (Jiri Olsa) [1169436]
- [tools] perf: Add name field into perf_hpp_fmt (Jiri Olsa) [1169436]
- [tools] perf/top: Add -w option for setting column width (Jiri Olsa) [1169436]
- [tools] perf/report: Honor column width setting (Jiri Olsa) [1169436]
- [tools] perf: Save column length in perf_hpp_fmt (Jiri Olsa) [1169436]
- [tools] perf: Make __hpp__fmt() receive an additional len argument (Jiri Olsa) [1169436]
- [tools] perf: Left-align output contents (Jiri Olsa) [1169436]
- [tools] perf: Fix make PYTHON override (Jiri Olsa) [1169436]
- [tools] perf/kmem: Do not ignore mmap events (Jiri Olsa) [1169436]
- [tools] perf: Show better error message in case we fail to open counters due to EBUSY error (Jiri Olsa) [1169436]
- [tools] perf: Allow out of order messages in forced flush (Jiri Olsa) [1169436]
- [tools] perf: Add debug prints for ordered events queue (Jiri Olsa) [1169436]
- [tools] perf: Add report.queue-size config file option (Jiri Olsa) [1169436]
- [tools] perf: Add perf_config_u64 function (Jiri Olsa) [1169436]
- [tools] perf: Add ordered_events__free function (Jiri Olsa) [1169436]
- [tools] perf: Add ordered_events__init function (Jiri Olsa) [1169436]
- [tools] perf: Use list_move in ordered_events_delete function (Jiri Olsa) [1169436]
- [tools] perf: Create ordered-events object (Jiri Olsa) [1169436]
- [tools] perf: Make perf_session__deliver_event global (Jiri Olsa) [1169436]
- [tools] perf: Flush ordered events in case of allocation failure (Jiri Olsa) [1169436]
- [tools] perf: Limit ordered events queue size (Jiri Olsa) [1169436]
- [tools] perf: Factor ordered_events__flush to be more generic (Jiri Olsa) [1169436]
- [tools] perf: Add ordered_events__(new (Jiri Olsa) [1169436]
- [tools] perf: Rename ordered_events members (Jiri Olsa) [1169436]
- [tools] perf: Rename ordered_samples struct to ordered_events (Jiri Olsa) [1169436]
- [tools] perf: Rename ordered_samples bool to ordered_events (Jiri Olsa) [1169436]
- [tools] perf/record: Honour --no-time command line option (Jiri Olsa) [1169436]
- [tools] perf/kvm/stat: Properly show submicrosecond times (Jiri Olsa) [1169436]
- [tools] perf/symbols: Make sure --symfs usage includes the path separator (Jiri Olsa) [1169436]
- [tools] perf/evlist: Don't run workload if not told to (Jiri Olsa) [1169436]
- [tools] perf: Fix arm64 build error (Jiri Olsa) [1169436]
- [tools] perf: saner perf_atoll() (Jiri Olsa) [1169436]
- [tools] Revert: perf: Fix jump label always changing during tracing (Jiri Olsa) [1169436]
- [tools] perf: Fix perf usage string leftover (Jiri Olsa) [1169436]
- [tools] perf/record: Store PERF_RECORD_FINISHED_ROUND only for nonempty rounds (Jiri Olsa) [1169436]
- [tools] perf/record: Always force PERF_RECORD_FINISHED_ROUND event (Jiri Olsa) [1169436]
- [tools] perf/inject: Add --kallsyms parameter (Jiri Olsa) [1169436]
- [tools] perf: Expose 'addr' functions so they can be reused (Jiri Olsa) [1169436]
- [tools] perf/session: Fix accounting of ordered samples queue (Jiri Olsa) [1169436]
- [tools] perf/powerpc: Include util/util.h and remove stringify macros (Jiri Olsa) [1169436]
- [tools] perf: Fix build on gcc 4.4.7 (Jiri Olsa) [1169436]
- [tools] perf: Add thread parameter to vdso__dso_findnew() (Jiri Olsa) [1169436]
- [tools] perf: Add dso__type() (Jiri Olsa) [1169436]
- [tools] perf: Separate the VDSO map name from the VDSO dso name (Jiri Olsa) [1169436]
- [tools] perf: Add vdso__new() (Jiri Olsa) [1169436]
- [tools] perf/machine: Fix the lifetime of the VDSO temporary file (Jiri Olsa) [1169436]
- [tools] perf: Group VDSO global variables into a structure (Jiri Olsa) [1169436]
- [tools] perf/session: Add ability to skip 4GiB or more (Jiri Olsa) [1169436]
- [tools] perf/session: Add ability to 'skip' a non-piped event stream (Jiri Olsa) [1169436]
- [tools] perf: Pass machine to vdso__dso_findnew() (Jiri Olsa) [1169436]
- [tools] perf: Add dso__data_size() (Jiri Olsa) [1169436]
- [tools] perf: Move rdtsc() function (Jiri Olsa) [1169436]
- [tools] perf/machine: Add ability to record the current tid for each cpu (Jiri Olsa) [1169436]
- [tools] perf: Add cpu to struct thread (Jiri Olsa) [1169436]
- [tools] perf: Add dsos__hit_all() (Jiri Olsa) [1169436]
- [tools] perf: Add dso__data_status_seen() (Jiri Olsa) [1169436]
- [tools] perf: Record whether a dso has data (Jiri Olsa) [1169436]
- [tools] perf/script: Do not print dangling '=>' for BTS (Jiri Olsa) [1169436]
- [tools] perf/script: Improve srcline display for BTS (Jiri Olsa) [1169436]
- [tools] perf: Fix jump label always changing during tracing (Jiri Olsa) [1169436]
- [tools] perf: Fix incorrect fd error comparison (Jiri Olsa) [1169436]
- [tools] perf/tests: Update attr test with PERF_FLAG_FD_CLOEXEC flag (Jiri Olsa) [1169436]
- [tools] perf: Enable close-on-exec flag on perf file descriptor (Jiri Olsa) [1169436]
- [tools] perf: Allow TSC conversion on any arch (Jiri Olsa) [1169436]
- [tools] perf: Remove needless getopt.h includes (Jiri Olsa) [1169436]
- [tools] perf: Add --debug optionto set debug variable (Jiri Olsa) [1169436]
- [tools] perf: Factor eprintf to allow different debug variables (Jiri Olsa) [1169436]
- [tools] perf: Move pr_* debug macros into debug object (Jiri Olsa) [1169436]
- [tools] perf: Remove verbose from functions prototypes (Jiri Olsa) [1169436]
- [tools] perf/machine: Fix leak of 'struct thread' on error path (Jiri Olsa) [1169436]
- [tools] perf/thread: Allow deletion of a thread with no map groups (Jiri Olsa) [1169436]
- [tools] perf/machine: Fix map groups of threads with unknown pids (Jiri Olsa) [1169436]
- [tools] perf/evsel: Add 'immediate' option (Jiri Olsa) [1169436]
- [tools] perf/evsel: Add 'no_aux_samples' option (Jiri Olsa) [1169436]
- [tools] perf: Add option macro OPT_CALLBACK_OPTARG (Jiri Olsa) [1169436]
- [tools] perf: Add feature test for __sync_val_compare_and_swap (Jiri Olsa) [1169436]
- [tools] perf/evlist: Pass mmap parameters in a struct (Jiri Olsa) [1169436]
- [tools] perf/session: Flag if the event stream is entirely in memory (Jiri Olsa) [1169436]
- [tools] perf/symbols: Add ability to iterate over a dso's symbols (Jiri Olsa) [1169436]
- [tools] perf/symbols: Do not attempt to read data from kallsyms (Jiri Olsa) [1169436]
- [tools] perf/symbols: Record whether a dso is 64-bit (Jiri Olsa) [1169436]
- [tools] perf/buildid-cache: Apply force option to copying kcore (Jiri Olsa) [1169436]
- [tools] perf/callchain: Fix appending a callchain from a previous sample (Jiri Olsa) [1169436]
- [tools] perf/inject: Fix build id injection (Jiri Olsa) [1169436]
- [tools] perf/symbols: Fix missing GNU IFUNC symbols (Jiri Olsa) [1169436]
- [tools] perf: Fix missing kernel map load (Jiri Olsa) [1169436]
- [tools] perf/record: Select comm_exec flag if supported (Jiri Olsa) [1169436]
- [tools] perf/script: Display PERF_RECORD_MISC_COMM_EXEC flag (Jiri Olsa) [1169436]
- [tools] perf/machine: Fix the value used for unknown pids (Jiri Olsa) [1169436]
- [tools] perf/script: Provide additional sample information on generic events (Jiri Olsa) [1169436]
- [tools] perf/script: Add callchain to generic and tracepoint events (Jiri Olsa) [1169436]
- [tools] perf/script: Add missing calls to Py_DECREF for return values (Jiri Olsa) [1169436]
- [tools] perf/kvm: Add skip_event() for --duration option (Jiri Olsa) [1169436]
- [tools] perf/kvm: Move arch specific code into arch/ (Jiri Olsa) [1169436]
- [tools] perf/kvm: Use defines of kvm events (Jiri Olsa) [1169436]
- [tools] perf/timechart: Add more options to IO mode (Jiri Olsa) [1169436]
- [tools] perf/timechart: Conditionally update start_time on fork (Jiri Olsa) [1169436]
- [tools] perf/timechart: Implement IO mode (Jiri Olsa) [1169436]
- [tools] perf/timechart: Fix rendering in Firefox (Jiri Olsa) [1169436]
- [tools] perf/trace: Fix build on 32-bit systems (Jiri Olsa) [1169436]
- [tools] perf/trace: Add pagefault statistics (Jiri Olsa) [1169436]
- [tools] perf: Suggest using -f to override perf.data file ownership message (Jiri Olsa) [1169436]
- [tools] perf: Convert open coded equivalents to asprintf() (Jiri Olsa) [1169436]
- [tools] perf: Allow to use cpuinfo on s390 (Jiri Olsa) [1169436]
- [tools] perf/kvm: Refactoring of cpu_isa_config() (Jiri Olsa) [1169436]
- [tools] perf/kvm: Simplify exit reasons tables definitions (Jiri Olsa) [1169436]
- [tools] perf/kvm: Introduce HAVE_KVM_STAT_SUPPORT flag (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Left justify column headers (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Add ui.show-headers config file option (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Display columns header text on 'H' press (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Add support for showing columns header (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Override ui_browser refresh_dimensions method (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Introduce gotorc method (Jiri Olsa) [1169436]
- [tools] perf/ui/browser: Allow overriding refresh_dimensions method (Jiri Olsa) [1169436]
- [tools] perf/ui/browser: Add ->rows to disambiguate from ->height (Jiri Olsa) [1169436]
- [tools] perf/x86/amd: Try to fix some mem allocation failure handling (Jiri Olsa) [1169436]
- [tools] perf/script: Handle the num array type in python properly (Jiri Olsa) [1169436]
- [tools] perf/script: Move the number processing into its own function (Jiri Olsa) [1169436]
- [tools] perf: Fix wrong condition for allocation failure (Jiri Olsa) [1169436]
- [tools] lib/traceevent: Fix a risk for doing free on uninitialized pointer (Jiri Olsa) [1169436]
- [tools] perf/trace: Add possibility to switch off syscall events (Jiri Olsa) [1169436]
- [tools] perf/trace: Add pagefaults record and replay support (Jiri Olsa) [1169436]
- [tools] perf/trace: Add support for pagefault tracing (Jiri Olsa) [1169436]
- [tools] perf/trace: Add perf_event parameter to tracepoint_handler (Jiri Olsa) [1169436]
- [tools] perf/scripts: Fallback to syscalls:* when raw_syscalls:* is not available (Jiri Olsa) [1169436]
- [tools] lib/traceevent: Clean up format of args in jbd2 plugin (Jiri Olsa) [1169436]
- [tools] lib/traceevent: Clean up format of args in cfg80211 plugin (Jiri Olsa) [1169436]
- [tools] lib/traceevent: Fix format in plugin_kvm (Jiri Olsa) [1169436]
- [tools] lib/traceevent: Fix and cleanup kvm_nested_vmexit tracepoints (Jiri Olsa) [1169436]
- [tools] lib/traceevent: Add back in kvm plugins nested_vmexit events (Jiri Olsa) [1169436]
- [tools] lib/traceevent: Factor out print_exit_reason in kvm plugin (Jiri Olsa) [1169436]
- [tools] lib/traceevent: Report unknown VMX exit reasons with code (Jiri Olsa) [1169436]
- [tools] perf/bench/sched-messaging: Drop barf() (Jiri Olsa) [1169436]
- [tools] perf/bench/mem: The -o and -n options are mutually exclusive (Jiri Olsa) [1169436]
- [tools] perf/bench/futex: Use global --repeat option (Jiri Olsa) [1169436]
- [tools] perf/bench: Add --repeat option (Jiri Olsa) [1169436]
- [tools] perf/bench/sched-messaging: Plug memleak (Jiri Olsa) [1169436]
- [tools] perf/ui/browser: Fix scrollbar refresh row index (Jiri Olsa) [1169436]
- [tools] perf/hists/browser: Remove ev_name argument from perf_evsel__hists_browse (Jiri Olsa) [1169436]
- [tools] perf/trace: Cache the is_exit syscall test (Jiri Olsa) [1169436]
- [tools] perf/trace: Remove needless reassignments (Jiri Olsa) [1169436]
- [tools] perf/evlist: Add suggestion of how to set perf_event_paranoid sysctl (Jiri Olsa) [1169436]
- [tools] perf/trace: Fix up fd -> pathname resolution (Jiri Olsa) [1169436]
- [tools] perf: Fix corruption of sibling list with hotplug (Jiri Olsa) [1169436]
- [tools] perf/x86/intel: Revert incomplete and undocumented Broadwell client support (Jiri Olsa) [1169436]
- [tools] perf: Fix typos in sample code in the perf_event.h header (Jiri Olsa) [1169436]
- [tools] perf: Fix and clean up initialization of pmu::event_idx (Jiri Olsa) [1169436]
- [tools] perf: Fix bogus kernel printk (Jiri Olsa) [1169436]
- [tools] perf: Fix unclone_ctx() vs. locking (Jiri Olsa) [1169436]
- [tools] perf/x86: Tone down kernel messages when the PMU check fails in a virtual environment (Jiri Olsa) [1169436]
- [tools] perf/x86/intel: Use Broadwell cache event list for Haswell (Jiri Olsa) [1169436]
- [tools] perf/x86: Add INST_RETIRED.ALL workarounds (Jiri Olsa) [1169436]
- [tools] perf/x86/intel: Add Broadwell core support (Jiri Olsa) [1169436]
- [tools] perf/x86/intel: Document all Haswell models (Jiri Olsa) [1169436]
- [tools] perf/x86/intel: Remove incorrect model number from Haswell perf (Jiri Olsa) [1169436]
- [tools] Revert: perf: Do not allow optimized switch for non-cloned events (Jiri Olsa) [1169436]
- [tools] perf: Fix child event initial state setup (Jiri Olsa) [1169436]
- [tools] perf: Do not POLLHUP event if it has children (Jiri Olsa) [1169436]
- [tools] perf: Do not check PERF_EVENT_STATE_EXIT on syscall read path (Jiri Olsa) [1169436]
- [tools] perf/x86: Fix section mismatch in split uncore driver (Jiri Olsa) [1169436]
- [tools] perf/x86/intel: Mark initialization code as such (Jiri Olsa) [1169436]
- [tools] perf/core: Replace rcu_assign_pointer() with RCU_INIT_POINTER() (Jiri Olsa) [1169436]
- [tools] perf/callchain: Replace rcu_assign_pointer() with RCU_INIT_POINTER() (Jiri Olsa) [1169436]
- [tools] perf: Add PERF_EVENT_STATE_EXIT state for events with exited task (Jiri Olsa) [1169436]
- [tools] perf: Fix perf_poll to return proper POLLHUP value (Jiri Olsa) [1169436]
- [tools] perf/x86: Clean up __intel_pmu_pebs_event() code (Jiri Olsa) [1169436]
- [tools] perf/x86: Fix data source encoding issues for load latency/precise store (Jiri Olsa) [1169436]
- [tools] perf/x86: Don't mark DataLA addresses as store (Jiri Olsa) [1169436]
- [tools] perf/x86: Revamp PEBS event selection (Jiri Olsa) [1169436]
- [tools] perf/x86/intel: Mark MEM_LOAD_UOPS_MISS_RETIRED as precise on SNB (Jiri Olsa) [1169436]
- [tools] perf/x86: Fix pp without LBR (Jiri Olsa) [1169436]
- [tools] perf: Do poll_wait() before checking condition in perf_poll() (Jiri Olsa) [1169436]
- [tools] perf: Add queued work to remove orphaned child events (Jiri Olsa) [1169436]
- [tools] perf: Set owner pointer for kernel events (Jiri Olsa) [1169436]
- [tools] perf/x86/intel: Update Intel models (Jiri Olsa) [1169436]
- [tools] perf/cgroup: Remove perf_put_cgroup() (Jiri Olsa) [1169436]
- [tools] perf: fix perf bug in fork() (Jiri Olsa) [1169436]
- [tools] perf: Fix a race condition in perf_remove_from_context() (Jiri Olsa) [1169436]
- [tools] perf: Handle compat ioctl (Jiri Olsa) [1169436]
- [tools] perf/x86: Micro-optimize nhmex_rbox_get_constraint() (Jiri Olsa) [1169436]
- [tools] perf: Make perf_event_init_context() function static (Jiri Olsa) [1169436]

* Mon Mar 23 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-233.el7]
- [x86] kvm: Prevent guest from writing non-canonical shared MSR addresses (Petr  Matousek) [1144885] {CVE-2014-3610}
- [x86] kvm: Check non-canonical addresses upon WRMSR (Petr  Matousek) [1144885] {CVE-2014-3610}
- [infiniband] core: Prevent integer overflow in ib_umem_get address arithmetic (Doug Ledford) [1179347] {CVE-2014-8159}
- [fs] bio: fix argument of __bio_add_page() for max_sectors > 0xffff (Fam Zheng) [1184759]
- [x86] pci: Add NEC variants to Stratus ftServer PCIe DMI check (Myron Stowe) [1187761]
- [s390] zcrypt: enable s390 hwrng to seed kernel entropy (Hendrik Brueckner) [1196398]
- [s390] zcrypt: improve device probing for zcrypt adapter cards (Hendrik Brueckner) [1196398]
- [acpi] fan: Use bus id as the name for non PNP0C0B (Fan) devices (Prarit Bhargava) [1174059]
- [acpi] fan: support INT3404 thermal device (Prarit Bhargava) [1174059]
- [acpi] fan: add ACPI 4.0 style fan support (Prarit Bhargava) [1174059]
- [acpi] fan: convert to platform driver (Prarit Bhargava) [1174059]
- [acpi] fan: use acpi_device_xxx_power instead of acpi_bus equivelant (Prarit Bhargava) [1174059]
- [acpi] fan: remove unused macro (Prarit Bhargava) [1174059]
- [acpi] fan: remove no need check for device pointer (Prarit Bhargava) [1174059]
- [acpi] fan: printk replacement (Prarit Bhargava) [1174059]
- [acpi] fan: do nothing in suspend and poweroff callback (Prarit Bhargava) [1174059]
- [acpi] fan: fix fan driver compile error when CONFIG_PM_SLEEP is undefined (Prarit Bhargava) [1174059]
- [acpi] thermal: step_wise: return instance->target by default (Prarit Bhargava) [1174059]
- [acpi] thermal: step_wise: cdev only needs update on a new target state (Prarit Bhargava) [1174059]
- [netdrv] vmxnet3: Reinitialize vmxnet3 backend on wakeup from hibernate (Neil Horman) [1181807]
- [netdrv] vmxnet3: Make Rx ring 2 size configurable (Neil Horman) [1181807]
- [netdrv] vmxnet3: Move PCI_VENDOR_ID_VMWARE to pci_ids.h (Neil Horman) [1181807]
- [netdrv] vmxnet3: Check for map error in vmxnet3_set_mc (Neil Horman) [1181807]
- [netdrv] vmxnet3: Remove DEFINE_PCI_DEVICE_TABLE macro use (Neil Horman) [1181807]
- [netdrv] vmxnet3: fix decimal printf format specifiers prefixed with 0x (Neil Horman) [1181807]
- [netdrv] vmxnet3: adjust ring sizes when interface is down (Neil Horman) [1181807]
- [netdrv] vmxnet3: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Neil Horman) [1181807]
- [netdrv] vmxnet3: get rid of SET_ETHTOOL_OPS (Neil Horman) [1181807]
- [netdrv] vmxnet3: Call dev_kfree_skb_any instead of dev_kfree_skb (Neil Horman) [1181807]
- [netdrv] vmxnet3: fix building without CONFIG_PCI_MSI (Neil Horman) [1181807]
- [netdrv] vmxnet3: Use pci_enable_msix_range() instead of pci_enable_msix() (Neil Horman) [1181807]
- [netdrv] vmxnet3: Fix MSI-X/MSI enablement code (Neil Horman) [1181807]
- [netdrv] vmxnet3: delete non-required instances of include <linux/init.h> (Neil Horman) [1181807]
- [netdrv] vmxnet3: use initialized skb pointer to set hash (Neil Horman) [1181807]
- [netdrv] vmxnet3: calls skb_set_hash (Neil Horman) [1181807]
- [netdrv] vmxnet3: remove unnecessary pci_set_drvdata() (Neil Horman) [1181807]
- [netdrv] vmxnet3: Remove extern from function prototypes (Neil Horman) [1181807]
- [netdrv] vmxnet3: Add support for virtual IOMMU (Neil Horman) [1181807]
- [net] netpoll: Remove dead packet receive code (CONFIG_NETPOLL_TRAP) (Neil Horman) [1181906]
- [net] netpoll: Move all receive processing under CONFIG_NETPOLL_TRAP (Neil Horman) [1181906]
- [net] netpoll: Consolidate neigh_tx processing in service_neigh_queue (Neil Horman) [1181906]
- [net] netpoll: Move netpoll_trap under CONFIG_NETPOLL_TRAP (Neil Horman) [1181906]
- [net] netpoll: Don't drop all received packets (Neil Horman) [1181906]
- [net] netpoll: Add netpoll_rx_processing (Neil Horman) [1181906]
- [net] netpoll: Warn if more packets are processed than are budgeted (Neil Horman) [1181906]
- [net] netpoll: Visit all napi handlers in poll_napi (Neil Horman) [1181906]
- [net] netpoll: Pass budget into poll_napi (Neil Horman) [1181906]
- [net] netpoll: move setting of NETPOLL_RX_DROP into netpoll_poll_dev (Neil Horman) [1181906]
- [net] netpoll: fix netconsole IPv6 setup (Neil Horman) [1181906]
- [net] netpoll: Use ether_addr_copy (Neil Horman) [1181906]
- [net] netpoll: Fix missing TXQ unlock and and OOPS (Neil Horman) [1181906]
- [net] netpoll: fix rx_hook() interface by passing the skb (Neil Horman) [1181906]
- [iommu] vt-d: Work around broken RMRR firmware entries (Myron Stowe) [1195802]
- [iommu] vt-d: Store bus information in RMRR PCI device path (Myron Stowe) [1195802]
- [pci] Handle read-only BARs on AMD CS553x devices (Myron Stowe) [1198314]
- [x86] kvm: add tracepoint to wait_lapic_expire (Marcelo Tosatti) [1175445]
- [x86] kvm: add option to advance tscdeadline hrtimer expiration (Marcelo Tosatti) [1175445]
- [powerpc] powernv: Add winkle support for offline cpus (Gustavo Duarte) [1123121]
- [powerpc] powernv: Redesign idle states management (Gustavo Duarte) [1123121]
- [powerpc] powernv: Enable Offline CPUs to enter deep idle states (Gustavo Duarte) [1123121]
- [powerpc] powernv: Return to cpu offline loop when finished in KVM guest (Gustavo Duarte) [1123121]
- [powerpc] powernv: Switch off MMU before entering nap/sleep/rvwinkle mode (Gustavo Duarte) [1123121]
- [powerpc] powernv: Don't call generic code on offline cpus (Gustavo Duarte) [1123121]
- [cpuidle] powernv: Back-end cpuidle driver for powernv platform (Gustavo Duarte) [1123121]
- [cpuidle] powernv: Only clear LPCR decrementer wakeup bit on fast sleep entry (Gustavo Duarte) [1123121]
- [kernel] tick: Fixup more fallout from hrtimer broadcast mode (Gustavo Duarte) [1123121]
- [kernel] time: Fixup fallout from recent clockevent/tick changes (Gustavo Duarte) [1123121]
- [kernel] tick: Introduce hrtimer based broadcast (Gustavo Duarte) [1123121]
- [cpuidle] Handle clockevents_notify(BROADCAST_ENTER) failure (Gustavo Duarte) [1123121]
- [kernel] time: Change the return type of clockevents_notify() to integer (Gustavo Duarte) [1123121]
- [cpuidle] powernv: Fix parsing of idle state flags from device-tree (Gustavo Duarte) [1123121]
- [cpuidle] powernv: Parse device tree to setup idle states (Gustavo Duarte) [1123121]
- [cpuidle] powernv: Add "Fast-Sleep" CPU idle state (Gustavo Duarte) [1123121]
- [input] mouse: synaptics - remove X250 from the topbuttonpad list (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - remove X1 Carbon 3rd gen from the topbuttonpad list (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - re-route tracksticks buttons on the Lenovo 2015 series (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - remove TOPBUTTONPAD property for Lenovos 2015 (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - retrieve the extended capabilities in query $10 (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - do not retrieve the board id on old firmwares (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - handle spurious release of trackstick buttons (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - fix middle button on Lenovo 2015 products (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - skip quirks when post-2013 dimensions (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - support min/max board id in min_max_pnpid_table (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - remove obsolete min/max quirk for X240 (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - query min dimensions for fw v8.1 (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - log queried and quirked dimension values (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - split synaptics_resolution(), query first (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - adjust min/max for Lenovo ThinkPad X1 Carbon 2nd (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - adjust min/max on Thinkpad E540 (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - add min/max quirk for Lenovo T440s (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: psmouse - add psmouse_matches_pnp_id helper function (Benjamin Tissoires) [1186106 1186112]
- [input] mouse: synaptics - add min/max quirk for pnp-id LEN2002 (Edge E531) (Benjamin Tissoires) [1186106 1186112]

* Fri Mar 13 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-232.el7]
- [fs] fsnotify: fix handling of renames in audit (Paul Moore) [1191562]
- [crypto] rng: RNGs must return 0 in success case (Herbert Xu) [1198978]
- [cpufreq] intel_pstate: Add support for SkyLake (Steve Best) [1189908]
- [s390] zcrypt: fixed domain scanning problem again (Hendrik Brueckner) [1193604]
- [s390] zcrypt: Number of supported ap domains is not retrievable (Hendrik Brueckner) [1193604]
- [s390] kprobes: add exrl to list of prohibited opcodes (Hendrik Brueckner) [1193608]
- [s390] kprobes: add support for compare and branch instructions (Hendrik Brueckner) [1193608]
- [s390] bpf: jit: initialize A register if 1st insn is BPF_S_LDX_B_MSH (Hendrik Brueckner) [1193604]
- [s390] bpf: jit: fix 32 bit divisions, use unsigned divide instructions (Hendrik Brueckner) [1193604]
- [s390] bpf: Zero extend parameters before calling C function (Hendrik Brueckner) [1193604]
- [s390] bpf: Fix sk_load_byte_msh() (Hendrik Brueckner) [1193604]
- [s390] bpf: Fix offset parameter for skb_copy_bits() (Hendrik Brueckner) [1193604]
- [s390] bpf: Fix skb_copy_bits() parameter passing (Hendrik Brueckner) [1193604]
- [s390] bpf: Fix JMP_JGE_K (A >= K) and JMP_JGT_K (A > K) (Hendrik Brueckner) [1193604]
- [s390] bpf: Fix JMP_JGE_X (A > X) and JMP_JGT_X (A >= X) (Hendrik Brueckner) [1193604]
- [s390] bpf: Fix ALU_NEG (A = -A) (Hendrik Brueckner) [1193604]
- [s390] dasd: remove unused code (Hendrik Brueckner) [1186326]
- [s390] dasd: fix infinite loop during format (Hendrik Brueckner) [1186326]
- [kernel] module: set nx before marking module MODULE_STATE_COMING (Hendrik Brueckner) [1196977]
- [s390] vdso: fix clock_gettime for CLOCK_THREAD_CPUTIME_ID, -2 and -3 (Hendrik Brueckner) [1195671]
- [s390] dasd: retry partition detection (Hendrik Brueckner) [1193605]
- [s390] dasd: fix list corruption for sleep_on requests (Hendrik Brueckner) [1186319]
- [net] openvswitch: Fix net exit (Jiri Benc) [1200859]
- [net] team: fix possible null pointer dereference in team_handle_frame (Jiri Pirko) [1188496]

* Tue Mar 10 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-231.el7]
- [crypto] aesni: fix "by8" variant for 128 bit keys (Herbert Xu) [1174971]
- [crypto] aesni: remove unused defines in "by8" variant (Herbert Xu) [1174971]
- [crypto] aesni: fix counter overflow handling in "by8" variant (Herbert Xu) [1174971]
- [crypto] aes: AES CTR x86_64 "by8" AVX optimization (Herbert Xu) [1174971]
- [fs] gfs2: Move gfs2_file_splice_write outside of #ifdef (Robert S Peterson) [1193910]
- [fs] gfs2: Allocate reservation during splice_write (Robert S Peterson) [1193910]
- [fs] Convert MessageID in smb2_hdr to LE (Sachin Prabhu) [1161441]
- [fs] nfsd: update mtime on truncate ("J. Bruce Fields") [1162558]
- [virt] kvm: ensure hard lockup detection is disabled by default (Andrew Jones) [1111262]
- [watchdog] control hard lockup detection default (Andrew Jones) [1111262]
- [watchdog] Fix print-once on enable (Andrew Jones) [1111262]
- [tools] cpupower: Fix no idle state information return value (Prarit Bhargava) [1168046]
- [misc] genwqe: Fix problem when reading HSI and Retc (Steve Best) [1188653]
- [char] tpm: Added Little Endian support to vtpm module (Steve Best) [1189017]
- [idle] intel_idle: support additional Broadwell model (Steve Best) [1166315]
- [powerpc] iommu: ddw: Fix endianness (Steve Best) [1189040]
- [powerpc] Fix sys_call_table declaration to enable syscall tracing (Steve Best) [1172684]
- [powerpc] pseries: Fix endian problems with LE migration (Steve Best) [1183198]
- [powerpc] powernv: Ignore smt-enabled on Power8 and later (Steve Best) [1180254]
- [powerpc] xmon: Fix another endiannes issue in RTAS call from xmon (Steve Best) [1186803]
- [pci] Add informational printk for invalid BARs (Myron Stowe) [1130170]
- [pci] Shrink decoding-disabled window while sizing BARs (Myron Stowe) [1130170]
- [pci] Restore detection of read-only BARs (Myron Stowe) [1130170]
- [kernel] resources: Clarify sanity check message (Myron Stowe) [1130170]
- [pci] Don't add disabled subtractive decode bus resources (Myron Stowe) [1130170]
- [pci] Don't print anything while decoding is disabled (Myron Stowe) [1130170]
- [pci] Don't set BAR to zero if dma_addr_t is too small (Myron Stowe) [1130170]
- [pci] Don't convert BAR address to resource if dma_addr_t is too small (Myron Stowe) [1130170]
- [pci] Reject BAR above 4GB if dma_addr_t is too small (Myron Stowe) [1130170]
- [pci] Fail safely if we can't handle BARs larger than 4GB (Myron Stowe) [1130170]

* Fri Feb 27 2015 Rafael Aquini <aquini@redhat.com> [3.10.0-230.el7]
- [net] sctp: fix slab corruption from use after free on INIT collisions (Daniel Borkmann) [1183959] {CVE-2015-1421}
- [net] ipv6: Fixed support for blackhole and prohibit routes (Hannes Frederic Sowa) [1129731]
- [kernel] audit: replace getname()/putname() hacks with reference counters (Paul Moore) [1155208]
- [kernel] audit: fix filename matching in __audit_inode() and __audit_inode_child() (Paul Moore) [1155208]
- [kernel] audit: enable filename recording via getname_kernel() (Paul Moore) [1155208]
- [fs] namei: simpler calling conventions for filename_mountpoint() (Paul Moore) [1155208]
- [fs] namei: create proper filename objects using getname_kernel() (Paul Moore) [1155208]
- [fs] namei: rework getname_kernel to handle up to PATH_MAX sized filenames (Paul Moore) [1155208]
- [fs] namei: cut down the number of do_path_lookup() callers (Paul Moore) [1155208]
- [fs] execve: use 'struct filename *' for executable name passing (Paul Moore) [1155208]
- [x86] ioapic: kcrash: Prevent crash_kexec() from deadlocking on ioapic_lock (Baoquan He) [1182424]
- [md] dm-thin: don't allow messages to be sent to a pool target in READ_ONLY or FAIL mode (Mike Snitzer) [1184592]
- [kernel] workqueue: fix subtle pool management issue which can stall whole worker_pool (Eric Sandeen) [1165535]
- [platform] thinkpad_acpi: support new BIOS version string pattern (Benjamin Tissoires) [1194830]
- [virt] storvsc: ring buffer failures may result in I/O freeze (Vitaly Kuznetsov) [1171409]
- [kernel] audit: restore AUDIT_LOGINUID unset ABI (Richard Guy Briggs) [1120491]
- [crypto] testmgr: mark rfc4106(gcm(aes)) as fips_allowed (Jarod Wilson) [1185400]

* Thu Jan 29 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-229.el7]
- [net] rtnetlink: allow to register ops without ops->setup set (Jiri Benc) [1186492]

* Thu Jan 29 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-228.el7]
- [fs] NFSv4.1: Fix an Oops in nfs41_walk_client_list (Steve Dickson) [1185784]
- [misc] redhat: don't suppress Revert patches from changelog (Jarod Wilson) [1187353]
- [infiniband] Revert: ipoib: Consolidate rtnl_lock tasks in workqueue (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: Make the carrier_on_task race aware (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: fix MCAST_FLAG_BUSY usage (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: fix mcast_dev_flush/mcast_restart_task race (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: change init sequence ordering (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: Use dedicated workqueues per interface (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: Make ipoib_mcast_stop_thread flush the workqueue (Doug Ledford) [1179740]
- [infiniband] Revert: ipoib: No longer use flush as a parameter (Doug Ledford) [1179740]
- [fs] fix deadlock in cifs_ioctl_clone() (Sachin Prabhu) [1183980]
- [md] dm-cache: fix missing ERR_PTR returns and handling (Mike Snitzer) [1182665]
- [fs] cifs: fix regression in cifs_create_mf_symlink() (Sachin Prabhu) [1186324]
- [net] ipv4: try to cache dst_entries which would cause a redirect (Hannes Frederic Sowa) [1181819]
- [fs] coredump: add new P variable in core_pattern (Jiri Olsa) [1186360]
- [drm] fix fb-helper vs MST dangling connector ptrs (Rob Clark) [1184968]
- [net] bridge: Program port vlan filters only if filtering is enabled in bridge (Vlad Yasevich) [1183958]
- [fs] cifs: Complete oplock break jobs before closing file handle (Sachin Prabhu) [1177215]
- [fs] LOCKD: Fix a race when initialising nlmsvc_timeout (Benjamin Coddington) [1144982]
- [scsi] hpsa: add in P840ar controller model name (Joseph Szczypek) [1185467]
- [scsi] hpsa: add in gen9 controller model names (Joseph Szczypek) [1185467]

* Tue Jan 27 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-227.el7]
- [fs] ext4: fix overwrite race condition (Jacob Tanenbaum) [1152607] {CVE-2014-8086}
- [media] ttusb-dec: buffer overflow in ioctl (Alexander Gordeev) [1167116] {CVE-2014-8884}
- [drm] i915: demote opregion excessive timeout WARN_ONCE to DRM_INFO_ONCE (Rob Clark) [1145627]
- [md] Revert: raid56: Don't perform reads to support writes until stripe is ready (Jes Sorensen) [1153796]
- [md] Revert: raid5: avoid livelock caused by non-aligned writes (Jes Sorensen) [1153796]
- [drm] i915: further quiet i915 (Rob Clark) [1163074]
- [scsi] megaraid_sas: endianness related bug fixes and code optimization (Tomas Henzl) [1179748]
- [s390] crypto: kernel oops at insmod of the z90crypt device driver (Hendrik Brueckner) [1172136]
- [drm] mgag200: Add command line option to specify preferred depth (Dave Airlie) [1044555]
- [drm] mgag200: Consolidate depth/bpp handling (Dave Airlie) [1044555]
- [fs] Revert: ext4: revert Disable punch hole on non-extent mapped files (Lukas Czerner) [1176840]

* Sun Jan 25 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-226.el7]
- [md] dm-cache: fix problematic dual use of a single migration count variable (Mike Snitzer) [1182665]
- [md] dm-cache: share cache-metadata object across inactive and active DM tables (Mike Snitzer) [1182665]
- [net] tun/macvtap: use consume_skb() instead of kfree_skb() when needed (Jiri Pirko) [1182805]
- [virt] Revert: hyperv: Add handler for RNDIS_STATUS_NETWORK_CHANGE event (Jason Wang) [1164163]
- [virt] kvm/vmx: invalid host cr4 handling across vm entries (Jacob Tanenbaum) [1153329] {CVE-2014-3690}
- [virt] virtio-scsi: Fix the race condition in virtscsi_handle_event (Fam Zheng) [1152140]
- [virt] kvm: workaround SuSE's 2.6.16 pvclock vs masterclock issue (Marcelo Tosatti) [1177718]
- [fs] bdi: avoid oops on device removal (Fam Zheng) [1087179]
- [mm] backing_dev: fix hung task on sync (Fam Zheng) [1087179]
- [mm] Revert: vmstat: create separate function to fold per cpu diffs into local counters (Larry Woodman) [1179654]
- [mm] Revert: vmstat: create fold_diff (Larry Woodman) [1179654]
- [mm] Revert: vmstat: use this_cpu() to avoid irqon/off sequence in refresh_cpu_vm_stats (Larry Woodman) [1179654]
- [mm] Revert: vmstat: on-demand vmstat workers V8 (Larry Woodman) [1179654]

* Thu Jan 22 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-225.el7]
- [net] team: avoid possible underflow of count_pending value for notify_peers and mcast_rejoin (Jiri Pirko) [1176697]
- [fs] seq_file: don't include mm.h in genksyms calculation (Ian Kent) [1183280]
- [scsi] Avoid crashing if device uses DIX but adapter does not support it (Ewan Milne) [1093012]

* Mon Jan 19 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-224.el7]
- [fs] xfs: catch invalid negative blknos in _xfs_buf_find() (Eric Sandeen) [1164128]
- [fs] proc: make proc_fd_permission() thread-friendly (Carlos Maiolino) [1171242]
- [fs] rpc: fix xdr_truncate_encode to handle buffer ending on page boundary ("J. Bruce Fields") [1176641]
- [fs] nfs: nfs4_fl_prepare_ds, fix bugs when the connect attempt fails (Steve Dickson) [1113248]
- [fs] gfs2: fix bad inode i_goal values during block allocation (Abhijith Das) [1144209]
- [fs] nfsd: allow turning off nfsv3 readdir_plus (Steve Dickson) [1178949]
- [fs] nfsd4: fix xdr4 count of server in fs_location4 (Benjamin Coddington) [1164055]
- [fs] nfsd4: fix xdr4 inclusion of escaped char (Benjamin Coddington) [1164055]
- [fs] xfs: replace global xfslogd wq with per-mount wq (Brian Foster) [1155929]
- [fs] xfs: mark all internal workqueues as freezable (Brian Foster) [1155929]
- [fs] overlayfs: Add call to mark_tech_preview (BZ 1180613) (David Howells) [1180613]
- [fs] aio: fix uncorrent dirty pages accouting when truncating AIO ring buffer (Jeff Moyer) [1159346]
- [infiniband] ocrdma: fix hardcoded max cqe and max send wr (Doug Ledford) [1158148]
- [crypto] aesni-intel: Add support for 192 & 256 bit keys to AESNI RFC4106 (Jarod Wilson) [1176266]
- [block] blk-mq: Fix a use-after-free (Fam Zheng) [1152159]
- [crypto] drbg: panic on continuous self test error (Jarod Wilson) [1179496]
- [ethernet] mlx4: Cache line CQE/EQE stride fixes (Doug Ledford) [1088499 1173483]
- [ethernet] mlx4: Add mlx4_en_get_cqe helper (Doug Ledford) [1088499 1173483]
- [ethernet] mlx4: Cache line EQE size support (Doug Ledford) [1088499 1173483]
- [infiniband] ocrdma: Fix ocrdma_query_qp() to report q_key value for UD QPs (Doug Ledford) [1167256]
- [infiniband] ocrdma: Always resolve destination mac from GRH for UD QPs (Doug Ledford) [1167256]
- [net] gre: fix the inner mac header in nbma tunnel xmit path (Alexander Duyck) [1168608]

* Tue Jan 13 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-223.el7]
- [md] dm-thin: fix crash by initializing thin device's refcount and completion earlier (Mike Snitzer) [1175282]
- [scsi] storvsc: Fix a bug in storvsc limits (Vitaly Kuznetsov) [1174162]
- [iser-target] Ignore non TEXT + LOGOUT opcodes for discovery (Andy Grover) [1058736]
- [iser-target] Add support for ISCSI_OP_TEXT opcode + payload handling (Andy Grover) [1058736]
- [iser-target] Rename sense_buf_dma/len to pdu_dma/len (Andy Grover) [1058736]
- [iscsi-target] Add IFC_SENDTARGETS_SINGLE support (Andy Grover) [1058736]
- [iscsi-target] Move sendtargets parsing into iscsit_process_text_cmd (Andy Grover) [1058736]
- [iscsi-target] Allow ->MaxXmitDataSegmentLength assignment for iser discovery (Andy Grover) [1058736]
- [iscsi-target] Refactor ISCSI_OP_TEXT_RSP TX handling (Andy Grover) [1058736]
- [iscsi-target] Refactor ISCSI_OP_TEXT RX handling (Andy Grover) [1058736]
- [iscsi] isert-target: Refactor ISCSI_OP_NOOP RX handling (Andy Grover) [1058736]
- [net] description of dma_cookie cause make xmldocs warning (Jiri Benc) [1173444]
- [net] tcp: make tcp_cleanup_rbuf private (Jiri Benc) [1173444]
- [net] net_dma: revert 'copied_early' (Jiri Benc) [1173444]
- [net] net_dma: mark broken (Jiri Benc) [1173444]
- [net] unix: allow set_peek_off to fail (Jiri Benc) [1123777]
- [net] ppp: ppp-ioctl.h: pull in ppp_defs.h (Jiri Benc) [1159802]
- [net] bridge: Add filtering support for default_pvid (Vlad Yasevich) [1164653]
- [net] bridge: Simplify pvid checks (Vlad Yasevich) [1164653]
- [net] bridge: Add a default_pvid sysfs attribute (Vlad Yasevich) [1164653]
- [net] bridge: Prepare for 802.1ad vlan filtering support (Vlad Yasevich) [1164653]
- [net] bridge: Fix the way to check if a local fdb entry can be deleted (Vlad Yasevich) [1164653]
- [net] bridge: Fix the way to insert new local fdb entries in br_fdb_changeaddr (Vlad Yasevich) [1164653]
- [net] Remove extern from function prototypes (Vlad Yasevich) [1164653]
- [ethernet] mlx5: Add more supported devices (Amir Vadai) [1169277]
- [infiniband] mlx4: Fix wrong usage of IPv4 protocol for multicast attach/detach (Amir Vadai) [1151331]
- [ethernet] mlx4: mlx4_en_set_settings() always fails when autoneg is set (Amir Vadai) [1170129]

* Thu Jan 08 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-222.el7]
- [scsi] qla2xxx: Update version number to 8.07.00.08.07.1-k2 (Chad Dupuis) [1085239]
- [scsi] qla2xxx: Move mailbox failure messages to a default debug level (Chad Dupuis) [1085239]
- [security] commoncap: don't alloc the credential unless needed in cap_task_prctl (Paul Moore) [1056347]
- [iommu] vt-d: Fix dmar_domain leak in iommu_attach_device (Myron Stowe) [1109829]
- [iommu] vt-d: Only remove domain when device is removed (Myron Stowe) [1109829]
- [base] core: Add BUS_NOTIFY_REMOVED_DEVICE event (Myron Stowe) [1109829]
- [powerpc] kdump: Ignore failure in enabling big endian exception during crash (Steve Best) [1170362]
- [infiniband] srpt: convert printk's to pr_* functions (Doug Ledford) [1174910]
- [infiniband] srpt: Handle GID change events (Doug Ledford) [1174910]
- [input] alps: fix v4 button press recognition (Benjamin Tissoires) [1107819]
- [input] alps: v7 - document the v7 touchpad packet protocol (Benjamin Tissoires) [1107819]
- [input] alps: v7 - fix finger counting for > 2 fingers on clickpads (Benjamin Tissoires) [1107819]
- [input] alps: v7 - sometimes a single touch is reported in mt[1] (Benjamin Tissoires) [1107819]
- [input] alps: v7 - ignore new packets (Benjamin Tissoires) [1107819]
- [powerpc] perf/hv-24x7: Use kmem_cache_free() instead of kfree (Gustavo Duarte) [1171795]
- [powerpc] perf/hv-24x7: Use per-cpu page buffer (Gustavo Duarte) [1171795]
- [powerpc] perf/hv-24x7: use kmem_cache instead of aligned stack allocations (Gustavo Duarte) [1171795]
- [powerpc] perf/hv-24x7: Use kmem_cache_free (Gustavo Duarte) [1171795]
- [powerpc] Fill in si_addr_lsb siginfo field (Gustavo Duarte) [1173267]
- [powerpc] Add VM_FAULT_HWPOISON handling to powerpc page fault handler (Gustavo Duarte) [1173267]
- [fs] dlm: fix missing endian conversion of rcom_status flags (Andrew Price) [1175900]
- [scsi] add Intel Multi-Flex to scsi scan blacklist (Hannes Frederic Sowa) [1175862]
- [scsi] do not issue SCSI RSOC command to Promise Vtrak E610f (Hannes Frederic Sowa) [1175862]
- [scsi] scsi_lib: rate-limit the error message from failing commands (Tomas Henzl) [1175785]
- [scsi] iscsi_ibft: Fix finding Broadcom specific ibft sign (Chris Leech) [1095169]

* Tue Jan 06 2015 Jarod Wilson <jarod@redhat.com> [3.10.0-221.el7]
- [ethernet] enic: fix rx skb checksum (Stefan Assmann) [1154182]
- [x86] uv: make kdump default action for 'power nmi' (George Beshers) [1175560]
- [virt] powerpc/kvm: book3s_hv - Fix KSM memory corruption (David Gibson) [1170394]
- [pci] Revert: Remove from bus_list and release resources in pci_release_dev() (Prarit Bhargava) [1172946]
- [powercap] rapl: add support for CPU model 0x3f (Rui Wang) [1177579]
- [kernel] audit: don't attempt to lookup PIDs when changing PID filtering audit rules (Paul Moore) [1172624]
- [ethernet] ixgbe: avoid possible read_reg panic caused by late method binding (John Greene) [1145772]
- [ethernet] ixgbe: bump version number (John Greene) [1145772]
- [ethernet] ixgbe: Add X550 support function pointers (John Greene) [1145772]
- [ethernet] ixgbe: Add new support for X550 MAC's (John Greene) [1145772]
- [ethernet] ixgbe: Add x550 SW/FW semaphore support (John Greene) [1145772]
- [ethernet] ixgbe: add methods for combined read and write operations (John Greene) [1145772]
- [ethernet] ixgbe: cleanup checksum to allow error results (John Greene) [1145772]
- [ethernet] ixgbe: Add timeout parameter to ixgbe_host_interface_command (John Greene) [1145772]
- [ethernet] ixgbe: Fix spurious release of semaphore in EEPROM access (John Greene) [1145772]
- [drm] i915: remove the IRQs enabled WARN from intel_disable_gt_powersave (Rob Clark) [1173317]
- [drm] i915: tame the chattermouth (Rob Clark) [1173317]
- [drm] ttm: Avoid memory allocation from shrinker functions (Rob Clark) [1173317]
- [drm] ttm: Fix possible stack overflow by recursive shrinker calls (Rob Clark) [1173317]
- [drm] ttm: Use mutex_trylock() to avoid deadlock inside shrinker functions (Rob Clark) [1173317]
- [drm] video/fb: Propagate error code from failing to unregister conflicting fb (Rob Clark) [1173317]
- [drm] i915: save/restore GMBUS freq across suspend/resume on gen4 (Rob Clark) [1173317]
- [drm] i915: resume MST after reading back hw state (Rob Clark) [1173317]
- [drm] dp-mst: Remove branches before dropping the reference (Rob Clark) [1173317]
- [drm] fb_helper: move deferred fb checking into restore mode (Rob Clark) [1173317]
- [drm] dp: retry AUX transactions 32 times (v1.1) (Rob Clark) [1173317]
- [drm] i915: Ignore long hpds on eDP ports (Rob Clark) [1173317]
- [drm] i915/dp: only use training pattern 3 on platforms that support it (Rob Clark) [1173317]
- [drm] radeon: sync all BOs involved in a CS (Rob Clark) [1173317]
- [drm] radeon: kernel panic in drm_calc_vbltimestamp_from_scanoutpos with 3.18.0-rc6 (Rob Clark) [1173317]
- [drm] i915: Unlock panel even when LVDS is disabled (Rob Clark) [1173317]
- [drm] i915: More cautious with pch fifo underruns (Rob Clark) [1173317]
- [drm] i915: Ignore SURFLIVE and flip counter when the GPU gets reset (Rob Clark) [1173317]
- [drm] i915: Kick fbdev before vgacon (Rob Clark) [1173317]
- [drm] i915: Handle failure to kick out a conflicting fb driver (Rob Clark) [1173317]
- [drm] i915: drop WaSetupGtModeTdRowDispatch:snb (Rob Clark) [1173317]
- [drm] radeon: add locking around atombios scratch space usage (Rob Clark) [1173317]
- [drm] radeon: add missing crtc unlock when setting up the MC (Rob Clark) [1173317]
- [drm] i915: Disable caches for Global GTT (Rob Clark) [1173317]
- [drm] i915: Do not leak pages when freeing userptr objects (Rob Clark) [1173317]
- [drm] ast: Fix HW cursor image (Rob Clark) [1173317]
- [drm] radeon: Use drm_malloc_ab instead of kmalloc_array (Rob Clark) [1173317]
- [drm] radeon/dpm: disable ulv support on SI (Rob Clark) [1173317]
- [drm] i915: Do a dummy DPCD read before the actual read (Rob Clark) [1173317]
- [drm] nouveau/bios: memset dcb struct to zero before parsing (Rob Clark) [1173317]
- [drm] nv50/disp: fix dpms regression on certain boards (Rob Clark) [1173317]
- [drm] nouveau/ltc: fix cbc issues on certain boards (Rob Clark) [1173317]
- [drm] nouveau/ltc: fix tag base address getting truncated if above 4GiB (Rob Clark) [1173317]
- [drm] nvc0-/fb/ram: fix use of non-existant ram if partitions aren't uniform (Rob Clark) [1173317]
- [drm] nouveau/bar: behave better if ioremap failed (Rob Clark) [1173317]
- [drm] nouveau: make sure display hardware is reinitialised on runtime resume (Rob Clark) [1173317]
- [drm] nouveau: punt fbcon resume out to a workqueue (Rob Clark) [1173317]
- [drm] nouveau/kms: restore acceleration before fb_set_suspend() resumes (Rob Clark) [1173317]
- [drm] nouveau/kms: take more care when pulling down accelerated fbcon (Rob Clark) [1173317]
- [drm] i915: Flush the PTEs after updating them before suspend (Rob Clark) [1153301]
- [drm] radeon/cik: use a separate counter for CP init timeout (Rob Clark) [1173317]
- [drm] radeon/dpm: fix resume on mullins (Rob Clark) [1173317]
- [drm] radeon: don't reset dma on r6xx-evergreen init (Rob Clark) [1173317]
- [drm] radeon: don't reset sdma on CIK init (Rob Clark) [1173317]
- [drm] radeon: don't reset dma on NI/SI init (Rob Clark) [1173317]
- [drm] radeon: add connector quirk for fujitsu board (Rob Clark) [1173317]
- [drm] radeon/dpm: set the thermal type properly for special configs (Rob Clark) [1173317]
- [drm] radeon: fix semaphore value init (Rob Clark) [1173317]
- [drm] radeon: handle broken disabled rb mask gracefully (6xx/7xx) (Rob Clark) [1173317]
- [drm] radeon: fix active_cu mask on SI and CIK after re-init (v3) (Rob Clark) [1173317]
- [drm] radeon: fix active cu count for SI and CIK (Rob Clark) [1173317]
- [drm] radeon: fix pm handling in radeon_gpu_reset (Rob Clark) [1173317]
- [drm] radeon: properly document reloc priority mask (Rob Clark) [1173317]
- [drm] radeon/dpm: select the appropriate vce power state for KV/KB/ML (Rob Clark) [1173317]
- [drm] radeon: Add missing lines to ci_set_thermal_temperature_range (Rob Clark) [1173317]
- [drm] radeon: Add ability to get and change dpm state when radeon PX card is turned off (Rob Clark) [1173317]
- [drm] vmwgfx: Fix a potential infinite spin waiting for fifo idle (Rob Clark) [1173317]
- [drm] ast: AST2000 cannot be detected correctly (Rob Clark) [1173317]
- [drm] ast: open key before detect chips (Rob Clark) [1173317]
- [drm] i915: Don't leak command parser tables on suspend/resume (Rob Clark) [1153301]
- [drm] i915/hdmi: fix hdmi audio state readout (Rob Clark) [1153301]
- [drm] i915: Wait for vblank before enabling the TV encoder (Rob Clark) [1153301]
- [drm] i915: Fix EIO/wedged handling in gem fault handler (Rob Clark) [1153301]
- [drm] i915: Fix lock dropping in intel_tv_detect() (Rob Clark) [1153301]
- [drm] i915: Remove bogus __init annotation from DMI callbacks (Rob Clark) [1153301]
- [drm] i915: Ignore VBT backlight presence check on Acer C720 (4005U) (Rob Clark) [1153301]
- [drm] i915: fix plane/cursor handling when runtime suspended (Rob Clark) [1153301]
- [drm] i915: don't try to retrain a DP link on an inactive CRTC (Rob Clark) [1153301]
- [drm] i915: Fix locking for intel_enable_pipe_a() (Rob Clark) [1153301]
- [drm] i915: Skip load detect when intel_crtc->new_enable==true (Rob Clark) [1153301]
- [drm] i915: Disable RCS flips on Ivybridge (Rob Clark) [1153301]
- [drm] i915: read HEAD register back in init_ring_common() to enforce ordering (Rob Clark) [1153301]
- [drm] i915: Fix crash when failing to parse MIPI VBT (Rob Clark) [1153301]
- [drm] radeon: tweak ACCEL_WORKING2 query for hawaii (Rob Clark) [1173317]
- [drm] radeon/atom: add new voltage fetch function for hawaii (Rob Clark) [1173317]
- [drm] radeon: set VM base addr using the PFP (Rob Clark) [1173317]
- [drm] radeon: load the lm63 driver for an lm64 thermal chip (Rob Clark) [1173317]
- [drm] radeon: re-enable dpm by default on BTC (Rob Clark) [1173317]
- [drm] radeon: re-enable dpm by default on cayman (Rob Clark) [1173317]
- [drm] radeon/dpm: handle voltage info fetching on hawaii (Rob Clark) [1173317]
- [drm] ttm: Choose a pool to shrink correctly in ttm_dma_pool_shrink_scan() (Rob Clark) [1173317]
- [drm] ttm: Fix possible division by 0 in ttm_dma_pool_shrink_scan() (Rob Clark) [1173317]
- [drm] ttm: fix handling of TTM_PL_FLAG_TOPDOWN (Rob Clark) [1173317]
- [drm] nouveau: Bump version from 1.1.1 to 1.1.2 (Rob Clark) [1173317]
- [drm] nouveau: Dis/Enable vblank irqs during suspend/resume (Rob Clark) [1173317]
- [drm] radeon: add additional SI pci ids (Rob Clark) [1173317]
- [drm] radeon: add new bonaire pci ids (Rob Clark) [1173317]
- [drm] radeon: add new KV pci id (Rob Clark) [1173317]
- [powerpc] add little endian flag to syscall_get_arch() (Richard Guy Briggs) [1169461]
- [powerpc] simplify syscall_get_arch() (Richard Guy Briggs) [1169461]

* Tue Dec 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-220.el7]
- [scsi] libcxgbi: fix freeing skb prematurely (Sai Vemuri) [1174982]
- [scsi] cxgb4i: use set_wr_txq() to set tx queues (Sai Vemuri) [1174982]
- [scsi] cxgb4i: handle non-pdu-aligned rx data (Sai Vemuri) [1174982]
- [scsi] cxgb4i: additional types of negative advice (Sai Vemuri) [1174982]
- [scsi] cxgb4i: set the max. pdu length in firmware (Sai Vemuri) [1174982]
- [scsi] cxgb4i: fix credit check for tx_data_wr (Sai Vemuri) [1174982]
- [scsi] cxgb4i: fix tx immediate data credit check (Sai Vemuri) [1174982]
- [net] ipv6: update Destination Cache entries when gateway turn into host (Jiri Pirko) [1114781]
- [net] ipsec: Don't update the pmtu on ICMPV6_DEST_UNREACH (Herbert Xu) [1158771]
- [s390] zfcp: remove access control tables interface (port leftovers) (Hendrik Brueckner) [1173553]
- [x86] perf: Use extended offcore mask on Haswell (Don Zickus) [1170795]
- [fs] ovl: ovl_dir_fsync() cleanup (David Howells) [985875]
- [fs] ovl: pass dentry into ovl_dir_read_merged() (David Howells) [985875]
- [fs] ovl: use lockless_dereference() for upperdentry (David Howells) [985875]
- [fs] ovl: allow filenames with comma (David Howells) [985875]
- [fs] ovl: fix race in private xattr checks (David Howells) [985875]
- [fs] ovl: fix remove/copy-up race (David Howells) [985875]
- [fs] ovl: rename filesystem type to "overlay" (David Howells) [985875]
- [fs] Don't warn if both ->rename() and ->rename2() iops are defined (David Howells) [985875]
- [fs] overlayfs: Fix the kABI for overlayfs (David Howells) [985875]
- [fs] overlayfs: don't poison cursor (David Howells) [985875]
- [fs] overlayfs: initialize ->is_cursor (David Howells) [985875]
- [fs] overlayfs: fix lockdep misannotation (David Howells) [985875]
- [fs] overlayfs: fix check for cursor (David Howells) [985875]
- [fs] overlayfs: barriers for opening upper-layer directory (David Howells) [985875]
- [kernel] rcu: Provide counterpart to rcu_dereference() for non-RCU situations (David Howells) [985875]
- [fs] overlayfs: embed middle into overlay_readdir_data (David Howells) [985875]
- [fs] overlayfs: embed root into overlay_readdir_data (David Howells) [985875]
- [fs] overlayfs: make ovl_cache_entry->name an array instead of pointer (David Howells) [985875]
- [fs] overlayfs: don't hold ->i_mutex over opening the real directory (David Howells) [985875]
- [fs] overlayfs: limit filesystem stacking depth (David Howells) [985875]
- [fs] overlayfs: overlay filesystem documentation (David Howells) [985875]
- [fs] overlayfs: implement show_options (David Howells) [985875]
- [fs] overlayfs: add statfs support (David Howells) [985875]
- [fs] overlayfs: filesystem (David Howells) [985875]
- [mm] shmem: support RENAME_WHITEOUT (David Howells) [985875]
- [fs] ext4: support RENAME_WHITEOUT (David Howells) [985875]
- [fs] vfs: add RENAME_WHITEOUT (David Howells) [985875]
- [fs] vfs: add whiteout support (David Howells) [985875]
- [fs] vfs: export check_sticky() (David Howells) [985875]
- [fs] vfs: introduce clone_private_mount() (David Howells) [985875]
- [fs] vfs: export __inode_permission() to modules (David Howells) [985875]
- [fs] vfs: export do_splice_direct() to modules (David Howells) [985875]
- [fs] vfs: add i_op->dentry_open() (David Howells) [985875]
- [fs] namei: trivial fix to vfs_rename_dir comment (David Howells) [985875]
- [fs] cifs: support RENAME_NOREPLACE (David Howells) [985875]
- [fs] hostfs: support rename flags (David Howells) [985875]
- [mm] shmem: support RENAME_EXCHANGE (David Howells) [985875]
- [mm] shmem: support RENAME_NOREPLACE (David Howells) [985875]
- [fs] btrfs: add RENAME_NOREPLACE (David Howells) [985875]
- [fs] bad_inode: add ->rename2() (David Howells) [985875]
- [fs] call rename2 if exists (David Howells) [985875]
- [fs] fuse: restructure ->rename2() (David Howells) [985875]
- [fs] fuse: add renameat2 support (David Howells) [985875]
- [fs] dcache: fix races between __d_instantiate() and checks of dentry flags (David Howells) [985875]
- [fs] ext4: add cross rename support (David Howells) [985875]
- [fs] vfs: add cross-rename (David Howells) [985875]
- [fs] vfs: lock_two_nondirectories - allow directory args (David Howells) [985875]
- [security] add flags to rename hooks (David Howells) [985875]
- [fs] vfs: add RENAME_NOREPLACE flag (David Howells) [985875]
- [fs] vfs: add renameat2 syscall (David Howells) [985875]
- [fs] namei: use common code for dir and non-dir (David Howells) [985875]
- [fs] namei: move d_move() up (David Howells) [985875]
- [fs] vfs: add d_is_dir() (David Howells) [985875]
- [fs] vfs: Put a small type field into struct dentry::d_flags (David Howells) [985875]

* Thu Dec 18 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-219.el7]
- [mm] vmstat: on-demand vmstat workers V8 (Larry Woodman) [1157802]
- [mm] vmstat: use this_cpu() to avoid irqon/off sequence in refresh_cpu_vm_stats (Larry Woodman) [1157802]
- [mm] vmstat: create fold_diff (Larry Woodman) [1157802]
- [mm] vmstat: create separate function to fold per cpu diffs into local counters (Larry Woodman) [1157802]
- [block] blk-mq: Fix uninitialized kobject at CPU hotplugging (Jeff Moyer) [1169232]
- [kernel] audit: AUDIT_FEATURE_CHANGE message format missing delimiting space (Richard Guy Briggs) [1165469]
- [fs] NFSv4.1: nfs41_clear_delegation_stateid shouldn't trust NFS_DELEGATED_STATE (Steve Dickson) [1166845]
- [fs] NFSv4: Fix races between nfs_remove_bad_delegation() and delegation return (Steve Dickson) [1166845]
- [fs] NFS: Don't try to reclaim delegation open state if recovery failed (Steve Dickson) [1166845]
- [fs] NFSv4: Ensure that we call FREE_STATEID when NFSv4.x stateids are revoked (Steve Dickson) [1166845]
- [fs] NFSv4: Ensure that we remove NFSv4.0 delegations when state has expired (Steve Dickson) [1166845]

* Wed Dec 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-218.el7]
- [scsi] cxgb4i: Don't block unload/cxgb4 unload when remote closes TCP connection (Sai Vemuri) [1169941]
- [kernel] kthread: partial revert of 81c98869faa5 ("kthread: ensure locality of task_struct allocations") (Gustavo Duarte) [953583]
- [mm] slub: fall back to node_to_mem_node() node if allocating on memoryless node (Gustavo Duarte) [953583]
- [mm] topology: add support for node_to_mem_node() to determine the fallback node (Gustavo Duarte) [953583]
- [mm] slub: search partial list on numa_mem_id(), instead of numa_node_id() (Gustavo Duarte) [953583]
- [kernel] kthread: ensure locality of task_struct allocations (Gustavo Duarte) [953583]
- [md] dm-thin: fix missing out-of-data-space to write mode transition if blocks are released (Mike Snitzer) [1173181]
- [md] dm-thin: fix inability to discard blocks when in out-of-data-space mode (Mike Snitzer) [1173181]
- [wireless] iwlwifi/mvm: update values for Smart Fifo (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/dvm: fix flush support for old firmware (Stanislaw Gruszka) [1155538]
- [wireless] ath5k: fix hardware queue index assignment (Stanislaw Gruszka) [1155538]
- [wireless] ath9k: fix BE/BK queue order (Stanislaw Gruszka) [1155538]
- [wireless] ath9k_hw: fix hardware queue allocation (Stanislaw Gruszka) [1155538]
- [wireless] ath9k: Fix RTC_DERIVED_CLK usage (Stanislaw Gruszka) [1155538]
- [wireless] rt2x00: do not align payload on modern H/W (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: Fix regression that triggers a kernel BUG with CCMP (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi: fix RFkill while calibrating (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: fix use-after-free in defragmentation (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: properly flush delayed scan work on interface removal (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: schedule the actual switch of the station before CSA count 0 (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: use secondary channel offset IE also beacons during CSA (Stanislaw Gruszka) [1155538]
- [wireless] rt2x00: add new rt2800usb device (Stanislaw Gruszka) [1155538]
- [wireless] Revert: iwlwifi/mvm: treat EAPOLs like mgmt frames wrt rate (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/dvm: drop non VO frames when flushing (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi: configure the LTR (Stanislaw Gruszka) [1155538]
- [wireless] mac80211: fix typo in starting baserate for rts_cts_rate_idx (Stanislaw Gruszka) [1155538]
- [wireless] rt2x00: add new rt2800usb devices (Stanislaw Gruszka) [1155538]
- [wireless] rt2x00: support Ralink 5362 (Stanislaw Gruszka) [1155538]
- [wireless] Revert: ath9k: reduce ANI firstep range for older chips (Stanislaw Gruszka) [1155538]
- [wireless] rt2800: correct BBP1_TX_POWER_CTRL mask (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi: Add missing PCI IDs for the 7260 series (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/mvm: disable BT Co-running by default (Stanislaw Gruszka) [1155538]
- [wireless] nl80211: clear skb cb before passing to netlink (Stanislaw Gruszka) [1155538]
- [wireless] ath9k/htc: fix random decryption failure (Stanislaw Gruszka) [1155538]
- [wireless] brcmfmac: handle IF event for P2P_DEVICE interface (Stanislaw Gruszka) [1155538]
- [wireless] Revert: mac80211: disable uAPSD if all ACs are under ACM (Stanislaw Gruszka) [1155538]
- [wireless] rtlwifi/rtl8192cu: Add new ID (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/mvm: set MAC_FILTER_IN_BEACON correctly for STA/P2P client (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/mvm: treat EAPOLs like mgmt frames wrt rate (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi: increase DEFAULT_MAX_TX_POWER (Stanislaw Gruszka) [1155538]
- [wireless] iwlwifi/mvm: fix endianity issues with Smart Fifo commands (Stanislaw Gruszka) [1155538]
- [wireless] Revert: iwlwifi/dvm: don't enable CTS to self (Stanislaw Gruszka) [1155538]
- [wireless] carl9170: fix sending URBs with wrong type when using full-speed (Stanislaw Gruszka) [1155538]

* Fri Dec 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-217.el7]
- [net] ipv6: yet another new IPV6_MTU_DISCOVER option IPV6_PMTUDISC_OMIT (Hannes Frederic Sowa) [1170116]
- [net] ipv4: yet another new IP_MTU_DISCOVER option IP_PMTUDISC_OMIT (Hannes Frederic Sowa) [1170116]
- [net] ipv4: use ip_skb_dst_mtu to determine mtu in ip_fragment (Hannes Frederic Sowa) [1170116]
- [net] ipv4: introduce ip_dst_mtu_maybe_forward and protect forwarding path against pmtu spoofing (Hannes Frederic Sowa) [1170116]
- [net] ipv6: move ip6_sk_accept_pmtu from generic pmtu update path to ipv6 one (Hannes Frederic Sowa) [1170116]
- [net] ipv6: support IPV6_PMTU_INTERFACE on sockets (Hannes Frederic Sowa) [1170116]
- [net] udp: do not report ICMP redirects to user space (Hannes Frederic Sowa) [1170116]
- [net] ipv4: new ip_no_pmtu_disc mode to always discard incoming frag needed msgs (Hannes Frederic Sowa) [1170116]
- [net] inet: make no_pmtu_disc per namespace and kill ipv4_config (Hannes Frederic Sowa) [1170116]
- [net] ipv4: improve documentation of ip_no_pmtu_disc (Hannes Frederic Sowa) [1170116]
- [net] ipv4: introduce new IP_MTU_DISCOVER mode IP_PMTUDISC_INTERFACE (Hannes Frederic Sowa) [1170116]
- [net] xfrm: revert ipv4 mtu determination to dst_mtu (Hannes Frederic Sowa) [1170116]
- [net] xfrm: introduce helper for safe determination of mtu (Hannes Frederic Sowa) [1170116]
- [net] netfilter: conntrack: disable generic tracking for known protocols (Daniel Borkmann) [1170520]
- [net] gre: Fix use-after-free panic in ipgre_rcv() (Panu Matilainen) [1117543]
- [net] netfilter: nf_conntrack_h323: lookup route from proper net namespace (Florian Westphal) [1163847]
- [net] netfilter: xt_tcpmss: lookup route from proper net namespace (Florian Westphal) [1163847]
- [net] netfilter: xt_tcpmss: Get mtu only if clamp-mss-to-pmtu is specified (Florian Westphal) [1163847]
- [wireless] cfg80211: don't WARN about two consecutive Country IE hint (Stanislaw Gruszka) [1164282]
- [fs] aio: fix race between aio event completion and reaping (Jeff Moyer) [1131312]
- [fs] proc/task_mmu: fix missing check during hugepage migration (Jacob Tanenbaum) [1105040] {CVE-2014-3940}
- [kernel] trace: insufficient syscall number validation in perf and ftrace subsystems (Jacob Tanenbaum) [1161570] {CVE-2014-7825 CVE-2014-7826}
- [ethernet] i40e: get pf_id from HW rather than PCI function (Stefan Assmann) [1078740]
- [ethernet] i40e: increase ARQ size (Stefan Assmann) [1078740]
- [x86] uv: Update the UV3 TLB shootdown logic (Frank Ramsay) [1170253]
- [tools] peeksiginfo: add PAGE_SIZE definition (Steve Best) [1172250]
- [base] bus: Fix unbalanced device reference in drivers_probe (Alex Williamson) [1158862]
- [char] tpm: Fix NULL return in tpm_ibmvtpm_get_desired_dma (Gustavo Duarte) [1154818]
- [powerpc] kvm: book3s_hv - Reserve cma region only in hypervisor mode (Gustavo Duarte) [1147740]
- [x86] traps: stop using IST for #SS (Petr  Matousek) [1172813] {CVE-2014-9322}

* Tue Dec 09 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-216.el7]
- [acpi] Revert: hotplug/pci: Simplify disable_slot() (Prarit Bhargava) [1158720]
- [infiniband] iser: Adjust data_length to include protection information (Amir Vadai) [1107622]
- [infiniband] iser: Bump version to 1.4.1 (Amir Vadai) [1107622]
- [infiniband] iser: Allow bind only when connection state is UP (Amir Vadai) [1107622]
- [infiniband] iser: Fix RX/TX CQ resource leak on error flow (Amir Vadai) [1107622]
- [infiniband] iser: Clarify a duplicate counters check (Amir Vadai) [1107622]
- [infiniband] iser: Replace connection waitqueue with completion object (Amir Vadai) [1107622]
- [infiniband] iser: Protect iser state machine with a mutex (Amir Vadai) [1107622]
- [infiniband] iser: Remove redundant return code in iser_free_ib_conn_res() (Amir Vadai) [1107622]
- [infiniband] iser: Seperate iser_conn and iscsi_endpoint storage space (Amir Vadai) [1107622]
- [infiniband] iser: Fix responder resources advertisement (Amir Vadai) [1107622]
- [infiniband] iser: Add TIMEWAIT_EXIT event handling (Amir Vadai) [1107622]
- [infiniband] iser: Support IPv6 address family (Amir Vadai) [1107622]
- [infiniband] iser: Bump version to 1.4 (Amir Vadai) [1107622]
- [infiniband] iser: Add missing newlines to logging messages (Amir Vadai) [1107622]
- [infiniband] iser: Fix a possible race in iser connection states transition (Amir Vadai) [1107622]
- [infiniband] iser: Simplify connection management (Amir Vadai) [1107622]
- [infiniband] iser: Bump driver version to 1.3 (Amir Vadai) [1107622]
- [infiniband] iser: Update Mellanox copyright note (Amir Vadai) [1107622]
- [infiniband] iser: Print QP information once connection is established (Amir Vadai) [1107622]
- [infiniband] iser: Remove struct iscsi_iser_conn (Amir Vadai) [1107622]
- [infiniband] iser: Drain the tx cq once before looping on the rx cq (Amir Vadai) [1107622]
- [infiniband] iser: Fix sector_t format warning (Amir Vadai) [1107622]
- [infiniband] iser: Publish T10-PI support to SCSI midlayer (Amir Vadai) [1107622]
- [infiniband] iser: Implement check_protection (Amir Vadai) [1107622]
- [infiniband] iser: Support T10-PI operations (Amir Vadai) [1107622]
- [infiniband] iser: Initialize T10-PI resources (Amir Vadai) [1107622]
- [infiniband] iser: Introduce pi_enable, pi_guard module parameters (Amir Vadai) [1107622]
- [infiniband] iser: Generalize fall_to_bounce_buf routine (Amir Vadai) [1107622]
- [infiniband] iser: Generalize iser_unmap_task_data and finalize_rdma_unaligned_sg (Amir Vadai) [1107622]
- [infiniband] iser: Replace fastreg descriptor valid bool with indicators container (Amir Vadai) [1107622]
- [infiniband] iser: Keep IB device attributes under iser_device (Amir Vadai) [1107622]
- [infiniband] iser: Move fast_reg_descriptor initialization to a function (Amir Vadai) [1107622]
- [infiniband] iser: Push the decision what memory key to use into fast_reg_mr routine (Amir Vadai) [1107622]
- [infiniband] iser: Avoid FRWR notation, use fastreg instead (Amir Vadai) [1107622]
- [infiniband] iser: Suppress completions for fast registration work requests (Amir Vadai) [1107622]
- [infiniband] iser: Fix use after free in iser_snd_completion() (Amir Vadai) [1107622]
- [scsi] libiscsi: Add check_protection callback for transports (Amir Vadai) [1107622]
- [mm] mem-hotplug: reset node present pages when hot-adding a new pgdat (Motohiro Kosaki) [1156396]
- [mm] mem-hotplug: reset node managed pages when hot-adding a new pgdat (Motohiro Kosaki) [1156396]
- [mm] make __free_pages_bootmem() only available at boot time (Motohiro Kosaki) [1156396]
- [mm] use a dedicated lock to protect totalram_pages and zone->managed_pages (Motohiro Kosaki) [1156396]
- [mm] accurately calculate zone->managed_pages for highmem zones (Motohiro Kosaki) [1156396]
- [md] dm-cache: fix spurious cell_defer when dealing with partial block at end of device (Mike Snitzer) [1165050]
- [md] dm-cache: dirty flag was mistakenly being cleared when promoting via overwrite (Mike Snitzer) [1165050]
- [md] dm-cache: only use overwrite optimisation for promotion when in writeback mode (Mike Snitzer) [1165050]
- [md] dm-cache: discard block size must be a multiple of cache block size (Mike Snitzer) [1165050]
- [md] dm-cache: fix a harmless race when working out if a block is discarded (Mike Snitzer) [1165050]
- [md] dm-cache: when reloading a discard bitset allow for a different discard block size (Mike Snitzer) [1165050]
- [md] dm-cache: fix some issues with the new discard range support (Mike Snitzer) [1165050]
- [md] dm-array: if resizing the array is a noop set the new root to the old one (Mike Snitzer) [1165050]
- [md] dm-bufio: fix memleak when using a dm_buffer's inline bio (Mike Snitzer) [1165050]
- [md] dm: use rcu_dereference_protected instead of rcu_dereference (Mike Snitzer) [1165246]
- [md] dm-thin: suspend/resume active thin devices when reloading thin-pool (Mike Snitzer) [1165246]
- [md] dm-thin: do not allow thin device activation while pool is suspended (Mike Snitzer) [1165246]
- [md] dm-thin: fix a race in thin_dtr (Mike Snitzer) [1165246]
- [md] dm-thin: remove stale 'trim' message in block comment above pool_message (Mike Snitzer) [1165246]
- [md] dm: update wait_on_bit calls for RHEL (Mike Snitzer) [1165246]
- [md] dm: enhance internal suspend and resume interface (Mike Snitzer) [1165246]
- [md] dm: add presuspend_undo hook to target_type (Mike Snitzer) [1165246]
- [md] dm: return earlier from dm_blk_ioctl if target doesn't implement .ioctl (Mike Snitzer) [1165246]
- [md] dm: do not call dm_sync_table() when creating new devices (Mike Snitzer) [1165246]
- [md] dm: sparse - Annotate field with __rcu for checking (Mike Snitzer) [1165246]
- [md] dm: Use rcu_dereference() for accessing rcu pointer (Mike Snitzer) [1165246]
- [md] dm: allow active and inactive tables to share dm_devs (Mike Snitzer) [1165246]
- [md] dm-mpath: stop queueing IO when no valid paths exist (Mike Snitzer) [1165246]

* Mon Dec 08 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-215.el7]
- [net] vxlan: Do not reuse sockets for a different address family (Marcelo Leitner) [1146107]
- [net] vti: Fix kernel panic due to tunnel not being removed on link deletion (Panu Matilainen) [1167725]
- [net] sctp: test if association is dead in sctp_wake_up_waiters (Daniel Borkmann) [1166467]
- [net] sctp: wake up all assocs if sndbuf policy is per socket (Daniel Borkmann) [1166467]
- [net] ip: better estimate tunnel header cut for correct ufo handling (Alexander Duyck) [1159577]
- [net] ipv6: gso: remove redundant locking (Alexander Duyck) [1159577]
- [net] ipv6: Do not treat a GSO_TCPV4 request from UDP tunnel over IPv6 as invalid (Alexander Duyck) [1159577]
- [net] ipv6: fib: fix fib dump restart (Panu Matilainen) [1163605]
- [net] ipv6: drop unused fib6_clean_all_ro() function and rt6_proc_arg struct (Panu Matilainen) [1163605]
- [net] ipv6: avoid high order memory allocations for /proc/net/ipv6_route (Panu Matilainen) [1163605]
- [net] ipv4: Fix incorrect error code when adding an unreachable route (Panu Matilainen) [1165552]
- [net] sctp: replace seq_printf with seq_puts (Daniel Borkmann) [1164214]
- [net] sctp: add transport state in /proc/net/sctp/remaddr (Daniel Borkmann) [1164214]
- [IB] isert: Adjust CQ size to HW limits (Andy Grover) [1166314]
- [ib_isert] Add max_send_sge=2 minimum for control PDU responses (Andy Grover) [1166314]
- [scsi] megaraid_sas: do not process IOCTLs and SCSI commands during driver removal (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: dndinaness related bug fixes (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: corrected return of wait_event from abort frame path (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: make HBA operational after LD_MAP_SYNC DCMD in OCR path (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: online Firmware upgrade support for Extended VD feature (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: update MAINTAINERS and copyright information for megaraid drivers (Tomas Henzl) [1162645]
- [scsi] megaraid_sas: driver version upgrade and remove some meta data of driver (06.805.06.01-rc1) (Tomas Henzl) [1162645]

* Mon Dec 08 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-214.el7]
- [powerpc] Drop useless warning in eeh_init() (Gustavo Duarte) [1156651]
- [powerpc] pseries: Decrease message level on EEH initialization (Gustavo Duarte) [1156651]
- [net] ceph: fixup includes in pagelist.h (Ilya Dryomov) [1165232]
- [net] ceph: change from BUG to WARN for __remove_osd() asserts (Ilya Dryomov) [1165232]
- [net] ceph: clear r_req_lru_item in __unregister_linger_request() (Ilya Dryomov) [1165232]
- [net] ceph: unlink from o_linger_requests when clearing r_osd (Ilya Dryomov) [1165232]
- [net] ceph: do not crash on large auth tickets (Ilya Dryomov) [1165232]
- [fs] ceph: fix flush tid comparision (Ilya Dryomov) [1165232]
- [net] ceph: eliminate unnecessary allocation in process_one_ticket() (Ilya Dryomov) [1165232]
- [block] rbd: Fix error recovery in rbd_obj_read_sync() (Ilya Dryomov) [1165232]
- [net] ceph: use memalloc flags for net IO (Ilya Dryomov) [1165232]
- [block] rbd: use a single workqueue for all devices (Ilya Dryomov) [1165232]
- [fs] ceph: fix divide-by-zero in __validate_layout() (Ilya Dryomov) [1165232]
- [block] rbd: rbd workqueues need a resque worker (Ilya Dryomov) [1165232]
- [net] ceph: ceph-msgr workqueue needs a resque worker (Ilya Dryomov) [1165232]
- [fs] ceph: fix bool assignments (Ilya Dryomov) [1165232]
- [net] ceph: separate multiple ops with commas in debugfs output (Ilya Dryomov) [1165232]
- [net] ceph: sync osd op definitions in rados.h (Ilya Dryomov) [1165232]
- [net] ceph: remove redundant declaration (Ilya Dryomov) [1165232]
- [fs] ceph: additional debugfs output (Ilya Dryomov) [1165232]
- [fs] ceph: export ceph_session_state_name function (Ilya Dryomov) [1165232]
- [fs] ceph: use pagelist to present MDS request data (Ilya Dryomov) [1165232]
- [net] ceph: reference counting pagelist (Ilya Dryomov) [1165232]
- [fs] ceph: fix llistxattr on symlink (Ilya Dryomov) [1165232]
- [fs] ceph: send client metadata to MDS (Ilya Dryomov) [1165232]
- [fs] ceph: remove redundant code for max file size verification (Ilya Dryomov) [1165232]
- [fs] ceph: move ceph_find_inode() outside the s_mutex (Ilya Dryomov) [1165232]
- [fs] ceph: request xattrs if xattr_version is zero (Ilya Dryomov) [1165232]
- [block] rbd: set the remaining discard properties to enable support (Ilya Dryomov) [1165232]
- [block] rbd: use helpers to handle discard for layered images correctly (Ilya Dryomov) [1165232]
- [block] rbd: extract a method for adding object operations (Ilya Dryomov) [1165232]
- [block] rbd: make discard trigger copy-on-write (Ilya Dryomov) [1165232]
- [block] rbd: tolerate -ENOENT for discard operations (Ilya Dryomov) [1165232]
- [block] rbd: fix snapshot context reference count for discards (Ilya Dryomov) [1165232]
- [block] rbd: read image size for discard check safely (Ilya Dryomov) [1165232]
- [block] rbd: initial discard bits (Ilya Dryomov) [1165232]
- [block] rbd: extend the operation type (Ilya Dryomov) [1165232]
- [block] rbd: skip the copyup when an entire object writing (Ilya Dryomov) [1165232]
- [block] rbd: add img_obj_request_simple() helper (Ilya Dryomov) [1165232]
- [block] rbd: access snapshot context and mapping size safely (Ilya Dryomov) [1165232]
- [block] rbd: do not return -ERANGE on auth failures (Ilya Dryomov) [1165232]
- [net] ceph: don't try checking queue_work() return value (Ilya Dryomov) [1165232]
- [fs] ceph: make sure request isn't in any waiting list when kicking request (Ilya Dryomov) [1165232]
- [fs] ceph: protect kick_requests() with mdsc->mutex (Ilya Dryomov) [1165232]
- [net] ceph: Convert pr_warning to pr_warn (Ilya Dryomov) [1165232]
- [fs] ceph: trim unused inodes before reconnecting to recovering MDS (Ilya Dryomov) [1165232]
- [net] ceph: fix a use after free issue in osdmap_set_max_osd (Ilya Dryomov) [1165232]
- [net] ceph: select CRYPTO_CBC in addition to CRYPTO_AES (Ilya Dryomov) [1165232]
- [net] ceph: resend lingering requests with a new tid (Ilya Dryomov) [1165232]
- [net] ceph: abstract out ceph_osd_request enqueue logic (Ilya Dryomov) [1165232]
- [block] rbd: fix error return code in rbd_dev_device_setup() (Ilya Dryomov) [1165232]
- [block] rbd: avoid format-security warning inside alloc_workqueue() (Ilya Dryomov) [1165232]
- [kernel] printk/register_console: prevent adding the same console twice (Artem Savkov) [1169766]
- [mm] hugetlb: add cond_resched_lock() in, return_unused_surplus_pages() (Motohiro Kosaki) [1142698]
- [mm] hugetlb: fix softlockup when a large number of, hugepages are freed (Motohiro Kosaki) [1142698]
- [kernel] sched: Use new KABI macros (Don Zickus) [1164383]
- [net] Use new KABI macros (Don Zickus) [1164383]
- [scsi] Use new KABI macros (Don Zickus) [1164383]
- [kernel] Use new KABI macros (Don Zickus) [1164383]
- [block] Use new KABI macros (Don Zickus) [1164383]
- [block] include: Use new KABI macros (Don Zickus) [1164383]
- [misc] Use new KABI macros (Don Zickus) [1164383]
- [x86] Use new KABI macros (Don Zickus) [1164383]
- [powerpc] Use new KABI macros (Don Zickus) [1164383]

* Wed Dec 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-213.el7]
- [scsi] ipr: don't log error messages when applications issues illegal requests (Gustavo Duarte) [1163019]
- [net] macvlan: Allow setting multicast filter on all macvlan types (Vlad Yasevich) [848197]
- [block] genhd: fix leftover might_sleep() in blk_free_devt() (Jeff Moyer) [1167728]
- [ethernet] mlx4: Add VXLAN ndo calls to the PF net device ops too (Florian Westphal) [1168212]
- [powerpc] xmon: le - Fix endiannes issue in RTAS call from xmon (Steve Best) [1160650]
- [mm] thp: close race between split and zap huge pages (Seth Jennings) [1165268]
- [mm] thp: close race between mremap() and split_huge_page() (Seth Jennings) [1165268]
- [mmc] rtsx: Change default tx phase (Don Zickus) [1106204]
- [mfd] rtsx: Copyright modifications (Don Zickus) [1106204]
- [mfd] rtsx: Configure to enter a deeper power-saving mode in S3 (Don Zickus) [1106204]
- [mfd] rtsx: Move some actions from rtsx_pci_init_hw to individual extra_init_hw (Don Zickus) [1106204]
- [mfd] rtsx: Add shutdown callback in rtsx_pci_driver (Don Zickus) [1106204]
- [mfd] rtsx: Read vendor setting from config space (Don Zickus) [1106204]
- [mfd] rtsx: Add support for RTL8411B (Don Zickus) [1106204]

* Mon Dec 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-212.el7]
- [fs] fsnotify: next_i is freed during fsnotify_unmount_inodes (Eric Sandeen) [1124997]
- [fs] btrfs: fix regression of btrfs device replace (Eric Sandeen) [1162983]
- [fs] ext4: don't count external journal blocks as overhead (Eric Sandeen) [1164366]
- [fs] Fix oops when creating symlinks on smb3 (Sachin Prabhu) [1161429]

* Wed Nov 26 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-211.el7]
- [net] sctp: fix memory leak in auth key management (Daniel Borkmann) [1160928]
- [net] sctp: fix NULL pointer dereference in af->from_addr_param on malformed packet (Daniel Borkmann) [1154002] {CVE-2014-7841}
- [net] tcp: zero retrans_stamp if all retrans were acked (Marcelo Leitner) [1162193]
- [net] netfilter: log: protect nf_log_register against double registering (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: ulog: compat with new structure (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: nat expression must select CONFIG_NF_NAT (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: add explicit Kconfig for NETFILTER_XT_NAT (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: masquerading needs to be independent of x_tables in Kconfig (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: NFT_CHAIN_NAT_IPV* is independent of NFT_NAT (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: move NAT Kconfig switches out of the iptables scope (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: NETFILTER_XT_TARGET_LOG selects NF_LOG_* (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: fix several Kconfig problems in NF_LOG_* (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_masq: register/unregister notifiers on module init/exit (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: allow to filter from prerouting and postrouting (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_compat: remove incomplete 32/64 bits arch compat code (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: wait for call_rcu completion on module removal (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_reject: introduce icmp code abstraction for inet and bridge (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: store and dump set policy (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: export rule-set generation ID (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add NFTA_MASQ_UNSPEC to nft_masq_attributes (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add new nft_masq expression (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_nat: include a flag attribute (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: extend NFT_MSG_DELTABLE to support flushing the ruleset (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add helpers to schedule objects deletion (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add devgroup support in meta expresion (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: rename nf_table_delrule_by_chain() (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add helper to unregister chain hooks (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: refactor rule deletion helper (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_chain_nat_ipv6: use generic IPv6 NAT code from core (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nat: move specific NAT IPv6 to core (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_rbtree: no need for spinlock from set destroy path (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_hash: no need for rcu in the hash set destroy path (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_nat: generalize IPv6 masquerading support for nf_tables (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_nat: generalize IPv4 masquerading support for nf_tables (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_chain_nat_ipv4: use generic IPv4 NAT code from core (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nat: move specific NAT IPv4 to core (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_meta: Add cpu attribute support (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_meta: add pkttype support (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix error return code (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: don't update chain with unset counters (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: uninitialize element key/data from the commit path (Marcelo Leitner) [1148041 1155088]
- [net] nftables: Convert nft_hash to use generic rhashtable (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: Avoid duplicate call to nft_data_uninit() for same key (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: check for unset NFTA_SET_ELEM_LIST_ELEMENTS attribute (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: simplify set dump through netlink (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: bridge: add reject support (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: 64bit stats need some extra synchronization (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: set NLM_F_DUMP_INTR if netlink dumping is stale (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: safe RCU iteration on list when dumping (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: skip transaction if no update flags in tables (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_log: fix coccinelle warnings (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_log: complete logging support (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_log: request explicit logger when loading rules (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_nat: don't dump port information if unset (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: indicate family when dumping set elements (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_compat: call {target, match}->destroy() to cleanup entry (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix wrong type in transaction when replacing rules (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: decrement chain use counter when replacing rules (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use u32 for chain use counter (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use RCU-safe list insertion when replacing rules (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: atomic allocation in set notifications from rcu callback (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: allow to delete several objects from a batch (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_rbtree: introduce locking (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: release objects in reverse order in the abort path (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix wrong transaction ordering in set elements (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: defer all object release via rcu (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: remove skb and nlh from context structure (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: simplify nf_tables_*_notify (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use new transaction infrastructure to handle elements (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use new transaction infrastructure to handle table (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: pass context to nf_tables_updtable() (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: disabling table hooks always succeeds (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use new transaction infrastructure to handle chain (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: refactor chain statistic routines (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: use new transaction infrastructure to handle sets (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add message type to transactions (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: relocate commit and abort routines in the source file (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: generalise transaction infrastructure (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: deconstify table and chain in context structure (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix trace of matching non-terminal rule (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix missing return trace at the end of non-base chain (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix bogus rulenum after goto action (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix tracing of the goto action (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix goto action (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: reset rule number counter after jump and goto (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: add helper for adding nat extension (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: relax string validation of NFTA_CHAIN_TYPE (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: Add meta expression key for bridge interface name (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: Make meta expression core functions public (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: Stack expression type depending on their family (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix nft_cmp_fast failure on big endian for size < 4 (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: handle more than 8 * PAGE_SIZE set name allocations (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: fix wrong format in request_module() (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: set names cannot be larger than 15 bytes (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add set_elem notifications (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_hash: use set global element counter instead of private one (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: implement proper set selection (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_ct: split nft_ct_init() into two functions for get/set (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_meta: split nft_meta_init() into two functions for get/set (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_ct: add missing ifdef for NFT_MARK setting (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: Add missing vmalloc.h include to nft_hash.c (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_nat: fix family validation (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_ct: remove family from struct nft_ct (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: restore notifications for anonymous set destruction (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: restore context for expression destructors (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: clean up nf_tables_trans_add() argument order (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_hash: bug fixes and resizing (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add optional user data area to rules (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: accept QUEUE/DROP verdict parameters (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_tables: add nft_dereference() macro (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nft_ct: labels get support (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_nat: add full port randomization support (Marcelo Leitner) [1148041 1155088]
- [net] nf_tables: Include appropriate header file in netfilter/nft_lookup.c (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: xt_log: add missing string format in nf_log_packet() (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: log: nf_log_packet() as real unified interface (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: log: split family specific code to nf_log_{ip, ip6, common}.c files (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_log: move log buffering to core logging (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nf_log: use an array of loggers instead of list (Marcelo Leitner) [1148041 1155088]
- [net] introduce netdev_alloc_pcpu_stats() for drivers (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: nfnetlink: add rcu_dereference_protected() helpers (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: ip_set: rename nfnl_dereference()/nfnl_set() (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: ipset: remove unused code (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: Remove extern from function prototypes (Marcelo Leitner) [1148041 1155088]
- [net] netfilter: Remove extern from function prototypes (Marcelo Leitner) [1148041 1155088]
- [net] openvswitch: remove dup comment in vport.h (Jiri Benc) [1110384]
- [net] openvswitch: restore OVS_FLOW_CMD_NEW notifications (Jiri Benc) [1110384]
- [net] openvswitch: Add recirc and hash action (Jiri Benc) [1110384]
- [net] openvswitch: simplify sample action implementation (Jiri Benc) [1110384]
- [net] openvswitch: Use tun_key only for egress tunnel path (Jiri Benc) [1110384]
- [net] openvswitch: refactor ovs flow extract API (Jiri Benc) [1110384]
- [net] openvswitch: Remove pkt_key from OVS_CB (Jiri Benc) [1110384]
- [net] openvswitch: change the data type of error status to atomic_long_t (Jiri Benc) [1110384]
- [net] genetlink: add function genl_has_listeners() (Jiri Benc) [1110384]
- [net] vxlan: Call udp_flow_src_port (Jiri Benc) [1110384]
- [net] udp: Add function to make source port for UDP tunnels (Jiri Benc) [1110384]
- [net] openvswitch: distinguish between the dropped and consumed skb (Jiri Benc) [1110384]
- [net] openvswitch: fix a memory leak (Jiri Benc) [1110384]
- [net] openvswitch: Fix memory leak in ovs_vport_alloc() error path (Jiri Benc) [1110384]
- [net] openvswitch: fix duplicate #include headers (Jiri Benc) [1110384]
- [net] openvswitch: Remove unlikely() for WARN_ON() conditions (Jiri Benc) [1110384]
- [net] openvswitch: Use IS_ERR_OR_NULL (Jiri Benc) [1110384]
- [net] openvswitch: Add skb_clone NULL check for the sampling action (Jiri Benc) [1110384]
- [net] openvswitch: Sample action without side effects (Jiri Benc) [1110384]
- [net] openvswitch: Avoid memory corruption in queue_userspace_packet() (Jiri Benc) [1110384]
- [net] openvswitch: Enable tunnel GSO for OVS bridge (Jiri Benc) [1110384]
- [net] openvswitch: Allow each vport to have an array of 'port_id's (Jiri Benc) [1110384]
- [net] openvswitch: make generic netlink group const (Jiri Benc) [1110384]
- [net] openvswitch: introduce rtnl ops stub (Jiri Benc) [1110384]
- [net] openvswitch: Use exact lookup for flow_get and flow_del (Jiri Benc) [1110384]
- [net] openvswitch: Fix tracking of flags seen in TCP flows (Jiri Benc) [1110384]
- [net] openvswitch: supply a dummy err_handler of gre_cisco_protocol to prevent kernel crash (Jiri Benc) [1110384]
- [net] openvswitch: Fix a double free bug for the sample action (Jiri Benc) [1110384]
- [net] openvswitch: Simplify genetlink code (Jiri Benc) [1110384]
- [net] openvswitch: Minimize ovs_flow_cmd_new (Jiri Benc) [1110384]
- [net] openvswitch: Split ovs_flow_cmd_new_or_set() (Jiri Benc) [1110384]
- [net] openvswitch: Minimize ovs_flow_cmd_del critical section (Jiri Benc) [1110384]
- [net] openvswitch: Reduce locking requirements (Jiri Benc) [1110384]
- [net] openvswitch: Fix ovs_flow_stats_get/clear RCU dereference (Jiri Benc) [1110384]
- [net] openvswitch: Fix typo (Jiri Benc) [1110384]
- [net] openvswitch: Minimize dp and vport critical sections (Jiri Benc) [1110384]
- [net] openvswitch: Make flow mask removal symmetric (Jiri Benc) [1110384]
- [net] openvswitch: Build flow cmd netlink reply only if needed (Jiri Benc) [1110384]
- [net] openvswitch: Clarify locking (Jiri Benc) [1110384]
- [net] openvswitch: Avoid assigning a NULL pointer to flow actions (Jiri Benc) [1110384]
- [net] openvswitch: Compact sw_flow_key (Jiri Benc) [1110384]
- [net] net/openvswitch: Use with RCU_INIT_POINTER(x, NULL) in vport-gre.c (Jiri Benc) [1110384]
- [net] openvswitch: Use TCP flags in the flow key for stats (Jiri Benc) [1110384]
- [net] openvswitch: Fix output of SCTP mask (Jiri Benc) [1110384]
- [net] openvswitch: Per NUMA node flow stats (Jiri Benc) [1110384]
- [net] openvswitch: Remove 5-tuple optimization (Jiri Benc) [1110384]
- [net] openvswitch: Use ether_addr_copy (Jiri Benc) [1110384]
- [net] openvswitch: flow_netlink: Use pr_fmt to OVS_NLERR output (Jiri Benc) [1110384]
- [net] openvswitch: Use net_ratelimit in OVS_NLERR (Jiri Benc) [1110384]
- [net] openvswitch: Added (unsigned long long) cast in printf (Jiri Benc) [1110384]
- [net] openvswitch: avoid cast-qual warning in vport_priv (Jiri Benc) [1110384]
- [net] openvswitch: avoid warnings in vport_from_priv (Jiri Benc) [1110384]
- [net] openvswitch: use const in some local vars and casts (Jiri Benc) [1110384]
- [net] openvswitch: get rid of SET_ETHTOOL_OPS (Jiri Benc) [1110384]
- [net] openvswitch: Correctly report flow used times for first 5 minutes after boot (Jiri Benc) [1110384]
- [net] openvswitch: Fix race (Jiri Benc) [1110384]
- [net] openvswitch: Read tcp flags only then the tranport header is present (Jiri Benc) [1110384]
- [net] openvswitch: rename ->sync to ->syncp (Jiri Benc) [1110384]
- [net] openvswitch: make functions local (Jiri Benc) [1110384]
- [net] Add utility function to copy skb hash (Jiri Benc) [1110384]
- [net] Change skb_get_rxhash to skb_get_hash (Jiri Benc) [1110384]
- [net] netlink: Re-add locking to netlink_lookup() and seq walker (Jiri Benc) [1140661]
- [lib] rhashtable: remove second linux/log2.h inclusion (Jiri Benc) [1140661]
- [lib] rhashtable: allow user to set the minimum shifts of shrinking (Jiri Benc) [1140661]
- [lib] rhashtable: fix lockdep splat in rhashtable_destroy() (Jiri Benc) [1140661]
- [lib] rhashtable: Spelling s/compuate/compute/ (Jiri Benc) [1140661]
- [net] netlink: Annotate RCU locking for seq_file walker (Jiri Benc) [1140661]
- [net] netlink: hold nl_sock_hash_lock during diag dump (Jiri Benc) [1140661]
- [net] netlink: fix lockdep splats (Jiri Benc) [1140661]
- [net] netlink: Convert netlink_lookup() to use RCU protected hash table (Jiri Benc) [1140661]
- [net] netlink: make compare exist all the time (Jiri Benc) [1140661]
- [net] netlink: Add compare function for netlink_table (Jiri Benc) [1140661]
- [lib] rhashtable: fix annotations for rht_for_each_entry_rcu() (Jiri Benc) [1140661]
- [lib] rhashtable: unexport and make rht_obj() static (Jiri Benc) [1140661]
- [lib] rhashtable: RCU annotations for next pointers (Jiri Benc) [1140661]
- [lib] rhashtable: Resizable, Scalable, Concurrent Hash Table (Jiri Benc) [1140661]
- [mm] add kvfree() (Jiri Benc) [1140661]
- [net] netlink: Fix handling of error from netlink_dump() (Jiri Benc) [1140661]
- [net] netlink: autosize skb lengthes (Jiri Benc) [1140661]
- [net] netlink: Eliminate kmalloc in netlink dump operation (Jiri Benc) [1140661]

* Mon Nov 24 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-210.el7]
- [misc] kabi: revert two kabi additions that need updated ppc64 sums (Jarod Wilson)

* Mon Nov 24 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-209.el7]
- [fs] xfs: write failure beyond EOF truncates too much data (Brian Foster) [1032968]
- [fs] xfs: xfs_vm_write_end truncates too much on failure (Brian Foster) [1032968]
- [fs] xfs: use ->invalidatepage() length argument (Brian Foster) [1032968]
- [fs] xfs: change invalidatepage prototype to accept length (Brian Foster) [1032968]
- [fs] xfs: restore buffer_head unwritten bit on ioend cancel (Brian Foster) [1162953]
- [fs] xfs: allow inode allocations in post-growfs disk space (Eric Sandeen) [1115201]
- [scsi] pm8001: Update nvmd response data to request buffer (Rich Bono) [1110943]
- [scsi] pm8001: fix pm8001_store_update_fw (Rich Bono) [1110943]
- [scsi] pm8001: Fix erratic calculation in update_flash (Rich Bono) [1110943]
- [scsi] pm8001: Fix invalid return when request_irq() failed (Rich Bono) [1110943]
- [scsi] pm8001: fix a memory leak in nvmd_resp (Rich Bono) [1110943]
- [scsi] pm8001: fix update_flash (Rich Bono) [1110943]
- [scsi] pm8001: fix a memory leak in flash_update (Rich Bono) [1110943]
- [scsi] pm8001: Cleaning up uninitialized variables (Rich Bono) [1110943]
- [scsi] pm8001: Fix to remove null pointer checks that could never happen (Rich Bono) [1110943]
- [scsi] pm8001: more fixes to honor return value (Rich Bono) [1110943]
- [scsi] pm8001: add a new spinlock to protect the CCB (Rich Bono) [1110943]
- [scsi] pm8001: honor return value (Rich Bono) [1110943]
- [scsi] pm8001: clean bitmap management functions (Rich Bono) [1110943]
- [scsi] pm8001: Fix hibernation issue (Rich Bono) [1110943]
- [scsi] pm8001: Fix potential null pointer dereference and memory leak (Rich Bono) [1110943]
- [scsi] pm80xx: Fix missing NULL pointer checks and memory leaks (Rich Bono) [1110943]
- [scsi] drivers/scsi/pm8001/pm8001_ctl.c: avoid world-writable sysfs files (Rich Bono) [1110943]
- [scsi] pm80xx: fix problem of pm8001_work_fn reseting incorrect phy device (Rich Bono) [1110943]
- [scsi] pm80xx: Fix missing NULL pointer checks and memory leaks (Rich Bono) [1110943]
- [scsi] pm80xx: Enable BAR shift to avoid BIOS conflict with MPI space for ATTO pm8001 based HBAs (Rich Bono) [1110943]
- [scsi] pm80xx: Read saved WWN from NVMD for ATTO pm8001 based HBAs (Rich Bono) [1110943]
- [scsi] pm80xx: Fixed return value issue (Rich Bono) [1110943]
- [md] dm-thin: fix pool_io_hints to avoid looking at max_hw_sectors (Mike Snitzer) [1156164]
- [kernel] audit: keep inode pinned (Paul Moore) [1162261]
- [block] nvme: cleanup nvme_split_flush_data() (David Milburn) [1161766]
- [scsi] ibmvfc: fix little endian issues (Steve Best) [1159781]
- [scsi] ibmvfc: Fix for offlining devices during error recovery (Steve Best) [1159781]

* Sat Nov 22 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-208.el7]
- [scsi] cxgb4i: send abort_rpl correctly (Sai Vemuri) [1163467]
- [Documentation] cxgbi: add maintainer for cxgb3i/cxgb4i (Sai Vemuri) [1163467]
- [ethernet] cxgb4vf: FL Starvation Threshold needs to be larger than the SGE's Egress Congestion Threshold (Sai Vemuri) [1163467]
- [ethernet] cxgb4: For T5 use Packing and Padding Boundaries for SGE DMA transfers (Sai Vemuri) [1163467]
- [ethernet] cxgb4vf: Move fl_starv_thres into adapter->sge data structure (Sai Vemuri) [1163467]
- [ethernet] cxgb4vf: Replace repetitive pci device ID's with right ones (Sai Vemuri) [1163467]
- [infinband] cxgb4: Make c4iw_wr_log_size_order static (Sai Vemuri) [1163467]
- [infinband] cxgb4: Add missing neigh_release in find_route (Sai Vemuri) [1163467]
- [infinband] cxgb4: Fix ntuple calculation for ipv6 and remove duplicate line (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Fix FW flash logic using ethtool (Sai Vemuri) [1163467]
- [infiniband] cxgb4: Take IPv6 into account for best_mtu and set_emss (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Wait for device to get ready before reading any register (Sai Vemuri) [1163467]
- [ethernet] cxgb4vf: Add 40G support for cxgb4vf driver (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Updated the LSO transfer length in CPL_TX_PKT_LSO for T5 (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Add support for adaptive rx (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Change default Interrupt Holdoff Packet Count Threshold (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Add Devicde ID for two more adapter (Sai Vemuri) [1163467]
- [ethernet] cxgb4vf: Remove superfluous "idx" parameter of CH_DEVICE() macro (Sai Vemuri) [1163467]
- [ethernet] cxgb4: Use BAR2 Going To Sleep (GTS) for T5 and later (Sai Vemuri) [1163467]
- [scsi] cxgbi: support ipv6 address host_param (Sai Vemuri) [1153834]
- [scsi] cxgb4i: Fix -Wmaybe-uninitialized warning (Sai Vemuri) [1153834]
- [scsi] cxgb4i: Remove duplicate call to dst_neigh_lookup() (Sai Vemuri) [1153834]
- [scsi] cxgb4i: Fix -Wunused-function warning (Sai Vemuri) [1153834]
- [ethernet] cxgb4: Fix build failure in cxgb4 when ipv6 is disabled/not in-built (Sai Vemuri) [1153834]
- [scsi] cxgb4i: Remove duplicated CLIP handling code (Sai Vemuri) [1153834]
- [ethernet] be2net: fix alignment on line wrap (Ivan Vecera) [1165755]
- [ethernet] be2net: remove multiple assignments on a single line (Ivan Vecera) [1165755]
- [ethernet] be2net: remove space after typecasts (Ivan Vecera) [1165755]
- [ethernet] be2net: remove unnecessary blank lines after an open brace (Ivan Vecera) [1165755]
- [ethernet] be2net: insert a blank line after function/struct//enum definitions (Ivan Vecera) [1165755]
- [ethernet] be2net: remove multiple blank lines (Ivan Vecera) [1165755]
- [ethernet] be2net: add blank line after declarations (Ivan Vecera) [1165755]
- [ethernet] be2net: remove return statements for void functions (Ivan Vecera) [1165755]
- [ethernet] be2net: add speed reporting for 20G-KR interface (Ivan Vecera) [1165755]
- [ethernet] be2net: add speed reporting for 40G/KR interface (Ivan Vecera) [1165755]
- [ethernet] be2net: fix sparse warnings in be_cmd_req_port_type{} (Ivan Vecera) [1165755]
- [ethernet] be2net: fix a sparse warning in be_cmd_modify_eqd() (Ivan Vecera) [1165755]
- [ethernet] be2net: enable PCIe error reporting on VFs too (Ivan Vecera) [1165755]
- [ethernet] be2net: send a max of 8 EQs to be_cmd_modify_eqd() on Lancer (Ivan Vecera) [1165755]
- [ethernet] be2net: fix port-type reporting in get_settings (Ivan Vecera) [1165755]
- [ethernet] be2net: add ethtool "-m" option support (Ivan Vecera) [1165755]
- [ethernet] be2net: fix RX fragment posting for jumbo frames (Ivan Vecera) [1165755]
- [ethernet] be2net: replace strcpy with strlcpy (Ivan Vecera) [1165755]
- [ethernet] be2net: fix some log messages (Ivan Vecera) [1165755]
- [ethernet] bna: fix skb->truesize underestimation (Ivan Vecera) [1165759]
- [ethernet] bna: allow transmit tagged frames (Ivan Vecera) [1165759]
- [ethernet] bna: use container_of to resolve bufdesc_ex from bufdesc (Ivan Vecera) [1165759]
- [ethernet] r8169: add support for RTL8168EP (Ivan Vecera) [1165764]
- [ethernet] r8169: add support for Byte Queue Limits (Ivan Vecera) [1165764]
- [ethernet] r8169: call "rtl8168_driver_start" "rtl8168_driver_stop" only when hardware dash function is enabled (Ivan Vecera) [1165764]
- [ethernet] r8169: modify the behavior of function "rtl8168_oob_notify" (Ivan Vecera) [1165764]
- [ethernet] r8169: change the name of function "r8168dp_check_dash" to "r8168_check_dash" (Ivan Vecera) [1165764]
- [ethernet] r8169: change the name of function"rtl_w1w0_eri" (Ivan Vecera) [1165764]
- [ethernet] r8169: for function "rtl_w1w0_phy" change its name and behavior (Ivan Vecera) [1165764]
- [ethernet] r8169: add more chips to support magic packet v2 (Ivan Vecera) [1165764]
- [ethernet] r8169: add support more chips to get mac address from backup mac address register (Ivan Vecera) [1165764]
- [ethernet] r8169: add disable/enable RTL8411B pll function (Ivan Vecera) [1165764]
- [ethernet] r8169: add disable/enable RTL8168G pll function (Ivan Vecera) [1165764]
- [ethernet] r8169: change uppercase number to lowercase number (Ivan Vecera) [1165764]
- [ethernet] r8169: fix an if condition (Ivan Vecera) [1165764]
- [ethernet] r8169: adjust __rtl8169_set_features (Ivan Vecera) [1165764]
- [ethernet] r8169: fix setting rx vlan (Ivan Vecera) [1165764]
- [ethernet] r8169: fix the default setting of rx vlan (Ivan Vecera) [1165764]

* Sat Nov 22 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-207.el7]
- [powerpc] use device_online/offline() instead of cpu_up/down() (Gustavo Duarte) [1157737]
- [ethernet] i40e: disable FCoE (Stefan Assmann) [1165175]
- [cpufreq] intel_pstate: Add CPUID for BDW-H CPU (Steve Best) [1164379]
- [mm] do not overwrite reserved pages counter at show_mem() (Rafael Aquini) [1125433]
- [alsa] Revert: Kconfig: rename HAS_IOPORT to HAS_IOPORT_MAP (Jarod Wilson) [1112200]
- [ethernet] enic: Do not call napi_disable when preemption is disabled (Stefan Assmann) [1145019]
- [ethernet] enic: fix possible deadlock in enic_stop/ enic_rfs_flw_tbl_free (Stefan Assmann) [1145019]
- [x86] uv_bau: Avoid NULL pointer reference in ptc_seq_show (Frank Ramsay) [1161183]
- [x86] uv_bau: Increase maximum CPUs per socket/hub (Frank Ramsay) [1161183]
- [mm] vmscan: do not throttle based on pfmemalloc reserves if node has no ZONE_NORMAL (Gustavo Duarte) [1148925]
- [char] hwrng/pseries: port to new read API and fix stack corruption (Gustavo Duarte) [1163659]
- [md] Revert: dm-cache: add call to mark_tech_preview (Mike Snitzer) [1159001]
- [md] dm-cache: emit a warning message if there are a lot of cache blocks (Mike Snitzer) [1159001]
- [md] dm-cache: improve discard support (Mike Snitzer) [1159001]
- [md] dm-cache: revert "prevent corruption caused by discard_block_size > cache_block_size" (Mike Snitzer) [1159001]
- [md] dm-cache: revert "remove remainder of distinct discard block size" (Mike Snitzer) [1159001]
- [md] dm-bio-prison: introduce support for locking ranges of blocks (Mike Snitzer) [1159001]
- [md] dm-btree: fix a recursion depth bug in btree walking code (Mike Snitzer) [1080894]
- [md] dm-cache-policy-mq: simplify ability to promote sequential IO to the cache (Mike Snitzer) [1159001]
- [md] dm-cache-policy-mq: tweak algorithm that decides when to promote a block (Mike Snitzer) [1159001]
- [security] selinux: fix inode security list corruption (Paul Moore) [1152274]

* Thu Nov 20 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-206.el7]
- [x86] quirks: Print the Intel graphics stolen memory range (Rob Clark) [1154053]
- [x86] quirks: Add Intel graphics stolen memory quirk for gen2 platforms (Rob Clark) [1154053]
- [x86] quirks: Add vfunc for Intel graphics stolen memory base address (Rob Clark) [1154053]
- [x86] quirks: use gen6 stolen detection for VLV (Rob Clark) [1154053]
- [x86] quirks: support GMS and GGMS changes on i915/bdw (Rob Clark) [1154053]
- [x86] quirks: add early quirk for reserving Intel graphics stolen memory v5 (Rob Clark) [1154053]
- [net] vmxnet3: fix netpoll race condition (Neil Horman) [1158001]
- [virt] virtio_balloon: update_balloon_size() - update correct field (Luiz Capitulino) [1163567]
- [firmware] memmap: don't create memmap sysfs of same firmware_map_entry (Takahiro MUNEDA) [1160173]
- [mm] memory-hotplug: clear pgdat which is allocated by bootmem in try_offline_node() (Larry Woodman) [1156393]
- [kernel] add panic_on_warn (Prarit Bhargava) [1163852]
- [virt] hyperv: Fix the total_data_buflen in send path (Jason Wang) [1156305]
- [virt] hyperv: Add handling of IP header with option field in netvsc_set_hash() (Jason Wang) [1156305]
- [virt] hyperv: Fix a bug in netvsc_start_xmit() (Jason Wang) [1156305]
- [virt] hyperv: Fix a bug in netvsc_send() (Jason Wang) [1156305]
- [powerpc] kexec: adjust crashkernel reservation for 2GB-4GB systems (Gustavo Duarte) [1074924]
- [virt] kvm/ioapic: conditionally delay irq delivery duringeoi broadcast (John Snow) [921526]
- [fs] file_table: get rid of s_files and files_lock (Gustavo Duarte) [1112805]
- [fs] super: uninline destroy_super(), consolidate alloc_super() (Gustavo Duarte) [1112805]
- [ethernet] mlx4: Advertize encapsulation offloads features only when VXLAN tunnel is set (Florian Westphal) [1097478]
- [ethernet] mlx4: Avoid leaking steering rules on flow creation error flow (Florian Westphal) [1097478]
- [ethernet] mlx4: Don't attempt to TX offload the outer UDP checksum for VXLAN (Florian Westphal) [1097478]
- [scsi] bnx2fc: fix tgt spinlock locking (Maurizio Lombardi) [1165169]
- [scsi] TUR path is down after adapter gets reset with multipath (Ewan Milne) [1153738]
- [scsi] call device handler for failed TUR command (Ewan Milne) [1153738]

* Sat Nov 15 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-205.el7]
- [mm] shmem: fix splicing from a hole while it's punched (Denys Vlasenko) [1118245] {CVE-2014-4171}
- [mm] shmem: fix faulting into a hole, not taking i_mutex (Denys Vlasenko) [1118245] {CVE-2014-4171}
- [mm] shmem: fix faulting into a hole while it's punched (Denys Vlasenko) [1118245] {CVE-2014-4171}
- [virt] kvm: detect LVTT changes under APICv (Radim Krcmar) [1151174]
- [virt] kvm: detect SPIV changes under APICv (Radim Krcmar) [1151174]
- [virt] kvm: recalculate_apic_map after enabling apic (Radim Krcmar) [1151174]
- [virt] kvm: trace kvm_ple_window grow/shrink (Radim Krcmar) [1163296]
- [virt] kvm/vmx: dynamise PLE window (Radim Krcmar) [1163296]
- [virt] kvm/vmx: make PLE window per-VCPU (Radim Krcmar) [1163296]
- [virt] kvm: introduce sched_in to kvm_x86_ops (Radim Krcmar) [1163296]
- [virt] kvm: add kvm_arch_sched_in (Radim Krcmar) [1163296]
- [kernel] uprobes: Don't assume that arch_uprobe->insn/ixol is u8[MAX_UINSN_BYTES] (Steve Best) [1159365]
- [drm] qxl: don't create too large primary surface (Dave Airlie) [1158233]
- [powerpc] pseries: Quieten ibm, pcie-link-speed-stats warning (Steve Best) [1162287]
- [md] dm-thin: fix potential for infinite loop in pool_io_hints (Mike Snitzer) [1156164]
- [virt] hyperv/vmbus: Increase the limit on the number of pfns we can handle (Jason Wang) [1160130]
- [virt] kvm: update masterclock values on TSC writes (Marcelo Tosatti) [1158039]
- [virt] kvm: emulate MOVNTDQ (Paolo Bonzini) [1117542]
- [crypto] af_alg: properly label AF_ALG socket (Ondrej Kozina) [1161148]
- [powerpc] vphn: NUMA node code expects big-endian (Steve Best) [1154673]

* Fri Nov 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-204.el7]
- [net] ip6_gre: Return an error when adding an existing tunnel (Alexander Duyck) [1151886 1152368]
- [net] ip6_tunnel: Return an error when adding an existing tunnel (Alexander Duyck) [1151886 1152368]
- [net] ip_tunnel: Don't allow to add the same tunnel multiple times (Alexander Duyck) [1151886 1152368]
- [net] gre: Use inner mac length when computing tunnel length (Alexander Duyck) [1151886 1152368]
- [net] gre: enable offloads for GRE (Alexander Duyck) [1151886 1152368]
- [net] ipv4: fix a potential use after free in gre_offload.c (Alexander Duyck) [1151886 1152368]
- [net] ipv4: fix a potential use after free in ip_tunnel_core.c (Alexander Duyck) [1151886 1152368]
- [net] gro: fix aggregation for skb using frag_list (Alexander Duyck) [1154239]
- [net] gro: make sure skb->cb[] initial content has not to be zero (Alexander Duyck) [1154239]
- [net] bridge: notify user space after fdb update (Alexander Duyck) [1109605]
- [net] bridge: Fix the way to find old local fdb entries in br_fdb_changeaddr (Alexander Duyck) [1109605]
- [net] handle encapsulation offloads when computing segment lengths (Jiri Benc) [1144571]
- [net] gso: make skb_gso_segment error handling more robust (Jiri Benc) [1144571]
- [net] gso: use feature flag argument in all protocol gso handlers (Jiri Benc) [1144571]
- [net] udp_offload: Use IS_ERR_OR_NULL (Jiri Benc) [1144571]
- [net] ipv4: Use IS_ERR_OR_NULL (Jiri Benc) [1144571]

* Wed Nov 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-203.el7]
- [fs] GFS2: If we use up our block reservation, request more next time (Robert S Peterson) [1142238]
- [fs] GFS2: Only increase rs_sizehint (Robert S Peterson) [1142238]
- [fs] GFS2: Set of distributed preferences for rgrps (Robert S Peterson) [1142238]
- [fs] autofs: fix symlinks aren't checked for expiry (Ian Kent) [1116182]
- [fs] GFS2: fix regression in dir_double_exhash (Robert S Peterson) [1160229]
- [fs] gfs2_atomic_open(): skip lookups on hashed dentry (Robert S Peterson) [1158150]
- [fs] splice: perform generic write checks (Eric Sandeen) [1155907]
- [fs] fs: seq_file: fallback to vmalloc allocation (Ian Kent) [1095623]
- [fs] fs: /proc/stat: convert to single_open_size() (Ian Kent) [1095623]
- [fs] fs: seq_file: always clear m->count when we free m->buf (Ian Kent) [1095623]

* Wed Nov 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-202.el7]
- [ethernet] mlx4: Use PTYS register to set ethtool settings (Speed) (Amir Vadai) [1060221]
- [ethernet] mlx4: Use PTYS register to query ethtool settings (Amir Vadai) [1060221]
- [ethernet] mlx4: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Amir Vadai) [1060221]
- [ethernet] mlx4: Add 100M, 20G, 56G speeds ethtool reporting support (Amir Vadai) [1060221]
- [ethernet] mlx4: Add ethernet backplane autoneg device capability (Amir Vadai) [1060221]
- [ethernet] mlx4: Introduce ACCESS_REG CMD and eth_prot_ctrl dev cap (Amir Vadai) [1060221]
- [ethernet] mlx4: Cable info, get_module_info/eeprom ethtool support (Amir Vadai) [1060221]
- [ethernet] mlx4: Introduce mlx4_get_module_info for cable module info reading (Amir Vadai) [1060221]
- [ethernet] mlx4: Enable CQE/EQE stride support (Amir Vadai) [1060221]
- [virt] kvm/vmx: defer load of APIC access page address during reset (Paolo Bonzini) [1140974]
- [virt] kvm: do not handle APIC access page if in-kernel irqchip is not in use (Paolo Bonzini) [1140974]
- [virt] kvm: Unpin and remove kvm_arch->apic_access_page (Paolo Bonzini) [1140974]
- [virt] kvm/vmx: Implement set_apic_access_page_addr (Paolo Bonzini) [1140974]
- [virt] kvm: Add request bit to reload APIC access page address (Paolo Bonzini) [1140974]
- [virt] kvm: Add arch specific mmu notifier for page invalidation (Paolo Bonzini) [1140974]
- [virt] kvm: Rename make_all_cpus_request() to kvm_make_all_cpus_request() and make it non-static (Paolo Bonzini) [1140974]
- [virt] kvm: Remove ept_identity_pagetable from struct kvm_arch (Paolo Bonzini) [1140974]
- [virt] kvm: Use APIC_DEFAULT_PHYS_BASE macro as the apic access page address (Paolo Bonzini) [1140974]
- [drm] vmwgfx: respect 'nomodeset' (Rob Clark) [1101381]
- [s390] qeth: don't query for info if hardware not ready (Hendrik Brueckner) [1147573]
- [block] Fix dev_t minor allocation lifetime (Jeff Moyer) [1139898]
- [md] dm-crypt: fix access beyond the end of allocated space (Mike Snitzer) [1135066]
- [fs] isofs: unbound recursion when processing relocated directories (Jacob Tanenbaum) [1142271] {CVE-2014-5471 CVE-2014-5472}
- [ethernet] be2net: use v1 of SET_FLOW_CONTROL command (Ivan Vecera) [1087128]
- [acpi] return 1 after successfully install cmos_rtc space handler (Amos Kong) [1159465]
- [x86] hyperv: Bypass the timer_irq_works() check (Jason Wang) [1058105]
- [mm] hugetlb: initialize PG_reserved for tail pages of gigantic compound pages (Luiz Capitulino) [1158506]
- [kernel] cpuset: PF_SPREAD_PAGE and PF_SPREAD_SLAB should be atomic flags (Aaron Tomlin) [1160360]
- [infiniband] qib: Correct reference counting in debugfs qp_stats (Rui Wang) [1150001]
- [x86] uv: Check for alloc_cpumask_var() failures properly in uv_nmi_setup() (George Beshers) [1155754]
- [powerpc] fadump: Fix endianess issues in firmware assisted dump handling (Steve Best) [1159773]

* Mon Nov 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-201.el7]
- [scsi] ipr: wait for aborted command responses (Gustavo Duarte) [1156530]
- [ethernet] mlx4: Protect port type setting by mutex (Amir Vadai) [1095345]
- [acpi] pm: Only set power states of devices that are power manageable (Amos Kong) [1142683]
- [x86] setup: Mark Intel Haswell ULT as supported (Prarit Bhargava) [1159006]
- [kernel] sched: Fix unreleased llc_shared_mask bit during CPU hotplug (Takahiro MUNEDA) [1116294]
- [mm] do not walk all of system memory during show_mem (Johannes Weiner) [1125433]
- [mm] remove noisy remainder of the scan_unevictable interface (Johannes Weiner) [1111215]
- [pci] Rename sysfs 'enabled' file back to 'enable' (Myron Stowe) [1159655]
- [kernel] sched/fair: Care divide error in update_task_scan_period() (Motohiro Kosaki) [1140979]
- [powerpc] numa: ensure per-cpu NUMA mappings are correct on topology update (Gustavo Duarte) [1150097]
- [powerpc] numa: use cached value of update->cpu in update_cpu_topology (Gustavo Duarte) [1150097]
- [powerpc] numa: Add ability to disable and debug topology updates (Gustavo Duarte) [1150097]
- [powerpc] numa: check error return from proc_create (Gustavo Duarte) [1150097]
- [powerpc] some changes in numa_setup_cpu() (Gustavo Duarte) [1150097]
- [powerpc] Only set numa node information for present cpus at boottime (Gustavo Duarte) [1150097]
- [powerpc] Fix warning reported by verify_cpu_node_mapping() (Gustavo Duarte) [1150097]
- [powerpc] reorder per-cpu NUMA information's initialization (Gustavo Duarte) [1150097]
- [powerpc] pseries: Make CPU hotplug path endian safe (Steve Best) [1159579]
- [powerpc] pseries: Fix endian issues in cpu hot-removal (Steve Best) [1159579]
- [powerpc] pseries: Fix endian issues in onlining cpu threads (Steve Best) [1159579]
- [x86] smpboot: Fix up typo in topology detection (Prarit Bhargava) [1156655]
- [x86] smpboot: Add new topology for multi-NUMA-node CPUs (Prarit Bhargava) [1158269]
- [kernel] sched: Rework sched_domain topology definition (Prarit Bhargava) [1158269]
- [usb] hub: take hub->hdev reference when processing from eventlist (Don Zickus) [1151508]
- [usb] ehci: unlink QHs even after the controller has stopped (Don Zickus) [1151491]
- [tools] testing/selftests/powerpc: Correct DSCR during TM context switch (Gustavo Duarte) [1134511]
- [tools] testing/selftests: Add infrastructure for powerpc selftests (Gustavo Duarte) [1134511]
- [scsi] ibmvscsi: Abort init sequence during error recovery (Gustavo Duarte) [1105496]
- [scsi] ibmvscsi: Add memory barriers for send / receive (Gustavo Duarte) [1105496]
- [x86] fpu: __restore_xstate_sig()->math_state_restore() needs preempt_disable() (Oleg Nesterov) [1121784]
- [x86] fpu: shift drop_init_fpu() from save_xstate_sig() to handle_signal() (Oleg Nesterov) [1121784]

* Fri Nov 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-200.el7]
- [fs] ext4: fix wrong assert in ext4_mb_normalize_request() (Lukas Czerner) [1146046]
- [mm] Remove false WARN_ON from pagecache_isize_extended() (Lukas Czerner) [1156096]
- [fs] ext4: check s_chksum_driver when looking for bg csum presence (Lukas Czerner) [1156096]
- [fs] ext4: move error report out of atomic context in ext4_init_block_bitmap() (Lukas Czerner) [1156096]
- [fs] ext4: Replace open coded mdata csum feature to helper function (Lukas Czerner) [1156096]
- [fs] ext4: fix reservation overflow in ext4_da_write_begin (Lukas Czerner) [1156096]
- [fs] ext4: add ext4_iget_normal() which is to be used for dir tree lookups (Lukas Czerner) [1156096]
- [fs] ext4: don't orphan or truncate the boot loader inode (Lukas Czerner) [1156096]
- [fs] ext4: grab missed write_count for EXT4_IOC_SWAP_BOOT (Lukas Czerner) [1156096]
- [fs] ext4: get rid of code duplication (Lukas Czerner) [1156096]
- [fs] ext4: fix over-defensive complaint after journal abort (Lukas Czerner) [1156096]
- [fs] ext4: fix return value of ext4_do_update_inode (Lukas Czerner) [1156096]
- [fs] ext4: fix mmap data corruption when blocksize < pagesize (Lukas Czerner) [1156096]
- [fs] vfs: fix data corruption when blocksize < pagesize for mmaped data (Lukas Czerner) [1156096]
- [fs] ext4: don't check quota format when there are no quota files (Lukas Czerner) [1156096]
- [fs] jbd2: avoid pointless scanning of checkpoint lists (Lukas Czerner) [1156096]
- [fs] ext4: explicitly inform user about orphan list cleanup (Lukas Czerner) [1156096]
- [fs] jbd2: jbd2_log_wait_for_space improve error detetcion (Lukas Czerner) [1156096]
- [fs] jbd2: free bh when descriptor block checksum fails (Lukas Czerner) [1156096]
- [fs] ext4: check EA value offset when loading (Lukas Czerner) [1156096]
- [fs] ext4: don't keep using page if inline conversion fails (Lukas Czerner) [1156096]
- [fs] ext4: validate external journal superblock checksum (Lukas Czerner) [1156096]
- [fs] jbd2: fix journal checksum feature flag handling (Lukas Czerner) [1156096]
- [fs] ext4: provide separate operations for sysfs feature files (Lukas Czerner) [1156096]
- [fs] ext4: add sysfs entry showing whether the fs contains errors (Lukas Czerner) [1156096]
- [fs] ext4: renumber EXT4_EX_* flags to avoid flag aliasing problems (Lukas Czerner) [1156096]
- [fs] ext4: fix comments about get_blocks (Lukas Czerner) [1156096]
- [fs] ext4: fix accidental flag aliasing in ext4_map_blocks flags (Lukas Czerner) [1156096]
- [fs] ext4: fix ZERO_RANGE bug hidden by flag aliasing (Lukas Czerner) [1156096]
- [fs] ext4: use ext4_update_i_disksize instead of opencoded ones (Lukas Czerner) [1156096]
- [fs] ext4: remove a duplicate call in ext4_init_new_dir() (Lukas Czerner) [1156096]
- [fs] ext4: add missing BUFFER_TRACE before ext4_journal_get_write_access (Lukas Czerner) [1156096]
- [fs] ext4: check inline directory before converting (Lukas Czerner) [1156096]
- [fs] ext4: fix incorrect locking in move_extent_per_page (Lukas Czerner) [1156096]
- [fs] ext4: use correct depth value (Lukas Czerner) [1156096]
- [fs] ext4: add i_data_sem sanity check (Lukas Czerner) [1156096]
- [fs] ext4: fix wrong size computation in ext4_mb_normalize_request() (Lukas Czerner) [1156096]
- [fs] ext4: make ext4_has_inline_data() as a inline function (Lukas Czerner) [1156096]
- [fs] ext4: remove readpage() check in ext4_mmap_file() (Lukas Czerner) [1156096]
- [fs] ext4: remove metadata reservation checks (Lukas Czerner) [1156096]
- [fs] ext4: rearrange initialization to fix EXT4FS_DEBUG (Lukas Czerner) [1156096]
- [fs] ext4: fix potential null pointer dereference in ext4_free_inode (Lukas Czerner) [1156096]
- [fs] ext4: decrement free clusters/inodes counters when block group declared bad (Lukas Czerner) [1156096]
- [fs] ext4: handle symlink properly with inline_data (Lukas Czerner) [1156096]
- [fs] ext4: reduce contention on s_orphan_lock (Lukas Czerner) [1156096]
- [fs] ext4: use sbi in ext4_orphan_[add|del]() (Lukas Czerner) [1156096]
- [fs] ext4: remove unnecessary double parentheses (Lukas Czerner) [1156096]
- [fs] ext4: do not destroy ext4_groupinfo_caches if ext4_mb_init() fails (Lukas Czerner) [1156096]
- [fs] ext4: make local functions static (Lukas Czerner) [1156096]
- [fs] ext4: fix block bitmap validation when bigalloc, ^flex_bg (Lukas Czerner) [1156096]
- [fs] ext4: fix block bitmap initialization under sparse_super2 (Lukas Czerner) [1156096]
- [fs] ext4: find the group descriptors on a 1k-block bigalloc, meta_bg filesystem (Lukas Czerner) [1156096]
- [fs] ext4: avoid unneeded lookup when xattr name is invalid (Lukas Czerner) [1156096]
- [fs] ext4: remove obsoleted check (Lukas Czerner) [1156096]
- [fs] ext4: add a new spinlock i_raw_lock to protect the ext4's raw inode (Lukas Czerner) [1156096]
- [fs] ext4: revert Disable punch hole on non-extent mapped files (Lukas Czerner) [1150178]
- [fs] ext4: fix transaction issues for ext4_fallocate and ext_zero_range (Lukas Czerner) [1150171]
- [fs] ext4: move i_size, i_disksize update routines to helper function (Lukas Czerner) [1150171]
- [fs] ext4: fix incorect journal credits reservation in ext4_zero_range (Lukas Czerner) [1150171]
- [fs] ext4: fix COLLAPSE RANGE test for bigalloc file systems (Lukas Czerner) [1150171]
- [fs] ext4: fix punch hole on files with indirect mapping (Lukas Czerner) [1150171]
- [fs] ext4: Fix block zeroing when punching holes in indirect block files (Lukas Czerner) [1150171]
- [fs] ext4: fix ZERO_RANGE test failure in data journalling (Lukas Czerner) [1150171]
- [fs] ext4: use EXT_MAX_BLOCKS in ext4_es_can_be_merged() (Lukas Czerner) [1150171]
- [fs] ext4: rename uninitialized extents to unwritten (Lukas Czerner) [1150171]
- [fs] ext4: disable COLLAPSE_RANGE for bigalloc (Lukas Czerner) [1150171]
- [fs] ext4: fix COLLAPSE_RANGE failure with 1KB block size (Lukas Czerner) [1150171]
- [fs] ext4: use EINVAL if not a regular file in ext4_collapse_range() (Lukas Czerner) [1150171]
- [fs] ext4: enforce we are operating on a regular file in ext4_zero_range() (Lukas Czerner) [1150171]
- [fs] ext4: fix extent merging in ext4_ext_shift_path_extents() (Lukas Czerner) [1150171]
- [fs] ext4: discard preallocations after removing space (Lukas Czerner) [1150171]
- [fs] ext4: no need to truncate pagecache twice in collapse range (Lukas Czerner) [1150171]
- [fs] ext4: fix removing status extents in ext4_collapse_range() (Lukas Czerner) [1150171]
- [fs] ext4: use filemap_write_and_wait_range() correctly in collapse range (Lukas Czerner) [1150171]
- [fs] ext4: use truncate_pagecache() in collapse range (Lukas Czerner) [1150171]
- [fs] ext4: always check ext4_ext_find_extent result (Lukas Czerner) [1150171]
- [fs] ext4: COLLAPSE_RANGE only works on extent-based files (Lukas Czerner) [1150171]
- [fs] ext4: fix byte order problems introduced by the COLLAPSE_RANGE patches (Lukas Czerner) [1150171]
- [fs] ext4: disallow all fallocate operation on active swapfile (Lukas Czerner) [1150171]
- [fs] ext4: move falloc collapse range check into the filesystem methods (Lukas Czerner) [1150171]
- [fs] ext4: fix COLLAPSE_RANGE test failure in data journalling mode (Lukas Czerner) [1150171]
- [fs] ext4: remove unneeded test of ret variable (Lukas Czerner) [1150171]
- [fs] ext4: Introduce FALLOC_FL_ZERO_RANGE flag for fallocate (Lukas Czerner) [1150171]
- [fs] ext4: Introduce FALLOC_FL_ZERO_RANGE flag for fallocate (Lukas Czerner) [1150171]
- [fs] ext4: refactor ext4_fallocate code (Lukas Czerner) [1150171]
- [fs] ext4: Update inode i_size after the preallocation (Lukas Czerner) [1150171]
- [fs] ext4: Add new flag(FALLOC_FL_COLLAPSE_RANGE) for fallocate (Lukas Czerner) [1150171]
- [fs] ext4: Add support FALLOC_FL_COLLAPSE_RANGE for fallocate (Lukas Czerner) [1150171]

* Wed Nov 05 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-199.el7]
- [fs] quota: remove dqptr_sem (Lukas Czerner) [1053111]
- [fs] quota: simplify remove_inode_dquot_ref() (Lukas Czerner) [1053111]
- [fs] quota: avoid unnecessary dqget()/dqput() calls (Lukas Czerner) [1053111]
- [fs] quota: protect Q_GETFMT by dqonoff_mutex (Lukas Czerner) [1053111]
- [fs] xfs: add a few more verifier tests (Eric Sandeen) [1059330 1061656]
- [fs] pipe: skip file_update_time on frozen fs (Eric Sandeen) [1107499]
- [fs] xfs: don't sleep in xlog_cil_force_lsn on shutdown (Eric Sandeen) [1088240]
- [fs] buffer: increase the buffer-head per-CPU LRU size (Zach Brown) [1053108]
- [fs] fs: check bh blocknr earlier when searching lru (Zach Brown) [1053108]
- [fs] truncate: drop 'oldsize' truncate_pagecache() parameter (Lukas Czerner) [1150139]
- [fs] ext4: avoid trying to kfree an ERR_PTR pointer (Lukas Czerner) [1150139]
- [fs] ext4: fix same-dir rename when inline data directory overflows (Lukas Czerner) [1150139]
- [fs] jbd2: fix descriptor block size handling errors with journal_csum (Lukas Czerner) [1150139]
- [fs] jbd2: fix infinite loop when recovering corrupt journal blocks (Lukas Czerner) [1150139]
- [fs] ext4: update i_disksize coherently with block allocation on error path (Lukas Czerner) [1150139]
- [fs] ext4: fix BUG_ON in mb_free_blocks() (Lukas Czerner) [1150139]
- [fs] ext4: propagate errors up to ext4_find_entry()'s callers (Lukas Czerner) [1150139]
- [fs] ext4: fix ext4_discard_allocated_blocks() if we can't allocate the pa struct (Lukas Czerner) [1150139]
- [fs] ext4: fix a potential deadlock in __ext4_es_shrink() (Lukas Czerner) [1150139]
- [fs] ext4: revert commit which was causing fs corruption after journal replays (Lukas Czerner) [1150139]
- [fs] ext4: disable synchronous transaction batching if max_batch_time==0 (Lukas Czerner) [1150139]
- [fs] ext4: clarify ext4_error message in ext4_mb_generate_buddy_error() (Lukas Czerner) [1150139]
- [fs] ext4: clarify error count warning messages (Lukas Czerner) [1150139]
- [fs] ext4: fix unjournalled bg descriptor while initializing inode bitmap (Lukas Czerner) [1150139]
- [fs] ext4: Fix hole punching for files with indirect blocks (Lukas Czerner) [1150139]
- [fs] ext4: Fix buffer double free in ext4_alloc_branch() (Lukas Czerner) [1150139]
- [fs] ext4: fix zeroing of page during writeback (Lukas Czerner) [1150139]
- [fs] ext4: fix data integrity sync in ordered mode (Lukas Czerner) [1150139]
- [fs] ext4: get rid of EXT4_MAP_UNINIT flag (Lukas Czerner) [1150139]
- [fs] ext4: fix ext4_count_free_clusters() with EXT4FS_DEBUG and bigalloc enabled (Lukas Czerner) [1150139]
- [fs] ext4: silence sparse check warning for function ext4_trim_extent (Lukas Czerner) [1150139]
- [fs] ext4: use i_size_read in ext4_unaligned_aio() (Lukas Czerner) [1150139]
- [fs] ext4: move ext4_update_i_disksize() into mpage_map_and_submit_extent() (Lukas Czerner) [1150139]
- [fs] ext4: return ENOMEM rather than EIO when find_###_page() fails (Lukas Czerner) [1150139]
- [fs] ext4: update PF_MEMALLOC handling in ext4_write_inode() (Lukas Czerner) [1150139]
- [fs] ext4: fix jbd2 warning under heavy xattr load (Lukas Czerner) [1150139]
- [fs] ext4: note the error in ext4_end_bio() (Lukas Czerner) [1150139]
- [fs] ext4: initialize multi-block allocator before checking block descriptors (Lukas Czerner) [1150139]
- [fs] ext4: FIBMAP ioctl causes BUG_ON due to handle EXT_MAX_BLOCKS (Lukas Czerner) [1150139]
- [fs] ext4: fix 64-bit number truncation warning (Lukas Czerner) [1150139]
- [fs] ext4: fix premature freeing of partial clusters split across leaf blocks (Lukas Czerner) [1150139]
- [fs] ext4: rename: split out helper functions (Lukas Czerner) [1150139]
- [fs] ext4: rename: move EMLINK check up (Lukas Czerner) [1150139]
- [fs] ext4: rename: create ext4_renament structure for local vars (Lukas Czerner) [1150139]
- [fs] ext4: make ext4_block_zero_page_range static (Lukas Czerner) [1150139]
- [fs] ext4: atomically set inode->i_flags in ext4_set_inode_flags() (Lukas Czerner) [1150139]
- [fs] ext4: optimize Hurd tests when reading/writing inodes (Lukas Czerner) [1150139]
- [fs] ext4: kill i_version support for Hurd-castrated file systems (Lukas Czerner) [1150139]
- [fs] ext4: fix partial cluster handling for bigalloc file systems (Lukas Czerner) [1150139]
- [fs] ext4: delete path dealloc code in ext4_ext_handle_uninitialized_extents (Lukas Czerner) [1150139]
- [fs] jbd2: improve error messages for inconsistent journal heads (Lukas Czerner) [1150139]
- [fs] jbd2: minimize region locked by j_list_lock in jbd2_journal_forget() (Lukas Czerner) [1150139]
- [fs] jbd2: minimize region locked by j_list_lock in journal_get_create_access() (Lukas Czerner) [1150139]
- [fs] jbd2: check jh->b_transaction without taking j_list_lock (Lukas Czerner) [1150139]
- [fs] jbd2: add transaction to checkpoint list earlier (Lukas Czerner) [1150139]
- [fs] jbd2: calculate statistics without holding j_state_lock and j_list_lock (Lukas Czerner) [1150139]
- [fs] jbd2: don't hold j_state_lock while calling wake_up() (Lukas Czerner) [1150139]
- [fs] jbd2: don't unplug after writing revoke records (Lukas Czerner) [1150139]
- [fs] ext4: Speedup WB_SYNC_ALL pass called from sync(2) (Lukas Czerner) [1150139]
- [fs] ext4: translate fallocate mode bits to strings (Lukas Czerner) [1150139]
- [fs] ext4: merge uninitialized extents (Lukas Czerner) [1150139]
- [fs] ext4: avoid exposure of stale data in ext4_punch_hole() (Lukas Czerner) [1150139]
- [fs] ext4: silence warnings in extent status tree debugging code (Lukas Czerner) [1150139]
- [fs] ext4: remove unused ac_ex_scanned (Lukas Czerner) [1150139]
- [fs] ext4: avoid possible overflow in ext4_map_blocks() (Lukas Czerner) [1150139]
- [fs] ext4: make sure ex.fe_logical is initialized (Lukas Czerner) [1150139]
- [fs] ext4: don't calculate total xattr header size unless needed (Lukas Czerner) [1150139]
- [fs] ext4: add ext4_es_store_pblock_status() (Lukas Czerner) [1150139]
- [fs] ext4: fix error return from ext4_ext_handle_uninitialized_extents() (Lukas Czerner) [1150139]
- [fs] ext4: address a benign compiler warning (Lukas Czerner) [1150139]
- [fs] jbd2: mark file-local functions as static (Lukas Czerner) [1150139]
- [fs] ext4: remove an unneeded check in mext_page_mkuptodate() (Lukas Czerner) [1150139]
- [fs] ext4: clean up error handling in swap_inode_boot_loader() (Lukas Czerner) [1150139]
- [fs] ext4: Add __init marking to init_inodecache (Lukas Czerner) [1150139]
- [fs] ext4: don't leave i_crtime.tv_sec uninitialized (Lukas Czerner) [1150139]
- [fs] ext4: fix online resize with a non-standard blocks per group setting (Lukas Czerner) [1150139]
- [fs] ext4: fix online resize with very large inode tables (Lukas Czerner) [1150139]
- [fs] ext4: don't try to modify s_flags if the the file system is read-only (Lukas Czerner) [1150139]
- [fs] ext4: fix error paths in swap_inode_boot_loader() (Lukas Czerner) [1150139]
- [fs] ext4: fix xfstest generic/299 block validity failures (Lukas Czerner) [1150139]
- [fs] ext4: delete "set but not used" variables (Lukas Czerner) [1150139]
- [fs] ext4: don't pass freed handle to ext4_walk_page_buffers (Lukas Czerner) [1150139]
- [fs] ext4: avoid clearing beyond i_blocks when truncating an inline data file (Lukas Czerner) [1150139]
- [fs] ext4: ext4_inode_is_fast_symlink should use EXT4_CLUSTER_SIZE (Lukas Czerner) [1150139]
- [fs] ext4: fix a typo in extents.c (Lukas Czerner) [1150139]
- [fs] ext4: use pd printk specificer (Lukas Czerner) [1150139]
- [fs] ext4: standardize error handling in ext4_da_write_inline_data_begin() (Lukas Czerner) [1150139]
- [fs] ext4: retry allocation when inline->extent conversion failed (Lukas Czerner) [1150139]
- [fs] ext4: enable punch hole for bigalloc (Lukas Czerner) [1150139]
- [fs] ext4: fix bigalloc regression (Lukas Czerner) [1150139]
- [fs] ext4: add explicit casts when masking cluster sizes (Lukas Czerner) [1150139]
- [fs] ext4: fix deadlock when writing in ENOSPC conditions (Lukas Czerner) [1150139]
- [fs] jbd2: rename obsoleted msg JBD->JBD2 (Lukas Czerner) [1150139]
- [fs] jbd2: revise KERN_EMERG error messages (Lukas Czerner) [1150139]
- [fs] jbd2: don't BUG but return ENOSPC if a handle runs out of space (Lukas Czerner) [1150139]
- [fs] ext4: Do not reserve clusters when fs doesn't support extents (Lukas Czerner) [1150139]
- [fs] ext4: fix del_timer() misuse for ->s_err_report (Lukas Czerner) [1150139]
- [fs] ext4: check for overlapping extents in ext4_valid_extent_entries() (Lukas Czerner) [1150139]
- [fs] ext4: fix use-after-free in ext4_mb_new_blocks (Lukas Czerner) [1150139]
- [fs] ext4: call ext4_error_inode() if jbd2_journal_dirty_metadata() fails (Lukas Czerner) [1150139]
- [fs] ext4: add prototypes for macro-generated functions (Lukas Czerner) [1150139]
- [fs] ext4: return non-zero st_blocks for inline data (Lukas Czerner) [1150139]
- [fs] ext4: use prandom_u32() instead of get_random_bytes() (Lukas Czerner) [1150139]
- [fs] ext4: remove unreachable code after ext4_can_extents_be_merged() (Lukas Czerner) [1150139]
- [fs] ext4: remove unreachable code in ext4_can_extents_be_merged() (Lukas Czerner) [1150139]
- [fs] ext4: don't count free clusters from a corrupt block group (Lukas Czerner) [1150139]
- [fs] ext4: drop set but otherwise unused variable from ext4_add_dirent_to_inline() (Lukas Czerner) [1150139]
- [fs] ext4: change ext4_read_inline_dir() to return 0 on success (Lukas Czerner) [1150139]
- [fs] ext4: pair trace_ext4_writepages & trace_ext4_writepages_result (Lukas Czerner) [1150139]
- [fs] ext4: fix performance regression in ext4_writepages (Lukas Czerner) [1150139]
- [fs] ext4: fixup kerndoc annotation of mpage_map_and_submit_extent() (Lukas Czerner) [1150139]
- [fs] ext4: fix performance regression in writeback of random writes (Lukas Czerner) [1150139]
- [fs] ext4: allow specifying external journal by pathname mount option (Lukas Czerner) [1150139]
- [fs] ext4: mark group corrupt on group descriptor checksum (Lukas Czerner) [1150139]
- [fs] ext4: mark block group as corrupt on inode bitmap error (Lukas Czerner) [1150139]
- [fs] ext4: mark block group as corrupt on block bitmap error (Lukas Czerner) [1150139]
- [fs] jbd2: Fix endian mixing problems in the checksumming code (Lukas Czerner) [1150139]
- [fs] ext4: isolate ext4_extents.h file (Lukas Czerner) [1150139]
- [fs] ext4: Fix misspellings using 'codespell' tool (Lukas Czerner) [1150139]
- [fs] ext4: convert write_begin methods to stable_page_writes semantics (Lukas Czerner) [1150139]
- [fs] ext4: fix lost truncate due to race with writeback (Lukas Czerner) [1150139]
- [fs] ext4: fix ext4_writepages() in presence of truncate (Lukas Czerner) [1150139]
- [fs] ext4: move test whether extent to map can be extended to one place (Lukas Czerner) [1150139]
- [fs] ext4: avoid reusing recently deleted inodes in no journal mode (Lukas Czerner) [1150139]
- [fs] ext4: allocate delayed allocation blocks before rename (Lukas Czerner) [1150139]
- [fs] ext4: start handle at least possible moment when renaming files (Lukas Czerner) [1150139]
- [fs] ext4: add support for extent pre-caching (Lukas Czerner) [1150139]
- [fs] ext4: cache all of an extent tree's leaf block upon reading (Lukas Czerner) [1150139]
- [fs] ext4: use unsigned int for es_status values (Lukas Czerner) [1150139]
- [fs] ext4: print the block number of invalid extent tree blocks (Lukas Czerner) [1150139]
- [fs] ext4: refactor code to read the extent tree block (Lukas Czerner) [1150139]
- [fs] ext4: add WARN_ON to check the length of allocated blocks (Lukas Czerner) [1150139]
- [fs] ext4: call ext4_es_lru_add() after handling cache miss (Lukas Czerner) [1150139]
- [fs] ext4: make the extent_status code more robust against ENOMEM failures (Lukas Czerner) [1150139]
- [fs] ext4: simplify calculation of blocks to free on error (Lukas Czerner) [1150139]
- [fs] ext4: fix spelling errors and a comment in extent_status tree (Lukas Czerner) [1150139]
- [fs] ext4: fix warning in ext4_evict_inode() (Lukas Czerner) [1150139]
- [fs] ext4: optimize starting extent in ext4_ext_rm_leaf() (Lukas Czerner) [1150139]
- [fs] jbd2: invalidate handle if jbd2_journal_restart() fails (Lukas Czerner) [1150139]
- [fs] ext4: fix up error handling for mpage_map_and_submit_extent() (Lukas Czerner) [1150139]
- [fs] ext4: delete unnecessary C statements (Lukas Czerner) [1150139]
- [fs] ext4: pass inode pointer instead of file pointer to punch hole (Lukas Czerner) [1150139]
- [fs] ext4: improve free space calculation for inline_data (Lukas Czerner) [1150139]
- [fs] ext4: reduce object size when !CONFIG_PRINTK (Lukas Czerner) [1150139]
- [fs] ext4: improve extent cache shrink mechanism to avoid to burn CPU time (Lukas Czerner) [1150139]
- [fs] ext4: delete unused variables (Lukas Czerner) [1150139]
- [fs] jbd2: remove debug dependency on debug_fs and update Kconfig help text (Lukas Czerner) [1150139]
- [fs] jbd2: use a single printk for jbd_debug() (Lukas Czerner) [1150139]
- [fs] ext4: fix data integrity for ext4_sync_fs (Lukas Czerner) [1150139]
- [fs] jbd2: optimize jbd2_journal_force_commit (Lukas Czerner) [1150139]
- [fs] ext4: don't use EXT4_FREE_BLOCKS_FORGET unnecessarily (Lukas Czerner) [1150139]
- [fs] ext4: use ext4_da_writepages() for all modes (Lukas Czerner) [1150139]
- [fs] ext4: remove ext4_ioend_wait() (Lukas Czerner) [1150139]
- [fs] ext4: don't wait for extent conversion in ext4_punch_hole() (Lukas Czerner) [1150139]
- [fs] ext4: Remove wait for unwritten extents in ext4_ind_direct_IO() (Lukas Czerner) [1150139]
- [fs] ext4: remove i_mutex from ext4_file_sync() (Lukas Czerner) [1150139]
- [fs] ext4: use generic_file_fsync() in ext4_file_fsync() in nojournal mode (Lukas Czerner) [1150139]
- [fs] ext4: remove wait for unwritten extent conversion from ext4_truncate() (Lukas Czerner) [1150139]
- [fs] ext4: protect extent conversion after DIO with i_dio_count (Lukas Czerner) [1150139]
- [fs] ext4: defer clearing of PageWriteback after extent conversion (Lukas Czerner) [1150139]
- [fs] ext4: split extent conversion lists to reserved & unreserved parts (Lukas Czerner) [1150139]
- [fs] ext4: use transaction reservation for extent conversion in ext4_end_io (Lukas Czerner) [1150139]
- [fs] ext4: remove buffer_uninit handling (Lukas Czerner) [1150139]
- [fs] ext4: silence warning in ext4_writepages() (Lukas Czerner) [1150139]
- [fs] ext4: restructure writeback path (Lukas Czerner) [1150139]
- [fs] ext4: use io_end for multiple bios (Lukas Czerner) [1150139]
- [fs] ext4: better estimate credits needed for ext4_da_writepages() (Lukas Czerner) [1150139]
- [fs] ext4: improve writepage credit estimate for files with indirect blocks (Lukas Czerner) [1150139]
- [fs] ext4: deprecate max_writeback_mb_bump sysfs attribute (Lukas Czerner) [1150139]
- [fs] ext4: stop messing with nr_to_write in ext4_da_writepages() (Lukas Czerner) [1150139]
- [fs] ext4: provide wrappers for transaction reservation calls (Lukas Czerner) [1150139]
- [fs] jbd2: transaction reservation support (Lukas Czerner) [1150139]
- [fs] jbd2: cleanup needed free block estimates when starting a transaction (Lukas Czerner) [1150139]
- [fs] jbd2: remove outdated comment (Lukas Czerner) [1150139]
- [fs] jbd2: refine waiting for shadow buffers (Lukas Czerner) [1150139]
- [fs] jbd2: remove journal_head from descriptor buffers (Lukas Czerner) [1150139]
- [fs] jbd2: don't create journal_head for temporary journal buffers (Lukas Czerner) [1150139]
- [fs] ext4: suppress ext4 orphan messages on mount (Lukas Czerner) [1150139]
- [fs] jbd2: fix block tag checksum verification brokenness (Lukas Czerner) [1150139]
- [fs] jbd2: use kmem_cache_zalloc for allocating journal head (Lukas Czerner) [1150139]
- [fs] jbd2: Fix oops in jbd2_journal_file_inode() (Lukas Czerner) [1144326]
- [fs] ext4: only zero partial blocks in ext4_zero_partial_blocks() (Lukas Czerner) [1144326]
- [fs] ext4: make punch hole code path work with bigalloc (Lukas Czerner) [1144326]
- [fs] ext4: update ext4_ext_remove_space trace point (Lukas Czerner) [1144326]
- [fs] ext4: remove unused code from ext4_remove_blocks() (Lukas Czerner) [1144326]
- [fs] ext4: remove unused discard_partial_page_buffers (Lukas Czerner) [1144326]
- [fs] ext4: use ext4_zero_partial_blocks in punch_hole (Lukas Czerner) [1144326]
- [fs] ext4: truncate_inode_pages() in orphan cleanup path (Lukas Czerner) [1144326]
- [fs] Revert "ext4: fix fsx truncate failure" (Lukas Czerner) [1144326]
- [fs] ext4: Call ext4_jbd2_file_inode() after zeroing block (Lukas Czerner) [1144326]
- [fs] Revert "ext4: remove no longer used functions in inode.c" (Lukas Czerner) [1144326]
- [fs] mm: teach truncate_inode_pages_range() to handle non page aligned ranges (Lukas Czerner) [1144326]
- [fs] ext4: use ->invalidatepage() length argument (Lukas Czerner) [1144326]
- [fs] jbd2: change jbd2_journal_invalidatepage to accept length (Lukas Czerner) [1144326]
- [fs] mm: change invalidatepage prototype to accept length (Lukas Czerner) [1144326]
- [fs] nfs: Fix a bogus warning in nfs_generic_pgio (Steve Dickson) [1150227]
- [fs] nfs: Fix an uninitialised pointer Oops in the writeback error path (Steve Dickson) [1150227]

* Mon Nov 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-198.el7]
- [block] nvme: Clear QUEUE_FLAG_STACKABLE (David Milburn) [1155716]
- [md] dm-raid: ensure superblock's size matches device's logical block size (Mike Snitzer) [1112804]
- [md] dm-thin: refactor requeue_io to eliminate spinlock bouncing (Mike Snitzer) [1156164]
- [md] dm-thin: optimize retry_bios_on_resume (Mike Snitzer) [1156164]
- [md] dm-thin: sort the deferred cells (Mike Snitzer) [1156164]
- [md] dm-thin: direct dispatch when breaking sharing (Mike Snitzer) [1156164]
- [md] dm-thin: remap the bios in a cell immediately (Mike Snitzer) [1156164]
- [md] dm-thin: defer whole cells rather than individual bios (Mike Snitzer) [1156164]
- [md] dm-thin: factor out remap_and_issue_overwrite (Mike Snitzer) [1156164]
- [md] dm-thin: performance improvement to discard processing (Mike Snitzer) [1156164]
- [md] dm-thin: grab a virtual cell before looking up the mapping (Mike Snitzer) [1156164]
- [md] dm-thin: implement thin_merge (Mike Snitzer) [1156164]
- [md] dm: improve documentation and code clarity in dm_merge_bvec (Mike Snitzer) [1156164]
- [md] dm-thin: adjust max_sectors_kb based on thinp blocksize (Mike Snitzer) [1156164]
- [block] fix alignment_offset math that assumes io_min is a power-of-2 (Mike Snitzer) [1156164]
- [md] dm-thin: throttle incoming IO (Mike Snitzer) [1156161]
- [md] dm-thin: prefetch missing metadata pages (Mike Snitzer) [1156161]
- [md] dm-transaction-manager: add support for prefetching blocks of metadata (Mike Snitzer) [1156161]
- [md] dm-thin-metadata: change dm_thin_find_block to allow blocking, but not issuing, IO (Mike Snitzer) [1156161]
- [md] dm-bio-prison: switch to using a red black tree (Mike Snitzer) [1156161]
- [md] dm-bufio: evict buffers that are past the max age but retain some buffers (Mike Snitzer) [1156161]
- [md] dm-bufio: switch from a huge hash table to an rbtree (Mike Snitzer) [1156161]
- [md] dm-bufio: change __GFP_IO to __GFP_FS in shrinker callbacks (Mike Snitzer) [1156161]
- [md] dm-bufio: when done scanning return from __scan immediately (Mike Snitzer) [1156161]
- [md] dm-bufio: update last_accessed when relinking a buffer (Mike Snitzer) [1156161]
- [md] dm-bufio: fully initialize shrinker (Mike Snitzer) [1156161]
- [misc] genwqe: Remove unnecessary include (Gustavo Duarte) [1088491]
- [misc] genwqe: Increase driver version number (Gustavo Duarte) [1088491]
- [misc] genwqe: Improve hardware error recovery (Gustavo Duarte) [1088491]
- [misc] genwqe: Add support for EEH error recovery (Gustavo Duarte) [1088491]
- [misc] genwqe: Add sysfs interface for bitstream reload (Gustavo Duarte) [1088491]
- [misc] genwqe: fix uninitialized return value in genwqe_free_sync_sgl() (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix format string mismatch in card_debugfs.c (Gustavo Duarte) [1088491]
- [misc] genwqe: Increase driver version number (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix multithreading problems (Gustavo Duarte) [1088491]
- [misc] genwqe: Ensure rc is not returning an uninitialized value (Gustavo Duarte) [1088491]
- [misc] genwqe: Add wmb before DDCB is started (Gustavo Duarte) [1088491]
- [misc] genwqe: Enable access to VPD flash area (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix potential memory leak when pinning memory (Gustavo Duarte) [1088491]
- [misc] genwqe: delete non-required instances of include <linux/init.h> (Gustavo Duarte) [1088491]
- [misc] genwqe: fix return value check in genwqe_device_create() (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix warnings for sparc (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix compile problems for Alpha (Gustavo Duarte) [1088491]
- [misc] genwqe: Rework return code for flash-update ioctl (Gustavo Duarte) [1088491]
- [misc] genwqe: Accidently casting to u32 where u64 is required (Gustavo Duarte) [1088491]
- [misc] genwqe: Replace dynamic_hex_dump with print_hex_dump_debug (Gustavo Duarte) [1088491]
- [misc] genwqe: Fix endian issues detected by sparse (Gustavo Duarte) [1088491]
- [misc] genwqe: Enable driver (Gustavo Duarte) [1088491]
- [misc] genwqe: Sysfs interfaces (Gustavo Duarte) [1088491]
- [misc] genwqe: Debugfs interfaces (Gustavo Duarte) [1088491]
- [misc] genwqe: Utility functions (Gustavo Duarte) [1088491]
- [misc] genwqe: Character device and DDCB queue (Gustavo Duarte) [1088491]
- [misc] genwqe: GenWQE PCI support, health monitoring and recovery (Gustavo Duarte) [1088491]
- [virt] kvm/vmx: handle invvpid vm exit gracefully (Petr  Matousek) [1144829] {CVE-2014-3646}
- [virt] kvm: fix PIT timer race condition (Petr  Matousek) [1144880] {CVE-2014-3611}

* Thu Oct 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-197.el7]
- [scsi] qla2xxx: Update version number to 8.07.00.08.07.1-k1 (Chad Dupuis) [1067179]
- [scsi] qla2xxx: Disable PCI device in shutdown handler (Chad Dupuis) [1067179]
- [wireless] rt2x00: Delete accidentally committed .rej file (Prarit Bhargava) [1158457]
- [ethernet] cxgb4: Allow T4/T5 firmware sizes up to 1MB (Sai Vemuri) [1147683]
- [ethernet] cxgb4i: avoid holding mutex in interrupt context (Sai Vemuri) [1147683]
- [ethernet] cxgb4: Don't allocate adapter structure for all PF's (Sai Vemuri) [1147683]
- [ethernet] cxgb4: Add device ID for new adapter and remove for dbg adapter (Sai Vemuri) [1147683]
- [ethernet] cxgb4: Add warning msg when attaching to adapters which have FLASHes smaller than 2Mb (Sai Vemuri) [1147683]
- [ethernet] cxgb4: Fix t4_flash_erase_sectors() to throw an error when requested to erase sectors which aren't in the FLASH (Sai Vemuri) [1147683]
- [ethernet] cxgb4: Add support to S25FL032P flash (Sai Vemuri) [1147683]
- [ethernet] cxgb4vf: Call dev_kfree/consume_skb_any instead of [dev_]kfree_skb (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Turn off SGE RX/TX Callback Timers and interrupts in PCI shutdown routine (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Adds device ID for few more Chelsio T4 Adapters (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Check if rx checksum offload is enabled, while reading hardware calculated checksum (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Adds device Id for few more Chelsio adapters (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Use pci_enable_msix_range() instead of pci_enable_msix() (Sai Vemuri) [1070945]
- [ethernet] cxgb4vf: Remove superfluous call to pci_disable_msix() (Sai Vemuri) [1070945]
- [kernel] printk: bump LOG_BUF_SHIFT (Jeff Moyer) [1156189]
- [net] cdc_ncm: fix control message ordering (Neil Horman) [1129796]
- [net] usb/huawei_cdc_ncm: add "subclass 3" devices (Neil Horman) [1129796]
- [net] usb/cdc_ncm: remove non-standard NCM device IDs (Neil Horman) [1129796]
- [net] usb/huawei_cdc_ncm: increase command buffer size (Neil Horman) [1129796]
- [net] usb: Introduce the huawei_cdc_ncm driver (Neil Horman) [1129796]
- [powerpc] perf/hv-24x7: Simplify catalog_read() (Steve Best) [1155924]
- [acpi] container: Fix error code path in container_device_attach() (Prarit Bhargava) [1128634]
- [kernel] timekeeping: Use cached ntp_tick_length when accumulating error (Prarit Bhargava) [1136839]
- [kernel] timekeeping: Rework frequency adjustments to work better w/ nohz (Prarit Bhargava) [1136839]
- [s390] zcrypt: Toleration of new crypto hardware (Hendrik Brueckner) [1136494]
- [s390] zcrypt: support for extended number of ap domains (Hendrik Brueckner) [1136494]
- [kernel] smp: flush any pending IPI callbacks before CPU offline (Gustavo Duarte) [1100093]
- [kernel] smp: print more useful debug info upon receiving IPI on an offline CPU (Gustavo Duarte) [1100093]

* Tue Oct 28 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-196.el7]
- [ethernet] mlx5: Add ConnectX-4 to list of supported devices (Amir Vadai) [1149439]
- [fs] cifs: NULL pointer dereference in SMB2_tcon (Jacob Tanenbaum) [1147529] {CVE-2014-7145}
- [x86] build: Add arch/x86/purgatory/ make generated files to gitignore (Prarit Bhargava) [1155577]
- [acpi] acpica: Add "Windows 2013" string to _OSI support (Lenny Szubowicz) [1087674]
- [pci] Export MSI message relevant functions (Myron Stowe) [1123366]
- [cpufreq] store_scaling_governor requires policy->rwsem to be held for duration of changing governors (Prarit Bhargava) [1089255]
- [edac] sb_edac: avoid INTERNAL ERROR message in EDAC with unspecified channel (Seth Jennings) [1056990]
- [kernel] module: lock around setting of MODULE_STATE_UNFORMED (Prarit Bhargava) [1127741]
- [acpi] Add container online uevent to acpi_bus_attach (Prarit Bhargava) [1140572]
- [scsi] fcoe: Convert uses of compare_ether_addr to ether_addr_equal (Neil Horman) [1087099]
- [scsi] fcoe: Fix missing mutex_unlock in fcoe_sysfs_fcf_add error path (Neil Horman) [1087099]
- [scsi] fcoe: Make fcoe_sysfs optional / fix fnic NULL exception (Neil Horman) [1087099]
- [scsi] fcoe: fix build error (Neil Horman) [1087099]
- [scsi] fcoe: convert bus code to use bus_groups (Neil Horman) [1087099]
- [scsi] fcoe: Reduce fcoe_sysfs_fcf_add() stack usage (Neil Horman) [1087099]
- [scsi] fcoe: Add missing newlines in debug messages (Neil Horman) [1087099]
- [scsi] fcoe: Declare fcoe_ctlr_mode_set() static (Neil Horman) [1087099]
- [fs] gfs2: Hash the negative dentry during inode lookup (Robert S Peterson) [1123986]

* Mon Oct 27 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-195.el7]
- [block] fix blk_abort_request on blk-mq (Jeff Moyer) [1146660]
- [block] blk-timeout: fix blk_add_timer (Jeff Moyer) [1146660]
- [block] blk-mq: limit memory consumption if a crash dump is active (Jeff Moyer) [1146660]
- [block] blk-mq: remove unnecessary blk_clear_rq_complete() (Jeff Moyer) [1146660]
- [block] blk-mq: pass a reserved argument to the timeout handler (Jeff Moyer) [1146660]
- [block] blk-mq: unshared timeout handler (Jeff Moyer) [1146660]
- [block] blk-mq: fix and simplify tag iteration for the timeout handler (Jeff Moyer) [1146660]
- [block] blk-mq: rename blk_mq_end_io to blk_mq_end_request (Jeff Moyer) [1146660]
- [block] blk-mq: call blk_mq_start_request from ->queue_rq (Jeff Moyer) [1146660]
- [block] blk-mq: remove REQ_END (Jeff Moyer) [1146660]
- [block] blk-mq: use blk_mq_start_hw_queues() when running requeue work (Jeff Moyer) [1146660]
- [block] blk-mq: fix potential oops on out-of-memory in __blk_mq_alloc_rq_maps() (Jeff Moyer) [1146660]
- [block] blk-mq: avoid infinite recursion with the FUA flag (Jeff Moyer) [1146660]
- [block] blk-mq: Avoid race condition with uninitialized requests (Jeff Moyer) [1146660]
- [block] blk-mq: request deadline must be visible before marking rq as started (Jeff Moyer) [1146660]
- [block] blk-mq: scale depth and rq map appropriate if low on memory (Jeff Moyer) [1146660]
- [block] blk-mq: cleanup after blk_mq_init_rq_map failures (Jeff Moyer) [1146660]
- [block] fix unbalanced bypass-disable in blk_register_queue (Jeff Moyer) [1146660]
- [block] bdi: an active gendisk always has a request_queue associated with it (Jeff Moyer) [1146660]
- [block] blk-mq: pass along blk_mq_alloc_tag_set return values (Jeff Moyer) [1146660]
- [block] blk-merge: fix blk_recount_segments (Jeff Moyer) [1146660]
- [block] blk-mq: correct a few wrong/bad comments (Jeff Moyer) [1146660]
- [block] blk-mq: don't allow merges if turned off for the queue (Jeff Moyer) [1146660]
- [block] blk-mq: fix WARNING "percpu_ref_kill() called more than once!" (Jeff Moyer) [1146660]
- [block] provide compat ioctl for BLKZEROOUT (Jeff Moyer) [1146660]
- [block] blkcg: don't call into policy draining if root_blkg is already gone (Jeff Moyer) [1146660]
- [block] don't assume last put of shared tags is for the host (Jeff Moyer) [1146660]
- [block] fix SG_[GS]ET_RESERVED_SIZE ioctl when max_sectors is huge (Jeff Moyer) [1146660]
- [block] fix BLKSECTGET ioctl when max_sectors is greater than USHRT_MAX (Jeff Moyer) [1146660]
- [block] blk-mq: collapse __blk_mq_drain_queue() into blk_mq_freeze_queue() (Jeff Moyer) [1146660]
- [block] blk-mq: decouble blk-mq freezing from generic bypassing (Jeff Moyer) [1146660]
- [block] blk-mq: draining can't be skipped even if bypass_depth was non-zero (Jeff Moyer) [1146660]
- [block] blk-mq: fix a memory ordering bug in blk_mq_queue_enter() (Jeff Moyer) [1146660]

* Fri Oct 24 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-194.el7]
- [fs] xfs: flush the range before zero range conversion (Eric Sandeen) [1145837]
- [fs] xfs: only set extent size hint when asked (Eric Sandeen) [1145837]
- [fs] xfs: project id inheritance is a directory only flag (Eric Sandeen) [1145837]
- [fs] xfs: use ranged writeback and invalidation for direct IO (Eric Sandeen) [1145837]
- [fs] xfs: don't zero partial page cache pages during O_DIRECT writes (Eric Sandeen) [1145837]
- [fs] xfs: don't zero partial page cache pages during O_DIRECT reads (Eric Sandeen) [1130294 1145837]
- [fs] xfs: don't dirty buffers beyond EOF (Eric Sandeen) [1145837]
- [fs] xfs: fix coccinelle warnings (Eric Sandeen) [1145837]
- [fs] xfs: flush both inodes in xfs_swap_extents (Eric Sandeen) [1145837]
- [fs] xfs: fix swapext ilock deadlock (Eric Sandeen) [1145837]
- [fs] xfs: dquot recovery needs verifiers (Eric Sandeen) [1145837]
- [fs] xfs: quotacheck leaves dquot buffers without verifiers (Eric Sandeen) [1145837]
- [fs] xfs: ensure verifiers are attached to recovered buffers (Eric Sandeen) [1145837]
- [fs] xfs: catch buffers written without verifiers attached (Eric Sandeen) [1145837]
- [fs] xfs: avoid false quotacheck after unclean shutdown (Eric Sandeen) [1145837]
- [fs] xfs: fix rounding error of fiemap length parameter (Eric Sandeen) [1145837]
- [fs] xfs: fix uflags detection at xfs_fs_rm_xquota (Eric Sandeen) [1145837]
- [fs] xfs: fix cil push sequence after log recovery (Eric Sandeen) [1145837]
- [fs] xfs: squash prealloc while over quota free space as well (Eric Sandeen) [1145837]
- [fs] xfs: run an eofblocks scan on ENOSPC/EDQUOT (Eric Sandeen) [1145837]
- [fs] xfs: support a union-based filter for eofblocks scans (Eric Sandeen) [1145837]
- [fs] xfs: add scan owner field to xfs_eofblocks (Eric Sandeen) [1145837]
- [fs] xfs: fix a couple error sequence jumps in xfs_mountfs() (Eric Sandeen) [1145837]
- [fs] xfs: null unused quota inodes when quota is on (Eric Sandeen) [1145837]
- [fs] xfs: refine the allocation stack switch (Eric Sandeen) [1145837]
- [fs] xfs: Fix rounding in xfs_alloc_fix_len() (Eric Sandeen) [1145837]
- [fs] xfs: tone down writepage/releasepage WARN_ONs (Eric Sandeen) [1145837]
- [fs] xfs: remove redundant checks from xfs_da_read_buf (Eric Sandeen) [1145837]
- [fs] xfs: keep sb_bad_features2 the same a sb_features2 (Eric Sandeen) [1145837]
- [fs] xfs: negate xfs_icsb_init_counters error value (Eric Sandeen) [1145837]
- [fs] xfs: negate mount workqueue init error value (Eric Sandeen) [1145837]
- [fs] xfs: fix wrong errno from xfs_initxattrs (Eric Sandeen) [1145837]
- [fs] xfs: xfs_commit_metadata returns wrong errno (Eric Sandeen) [1145837]
- [fs] xfs: fix incorrect error sign in xfs_file_aio_read (Eric Sandeen) [1145837]
- [fs] xfs: xfs_dir_fsync() returns positive errno (Eric Sandeen) [1145837]
- [fs] xfs: fix directory readahead offset off-by-one (Eric Sandeen) [1145837]
- [fs] xfs: remote attribute overwrite causes transaction overrun (Eric Sandeen) [1145837]
- [fs] xfs: Fix wrong error codes being returned (Eric Sandeen) [1145837]
- [fs] xfs: bulletfproof xfs_qm_scall_trunc_qfiles() (Eric Sandeen) [1145837]
- [fs] xfs: fix Q_XQUOTARM ioctl (Eric Sandeen) [1145837]
- [fs] xfs: fully support v5 format filesystems (Eric Sandeen) [1145837]
- [fs] xfs: wrong error sign conversion during failed DIO writes (Eric Sandeen) [1145837]
- [fs] xfs: unmount does not wait for shutdown during unmount (Eric Sandeen) [1145837]
- [fs] xfs: don't map ranges that span EOF for direct IO (Eric Sandeen) [1145837]
- [fs] xfs: zeroing space needs to punch delalloc blocks (Eric Sandeen) [1145837]
- [fs] xfs: kill buffers over failed write ranges properly (Eric Sandeen) [1145837]
- [fs] xfs: extra semi-colon breaks a condition (Eric Sandeen) [1145837]
- [fs] xfs: xfs_check_page_type buffer checks need help (Eric Sandeen) [1145837]
- [wireless] Backport mwl8k driver from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport mwifiex driver from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport brcm80211 drivers from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport rtlwifi drivers from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport rt2x00 driver from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport ath drivers from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport iwlegacy drivers from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport iwlwifi driver from linux 3.16 (Stanislaw Gruszka) [1085079 1107878 1136324]
- [wireless] Backport mac80211 from linux 3.16 (Stanislaw Gruszka) [1136324]
- [wireless] Backport wireless core from linux 3.16 (Stanislaw Gruszka) [1136324]
- [kernel] if_ether: add IEEE 802.21 Ethertype (Stanislaw Gruszka) [1136324]
- [kernel] PTR_RET is now PTR_ERR_OR_ZERO (Stanislaw Gruszka) [1136324]
- [net] etherdevice: Add ether_addr_equal_unaligned (Stanislaw Gruszka) [1136324]

* Thu Oct 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-193.el7]
- [net] ipv4: fix a race in update_or_create_fnhe() (Hannes Frederic Sowa) [1155155]
- [net] ipv4: irq safe sk_dst_[re]set() and ipv4_sk_update_pmtu() fix (Hannes Frederic Sowa) [1155155]
- [net] ipv4: fix dst race in sk_dst_get() (Hannes Frederic Sowa) [1155155]
- [net] ipv4: fix a race in ip4_datagram_release_cb() (Hannes Frederic Sowa) [1155155]
- [net] sctp: fix remote memory pressure from excessive queueing (Daniel Borkmann) [1152755] {CVE-2014-3688}
- [net] sctp: fix panic on duplicate ASCONF chunks (Daniel Borkmann) [1152755] {CVE-2014-3687}
- [net] sctp: fix skb_over_panic when receiving malformed ASCONF chunks (Daniel Borkmann) [1152755] {CVE-2014-3673}
- [net] sctp: handle association restarts when the socket is closed (Daniel Borkmann) [1152755]
- [net] ipv4: fix nexthop attlen check in fib_nh_match (Jiri Pirko) [1153654]
- [net] packet: handle too big packets for PACKET_V3 (Hannes Frederic Sowa) [1152248]
- [net] sendmsg: fix NULL pointer dereference (Hannes Frederic Sowa) [1152251]
- [net] ipv6: remove rt6i_genid (Hannes Frederic Sowa) [1150017]
- [net] ipv6: remove prune parameter for fib6_clean_all (Hannes Frederic Sowa) [1150017]
- [net] ipv6: bump genid when delete/add address (Hannes Frederic Sowa) [1150017]
- [net] split rt_genid for ipv4 and ipv6 (Hannes Frederic Sowa) [1150017]
- [net] ipv4: use separate genid for next hop exceptions (Hannes Frederic Sowa) [1150017]
- [net] ipv4: properly refresh rtable entries on pmtu/redirect events (Hannes Frederic Sowa) [1150017]
- [net] bridge: Don't include NDA_VLAN for FDB entries with vid 0 (Vlad Yasevich) [1139809]
- [net] bridge: Prevent insertion of FDB entry with disallowed vlan (Vlad Yasevich) [1139809]
- [net] bridge: Fix double free and memory leak around br_allowed_ingress (Vlad Yasevich) [1139809]
- [net] bridge: Fix crash with vlan filtering and tcpdump (Vlad Yasevich) [1139809]
- [net] bridge: Fix handling stacked vlan tags (Vlad Yasevich) [1139809]
- [net] bridge: Fix inabillity to retrieve vlan tags when tx offload is disabled (Vlad Yasevich) [1139809]
- [net] bridge: Use RCU_INIT_POINTER(x, NULL) in br_vlan.c (Vlad Yasevich) [1139809]
- [net] bridge: Remove unnecessary vlan_put_tag in br_handle_vlan (Vlad Yasevich) [1139809]
- [net] bridge: use list_for_each_entry_continue_reverse (Vlad Yasevich) [896669]
- [net] bridge: Fix incorrect judgment of promisc (Vlad Yasevich) [896669]
- [net] bridge: fix the unbalanced promiscuous count when add_if failed (Vlad Yasevich) [896669]
- [net] bridge: fix spelling of promiscuous (Vlad Yasevich) [896669]
- [net] bridge: fix build (Vlad Yasevich) [896669]
- [net] bridge: Automatically manage port promiscuous mode (Vlad Yasevich) [896669]
- [net] bridge: Add addresses from static fdbs to non-promisc ports (Vlad Yasevich) [896669]
- [net] bridge: Introduce BR_PROMISC flag (Vlad Yasevich) [896669]
- [net] bridge: Add functionality to sync static fdb entries to hw (Vlad Yasevich) [896669]
- [net] bridge: Keep track of ports capable of automatic discovery (Vlad Yasevich) [896669]
- [net] bridge: Turn flag change macro into a function (Vlad Yasevich) [896669]
- [net] bridge: Add a flag to control unicast packet flood (Vlad Yasevich) [896669]
- [net] bridge: Add flag to control mac learning (Vlad Yasevich) [896669]

* Thu Oct 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-192.el7]
- [infiniband] ocrdma: convert kernel va to pa for mmap in user (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: use right macro in query ah (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: resolve L2 address when creating user AH (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: get vlan tag from ib_qp_attrs (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: add default gid at index 0 (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: do not skip setting deffered_arm (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Report actual value of max_fast_reg_page_list_len (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: report asic-id in query device (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Update sli data structure for endianness (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Obtain SL from device structure (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Update the ocrdma module version string (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Fix a sparse warning (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Initialize the GID table while registering the device (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Increase the size of STAG array in dev structure to 16K (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Add missing adapter mailbox opcodes (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Return proper value for max_mr_size (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Do proper cleanup even if FW is in error state (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Allow only SEND opcode in case of UD QPs (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Avoid reporting wrong completions in case of error CQEs (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Delete AH table if ocrdma_init_hw fails after AH table creation (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Remove hardcoding of the max DPP QPs supported (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Handle shutdown event from be2net driver (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Add hca_type and fixing fw_version string in device atrributes (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Query and initalize the PFC SL (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Avoid posting DPP requests for RDMA READ (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Convert to use simple_open() (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Unregister inet notifier when unloading ocrdma (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Fix warnings about pointer <-> integer casts (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Code clean-up (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Display FW version (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Query controller information (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Support non-embedded mailbox commands (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Handle CQ overrun error (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Display proper value for max_mw (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Use non-zero tag in SRQ posting (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Memory leak fix in ocrdma_dereg_mr() (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Increment abi version count (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Update version string (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: ABI versioning between ocrdma and be2net (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Allow DPP QP creation (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Read ASIC_ID register to select asic_gen (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: SQ and RQ doorbell offset clean up (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: EQ full catastrophe avoidance (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Fix load time panic during GID table init (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Fix traffic class shift (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Add dependency on INET (Doug Ledford) [1081067 1088577]
- [infiniband] ocrdma: Move ocrdma_inetaddr_event outside of "#if CONFIG_IPV6" (Doug Ledford) [1081067 1088577]
- [mm] thp: do not allow thp faults to avoid cpuset restrictions (Frank Ramsay) [1149786]
- [mm] thp: add VM_INIT_DEF_MASK and PRCTL_THP_DISABLE (Frank Ramsay) [1149786]
- [fs] exec: kill the unnecessary mm->def_flags setting in load_elf_binary() (Frank Ramsay) [1149786]
- [mm] Revert: thp: make MADV_HUGEPAGE check for mm->def_flags (Frank Ramsay) [1149786]
- [block] disable entropy contributions for nonrot devices (Mike Snitzer) [852425]
- [crypto] qat: Enforce valid numa configuration (Nikolay Aleksandrov) [1152642]
- [crypto] qat: Prevent dma mapping zero length assoc data (Nikolay Aleksandrov) [1152642]
- [pci] Add ACS quirk for Intel 10G NICs (Alex Williamson) [1141399]
- [pci] Add ACS quirk for Solarflare SFC9120 & SFC9140 (Alex Williamson) [1131552]
- [infiniband] ipoib: validate struct ipoib_cb size (Doug Ledford) [1107621 1140601]
- [infiniband] ipoib: No longer use flush as a parameter (Doug Ledford) [1107621]
- [infiniband] ipoib: Make ipoib_mcast_stop_thread flush the workqueue (Doug Ledford) [1107621]
- [infiniband] ipoib: Use dedicated workqueues per interface (Doug Ledford) [1107621]
- [infiniband] ipoib: change init sequence ordering (Doug Ledford) [1107621]
- [infiniband] ipoib: fix mcast_dev_flush/mcast_restart_task race (Doug Ledford) [1107621]
- [infiniband] ipoib: fix MCAST_FLAG_BUSY usage (Doug Ledford) [1107621]
- [infiniband] ipoib: Make the carrier_on_task race aware (Doug Ledford) [1107621]
- [infiniband] ipoib: Consolidate rtnl_lock tasks in workqueue (Doug Ledford) [1107621]
- [infiniband] ipoib: Remove unnecessary test for NULL before debugfs_remove() (Doug Ledford) [1107621]
- [infiniband] ipoib: Avoid multicast join attempts with invalid P_key (Doug Ledford) [1107621]
- [infiniband] ipoib: Avoid flushing the workqueue from worker context (Doug Ledford) [1107621]
- [infiniband] ipoib: Use P_Key change event instead of P_Key polling mechanism (Doug Ledford) [1107621]
- [infiniband] ipoib: Report operstate consistently when brought up without a link (Doug Ledford) [1107621]
- [net] svcrdma: remove rdma_create_qp() failure recovery logic (Doug Ledford) [1107621]
- [net] svcrdma: send_write() must not overflow the device's max sge (Doug Ledford) [1107621]
- [net] svcrdma: Fence LOCAL_INV work requests (Doug Ledford) [1107621]
- [net] svcrdma: refactor marshalling logic (Doug Ledford) [1107621]
- [net] sunrpc: Fix regression in NFSRDMA server (Doug Ledford) [1107621]
- [net] svcrdma: fix printk when memory allocation fails (Doug Ledford) [1107621]
- [kernel] uapi: Include socket.h in rdma_user_cm.h (Doug Ledford) [1107621]
- [infiniband] Return error for unsupported QP creation flags (Doug Ledford) [1107621]
- [infiniband] Allow build of hw/ and ulp/ subdirectories independently (Doug Ledford) [1107621]
- [infiniband] ehca: Returns an error on ib_copy_to_udata() failure (Doug Ledford) [1107621]
- [net] sched: shrink struct qdisc_skb_cb to 28 bytes (Doug Ledford) [1107621 1140601]

* Tue Oct 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-191.el7]
- [fs] fuse: ignore entry-timeout LOOKUP_REVAL (Carlos Maiolino) [1124880]
- [fs] fuse: Timeout comparison fix (Carlos Maiolino) [1128802]
- [fs] lockd: Try to reconnect if statd has moved (Benjamin Coddington) [1120850]
- [fs] sunrpc: Don't wake tasks during connection abort (Benjamin Coddington) [1120850]
- [fs] Revert: writeback: do not sync data dirtied after sync start (Brian Foster [1085828]
- [fs] nfsd4: fix corruption of NFSv4 read data ("J. Bruce Fields") [1148055]
- [fs] gfs2: revert "GFS2: d_splice_alias() can't return error" (Robert S Peterson) [1141899]

* Mon Oct 20 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-190.el7]
- [scsi] mpt3sas: Use pci_enable_msix_exact() instead of pci_enable_msix() (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Use pci_enable_msix_exact() instead of pci_enable_msix() (Tomas Henzl) [1088524]
- [scsi] mpt2sas: fix undefined reference to `__udivdi3' compilation errors (Tomas Henzl) [1088524]
- [scsi] mpt3sas, mpt2sas: fix scsi_add_host error handling problems in _scsih_probe (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Bump mpt3sas driver version to 04.100.00.00 (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Added Reply Descriptor Post Queue (RDPQ) Array support (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Added OEM branding Strings (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Copyright in driver sources is updated for year the 2014 (Tomas Henzl) [1088524]
- [scsi] mpt3sas: MPI2.5 Rev H (2.5.3) specifications (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Bump mpt3sas driver version to 03.100.00.00 (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Clear PFA Status on SGPIO when PFA Drive is Removed or Replaced (Tomas Henzl) [1088524]
- [scsi] mpt3sas: MPI2.5 Rev G (2.5.2) specifications (Tomas Henzl) [1088524]
- [scsi] mpt3sas: delay scsi_add_host call to work with scsi-mq (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Rework the MSI-X grouping code (Tomas Henzl) [1088524]
- [scsi] mpt3sas: combine fw_event_work and its event_data (Tomas Henzl) [1088524]
- [scsi] mpt3sas: correct scsi_(target, device) hostdata allocation (Tomas Henzl) [1088524]
- [scsi] mpt3sas: Remove phys on topology change (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Bump mpt2sas driver version to 18.100.00.00 (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Get IOC_FACTS information using handshake protocol only after HBA card gets into READY or Operational state (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Added Reply Descriptor Post Queue (RDPQ) Array support (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Avoid type casting for direct I/O commands (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Bump mpt2sas driver version to 17.100.00.00 (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Clear PFA Status on SGPIO when PFA Drive is Removed or Replaced (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Copyright in driver sources is updated for year the 2014 (Tomas Henzl) [1088524]
- [scsi] mpt2sas: MPI2 Rev Y (2.00.17) and Rev Z (2.00.18) specifications (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Added driver module parameter max_msix_vectors (Tomas Henzl) [1088524]
- [scsi] mpt2sas: delay scsi_add_host call to work with scsi-mq (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Rework the MSI-X grouping code (Tomas Henzl) [1088524]
- [scsi] mpt2sas: annotate ioc->reply_post_host_index as __iomem (Tomas Henzl) [1088524]
- [scsi] mpt2sas: combine fw_event_work and its event_data (Tomas Henzl) [1088524]
- [scsi] mpt2sas: correct scsi_(target, device) hostdata allocation (Tomas Henzl) [1088524]
- [scsi] mpt2sas: Don't disable device twice at suspend (Tomas Henzl) [1088524]

* Fri Oct 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-189.el7]
- [scsi] lpfc: driver release 10.2.8021.1 for RHEL7 (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fixed crash from page fault caused by use after rport delete (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fix locking issues with abort data paths (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fix race between LOGO/PLOGI handling causing NULL pointer (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fix IP Reset processing - wait for RDY before proceeding (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fix quarantined XRI recovery qualifier state in link bounce (Rob Evers) [1149846]
- [scsi] lpfc: 10.4.8000.0: Fix discovery timeout during nameserver login (Rob Evers) [1149846]
- [net] ipv6: mld: answer mldv2 queries with mldv1 reports in mldv1 fallback (Daniel Borkmann) [1143429]
- [net] team: avoid race condition in scheduling delayed work (Jiri Pirko) [1149239]
- [net] fix UDP tunnel GSO of frag_list GRO packets (Jiri Benc) [1119392]
- [net] vxlan: fix incorrect initializer in union vxlan_addr (Daniel Borkmann) [1130643]
- [net] vxlan: fix crash when interface is created with no group (Daniel Borkmann) [1130643]
- [net] vxlan: fix nonfunctional neigh_reduce() (Daniel Borkmann) [1130643]
- [net] vxlan: fix potential NULL dereference in arp_reduce() (Daniel Borkmann) [1130643]
- [net] vxlan: remove unused port variable in vxlan_udp_encap_recv() (Daniel Borkmann) [1130643]
- [net] vxlan: remove extra newline after function definition (Daniel Borkmann) [1130643]

* Mon Oct 13 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-188.el7]
- [kernel] workqueue: Add quiescent state between work items (Jiri Pirko) [1149250]
- [crypto] qat: Enable interrupts from all 32 bundles (Nikolay Aleksandrov) [1091130]
- [char] ipmi: Clear drvdata when interface is removed (Tony Camuso) [1136589]
- [md] raid5: disable 'DISCARD' by default due to safety concerns (Jes Sorensen) [1149931]
- [md] raid1: fix_read_error should act on all non-faulty devices (Jes Sorensen) [1149931]
- [virt] hyperv: NULL dereference on error (Jason Wang) [1146357]
- [virt] hyperv: Increase the buffer length for netvsc_channel_cb() (Jason Wang) [1146357]
- [virt] hyperv: Adjust the size of sendbuf region to support ws2008r2 (Jason Wang) [1146357]
- [virt] hyperv/net: Increase the size of the sendbuf region (Jason Wang) [1146357]
- [virt] hyperv: Fix error return code in netvsc_init_buf() (Jason Wang) [1146357]
- [virt] hyperv: Add netpoll support (Jason Wang) [1146357]
- [virt] hyperv/net: remove unnecessary null test before kfree (Jason Wang) [1146357]
- [virt] hyperv: Add handler for RNDIS_STATUS_NETWORK_CHANGE event (Jason Wang) [1146357]
- [virt] hyperv: fix apparent cut-n-paste error in send path teardown (Jason Wang) [1146357]
- [virt] hyperv: Add hash value into RNDIS Per-packet info (Jason Wang) [1146357]
- [virt] hyperv/net: Add support for netvsc build without CONFIG_SYSFS flag (Jason Wang) [1146357]
- [virt] hyperv: Properly handle checksum offload (Jason Wang) [1146357]
- [virt] hyperv: Enable sendbuf mechanism on the send path (Jason Wang) [1146357]
- [virt] hyperv: Simplify the send_completion variables (Jason Wang) [1146357]
- [virt] hyperv: Remove recv_pkt_list and lock (Jason Wang) [1146357]
- [virt] hyperv: Add support for virtual Receive Side Scaling (vRSS) (Jason Wang) [1146357]
- [virt] hyperv/net: Address UDP checksum issues (Jason Wang) [1146357]
- [virt] hyperv/net: Negotiate suitable ndis version for offload support (Jason Wang) [1146357]
- [virt] hyperv/net: Allocate memory for all possible per-pecket information (Jason Wang) [1146357]
- [virt] hyperv/net: Enable large send offload (Jason Wang) [1146357]
- [virt] hyperv/net: Enable send side checksum offload (Jason Wang) [1146357]
- [virt] hyperv/net: Enable receive side IP checksum offload (Jason Wang) [1146357]
- [virt] hyperv/net: Enable offloads on the host (Jason Wang) [1146357]
- [virt] hyperv/net: Cleanup the send path (Jason Wang) [1146357]
- [virt] hyperv/net: Enable scatter gather I/O (Jason Wang) [1146357]
- [virt] hyperv: Move state setting for link query (Jason Wang) [1146357]
- [virt] hyperv: Add latest NetVSP versions to auto negotiation (Jason Wang) [1146357]
- [virt] hyperv/net: Cleanup the netvsc receive callback functio (Jason Wang) [1146357]
- [virt] hyperv/net: Cleanup the receive path (Jason Wang) [1146357]
- [virt] hyperv/net: Get rid of the rndis_filter_packet structure (Jason Wang) [1146357]
- [virt] hyperv: Fix the carrier status setting (Jason Wang) [1146357]
- [virt] hyperv/util: Fix a bug in the KVP code (Jason Wang) [1102584]
- [virt] hyperv/vmbus: Fix a bug in the channel callback dispatch code (Jason Wang) [1146357]
- [virt] hyperv: remove meaningless pr_err() in vmbus_recvpacket_raw() (Jason Wang) [1146357]
- [virt] tools/hyperv: Handle the case when the target file exists correctly (Jason Wang) [1146358]
- [virt] hyperv/hv_fcopy: fix a race condition for SMP guest (Jason Wang) [1146358]
- [virt] hyperv: fcopy_open() can be static (Jason Wang) [1146358]
- [virt] hyperv: Implement the file copy service (Jason Wang) [1146358]
- [virt] hyperv: Add hyperv.h to uapi headers (Jason Wang) [1146358]
- [virt] hyperv/vmbus: Fix a bug in vmbus_open() (Jason Wang) [1146358]
- [virt] hyperv/vmbus: Properly protect calls to smp_processor_id() (Jason Wang) [1146358]
- [virt] hyperv: Remove unnecessary comparison of unsigned against 0 (Jason Wang) [1146358]
- [virt] hyperv/vmbus: Implement per-CPU mapping of relid to channel (Jason Wang) [1146358]
- [virt] hyperv: Eliminate the channel spinlock in the callback path (Jason Wang) [1146358]
- [virt] hyperv/vmbus: Support per-channel driver state (Jason Wang) [1146358]

* Fri Oct 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-187.el7]
- [ethernet] qlcnic: Remove duplicate object file from Makefile (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Initialize dcbnl_ops before register_netdev (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Set driver version before registering netdev (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix update of ethtool stats (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.61 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance Tx timeout debug data collection (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.60 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Optimize ring count validations (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Pre-allocate DMA buffer used for minidump collection (Chad Dupuis) [1089352]
- [ethernet] qlcnic: remove duplicate QLC_83XX_GET_LSO_CAPABILITY define (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Initialize mailbox cmd structure to zero (Chad Dupuis) [1089352]
- [ethernet] qlcnic: info leak in qlcnic_dcb_peer_app_info() (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Use time_before() (Chad Dupuis) [1089352]
- [ethernet] qlcnic: get rid of SET_ETHTOOL_OPS (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.59 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Collect firmware dump using DMA on 82xx adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add mac learning support to SR-IOV VF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add support to process commands in atomic context (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow SR-IOV VF probe in hypervisor (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Set real_num_{tx|rx}_queues properly (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix panic while dumping TX queues on TX timeout (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.58 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Limit vNIC support in legacy interrupt mode (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add driver logs in error path (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow setting TX interrupt coalescing parameters from VF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add hwmon interface to export board temperature (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Optimize MAC learning code (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix memory leak (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Reset firmware API lock at driver load time (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix MSI-X initialization code (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Do not disable SR-IOV when VFs are assigned to VMs (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix QLogic application/driver interface for virtual NIC configuration (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix PVID configuration on eSwitch port (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix max ring count calculation (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix to send INIT_NIC_FUNC as first mailbox (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix panic due to uninitialzed delayed_work struct in use (Chad Dupuis) [1089352]
- [ethernet] qlcnic: include irq.h for irq definitions (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix build failure due to undefined reference to `vxlan_get_rx_port' (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Remove casts of pointer to same type (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.57 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add VXLAN Rx offload support (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add VXLAN Tx offload support (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb, a couple off by one bugs (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix number of rings when we fall back from msix to legacy (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow any VLAN to be configured from VF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix usage of use_msi and use_msi_x module parameters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix function return error check (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.56 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance semaphore lock access failure error message (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow vlan0 traffic (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance driver message in failed state (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Updates to QLogic application/driver interface for virtual NIC configuration (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Re-factor firmware minidump template header handling (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Cleanup qlcnic_enable_msix() return values (Chad Dupuis) [1089352]
- [ethernet] qlcnic: update version to 5.3.55 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix loopback test failure (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix initialization of vlan list (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Correct off-by-one errors in bounds checks (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance logic to calculate msix vectors (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Refactor interrupt coalescing code for all adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update poll controller code path (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Interrupt code cleanup (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance Tx timeout debugging (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Use bool for rx_mac_learn (Chad Dupuis) [1089352]
- [ethernet] qlcnic: fix sparse warnings (Chad Dupuis) [1089352]
- [ethernet] qlcnic: remove unused code (Chad Dupuis) [1089352]
- [ethernet] qlcnic: make local functions static (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.54 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enable IPv6 LRO even if IP address is not programmed (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix SR-IOV cleanup code path (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enable beaconing for 83xx/84xx Series adapter (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Do MAC learning for SRIOV PF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Turn on promiscous mode for SRIOV PF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enable VF flood bit on PF (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Restrict VF from configuring any VLAN mode (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Convert vmalloc/memset to kcalloc (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix ethtool statistics length calculation (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix bug in TX statistics (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix resource allocation for TX queues (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix loopback diagnostic test (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Mark functions as static in qlcnic_83xx_hw.c (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Mark functions as static in qlcnic_io.c (Chad Dupuis) [1089352]
- [ethernet] qlcnic: update version to 5.3.53 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Support for 16 virtual NIC functions (Chad Dupuis) [1089352]
- [ethernet] qlcnic: VLAN enhancement for 84XX adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow single Tx/Rx queue for all adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Refactor initialize nic code path (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Issue INIT_NIC command only once (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Disable DCB operations from SR-IOV VFs (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Dump mailbox registers when mailbox command times out (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix mailbox processing during diagnostic test (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Allow firmware dump collection when auto firmware recovery is disabled (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix memory allocation (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix TSS/RSS validation for 83xx/84xx series adapter (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix TSS/RSS ring validation logic (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix typo in printk (Chad Dupuis) [1089352]
- [ethernet] qlcnic: update version to 5.3.52 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enable multiple Tx queue support for 83xx/84xx Series adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: refactor Tx/SDS ring calculation and validation in driver (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance ethtool Statistics for Multiple Tx queue (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Register netdev in FAILED state for 83xx/84xx (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Do not read QLCNIC_FW_CAPABILITY_MORE_CAPS bit for 83xx adapter (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Do not force adapter to perform LRO without destination IP check (Chad Dupuis) [1089352]
- [ethernet] qlcnic: remove unnecessary pci_set_drvdata() (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Validate Tx queue only for 82xx adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: update version to 5.3.51 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Skip unknown entry type while collecting firmware dump (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb code cleanup and refactoring (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Remove redundant eSwitch enable commands (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update ethtool standard pause settings (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Firmware dump collection when auto recovery is disabled (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance ethtool to display ring indices and interrupt mask (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Print informational messages only once during driver load (Chad Dupuis) [1089352]
- [ethernet] qlcnic: add missing destroy_workqueue() on error path in qlcnic_probe() (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Miscellaneous conversions to ETH_ALEN (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix SR-IOV configuration (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix register device in FAILED state for 82xx (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix warning reported by kbuild test robot (Chad Dupuis) [1089352]
- [ethernet] qlcnic: use standard NAPI weights (Chad Dupuis) [1089352]
- [ethernet] qlcnic: remove a stray semicolon (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Fix sparse warning (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Convert uses of compare_ether_addr to ether_addr_equal (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.50 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add support for per port eswitch configuration (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Restructuring of qlc_83xx_fw_info structure (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add AER support for 83xx adapter (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Add AER callback handlers (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Store firmware dump state in CAMRAM register (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Use firmware recommended dump capture mask as default (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Remove inline keyword (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Enhance PVID handling for 84xx adapters (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Update version to 5.3.49 (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb, Add support for CEE Netlink interface (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb: Register DCB AEN handler (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb, Get DCB parameters from the adapter (Chad Dupuis) [1089352]
- [ethernet] qlcnic: dcb, Query adapter DCB capabilities (Chad Dupuis) [1089352]
- [ethernet] qlcnic: Back off patch for the upstream commit "d6e9c89a8d3cf0a5184badbcd50169179af27721" (Chad Dupuis) [1089352]
- [ethernet] be2net: query max_tx_qs for BE3 super-nic profile from FW (Ivan Vecera) [1088575]
- [ethernet] be2net: define macro for_all_tx_queues_on_eq() (Ivan Vecera) [1088575]
- [ethernet] be2net: get rid of TX budget (Ivan Vecera) [1088575]
- [ethernet] be2net: make be_cmd_get_regs() return a status (Ivan Vecera) [1088575]
- [ethernet] be2net: define BE_MAX_MTU (Ivan Vecera) [1088575]
- [ethernet] be2net: remove unncessary gotos (Ivan Vecera) [1088575]
- [ethernet] be2net: fix log messages in lancer FW download path (Ivan Vecera) [1088575]
- [ethernet] be2net: Add a dma_mapping_error counter in ethtool (Ivan Vecera) [1088575]
- [ethernet] be2net: Add TX completion error statistics in ethtool (Ivan Vecera) [1088575]
- [ethernet] be2net: add a description for counter rx_input_fifo_overflow_drop (Ivan Vecera) [1088575]
- [ethernet] be2net: shorten AMAP_GET/SET_BITS() macro calls (Ivan Vecera) [1088575]
- [ethernet] be2net: add a few log messages (Ivan Vecera) [1088575]
- [ethernet] be2net: Set skb->csum_level for encapsulated checksum (Ivan Vecera) [1088575]
- [ethernet] be2net: Remove DEFINE_PCI_DEVICE_TABLE macro use (Ivan Vecera) [1088575]
- [ethernet] be2net: support deleting FW dump via ethtool (only for Lancer) (Ivan Vecera) [1088575]
- [ethernet] be2net: ignore VF mac address setting for the same mac (Ivan Vecera) [1088575]
- [ethernet] be2net: ignore get/set profile FW cmd failures (Ivan Vecera) [1088575]
- [ethernet] be2net: Issue shutdown event to ocrdma driver (Ivan Vecera) [1088575]
- [ethernet] be2net: update driver version to 10.4 (Ivan Vecera) [1088575]
- [ethernet] be2net: use adapter->flags to track SRIOV state (Ivan Vecera) [1088575]
- [ethernet] be2net: avoid SRIOV config for BE2 chip (Ivan Vecera) [1088575]
- [ethernet] be2net: use be_max_vfs() macro to access max-vfs (Ivan Vecera) [1088575]
- [ethernet] be2net: use "if (!foo)" test style (Ivan Vecera) [1088575]
- [ethernet] be2net: remove unused structures in be_cmds.h (Ivan Vecera) [1088575]
- [ethernet] be2net: reduce arguments passed to FW-cmd routines (Ivan Vecera) [1088575]
- [ethernet] be2net: update UE bit description strings (Ivan Vecera) [1088575]
- [ethernet] be2net: fix return status of some ndo methods (Ivan Vecera) [1088575]
- [ethernet] be2net: fix return status of some ethtool methods (Ivan Vecera) [1088575]
- [ethernet] be2net: return -ENOMEM for memory allocation failures (Ivan Vecera) [1088575]
- [ethernet] be2net: return -ETIMEDOUT when a FW-cmd times out (Ivan Vecera) [1088575]
- [ethernet] be2net: fix error status for FW-download (Ivan Vecera) [1088575]
- [ethernet] be2net: use -ENETDOWN error status when interface is down (Ivan Vecera) [1088575]
- [ethernet] be2net: set EQ DB clear-intr bit in be_open() (Ivan Vecera) [1088575]
- [ethernet] be2net: re-enable vlan filtering mode asap (Ivan Vecera) [1088575]
- [ethernet] be2net: create optimal number of queues on SR-IOV config (Ivan Vecera) [1088575]
- [ethernet] be2net: read VF's capabilities from GET_PROFILE_CONFIG cmd (Ivan Vecera) [1088575]
- [ethernet] be2net: remove be_cmd_get_profile_config_mbox/mccq() variants (Ivan Vecera) [1088575]
- [ethernet] be2net: fix qnq mode detection on VFs (Ivan Vecera) [1088575]
- [ethernet] be2net: cleanup MCC async event processing code (Ivan Vecera) [1088575]
- [ethernet] be2net: move async cmd processing to a separate routine (Ivan Vecera) [1088575]
- [ethernet] be2net: re-factor MCCQ error status handling code (Ivan Vecera) [1088575]
- [ethernet] be2net: support flashing new regions on Skyhawk-R (Ivan Vecera) [1088575]
- [ethernet] be2net: fixup TX-rate setting code for Skyhawk-R (Ivan Vecera) [1088575]
- [ethernet] be2net: skip multicast promiscuos setting in already set (Ivan Vecera) [1088575]
- [ethernet] be2net: Add support to configure SR-IOV VF minimum and maximum Tx rate through ip tool (Ivan Vecera) [1088575]
- [ethernet] be2net: get rid of SET_ETHTOOL_OPS (Ivan Vecera) [1088575]
- [ethernet] be2net: use MCCQ instead of MBOX in be_cmd_rss_config() (Ivan Vecera) [1088575]
- [ethernet] be2net: include rx-compl error counter in ethtool stats (Ivan Vecera) [1088575]
- [ethernet] be2net: remove unused code in be_cmd_vlan_config() (Ivan Vecera) [1088575]
- [ethernet] be2net: covert vlan array to bit-map (Ivan Vecera) [1088575]
- [ethernet] be2net: fix line wrap and function call indentation in be_ethtool.c (Ivan Vecera) [1088575]
- [ethernet] be2net: fix function call indentation in be_cmds.c (Ivan Vecera) [1088575]
- [ethernet] be2net: fix line wrap and function call indentation in be_main.c (Ivan Vecera) [1088575]
- [ethernet] be2net: Support for configurable RSS hash key (Ivan Vecera) [1088575]
- [ethernet] be2net: Fix to reap TX compls till HW doesn't respond for some time (Ivan Vecera) [1088575]
- [ethernet] be2net: Add abi version between be2net and ocrdma (Ivan Vecera) [1088575]
- [ethernet] be2net: fix build dependency on VxLAN (Ivan Vecera) [1088575 1093399 1099545]
- [ethernet] be2net: csum, tso and rss steering offload support for VxLAN (Ivan Vecera) [1088575 1093399 1099545]
- [ethernet] be2net: add FW cmds needed for VxLAN offloads (Ivan Vecera) [1088575 1093399 1099545]
- [ethernet] be2net: Call dev_kfree_skby_any instead of kfree_skb (Ivan Vecera) [1088575]
- [ethernet] be2net: update driver version to 10.2 (Ivan Vecera) [1088575]
- [ethernet] be2net: Fix vlans_added counter (Ivan Vecera) [1088575]
- [ethernet] be2net: Create multiple TXQs on RSS capable multi-channel BE3-R interfaces (Ivan Vecera) [1088575]
- [ethernet] be2net: fix pmac_id[] allocation size (Ivan Vecera) [1088575]
- [ethernet] be2net: log LPVID used in multi-channel configs (Ivan Vecera) [1088575]
- [ethernet] be2net: Add link state control for VFs (Ivan Vecera) [1088575]
- [ethernet] be2net: Use GET_PROFILE_CONFIG cmd for BE3-R to query max-vfs (Ivan Vecera) [1088575]
- [ethernet] be2net: dma_sync each RX frag before passing it to the stack (Ivan Vecera) [1088575]
- [ethernet] be2net: isolate TX workarounds not applicable to Skyhawk-R (Ivan Vecera) [1088575]
- [ethernet] be2net: Fix skb double free in be_xmit_wrokarounds() failure path (Ivan Vecera) [1088575]
- [ethernet] be2net: clear promiscuous bits in adapter->flags while disabling promiscuous mode (Ivan Vecera) [1088575]
- [ethernet] be2net: Fix to reset transparent vlan tagging (Ivan Vecera) [1088575]
- [ethernet] be2net: Use pci_enable_msix_range() instead of pci_enable_msix() (Ivan Vecera) [1088575]
- [ethernet] be2net: refactor multi-channel config code for Skyhawk-R chip (Ivan Vecera) [1088575]
- [ethernet] be2net: Update copyright year (Ivan Vecera) [1088575]
- [ethernet] be2net: Log a kernel message when UE is detected in BE & Skyhawk (Ivan Vecera) [1088575]
- [ethernet] be2net: Explicitly initialize u64_stats_sync structures for lockdep (Ivan Vecera) [1088575]
- [drm] bochs: changes from 3.14..3.15 for bochs (Gerd Hoffmann) [1043379]
- [drm] bochs: replace ALIGN(PAGE_SIZE) by PAGE_ALIGN (Gerd Hoffmann) [1043379]
- [drm] bochs: Remove unecessary NULL check in gem_free (Gerd Hoffmann) [1043379]
- [drm] bochs: Remove unnecessary NULL check in bo_unref (Gerd Hoffmann) [1043379]
- [drm] bochs: drop unused struct fields (Gerd Hoffmann) [1043379]
- [drm] bochs: add power management support (Gerd Hoffmann) [1043379]
- [drm] bochs: fix bochs kconfig dependencies (Gerd Hoffmann) [1043379]
- [drm] bochs: new driver (Gerd Hoffmann) [1043379]
- [iommu] amd: Split init_iommu_group() from iommu_init_device() (Myron Stowe) [1141937]
- [iommu] Rework iommu_group_get_for_pci_dev() (Myron Stowe) [1141937]

* Thu Oct 09 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-186.el7]
- [kernel] sched/balancing: Reduce the rate of needless idle load balancing (Larry Woodman) [1120318]
- [kernel] sched/fair: Implement fast idling of CPUs when the system is partially loaded (Larry Woodman) [1120318]
- [kernel] sched: Skip double execution of pick_next_task_fair() (Larry Woodman) [1120318]
- [md] Revert: dm: change sector_count member in clone_info from sector_t to unsigned (Mike Snitzer) [1147574]
- [md] Revert: dm: introduce dm_accept_partial_bio (Mike Snitzer) [1147574]
- [md] Revert: dm-snapshot: allocate a per-target structure for snapshot-origin target (Mike Snitzer) [1147574]
- [md] Revert: dm-snapshot: do not split read bios sent to snapshot-origin target (Mike Snitzer) [1147574]
- [virt] kvm: nested vmx - disable perf cpuid reporting (Marcelo Tosatti) [1083969]
- [mm] slub: Handle NULL parameter in kmem_cache_flags (Ilya Dryomov) [1143028]
- [crypto] algif: avoid excessive use of socket buffer in skcipher (Ondrej Kozina) [1136075]
- [kernel] time/clocksource: Move cycle_last validation to core code (Prarit Bhargava) [1148398]
- [kernel] time/clocksource: Make delta calculation a function (Prarit Bhargava) [1148398]
- [mm] vmscan: clear kswapd's special reclaim powers before exiting (Motohiro Kosaki) [810042]
- [x86] mm/numa: fix array index overflow when synchronizing nid to memblock.reserved (Motohiro Kosaki) [810042]
- [x86] mm/numa: initialize numa_kernel_nodes in numa_clear_kernel_node_hotplug() (Motohiro Kosaki) [810042]
- [mm] page_alloc: make movable_node have higher priority (Motohiro Kosaki) [810042]
- [x86] memblock, mem_hotplug: make memblock skip hotpluggable regions if needed (Motohiro Kosaki) [810042]
- [x86] mm: mark all nodes the kernel resides un-hotpluggable (Motohiro Kosaki) [810042]
- [x86] mm: mark hotpluggable memory in memblock (Motohiro Kosaki) [810042]
- [mm] memblock: make memblock_set_node() support different memblock_type (Motohiro Kosaki) [810042]
- [mm] memblock/mem_hotplug: introduce MEMBLOCK_HOTPLUG flag to mark hotpluggable regions (Motohiro Kosaki) [810042]
- [mm] memblock: numa - introduce flags field into memblock (Motohiro Kosaki) [810042]
- [mm] memblock: debug - correct displaying of upper memory boundary (Motohiro Kosaki) [810042]
- [x86] mm: get pg_data_t's memory from other node (Motohiro Kosaki) [810042]
- [mm] mem-hotplug: introduce movable_node boot option (Motohiro Kosaki) [810042]
- [x86] kernel/setup: do reserve_crashkernel() after SRAT is parsed (Motohiro Kosaki) [810042]
- [x86] mem-hotplug: support initialize page tables in bottom-up (Motohiro Kosaki) [810042]
- [x86] mm: factor out of top-down direct mapping setup (Motohiro Kosaki) [810042]
- [mm] memblock: introduce bottom-up allocation mode (Motohiro Kosaki) [810042]
- [mm] memblock: factor out of top-down allocation (Motohiro Kosaki) [810042]
- [x86] mm: Add 'step_size' comments to init_mem_mapping() (Motohiro Kosaki) [810042]
- [x86] srat: Print Hot-Pluggable Field in SRAT (Motohiro Kosaki) [810042]

* Thu Oct 09 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-185.el7]
- [fs] udf: Avoid infinite loop when processing indirect ICBs (Jacob Tanenbaum) [1142322] {CVE-2014-6410}
- [fs] eliminate BUG() call when there's an unexpected lock on file close (Frank Sorenson) [1148130]
- [hid] fix off by one error in various _report_fixup routines (Jacob Tanenbaum) [1141394] {CVE-2014-3184}
- [hid] logitech-dj: fix OOB array access (Jacob Tanenbaum) [1141212] {CVE-2014-3182}
- [hid] picolcd: fix memory corruption via OOB write (Jacob Tanenbaum) [1141409] {CVE-2014-3186}
- [usb] serial/whiteheat: fix memory corruption flaw (Jacob Tanenbaum) [1141404] {CVE-2014-3185}
- [hid] fix OOB write in magicmouse driver (Jacob Tanenbaum) [1141177] {CVE-2014-3181}
- [x86] uv/nmi: Fix UV NMI handler when KDB not configured (George Beshers) [1138519]
- [x86] uv/nmi: Fix Sparse warnings (George Beshers) [1138519]
- [kernel] debug: Fix no KDB config problem (George Beshers) [1138519]
- [x86] uv: Add call to KGDB/KDB from NMI handler (George Beshers) [1138519]
- [kernel] debug: Add support for external NMI handler to call KGDB/KDB (George Beshers) [1138519]
- [x86] uv: Add kdump to UV NMI handler (George Beshers) [1138519]
- [x86] uv: Add summary of cpu activity to UV NMI handler (George Beshers) [1138519]
- [x86] uv: Update UV support for external NMI signals (George Beshers) [1138519]
- [x86] uv: Move NMI support (George Beshers) [1138519]
- [infiniband] ipath: Add P_Key change event support (Doug Ledford) [1085961]
- [infiniband] qib: Additional Intel branding changes (Doug Ledford) [1085961]
- [infiniband] ipath: Use time_before()/_after() (Doug Ledford) [1085961]
- [infiniband] ipath: Translate legacy diagpkt into newer extended diagpkt (Doug Ledford) [1085961]
- [infiniband] qib: Fix port in pkey change event (Doug Ledford) [1085961]
- [infiniband] qib: Use pci_enable_msix_range() instead of pci_enable_msix() (Doug Ledford) [1085961]
- [infiniband] qib: Cleanup qib_register_observer() (Doug Ledford) [1085961]
- [infiniband] qib: Change SDMA progression mode depending on single- or multi-rail (Doug Ledford) [1085961]
- [infiniband] qib: Remove duplicate check in get_a_ctxt() (Doug Ledford) [1085961]
- [infiniband] qib: Fix memory leak of recv context when driver fails to initialize (Doug Ledford) [1085961]
- [infiniband] qib: fixup indentation in qib_ib_rcv() (Doug Ledford) [1085961]
- [infiniband] qib: add missing braces in do_qib_user_sdma_queue_create() (Doug Ledford) [1085961]
- [infiniband] qib: Modify software pma counters to use percpu variables (Doug Ledford) [1085961]
- [infiniband] qib: Add percpu counter replacing qib_devdata int_counter (Doug Ledford) [1085961]
- [infiniband] qib: Fix debugfs ordering issue with multiple HCAs (Doug Ledford) [1085961]
- [infiniband] ipath: Fix potential buffer overrun in sending diag packet routine (Doug Ledford) [1085961]
- [infiniband] qib: Fix potential buffer overrun in sending diag packet routine (Doug Ledford) [1085961]
- [infiniband] qib: Add missing serdes init sequence (Doug Ledford) [1085961]
- [infiniband] qib: Fix QP check when looping back to/from QP1 (Doug Ledford) [1085961]
- [kernel] audit: drop arch from __audit_syscall_entry() interface (Richard Guy Briggs) [1053921]
- [kernel] audit: fix build error when asm/syscall.h does not exist (Richard Guy Briggs) [1053921]
- [kernel] audit: add arch field to seccomp event log (Richard Guy Briggs) [1053921]
- [kernel] audit: __audit_syscall_entry - ignore arch arg and call syscall_get_arch() directly (Richard Guy Briggs) [1053921]
- [kernel] audit: audit_syscall_entry() should not require the arch (Richard Guy Briggs) [1053921]
- [kernel] audit: implement syscall_get_arch for all arches (Richard Guy Briggs) [1053921]
- [kernel] syscall.h: fix doc text for syscall_get_arch() (Richard Guy Briggs) [1053921]
- [kernel] audit: use uapi/linux/audit.h for AUDIT_ARCH declarations (Richard Guy Briggs) [1053921]
- [kernel] syscall_get_arch: remove useless function arguments (Richard Guy Briggs) [1053921]

* Wed Oct 08 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-184.el7]
- [scsi] cxgb4i: Fix ipv6 build failure caught with randconfig (Sai Vemuri) [1126539]
- [scsi] cxgb4i: remove spurious use of rcu (Sai Vemuri) [1126539]
- [scsi] cxgb4i Guard ipv6 code with a config check (Sai Vemuri) [1126539]
- [scsi] cxgb4i: Add ipv6 code to driver, call into libcxgbi ipv6 api (Sai Vemuri) [1126539]
- [scsi] libcxgbi: Add ipv6 api to driver (Sai Vemuri) [1126539]
- [scsi] cxgb4i: Use cxgb4_select_ntuple to correctly calculate ntuple fields (Sai Vemuri) [1126539]
- [ethernet] cxgb4: Issue mbox commands on correct mbox (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Avoid dumping Write-only registers in register dump (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Detect and display firmware reported errors (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fix T5 adapter accessing T4 adapter registers (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fixed the code to use correct length for part number (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fix for handling 1Gb/s SFP+ Transceiver Modules (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Free completed tx skbs promptly (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fix race condition in cleanup (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Update FW version string to match FW binary version (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fix for SR-IOV VF initialization (Sai Vemuri) [1124947]
- [scsi] cxgb4i: Move stray CPL definitions to cxgb4 driver (Sai Vemuri) [1124947]
- [ethernet] cxgb4: only free allocated fls (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Only call CQ completion handler if it is armed (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fixed incorrect check for memory operation in t4_memory_rw (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Don't limit TPTE count to 32KB (Sai Vemuri) [1124947]
- [infiniband] cxgb4: advertise the correct device max attributes (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Support query_qp() verb (Sai Vemuri) [1124947]
- [infiniband] cxgb4: log detailed warnings for negative advice (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Add the MC1 registers to read in the interrupt handler (Sai Vemuri) [1124947]
- [infiniband] cxgb4: fix for 64-bit integer division (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Export symbols required by cxgb4i for ipv6 support and required defines (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Move common defines to cxgb4 (Sai Vemuri) [1124947]
- [infiniband] cxgb4: work request logging feature (Sai Vemuri) [1124947]
- [ethernet] cxgb4: display TPTE on errors (Sai Vemuri) [1124947]
- [ethernet] cxgb4: use firmware ord/ird resource limits (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Detect Ing. Padding Boundary at run-time (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Call iwpm_init() only once (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Initialize the device status page (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Clean up connection on ARP error (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix skb_leak in reject_cr() (Sai Vemuri) [1124947]
- [ethernet] cxgb4: remove unnecessary null test before debugfs_remove_recursive (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Adds device ID for few more Chelsio T4 Adapters (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Replaced the backdoor mechanism to access the HW memory with PCIe Window method (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Use FW interface to get BAR0 value (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fixes cxgb4 probe failure in VM when PF is exposed through PCI Passthrough (Sai Vemuri) [1124947]
- [ethernet] cxgb4: use dev_port to identify ports (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Not need to hold the adap_rcu_lock lock when read adap_rcu_list (Sai Vemuri) [1124947]
- [infiniband] cxgb4: don't truncate the recv window size (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Choose appropriate hw mtu index and ISS for iWARP connections (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Allocate and use IQs specifically for indirect interrupts (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Add support for iWARP Port Mapper user space service (Sai Vemuri) [1124947]
- [infiniband] cxgb4: add missing padding at end of struct c4iw_alloc_ucontext_resp (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Add missing padding at end of struct c4iw_create_cq_resp (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix vlan support (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix memory leaks in c4iw_alloc() error paths (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Check if rx checksum offload is enabled, while reading hardware calculated checksum (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Decode the firmware port and module type a bit more for ethtool (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Decode PCIe Gen3 link speed (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Update Kconfig to include Chelsio T5 adapter (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Only allow kernel db ringing for T4 devs (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Force T5 connections to use TAHOE congestion control (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix endpoint mutex deadlocks (Sai Vemuri) [1124947]
- [ethernet] cxgb4: use the correct max size for firmware flash (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Save the correct mac addr for hw-loopback connections in the L2T (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix over-dereference when terminating (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Use uninitialized_var() (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Add missing debug stats (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Initialize reserved fields in a FW work request (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Use pr_warn_ratelimited (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Max fastreg depth depends on DSGL support (Sai Vemuri) [1124947]
- [infiniband] cxgb4: SQ flush fix (Sai Vemuri) [1124947]
- [infiniband] cxgb4: rmb() after reading valid gen bit (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Endpoint timeout fixes (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Use the BAR2/WC path for kernel QPs and T5 devices (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Disable DSGL use by default (Sai Vemuri) [1124947]
- [infiniband] cxgb4: rx_data() needs to hold the ep mutex (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Drop RX_DATA packets if the endpoint is gone (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Lock around accept/reject downcalls (Sai Vemuri) [1124947]
- [infiniband] cxgb4: set error code on kmalloc() failure (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Adds device ID for few more Chelsio Adapters (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Remove addressof casts to same type (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Call dev_kfree/consume_skb_any instead of [dev_]kfree_skb (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Update snd_seq when sending MPA messages (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Connect_request_upcall fixes (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Ignore read reponse type 1 CQEs (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix possible memory leak in RX_PKT processing (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Don't leak skb in c4iw_uld_rx_handler() (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Save the correct map length for fast_reg_page_lists (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Default peer2peer mode to 1 (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Mind the sq_sig_all/sq_sig_type QP attributes (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix incorrect BUG_ON conditions (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Always release neigh entry (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Allow loopback connections (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Cap CQ size at T4_MAX_IQ_SIZE (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix four byte info leak in c4iw_create_cq() (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix underflows in c4iw_create_qp() (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Doorbell Drop Avoidance Bug Fixes (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Treat CPL_ERR_KEEPALV_NEG_ADVICE as negative advice (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Calculate len properly for LSO path (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Updates for T5 SGE's Egress Congestion Threshold (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Rectify emitting messages about SGE Ingress DMA channels being potentially stuck (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Add code to dump SGE registers when hitting idma hangs (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Fix some small bugs in t4_sge_init_soft() when our Page Size is 64KB (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Stop using ethtool SPEED_* constants (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Add more PCI device ids (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Don't assume LSO only uses SGL path in t4_eth_xmit() (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Remove unused registers and add missing ones (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Query firmware for T5 ULPTX MEMWRITE DSGL capabilities (Sai Vemuri) [1124947]
- [ethernet] cxgb4: LE-Workaround is not atomic in firmware (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Allow >10G ports to have multiple queues (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Print adapter VPD Part Number instead of Engineering Change field (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Add support to recognize 40G links (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Add missing neigh_release in LE-Workaround path (Sai Vemuri) [1124947]
- [infiniband] cxgb4: Fix gcc warning on 32-bit arch (Sai Vemuri) [1124947]
- [ethernet] cxgb4: silence shift wrapping static checker warning (Sai Vemuri) [1124947]
- [ethernet] cxgb4: Changed FW check version to match FW binary version (Sai Vemuri) [1124947]
- [ethernet] cxgb4: make functions static and remove dead code (Sai Vemuri) [1124947]
- [tools] perf: Disable kernel symbol demangling by default (Jiri Olsa) [1140522]
- [tools] perf/symbols: Don't demangle parameters and such by default (Jiri Olsa) [1140522]
- [powerpc] pseries: Fix endian issues in memory hotplug (Steve Best) [1142244]
- [powerpc] pseries/hvcserver: Fix endian issue in hvcs_get_partner_info (Steve Best) [1142244]
- [powerpc] powernv: Interface to register/unregister opal dump region (Steve Best) [1142244]
- [kernel] printk: Add function to return log buffer address and size (Steve Best) [1142244]
- [acpi] hotplug: Check scan handlers in acpi_scan_hot_remove() (Prarit Bhargava) [1141846]
- [acpi] hotplug: Simplify acpi_set_hp_context() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Eliminate acpiphp_dev_to_bridge() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Add hotplug contexts to PCI host bridges (Prarit Bhargava) [1141846]
- [acpi] Remove duplicate definitions of PREFIX (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Use pci_device_is_present() (Prarit Bhargava) [1141846]
- [acpi] hotplug: Rework deferred execution of acpi_device_hotplug() (Prarit Bhargava) [1141846]
- [ata] libata-acpi: Add hotplug contexts to ACPI companions of SATA devices (Prarit Bhargava) [1141846]
- [acpi] dock: Add .uevent() callback to struct acpi_hotplug_context (Prarit Bhargava) [1141846]
- [acpi] dock: Use callback pointers from devices' ACPI hotplug contexts (Prarit Bhargava) [1141846]
- [acpi] dock: Use ACPI device object pointers instead of ACPI handles (Prarit Bhargava) [1141846]
- [acpi] hotplug: Add .fixup() callback to struct acpi_hotplug_context (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Do not clear event callback pointer for docks (Prarit Bhargava) [1141846]
- [acpi] Drop acpi_evaluate_hotplug_ost() and ACPI_HOTPLUG_OST (Prarit Bhargava) [1141846]
- [acpi] rename acpi_evaluate_hotplug_ost() to acpi_evaluate_ost() (Prarit Bhargava) [1141846]
- [acpi] dock: Dispatch dock notifications from the global notify handler (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Add ACPIPHP contexts to devices handled by PCIeHP (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Rename register_slot() to acpiphp_add_context() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Relax the checking of _STA return values (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Execute _EJ0 under the ACPI scan lock (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Hotplug notifications from acpi_bus_notify() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Simplify acpi_install_hotplug_notify_handler() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Rework acpiphp_check_host_bridge() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Rework the handling of eject requests (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Consolidate ACPIPHP with ACPI core hotplug (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Define hotplug context lock in the core (Prarit Bhargava) [1141846]
- [acpi] hotplug: Fix potential race in acpi_bus_notify() (Prarit Bhargava) [1141846]
- [acpi] acpica: Introduce acpi_get_data_full() and rework acpi_get_data() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Do not pass ACPI handle to hotplug_event() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Use acpi_handle_debug() in hotplug_event() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Simplify hotplug_event() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Drop crit_sect locking (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Drop acpiphp_bus_add() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Store acpi_device pointer in acpiphp_context (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Rework acpiphp_no_hotplug() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Drop acpiphp_bus_trim() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Simplify register_slot() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Proper kerneldoc comments for enumeration/removal (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Simplify disable_slot() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Fix bridge removal race vs dock events (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Fix bridge removal race in handle_hotplug_event() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Scan root bus under the PCI rescan-remove lock (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Move PCI rescan-remove locking to hotplug_event() (Prarit Bhargava) [1141846]
- [acpi] hotplug/pci: Remove entries from bus->devices in reverse order (Prarit Bhargava) [1141846]
- [acpi] acpiphp: Fix radeon/nouveau VGA switcheroo problem related to hotplug (Prarit Bhargava) [1141846]
- [acpi] hotplug: Handle containers in a special way (Prarit Bhargava) [1141846]
- [acpi] hotplug: Add demand_offline hotplug profile flag (Prarit Bhargava) [1141846]
- [acpi] bind: Move acpi_get_child() to drivers/ide/ide-acpi.c (Prarit Bhargava) [1141846]
- [acpi] bind: Pass struct acpi_device pointer to acpi_bind_one() (Prarit Bhargava) [1141846]
- [acpi] bind: Rework struct acpi_bus_type (Prarit Bhargava) [1141846]
- [acpi] bind: Redefine acpi_preset_companion() (Prarit Bhargava) [1141846]
- [acpi] bind: Redefine acpi_get_child() (Prarit Bhargava) [1141846]
- [pci] acpi: Use acpi_find_child_device() for child devices lookup (Prarit Bhargava) [1141846]
- [acpi] bind: Simplify child device lookups (Prarit Bhargava) [1141846]
- [acpi] libata: Store an ACPI device pointer in struct acpi_dev_node (Prarit Bhargava) [1141846]
- [ata] libata: remove power dependent device handling (Prarit Bhargava) [1141846]
- [acpi] bind: Prefer device objects with _STA to those without it (Prarit Bhargava) [1141846]
- [drm] nouveau/nouveau_acpi: convert acpi_get_handle() to acpi_has_method() (Prarit Bhargava) [1141846]
- [acpi] libata: Remove ata_dev_acpi_handle stub in libata.h (Prarit Bhargava) [1141846]
- [ata] libata-acpi: rework the ata acpi bind support (Prarit Bhargava) [1141846]
- [acpi] Cleanup sparse warning on acpi_os_initialize1() (Prarit Bhargava) [1141846]

* Tue Oct 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-183.el7]
- [infiniband] usnic: backport to older netdev notifier arguments (Doug Ledford) [916382]
- [infiniband] usnic: Fix source file missing copyright and license (Doug Ledford) [916382]
- [infiniband] usnic: Remove '0x' when using pa format (Doug Ledford) [916382]
- [infiniband] usnic: Fix smatch endianness error (Doug Ledford) [916382]
- [infiniband] usnic: Remove unused includes of <linux/version.h> (Doug Ledford) [916382]
- [infiniband] usnic: Use GFP_ATOMIC under spinlock (Doug Ledford) [916382]
- [infiniband] usnic: Remove unused variable in usnic_debugfs_exit() (Doug Ledford) [916382]
- [infiniband] usnic: Set userspace/kernel ABI ver to 4 (Doug Ledford) [916382]
- [infiniband] usnic: Advertise usNIC devices as RDMA_NODE_USNIC_UDP (Doug Ledford) [916382]
- [infiniband] usnic: Add dependency on CONFIG_INET (Doug Ledford) [916382]
- [infiniband] usnic: Fix endianness-related warnings (Doug Ledford) [916382]
- [infiniband] usnic: Append documentation to usnic_transport.h and cleanup (Doug Ledford) [916382]
- [infiniband] usnic: Fix typo "Ignorning" -> "Ignoring" (Doug Ledford) [916382]
- [infiniband] usnic: Expose flows via debugfs (Doug Ledford) [916382]
- [infiniband] usnic: Use for_each_sg instead of a for-loop (Doug Ledford) [916382]
- [infiniband] usnic: Remove superflous parentheses (Doug Ledford) [916382]
- [infiniband] usnic: Add UDP support in usnic_ib_qp_grp.[hc] (Doug Ledford) [916382]
- [infiniband] usnic: Add UDP support in u*verbs.c, u*main.c and u*util.h (Doug Ledford) [916382]
- [infiniband] usnic: Add UDP support to usnic_transport.[hc] (Doug Ledford) [916382]
- [infiniband] usnic: Add UDP support to usnic_fwd.[hc] (Doug Ledford) [916382]
- [infiniband] usnic: Update ABI and Version file for UDP support (Doug Ledford) [916382]
- [infiniband] usnic: Port over sysfs to new usnic_fwd.h (Doug Ledford) [916382]
- [infiniband] usnic: Port over usnic_ib_qp_grp.[hc] to new usnic_fwd.h (Doug Ledford) [916382]
- [infiniband] usnic: Port over main.c and verbs.c to the usnic_fwd.h (Doug Ledford) [916382]
- [infiniband] usnic: Push all forwarding state to usnic_fwd.[hc] (Doug Ledford) [916382]
- [infiniband] usnic: Add struct usnic_transport_spec (Doug Ledford) [916382]
- [infiniband] usnic: Change WARN_ON to lockdep_assert_held (Doug Ledford) [916382]
- [infiniband] usnic: Add Cisco VIC low-level hardware driver (Doug Ledford) [916382]
- [md] dm-table: propagate QUEUE_FLAG_NO_SG_MERGE (Jeff Moyer) [1105698]
- [virt] virtio_blk: support multi virt queues per virtio-blk device (Jeff Moyer) [1105698]
- [virt] virtio_blk: introduce feature of VIRTIO_BLK_F_MQ (Jeff Moyer) [1105698]
- [virt] virtio_blk: don't hold spin lock during world switch (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: remove alloc_hctx and free_hctx methods (Jeff Moyer) [1105698]
- [virt] virtio_blk: fix race between start and stop queue (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: add async parameter to blk_mq_start_stopped_hw_queues (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: split out tag initialization, support shared tags (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: add ->init_request and ->exit_request methods (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: do not initialize req->special (Jeff Moyer) [1105698]
- [virt] virtio_blk: base queue-depth on virtqueue ringsize or module param (Jeff Moyer) [1105698]
- [virt] virtio_blk, blk-mq: allow blk_mq_init_commands() to return failure (Jeff Moyer) [1105698]
- [virt] virtio_blk: don't crash, report error if virtqueue is broken (Jeff Moyer) [1105698]
- [virt] virtio_blk: use blk_mq_complete_request (Jeff Moyer) [1105698]
- [virt] virtio_blk: virtqueue_kick() must be ordered with other virtqueue operations (Jeff Moyer) [1105698]
- [virt] virtio_blk: blk-mq support (Jeff Moyer) [1105698]
- [virt] virtio: use size-based config accessors (Jeff Moyer) [1105698]
- [virt] virtio_config: introduce size-based accessors (Jeff Moyer) [1105698]
- [virt] virtio_blk: Add missing 'static' qualifiers (Jeff Moyer) [1105698]
- [block] cfq-iosched: Add comments on update timing of weight (Vivek Goyal) [1116126]
- [block] cfq-iosched: Fix wrong children_weight calculation (Vivek Goyal) [1116126]
- [fs] aio: block exit_aio() until all context requests are completed (Jeff Moyer) [1122092]
- [fs] aio: add missing smp_rmb() in read_events_ring (Jeff Moyer) [1131312]
- [fs] aio: fix reqs_available handling (Jeff Moyer) [1122092]
- [fs] aio: report error from io_destroy() when threads race in io_destroy() (Jeff Moyer) [1122092]
- [fs] aio: block io_destroy() until all context requests are completed (Jeff Moyer) [1122092]
- [fs] aio: v4 ensure access to ctx->ring_pages is correctly serialised for migration (Jeff Moyer) [1122092]
- [fs] aio/migratepages: make aio migrate pages sane (Jeff Moyer) [1122092]
- [fs] aio: clean up and fix aio_setup_ring page mapping (Jeff Moyer) [1122092]
- [md] dm-cache: fix race affecting dirty block count (Mike Snitzer) [1140362]
- [md] dm-cache: fix race causing dirty blocks to be marked as clean (Mike Snitzer) [1140362]
- [infiniband] mlx4: Fix wrong endianess access with QP context flags (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Set vlan stripping policy by the right command (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Avoid dealing with MAC index in UPDATE_QP wrapper if not needed (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use the correct VSD mask in UPDATE_QP (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Correctly configure single ported VFs from the host (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: do not ignore autoneg in mlx4_en_set_pauseparam() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Set user-space raw Ethernet QPs to properly handle VXLAN traffic (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Move the tunnel steering helper function to mlx4_core (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Set skb->csum_level for encapsulated checksum (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Avoid executing gid task when device is being removed (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix lockdep splat for the iboe lock (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Get upper dev addresses as RoCE GIDs when port comes up (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Reorder steps in RoCE GID table initialization (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Don't duplicate the default RoCE GID (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Avoid null pointer dereference in mlx4_ib_scan_netdevs() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use is_kdump_kernel() to detect kdump kernel (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Use ARRAY_SIZE instead of sizeof/sizeof[0] (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Use ARRAY_SIZE instead of sizeof/sizeof[0] (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add support for secure-host and SMP firewall (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4_ib: Add support for user MR re-registration (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add helper functions to support MR re-registration (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Adjust events to use unsigned long param instead of void ptr (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: minor fixes (mainly avoidance of hidden casts) (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Move pci device handling from mlx5_ib to mlx5_core (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: mlx4_en_[gs]et_priv_flags() can be static (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Reduce memory consumption on kdump kernel (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use low memory profile on kdump kernel (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Disable blueflame using ethtool private flags (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: current_mac isn't updated in port up (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: cq->irq_desc wasn't set in legacy EQ's (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Remove MCG in case it is attached to promiscuous QPs only (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: In SR-IOV mode host should add promisc QP to default entry only (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Make sure the max number of QPs per MCG isn't exceeded (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Make sure that negative array index isn't used (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix leakage of SW multicast entries (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Enable "block multicast loopback" for kernel consumers (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: mark napi id for gro_skb (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx5: Fix possible race between mr tree insert/delete (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Ignore budget on TX napi polling (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix mac_hash database inconsistency (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Do not count LLC/SNAP in MTU calculation (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Do not disable vlan filter during promiscuous mode (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Verify port number in __mlx4_unregister_mac (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Run loopback test only when port is up (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix set port ratelimit for 40GE (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Don't configure the HW vxlan parser when vxlan offloading isn't set (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: IRQ affinity hint is not cleared on port down (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Don't use irq_affinity_notifier to track changes in IRQ affinity map (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix the error flow when probing with invalid VF configuration (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use affinity hint (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Keep only one driver entry release mlx4_priv (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix SRIOV free-pool management when enforcing resource quotas (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix gfp passing in create_qp_common() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix GFP flags parameters to be gfp_t (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Implement IB_QP_CREATE_USE_GFP_NOIO (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Reset RoCE VF gids when guest driver goes down (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Add interface for selecting VFs to enable QP0 via MLX proxy QPs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Add infrastructure for selecting VFs to enable QP0 via MLX proxy QPs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Preparation for VFs to issue/receive SMI (QP0) requests/responses (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: SET_PORT called by mlx4_ib_modify_port should be wrapped (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix incorrect FLAGS1 bitmap test in mlx4_QUERY_FUNC_CAP (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix memory leaks in SR-IOV error paths (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: fix unitialised variable is_mcast (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Fix warning about cast of wr_id back to pointer on 32 bits (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: add missing padding at end of struct mlx5_ib_create_srq (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: add missing padding at end of struct mlx5_ib_create_cq (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Refactor UMR to have its own context struct (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Set QP offsets and parameters for user QPs and not just for kernel QPs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Store MR attributes in mlx5_mr_core during creation and after UMR (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Add MR to radix tree in reg_mr_callback (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Fix error handling in reg_umr (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Copy DIF fields only when input and output space values match (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Simplify signature handover wqe for interleaved buffers (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Fix signature handover operation for interleaved buffers (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Replace pr_warning() with pr_warn() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Deprecate use_prio module parameter (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix uninitialized use of 'port_up' in mlx4_en_set_channels() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Invoke UPDATE_QP for proxy QP1 on MAC changes (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add UPDATE_QP SRIOV wrapper support (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix inaccurate return value of mlx4_flow_attach() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Using positive error value for unsigned (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Protect MAC address modification with the state_lock mutex (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Removed unnecessary bit operation condition (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix smatch error - possible access to a null variable (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix errors in MAC address changing when port is down (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: User prio mapping gets corrupted when changing number of channels (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Enforce irq affinity changes immediatly (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mellanox: Logging message cleanups (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Don't issue PCIe speed/width checks for VFs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Load the Eth driver first (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix slave id computation for single port VF (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Adjust port number in qp_attach wrapper when detaching (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: don't use napi_synchronize inside mlx4_en_netpoll (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Defer VF initialization till PF is fully initialized (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Preserve pci_dev_data after __mlx4_remove_one() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Add block multicast loopback support (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mthca: Use pci_enable_msix_exact() instead of pci_enable_msix() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Set proper build dependancy with vxlan (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Make buffer larger to avoid overflow warning (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix some indenting in mlx4_ib_add() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mthca: Return an error on ib_copy_to_udata() failure (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Implement vxlan ndo calls (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add support for CONFIG_DEV command (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: USe one wrapper that returns -EPERM (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: pass pci_device_id.driver_data to __mlx4_init_one during reset (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Use actual number of PCI functions (PF + VFs) for alias GUID logic (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Adapt num_vfs/probed_vf params for single port VF (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Adapt code for N-Port VF (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add utils for N-Port VFs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Add data structures to support N-Ports per VF (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4_ib: Adapt code to use caps.num_ports instead of a constant (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix a sparse endianness warning (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Don't receive packets when the napi budget == 0 (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Deregister multicast vxlan steering rules when going down (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Call dev_kfree_skb_any instead of dev_kfree_skb (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Load the IB driver when the device supports IBoE (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Handle vxlan steering rules for mac address changes (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix wrong dump of the vxlan offloads device capability (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Activate RoCE/SRIOV (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix SIDR support of for UD QPs under SRIOV/RoCE (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Implement IP based gids support for RoCE/SRIOV (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Add ref counting to port MAC table for RoCE (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: In RoCE allow guests to have multiple GIDS (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: For RoCE, allow slaves to set the GID entry at that slave's index (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Adjust QP1 multiplexing for RoCE/SRIOV (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5_core: remove unreachable function call in module init (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Expose support for signature MR feature (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Collect signature error completion (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Support IB_WR_REG_SIG_MR (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Keep mlx5 MRs in a radix tree under device (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Remove MTT access mode from umr flags helper function (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Break up wqe handling into begin & finish routines (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Initialize mlx5_ib_qp signature-related members (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx5: Implement create_mr and destroy_mr (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: mlx4_en_verify_params() can be static (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Change Connect-X description in kconfig (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use union for BlueFlame WQE (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix sparse warning (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix selftest failing on non 10G link speed (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Replace mlx4_en_mac_to_u64() with mlx4_mac_to_u64() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Move queue stopped/waked counters to be per ring (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Pad ethernet packets smaller than 17 bytes (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Verify mlx4_en module parameters (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix UP limit in ieee_ets->prio_tc (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix bad use of dev_id (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Expose port number through sysfs (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx: Bump all Mellanox driver versions (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Fix limiting number of IRQ's instead of RSS queues (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Set number of RX rings in a utility function (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx5: Use pci_enable_msix_range() instead of pci_enable_msix() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Use pci_enable_msix_range() instead of pci_enable_msix() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Use IS_ENABLED(CONFIG_IPV6) (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Add dependency INET (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mlx4: Fix error return code (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: call gro handler for encapsulated frames (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Select PTP_1588_CLOCK (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: fix error return code in mlx4_en_get_qp() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: slight optimization of addr compare (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: mlx4 calls skb_set_hash (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx4: Implement the SIOCGHWTSTAMP ioctl (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: When marsheling uverbs path, clear unused fields (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: Add user space RMPP support (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: add new ioctl to ABI to support new registration options (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: Add dev_notice messages for various umad/mad registration failures (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: Update module to [pr|dev]_* style print messages (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] umad: Update module to [pr|dev]_* style print messages (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] iwcm: Use a default listen backlog if needed (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Add user MR re-registration support (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] rdma/core: Add support for iWARP Port Mapper user space service (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] umad: Fix use-after-free on close (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] umad: Fix error handling (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Fix kobject leak on device register error flow (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Fix port kobject deletion during error flow (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Remove unneeded kobject_get/put calls (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Fix sparse warnings about redeclared functions (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: Fix sparse warning about gfp_t use (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] Add a QP creation flag to use GFP_NOIO allocations (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Remove overload in ib_sg_dma* (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] ehca: Remove ib_sg_dma_address() and ib_sg_dma_len() overloads (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] ipath: Remove ib_sg_dma_address() and ib_sg_dma_len() overloads (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] qib: Remove ib_sg_dma_address() and ib_sg_dma_len() overloads (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] mad: Check and handle potential DMA mapping errors (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Introduce signature verbs API (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Introduce protected memory regions (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] Refactor umem to use linear SG table (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Fix unused variable warning (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] cma: Handle global/non-linklocal IPv6 addresses in cma_check_linklocal() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] cm: Fix missing unlock on error in cm_init_qp_rtr_attr() (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Make ib_addr a core IB module (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Add support for RDMA_NODE_USNIC_UDP (Amir Vadai) [1107617 1107618 1107619 1107620]
- [infiniband] core: Add RDMA_TRANSPORT_USNIC_UDP (Amir Vadai) [1107617 1107618 1107619 1107620]
- [kernel] genirq: Allow forcing cpu affinity of interrupts (Amir Vadai) [1107617 1107618 1107619 1107620]
- [lib] cpumask: cpumask_set_cpu_local_first to use all cores when numa node is not defined (Amir Vadai) [1107617 1107618 1107619 1107620]
- [lib] cpumask: Utility function to set n'th cpu - local cpu first (Amir Vadai) [1107617 1107618 1107619 1107620]
- [ethernet] mlx: Convert ethernet mac address declarations to use ETH_ALEN (Amir Vadai) [1107617 1107618 1107619 1107620]
- [net] core: Add sysfs file for port number (Amir Vadai) [1107617 1107618 1107619 1107620]

* Tue Oct 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-182.el7]
- [ethernet] qlge: Remove DEFINE_PCI_DEVICE_TABLE macro use (Chad Dupuis) [1089357]
- [ethernet] qlge: get rid of SET_ETHTOOL_OPS (Chad Dupuis) [1089357]
- [ethernet] qlge: Convert /n to \n (Chad Dupuis) [1089357]
- [ethernet] qlge: remove open-coded skb_cow_head (Chad Dupuis) [1089357]
- [ethernet] qlge: Do not propaged vlan tag offloads to vlans (Chad Dupuis) [1089357]
- [ethernet] qlge: Get rid of an redundant assignment (Chad Dupuis) [1089357]
- [ethernet] qlge: delete non-required instances of include <linux/init.h> (Chad Dupuis) [1089357]
- [ethernet] qlge: Fix vlan netdev features (Chad Dupuis) [1089357]
- [ethernet] qlge: make local function static (Chad Dupuis) [1089357]
- [ethernet] qlge: Update version to 1.00.00.34 (Chad Dupuis) [1089357]
- [ethernet] qlge: Allow enable/disable rx/tx vlan acceleration independently (Chad Dupuis) [1089357]
- [ethernet] qlge: Fix ethtool statistics (Chad Dupuis) [1089357]
- [ethernet] qlge: remove unnecessary pci_set_drvdata() (Chad Dupuis) [1089357]
- [ethernet] qlge: Update version to 1.00.00.33 (Chad Dupuis) [1089357]
- [ethernet] qlge: Enhance nested VLAN (Q-in-Q) handling (Chad Dupuis) [1089357]
- [ethernet] qlge: call ql_core_dump() only if dump memory was allocated (Chad Dupuis) [1089357]
- [kernel] audit: allow user processes to log from another PID namespace (Richard Guy Briggs) [1010455]
- [kernel] audit: anchor all pid references in the initial pid namespace (Richard Guy Briggs) [1010455]
- [kernel] audit: convert PPIDs to the inital PID namespace (Richard Guy Briggs) [1010455]
- [kernel] sched: declare pid_alive as inline (Richard Guy Briggs) [1010455]
- [kernel] pid: get pid_t ppid of task in init_pid_ns (Richard Guy Briggs) [1010455]
- [net] netlabel: shorter names for the NetLabel catmap funcs/structs (Paul Moore) [1119662]
- [net] netlabel: fix the catmap walking functions (Paul Moore) [1119662]
- [net] netlabel: fix the horribly broken catmap functions (Paul Moore) [1119662]
- [net] netlabel: fix a problem when setting bits below the previously lowest bit (Paul Moore) [1119662]
- [kernel] sched/time: fix lock inversion in thread_group_cputime (Rik van Riel) [1120307]
- [kernel] seqlock: add irqsave variant of read_seqbegin_or_lock (Rik van Riel) [1120307]
- [kernel] sched: make lockless sys_times kABI-friendly (Rik van Riel) [1120307]
- [kernel] sched/cputime: atomically increment stime & utime (Rik van Riel) [1120307]
- [kernel] time, signal: protect resource use statistics with seqlock (Rik van Riel) [1120307]
- [kernel] exit: always reap resource stats in __exit_signal (Rik van Riel) [1120307]
- [kernel] seqcount: Provide raw_read_seqcount() (Rik van Riel) [1120307]
- [kernel] take read_seqbegin_or_lock() and friends to seqlock.h (Rik van Riel) [1120307]
- [kernel] sched: change thread_group_cputime() to use for_each_thread() (Rik van Riel) [1120307]
- [usb] usb3503: Fix a warning for using an uninitialized variable (Don Zickus) [1148954]
- [ethernet] tg3: prevent ifup/ifdown during PCI error recovery (Ivan Vecera) [1088637]
- [ethernet] tg3: fix return value in tg3_get_stats64 (Ivan Vecera) [1088637]
- [ethernet] tg3: Remove DEFINE_PCI_DEVICE_TABLE macro use (Ivan Vecera) [1088637]
- [ethernet] tg3: Modify tg3_tso_bug() to handle multiple TX rings (Ivan Vecera) [1088637]
- [ethernet] tg3: Clear NETIF_F_TSO6 flag before doing software GSO (Ivan Vecera) [1088637]
- [ethernet] tg3: Replace ethtool_ops::{get, set}_rxfh_indir() with {get, set}_rxfh() (Ivan Vecera) [1088637]
- [ethernet] tg3: Update copyright and version to 3.137 (Ivan Vecera) [1088637]
- [ethernet] tg3: Prevent page allocation failure during TSO workaround (Ivan Vecera) [1088637]
- [ethernet] tg3: Don't modify ip header fields when doing GSO (Ivan Vecera) [1088637]
- [ethernet] tg3: update rx_jumbo_pending ring param only when jumbo frames are enabled (Ivan Vecera) [1088637]
- [ethernet] tg3: remove open-coded skb_cow_head (Ivan Vecera) [1088637]
- [ethernet] tg3: remove empty MDIO bus reset function (Ivan Vecera) [1088637]
- [ethernet] tg3: Do not include vlan acceleration features in vlan_features (Ivan Vecera) [1088637]
- [ethernet] tg3: Call dev_kfree_skby_any instead of dev_kfree_skb (Ivan Vecera) [1088637]
- [ethernet] tg3: Use pci_enable_msix_range() instead of pci_enable_msix() (Ivan Vecera) [1088637]
- [ethernet] tg3: Fix deadlock in tg3_change_mtu() (Ivan Vecera) [1088637]
- [ethernet] tg3: cleanup an error path in tg3_phy_reset_5703_4_5() (Ivan Vecera) [1088637]
- [ethernet] tg3: delete non-required instances of include <linux/init.h> (Ivan Vecera) [1088637]
- [ethernet] tg3: Implement the SIOCGHWTSTAMP ioctl (Ivan Vecera) [1088637]

* Mon Oct 06 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-181.el7]
- [tools] perf/powerpc: Adjust callchain based on DWARF debug info (Jiri Olsa) [1113736]
- [tools] perf: Allow to specify lib compile variable for spec usage (Jiri Olsa) [879133]
- [tools] perf/symbols: Get kernel start address by symbol name (Jiri Olsa) [1134356]
- [tools] perf: Fix segfault in cumulative.callchain report (Jiri Olsa) [1134356]
- [tools] perf/tests: Add test for closing dso objects on EMFILE error (Jiri Olsa) [1134356]
- [tools] perf/tests: Add test for caching dso file descriptors (Jiri Olsa) [1134356]
- [tools] perf/tests: Allow reuse of test_file function (Jiri Olsa) [1134356]
- [tools] perf/tests: Spawn child for each test (Jiri Olsa) [1134356]
- [tools] perf: Add dso__data_* interface descriptons (Jiri Olsa) [1134356]
- [tools] perf: Allow to close dso fd in case of open failure (Jiri Olsa) [1134356]
- [tools] perf: Add file size check and factor dso__data_read_offset (Jiri Olsa) [1134356]
- [tools] perf: Cache dso data file descriptor (Jiri Olsa) [1134356]
- [tools] perf: Add global count of opened dso objects (Jiri Olsa) [1134356]
- [tools] perf: Add global list of opened dso objects (Jiri Olsa) [1134356]
- [tools] perf: Add data_fd into dso object (Jiri Olsa) [1134356]
- [tools] perf: Separate dso data related variables (Jiri Olsa) [1134356]
- [tools] perf: Cache register accesses for unwind processing (Jiri Olsa) [1134356]
- [tools] perf/record: Fix to honor user freq/interval properly (Jiri Olsa) [1134356]
- [tools] perf/timechart: Reflow documentation (Jiri Olsa) [1134356]
- [tools] perf/probe: Improve error messages in --line option (Jiri Olsa) [1134356]
- [tools] perf/probe: Improve an error message of perf probe --vars mode (Jiri Olsa) [1134356]
- [tools] perf/probe: Show error code and description in verbose mode (Jiri Olsa) [1134356]
- [tools] perf/probe: Improve error message for unknown member of data structure (Jiri Olsa) [1134356]
- [tools] perf/tests: Show the inner make output when an error happens (Jiri Olsa) [1134356]
- [tools] perf: Emit more precise message for missing glibc static library (Jiri Olsa) [1134356]
- [tools] perf: Add dcacheline sort (Jiri Olsa) [1134356]
- [tools] perf: Add support to dynamically get cacheline size (Jiri Olsa) [1134356]
- [tools] perf: Add cpumode to struct hist_entry (Jiri Olsa) [1134356]
- [tools] perf/report: Add mem-mode documentation to report command (Jiri Olsa) [1134356]
- [tools] perf: Update mmap2 interface with protection and flag bits (Jiri Olsa) [1134356]
- [tools] perf/script/python: Print array argument as string (Jiri Olsa) [1134356]
- [tools] perf: Prettify the tags/TAGS/cscope targets output (Jiri Olsa) [1134356]
- [tools] perf: Fix pipe check regression in attr event callback (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Added support for __get_bitmask() macro (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Add options to function plugin (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Add options to plugins (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Add flag to not load event plugins (Jiri Olsa) [1134356]
- [tools] perf/documentation: Add description for conditional branch filter (Jiri Olsa) [1134356]
- [tools] Revert: perf: Disable PERF_RECORD_MMAP2 support (Jiri Olsa) [1134356]
- [tools] perf: Add conditional branch filter 'cond' to perf record (Jiri Olsa) [1134356]
- [tools] perf: Fix 'make help' message error (Jiri Olsa) [1134356]
- [tools] perf/record: Fix poll return value propagation (Jiri Olsa) [1134356]
- [tools] perf: Move elide bool into perf_hpp_fmt struct (Jiri Olsa) [1134356]
- [tools] perf: Remove elide setup for SORT_MODE__MEMORY mode (Jiri Olsa) [1134356]
- [tools] perf: Fix "==" into "=" in ui_browser__warning assignment (Jiri Olsa) [1134356]
- [tools] perf: Allow overriding sysfs and proc finding with env var (Jiri Olsa) [1134356]
- [tools] perf: Consider header files outside perf directory in tags target (Jiri Olsa) [1134356]
- [tools] perf: Add warning when disabling perl scripting support due to missing devel files (Jiri Olsa) [1134356]
- [tools] perf/trace: Warn the user when not available (Jiri Olsa) [1134356]
- [tools] perf/tests: Add a test case for cumulating callchains (Jiri Olsa) [1134356]
- [tools] perf/tests: Define and use symbolic names for fake symbols (Jiri Olsa) [1134356]
- [tools] perf: Reset output/sort order to default (Jiri Olsa) [1134356]
- [tools] perf/ui/gtk: Fix callchain display (Jiri Olsa) [1134356]
- [tools] perf/ui/stdio: Fix invalid percentage value of cumulated hist entries (Jiri Olsa) [1134356]
- [tools] perf: Enable --children option by default (Jiri Olsa) [1134356]
- [tools] perf/top: Add top.children config option (Jiri Olsa) [1134356]
- [tools] perf/top: Add --children option (Jiri Olsa) [1134356]
- [tools] perf/top: Convert to hist_entry_iter (Jiri Olsa) [1134356]
- [tools] perf: Add callback function to hist_entry_iter (Jiri Olsa) [1134356]
- [tools] perf: Do not auto-remove Children column if --fields given (Jiri Olsa) [1134356]
- [tools] perf/report: Add report.children config option (Jiri Olsa) [1134356]
- [tools] perf/report: Add --children option (Jiri Olsa) [1134356]
- [tools] perf: Add more hpp helper functions (Jiri Olsa) [1134356]
- [tools] perf: Apply percent-limit to cumulative percentage (Jiri Olsa) [1134356]
- [tools] perf/ui/gtk: Add support to accumulated hist stat (Jiri Olsa) [1134356]
- [tools] perf/ui/browser: Add support to accumulated hist stat (Jiri Olsa) [1134356]
- [tools] perf/ui/hist: Add support to accumulated hist stat (Jiri Olsa) [1134356]
- [tools] perf: Save callchain info for each cumulative entry (Jiri Olsa) [1134356]
- [tools] perf/callchain: Add callchain_cursor_snapshot() (Jiri Olsa) [1134356]
- [tools] perf/report: Cache cumulative callchains (Jiri Olsa) [1134356]
- [tools] perf: Update cpumode for each cumulative entry (Jiri Olsa) [1134356]
- [tools] perf/hists: Accumulate hist entry stat based on the callchain (Jiri Olsa) [1134356]
- [tools] perf/hists: Check if accumulated when adding a hist entry (Jiri Olsa) [1134356]
- [tools] perf/hists: Add support for accumulated stat of hist entry (Jiri Olsa) [1134356]
- [tools] perf: Introduce struct hist_entry_iter (Jiri Olsa) [1134356]
- [tools] perf: Introduce hists__inc_nr_samples() (Jiri Olsa) [1134356]
- [tools] perf: Add automatic remapping of Android libraries (Jiri Olsa) [1134356]
- [tools] perf: Add cat as fallback pager (Jiri Olsa) [1134356]
- [tools] perf/tests: Add a testcase for histogram output sorting (Jiri Olsa) [1134356]
- [tools] perf/tests: Factor out print_hists_*() (Jiri Olsa) [1134356]
- [tools] perf: Introduce reset_output_field() (Jiri Olsa) [1134356]
- [tools] perf: Get rid of obsolete hist_entry__sort_list (Jiri Olsa) [1134356]
- [tools] perf/hists: Reset width of output fields with header length (Jiri Olsa) [1134356]
- [tools] perf: Skip elided sort entries (Jiri Olsa) [1134356]
- [tools] perf/top: Add --fields option to specify output fields (Jiri Olsa) [1134356]
- [tools] perf/report/tui: Fix a bug when --fields/sort is given (Jiri Olsa) [1134356]
- [tools] perf: Add ->sort() member to struct sort_entry (Jiri Olsa) [1134356]
- [tools] perf/report: Add -F option to specify output fields (Jiri Olsa) [1134356]
- [tools] perf: Call perf_hpp__init() before setting up GUI browsers (Jiri Olsa) [1134356]
- [tools] perf: Consolidate management of default sort orders (Jiri Olsa) [1134356]
- [tools] perf: Allow hpp fields to be sort keys (Jiri Olsa) [1134356]
- [tools] perf/ui: Get rid of callback from __hpp__fmt() (Jiri Olsa) [1134356]
- [tools] perf: Consolidate output field handling to hpp format routines (Jiri Olsa) [1134356]
- [tools] perf: Use hpp formats to sort final output (Jiri Olsa) [1134356]
- [tools] perf: Support event grouping in hpp ->sort() (Jiri Olsa) [1134356]
- [tools] perf: Use hpp formats to sort hist entries (Jiri Olsa) [1134356]
- [tools] perf: Convert sort entries to hpp formats (Jiri Olsa) [1134356]
- [tools] perf: Add ->cmp(), ->collapse() and ->sort() to perf_hpp_fmt (Jiri Olsa) [1134356]
- [tools] perf: Add libdw DWARF post unwind support for ARM (Jiri Olsa) [1134356]
- [tools] perf/tests: Add dwarf unwind test on ARM (Jiri Olsa) [1134356]
- [tools] perf/tests: Introduce perf_regs_load function on ARM (Jiri Olsa) [1134356]
- [tools] perf: Consolidate types.h for ARM and ARM64 (Jiri Olsa) [1134356]
- [tools] perf/session: Fix possible null pointer dereference in session.c (Jiri Olsa) [1134356]
- [tools] perf/sched: Cleanup, remove unused variables in map_switch_event() (Jiri Olsa) [1134356]
- [tools] perf/sched: Remove nr_state_machine_bugs in perf latency (Jiri Olsa) [1134356]
- [tools] perf: Remove usage of trace_sched_wakeup(.success) (Jiri Olsa) [1134356]
- [tools] perf: Use tid for finding thread (Jiri Olsa) [1134356]
- [tools] perf: Get rid of on_exit() feature test (Jiri Olsa) [1134356]
- [tools] perf/record: Propagate exit status of a command line workload (Jiri Olsa) [1134356]
- [tools] perf: Clarify the output of perf sched map (Jiri Olsa) [1134356]
- [tools] perf: Adapt the TASK_STATE_TO_CHAR_STR to new value in kernel space (Jiri Olsa) [1134356]
- [tools] perf: Add missing event for perf sched record (Jiri Olsa) [1134356]
- [tools] perf: Move ACCESS_ONCE from perf.h header (Jiri Olsa) [1134356]
- [tools] perf: Move sys_perf_event_open function from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Move syscall and arch specific defines from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Move perf_call_graph_mode enum from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Move sample data structures from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Remove PR_TASK_PERF_EVENTS_* from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Remove asmlinkage define from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Remove min define from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Remove unlikely define from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Remove MAX_COUNTERS define from perf.h (Jiri Olsa) [1134356]
- [tools] perf: Consolidate types.h (Jiri Olsa) [1134356]
- [tools] perf: Unify export.h (Jiri Olsa) [1134356]
- [tools] perf/arm64: Wire up perf_regs and unwind support (Jiri Olsa) [1134356]
- [tools] perf: Move u64_swap union (Jiri Olsa) [1134356]
- [tools] perf/tests: add a test of kvm-390 trace event (Jiri Olsa) [1134356]
- [tools] perf/tests: Add numeric identifier to evlist_test (Jiri Olsa) [1134356]
- [tools] perf: Parse tracepoints with '-' in system name (Jiri Olsa) [1134356]
- [tools] perf: Handle EINTR error for readn/writen (Jiri Olsa) [1134356]
- [tools] perf/tests: Add map groups sharing with thread object test (Jiri Olsa) [1134356]
- [tools] perf: Share map_groups among threads of the same group (Jiri Olsa) [1134356]
- [tools] perf: Reference count map_groups objects (Jiri Olsa) [1134356]
- [tools] perf: Allocate thread map_groups's dynamically (Jiri Olsa) [1134356]
- [tools] perf/tests: Add thread maps lookup automated tests (Jiri Olsa) [1134356]
- [tools] perf/tests: Add a test case for hists filtering (Jiri Olsa) [1134356]
- [tools] perf/tests: Factor out fake_setup_machine() (Jiri Olsa) [1134356]
- [tools] perf/hists/tui: Count callchain rows separately (Jiri Olsa) [1134356]
- [tools] perf/top/tui: Update nr_entries properly after a filter is applied (Jiri Olsa) [1134356]
- [tools] perf/ui/tui: Rename hist_browser__update_nr_entries() (Jiri Olsa) [1134356]
- [tools] perf/ui/tui: Fix off-by-one in hist_browser__update_nr_entries() (Jiri Olsa) [1134356]
- [tools] perf/hists: Add missing update on filtered stats in hists__decay_entries() (Jiri Olsa) [1134356]
- [tools] perf: Account entry stats when it's added to the output tree (Jiri Olsa) [1134356]
- [tools] perf/hists: Collapse expanded callchains after filter is applied (Jiri Olsa) [1134356]
- [tools] perf/hists: Add a couple of hists stat helper functions (Jiri Olsa) [1134356]
- [tools] perf/hists: Move column length calculation out of hists__inc_stats() (Jiri Olsa) [1134356]
- [tools] perf/hists: Rename hists__inc_stats() (Jiri Olsa) [1134356]
- [tools] perf/report: Count number of entries separately (Jiri Olsa) [1134356]
- [tools] perf/callchain: Add generic report parse callchain callback function (Jiri Olsa) [1134356]
- [tools] perf/kmem: Utilize the new generic cpunode_map (Jiri Olsa) [1134356]
- [tools] perf: Use cpu/possible instead of cpu/kernel_max (Jiri Olsa) [1134356]
- [tools] perf: Allow ability to map cpus to nodes easily (Jiri Olsa) [1134356]
- [tools] perf: Fix pmu object compilation error (Jiri Olsa) [1134356]
- [tools] perf/sched: Introduce --list-cmds for use by scripts (Jiri Olsa) [1134356]
- [tools] perf/lock: Introduce --list-cmds for use by scripts (Jiri Olsa) [1134356]
- [tools] perf/mem: Introduce --list-cmds for use by scripts (Jiri Olsa) [1134356]
- [tools] perf/kmem: Introduce --list-cmds for use by scripts (Jiri Olsa) [1134356]
- [tools] perf: Show absolute percentage by default (Jiri Olsa) [1134356]
- [tools] perf/ui/tui: Add 'F' hotkey to toggle percentage output (Jiri Olsa) [1134356]
- [tools] perf: Add hist.percentage config option (Jiri Olsa) [1134356]
- [tools] perf/diff: Add --percentage option (Jiri Olsa) [1134356]
- [tools] perf/top: Add --percentage option (Jiri Olsa) [1134356]
- [tools] perf/report: Add --percentage option (Jiri Olsa) [1134356]
- [tools] perf/hists: Add support for showing relative percentage (Jiri Olsa) [1134356]
- [tools] perf/probe: Fix perf probe to find correct variable DIE (Jiri Olsa) [1134356]
- [tools] perf/probe: Fix a segfault if asked for variable it doesn't find (Jiri Olsa) [1134356]
- [tools] perf/tests/x86: Fix stack map lookup in dwarf unwind test (Jiri Olsa) [1134356]
- [tools] perf/x86: Fix perf to use non-executable stack, again (Jiri Olsa) [1134356]
- [tools] perf: Remove extra '/' character in events file path (Jiri Olsa) [1134356]
- [tools] perf/machine: Search for modules in s/lib/modules/s (Jiri Olsa) [1134356]
- [tools] perf/tests: Add static build make test (Jiri Olsa) [1134356]
- [tools] perf: Fix bfd dependency libraries detection (Jiri Olsa) [1134356]
- [tools] perf: Use LDFLAGS instead of ALL_LDFLAGS (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Fix memory leak in pretty_print() (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Fix backward compatibility macros for pevent filter enums (Jiri Olsa) [1134356]
- [tools] perf: Disable libdw unwind for all but x86 arch (Jiri Olsa) [1134356]
- [tools] perf/tests/x86: Fix memory leak in sample_ustack() (Jiri Olsa) [1134356]
- [tools] perf: Improve error reporting (Jiri Olsa) [1134356]
- [tools] perf: Adjust symbols in VDSO (Jiri Olsa) [1134356]
- [tools] perf/kvm: Fix 'Min time' counting in report command (Jiri Olsa) [1134356]
- [tools] perf: Instead of redirecting flex output, use -o (Jiri Olsa) [1134356]
- [tools] perf: Fix double free in perf test 21 (code-reading.c) (Jiri Olsa) [1134356]
- [tools] perf/stat: Initialize statistics correctly (Jiri Olsa) [1134356]
- [tools] perf/bench: Set more defaults in the 'numa' suite (Jiri Olsa) [1134356]
- [tools] perf/bench: Update manpage to mention numa and futex (Jiri Olsa) [1134356]
- [tools] perf/probe: Use dwarf_getcfi_elf() instead of dwarf_getcfi() (Jiri Olsa) [1134356]
- [tools] perf/probe: Fix to handle errors in line_range searching (Jiri Olsa) [1134356]
- [tools] perf/probe: Fix --line option behavior (Jiri Olsa) [1134356]
- [tools] perf: Pick up libdw without explicit LIBDW_DIR (Jiri Olsa) [1134356]
- [tools] perf/callchains: Disable unwind libraries when libelf isn't found (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Do not call warning() directly (Jiri Olsa) [1134356]
- [tools] perf/lib/traceevent: Print event name when show warning if possible (Jiri Olsa) [1134356]
- [tools] perf/top: Fix documentation of invalid -s option (Jiri Olsa) [1134356]
- [tools] perf: Allow building for tile (Jiri Olsa) [1134356]
- [tools] perf: Remove unused simple_strtoul() function (Jiri Olsa) [1134356]
- [tools] perf: Update some code references in design.txt (Jiri Olsa) [1134356]
- [tools] perf/evsel: Update function names in debug messages (Jiri Olsa) [1134356]
- [tools] perf: Remove thread__find_map function (Jiri Olsa) [1134356]
- [tools] perf/annotate: Print the evsel name in the stdio output (Jiri Olsa) [1134356]
- [tools] perf/report: Use ui__has_annotation() (Jiri Olsa) [1134356]
- [tools] perf: Fix memory leak when synthesizing thread records (Jiri Olsa) [1134356]
- [tools] perf: Use tid in mmap/mmap2 events to find maps (Jiri Olsa) [1134356]
- [tools] perf/report: Merge al->filtered with hist_entry->filtered (Jiri Olsa) [1134356]
- [tools] perf/symbols: Apply all filters to an addr_location (Jiri Olsa) [1134356]
- [tools] perf/symbols: Record the reason for filtering an address_location (Jiri Olsa) [1134356]
- [tools] perf/sched: Fixup header alignment in 'latency' output (Jiri Olsa) [1134356]
- [tools] perf/timechart: Fix off-by-one error in 'record' argv handling (Jiri Olsa) [1134356]
- [tools] perf/machine: Factor machine__find_thread to take tid argument (Jiri Olsa) [1134356]
- [tools] perf: Speed up thread map generation (Jiri Olsa) [1134356]
- [tools] perf/kvm: introduce --list-cmds for use by scripts (Jiri Olsa) [1134356]
- [tools] perf/ui/hists: Pass evsel to hpp->header/width functions explicitly (Jiri Olsa) [1134356]
- [tools] perf/symbols: Introduce thread__find_cpumode_addr_location (Jiri Olsa) [1134356]
- [tools] perf/session: Change header.misc dump from decimal to hex (Jiri Olsa) [1134356]
- [tools] perf/ui/tui: Reuse generic __hpp__fmt() code (Jiri Olsa) [1134356]
- [tools] perf/ui/hists: Pass struct hpp to print functions (Jiri Olsa) [1134356]
- [tools] perf/ui/gtk: Reuse generic __hpp__fmt() code (Jiri Olsa) [1134356]
- [tools] perf/ui/stdio: Fix invalid output on event group report (Jiri Olsa) [1134356]
- [tools] perf: Fix synthesizing mmaps for threads (Jiri Olsa) [1134356]
- [tools] perf/probe: Clarify x86 register naming for perf probe (Jiri Olsa) [1134356]
- [tools] perf/mem: Clarify load-latency in documentation (Jiri Olsa) [1134356]
- [tools] perf/bench: Add futex-requeue microbenchmark (Jiri Olsa) [1134356]
- [tools] perf/bench: Add futex-wake microbenchmark (Jiri Olsa) [1134356]
- [tools] perf/bench: Add futex-hash microbenchmark (Jiri Olsa) [1134356]
- [tools] perf: Disable user-space callchain/stack dumps for function trace events (Jiri Olsa) [1134356]
- [tools] perf/symbols: Check compatible symtab type before loading dso (Jiri Olsa) [1134356]
- [tools] perf/symbols: Check return value of filename__read_debuglink() (Jiri Olsa) [1134356]
- [tools] perf/tests: Add NO_LIBDW_DWARF_UNWIND make test (Jiri Olsa) [1134356]
- [tools] perf: Setup default dwarf post unwinder (Jiri Olsa) [1134356]
- [tools] perf: Add libdw DWARF post unwind support (Jiri Olsa) [1134356]
- [tools] perf: Add feature check for libdw dwarf unwind (Jiri Olsa) [1134356]
- [tools] perf: Warn the user about how to enable libunwind support (Jiri Olsa) [1134356]
- [tools] perf: Add variable display for VF make output (Jiri Olsa) [1134356]
- [tools] perf: Factor features display code (Jiri Olsa) [1134356]
- [tools] perf: Fix bison OUTPUT directories dependency (Jiri Olsa) [1134356]
- [tools] perf/tests: Add pmu-bison.o make test (Jiri Olsa) [1134356]
- [tools] perf/tests: Fix *.o make tests (Jiri Olsa) [1134356]
- [tools] perf/probe: Support distro-style debuginfo for uprobe (Jiri Olsa) [1134356]
- [tools] perf/probe: Allow to add events on the local functions (Jiri Olsa) [1134356]
- [tools] perf/probe: Show source-level or symbol-level info for uprobes (Jiri Olsa) [1134356]
- [tools] perf/probe: Show appropriate symbol for ref_reloc_sym based kprobes (Jiri Olsa) [1134356]
- [tools] perf/probe: Find given address from offline dwarf (Jiri Olsa) [1134356]
- [tools] perf/probe: Use ref_reloc_sym based address instead of the symbol name (Jiri Olsa) [1134356]
- [tools] perf/probe: Show in what binaries/modules probes are set (Jiri Olsa) [1134356]
- [tools] perf/probe: Unify show_available_functions for uprobes/kprobes (Jiri Olsa) [1134356]
- [tools] perf/probe: Replace line_list with intlist (Jiri Olsa) [1134356]
- [tools] perf/probe: Remove incorrect symbol check for --list (Jiri Olsa) [1134356]
- [tools] perf/probe: Fix to do exit call for symbol maps (Jiri Olsa) [1134356]
- [tools] perf/symbols: No need to export dso__first_symbol (Jiri Olsa) [1134356]
- [tools] perf: Drop prefetch.h (Jiri Olsa) [1134356]
- [tools] perf: Move hash.h header (Jiri Olsa) [1134356]
- [tools] perf: Move fs.* to lib/api/fs/ (Jiri Olsa) [1134356]
- [tools] perf/callchain: Separate perf_reg_value function in perf_regs object (Jiri Olsa) [1134356]
- [tools] perf/callchain: Introduce HAVE_DWARF_UNWIND_SUPPORT macro (Jiri Olsa) [1134356]
- [tools] perf/callchain: Rename unwind__arch_reg_id into libunwind__arch_reg_id (Jiri Olsa) [1134356]
- [tools] perf/callchain: Separate libunwind code to special object (Jiri Olsa) [1134356]
- [tools] perf/callchain: Add mask into struct regs_dump (Jiri Olsa) [1134356]
- [tools] perf/callchain: Do not report zero address in unwind (Jiri Olsa) [1134356]
- [tools] perf: Fix dwarf unwind max_stack processing (Jiri Olsa) [1134356]
- [tools] perf/tests/x86: Add dwarf unwind test (Jiri Olsa) [1134356]
- [tools] perf/tests/x86: Introduce perf_regs_load function (Jiri Olsa) [1134356]
- [tools] perf: Fix memory leak in event_format__print function (Jiri Olsa) [1134356]
- [tools] perf/record: Add readable output for callchain debug (Jiri Olsa) [1134356]
- [tools] perf: Add call-graph option support into .perfconfig (Jiri Olsa) [1134356]
- [tools] perf: Put proper period for for samples without PERIOD sample_type (Jiri Olsa) [1134356]
- [tools] perf/report: Remove some needless container_of usage (Jiri Olsa) [1134356]
- [tools] perf: Shorten sample symbol resolving function signature (Jiri Olsa) [1134356]
- [tools] perf: Shorten sample symbol resolving function signature (Jiri Olsa) [1134356]
- [tools] perf/report: Use al->cpumode where applicable (Jiri Olsa) [1134356]
- [x86] perf/intel: Avoid spamming kernel log for BTS buffer failure (Jiri Olsa) [1134356]
- [x86] perf/intel: Protect LBR and extra_regs against KVM lying (Jiri Olsa) [1134356]
- [kernel] perf: Fix lockdep warning on process exit (Jiri Olsa) [1134356]
- [x86] perf/intel: Use proper dTLB-load-misses event on IvyBridge (Jiri Olsa) [1134356]
- [kernel] Revert: perf: Always destroy groups on exit (Jiri Olsa) [1134356]
- [kernel] perf: Do not allow optimized switch for non-cloned events (Jiri Olsa) [1134356]
- [kernel] perf: Pass protection and flags bits through mmap2 interface (Jiri Olsa) [1134356]
- [kernel] perf: Differentiate exec() and non-exec() comm events (Jiri Olsa) [1134356]
- [kernel] perf: Fix perf_event_comm() vs. exec() assumption (Jiri Olsa) [1134356]
- [x86] perf: Add conditional branch filtering support (Jiri Olsa) [1134356]
- [kernel] perf: Add new conditional branch filter 'PERF_SAMPLE_BRANCH_COND' (Jiri Olsa) [1134356]
- [x86] perf: Use common PMU interrupt disabled code (Jiri Olsa) [1134356]
- [kernel] perf: Disable sampled events if no PMU interrupt (Jiri Olsa) [1134356]
- [kernel] perf: Fix use after free in perf_remove_from_context() (Jiri Olsa) [1134356]
- [kernel] perf/events/core: Drop unused variable after cleanup (Jiri Olsa) [1134356]
- [x86] perf/intel: fix Haswell precise store data source encoding (Jiri Olsa) [1134356]
- [kernel] perf: Fix perf_event_open(.flags) test (Jiri Olsa) [1134356]
- [kernel] perf: Simplify perf_event_exit_task_context() (Jiri Olsa) [1134356]
- [kernel] perf: Rework free paths (Jiri Olsa) [1134356]
- [kernel] perf: Validate locking assumption (Jiri Olsa) [1134356]
- [kernel] perf: Always destroy groups on exit (Jiri Olsa) [1134356]
- [kernel] perf: Ensure consistent inherit state in groups (Jiri Olsa) [1134356]
- [x86] perf: Export perf_assign_events() (Jiri Olsa) [1134356]
- [kernel] perf: Allow building PMU drivers as modules (Jiri Olsa) [1134356]
- [kernel] perf: Prevent false warning in perf_swevent_add (Jiri Olsa) [1134356]
- [kernel] perf: Limit perf_event_attr::sample_period to 63 bits (Jiri Olsa) [1134356]
- [kernel] perf: Fix perf_event_init_context() (Jiri Olsa) [1134356]
- [kernel] perf: Fix race in removing an event (Jiri Olsa) [1134356]
- [x86] perf: Fix RAPL rdmsrl_safe() usage (Jiri Olsa) [1134356]
- [x86] perf/intel: Use rdmsrl_safe() when initializing RAPL PMU (Jiri Olsa) [1134356]
- [x86] perf/intel/rapl: Fix CPU hotplug callback registration (Jiri Olsa) [1134356]
- [x86] perf: Enable DRAM RAPL support on Intel Haswell (Jiri Olsa) [1134356]
- [kernel] perf: Optimize group_sched_in() (Jiri Olsa) [1134356]
- [x86] perf: Add a few more comments (Jiri Olsa) [1134356]
- [kernel] perf: Remove redundant PMU assignment (Jiri Olsa) [1134356]
- [kernel] perf: Fix prototype of find_pmu_context() (Jiri Olsa) [1134356]
- [x86] perf: Warn to early_printk() in case irq_work is too slow (Jiri Olsa) [1134356]
- [x86] perf/p4: Block PMIs on init to prevent a stream of unkown NMIs (Jiri Olsa) [1134356]
- [x86] perf/p4: Fix counter corruption when using lots of perf groups (Jiri Olsa) [1134356]
- [x86] perf: Push the duration-logging printk() to IRQ context (Jiri Olsa) [1134356]
- [kernel] workqueue: apply __WQ_ORDERED to create_singlethread_workqueue() (Tomas Henzl) [1131563]
- [md] raid10: always initialise ->state on newly allocated r10_bio (Jes Sorensen) [1085530]
- [md] raid10: avoid memory leak on error path during reshape (Jes Sorensen) [1085530]
- [md] raid10: Fix memory leak when raid10 reshape completes (Jes Sorensen) [1085530]
- [md] raid10: fix memory leak when reshaping a RAID10 (Jes Sorensen) [1085530]
- [md] raid5: avoid livelock caused by non-aligned writes (Jes Sorensen) [1085530]
- [md] don't allow bitmap file to be added to raid0/linear (Jes Sorensen) [1085530]
- [md] raid0: check for bitmap compatability when changing raid levels (Jes Sorensen) [1085530 1126348]
- [md] Recovery speed is wrong (Jes Sorensen) [1085530 1128517]
- [md] disable probing for md devices 512 and over (Jes Sorensen) [1085530]
- [md] raid1, raid10: always abort recover on write error (Jes Sorensen) [1085530]
- [md] flush writes before starting a recovery (Jes Sorensen) [1085530 1115749]
- [md] make sure GET_ARRAY_INFO ioctl reports correct "clean" status (Jes Sorensen) [1085530]
- [md] raid5: speedup sync_request processing (Jes Sorensen) [1085530]
- [md] raid5: deadlock between retry_aligned_read with barrier io (Jes Sorensen) [1085530]
- [md] raid5: add an option to avoid copy data from bio to stripe cache (Jes Sorensen) [1085530]
- [md] bitmap: remove confusing code from filemap_get_page (Jes Sorensen) [1085530]
- [md] raid5: avoid release list until last reference of the stripe (Jes Sorensen) [1085530]
- [md] md_clear_badblocks should return an error code on failure (Jes Sorensen) [1085530]
- [md] raid56: Don't perform reads to support writes until stripe is ready (Jes Sorensen) [1085530]
- [md] refuse to change shape of array if it is active but read-only (Jes Sorensen) [1085530]
- [md] always set MD_RECOVERY_INTR when interrupting a reshape thread (Jes Sorensen) [1085530]
- [md] always set MD_RECOVERY_INTR when aborting a reshape or other "resync" (Jes Sorensen) [1085530]
- [md] avoid possible spinning md thread at shutdown (Jes Sorensen) [1085530]
- [md] raid5: fix a race of stripe count check (Jes Sorensen) [1085530]
- [md] raid5: get_active_stripe avoids device_lock (Jes Sorensen) [1085530]
- [md] raid5: make_request does less prepare wait (Jes Sorensen) [1085530]
- [md] avoid oops on unload if some process is in poll or select (Jes Sorensen) [1085530]
- [md] raid1: r1buf_pool_alloc, free allocate pages when subsequent allocation fails (Jes Sorensen) [1085530]
- [md] bitmap: don't abuse i_writecount for bitmap files (Jes Sorensen) [1085530]
- [md] raid5: Fix CPU hotplug callback registration (Jes Sorensen) [1085530]
- [md] raid1: restore ability for check and repair to fix read errors (Jes Sorensen) [1085530]
- [md] raid5: close recently introduced race in stripe_head management (Jes Sorensen) [1085530]
- [md] raid5: fix long-standing problem with bitmap handling on write failure (Jes Sorensen) [1085530]
- [md] check command validity early in md_ioctl() (Jes Sorensen) [1085530]
- [md] ensure metadata is writen after raid level change (Jes Sorensen) [1085530]
- [md] raid10: avoid fullsync when not necessary (Jes Sorensen) [1085530]
- [md] allow a partially recovered device to be hot-added to an array (Jes Sorensen) [1085530]
- [md] fix problem when adding device to read-only array with bitmap (Jes Sorensen) [1085530]
- [md] raid10: fix bug when raid10 recovery fails to recover a block (Jes Sorensen) [1085530]
- [md] raid5: fix a recently broken BUG_ON() (Jes Sorensen) [1085530]
- [md] raid10: fix two bugs in handling of known-bad-blocks (Jes Sorensen) [1085530]
- [md] raid5: Fix possible confusion when multiple write errors occur (Jes Sorensen) [1085530]
- [Documentation] fix some typos in md documentation (Jes Sorensen) [1085530]
- [md] raid5: fix newly-broken locking in get_active_stripe (Jes Sorensen) [1085530]
- [md] test mddev->flags more safely in md_check_recovery (Jes Sorensen) [1085530]
- [md] raid5: fix new memory-reference bug in alloc_thread_groups (Jes Sorensen) [1085530]
- [block] submit_bio_wait() conversions (Jes Sorensen) [1085530]
- [md] raid5: Use conf->device_lock protect changing of multi-thread resources (Jes Sorensen) [1085530]
- [md] raid5: Before freeing old multi-thread worker, it should flush them (Jes Sorensen) [1085530]
- [md] raid5: For stripe with R5_ReadNoMerge, we replace REQ_FLUSH with REQ_NOMERGE (Jes Sorensen) [1085530]
- [md] raid1: Add some macros to make code clearly (Jes Sorensen) [1085530]
- [md] raid1: Replace raise_barrier/lower_barrier with freeze_array/unfreeze_array when reconfiguring the array (Jes Sorensen) [1085530]
- [md] raid1: Add a field array_frozen to indicate whether raid in freeze state (Jes Sorensen) [1085530]
- [md] Convert use of typedef ctl_table to struct ctl_table (Jes Sorensen) [1085530]
- [md] raid5: avoid deadlock when raid5 array has unack badblocks during md_stop_writes (Jes Sorensen) [1085530]
- [md] use MD_RECOVERY_INTR instead of kthread_should_stop in resync thread (Jes Sorensen) [1085530]
- [md] fix some places where mddev_lock return value is not checked (Jes Sorensen) [1085530]
- [md] raid5: Retry R5_ReadNoMerge flag when hit a read error (Jes Sorensen) [1085530]
- [md] raid5: relieve lock contention in get_active_stripe() (Jes Sorensen) [1085530]
- [md] raid5: relieve lock contention in get_active_stripe() (Jes Sorensen) [1085530]
- [md] raid5: add proper locking to error path of raid5_start_reshape (Jes Sorensen) [1085530]
- [kernel] wait: add wait_event_cmd() (Jes Sorensen) [1085530]
- [md] raid5: Use slow_path to release stripe when mddev->thread is null (Jes Sorensen) [1085530]
- [block] Consolidate duplicated bio_trim() implementations (Jes Sorensen) [1085530]
- [md] raid5: fix "distingush" typo (Jes Sorensen) [1085530]
- [md] raid5: only wakeup necessary threads (Jes Sorensen) [1085530]
- [md] raid5: flush out all pending requests before proceeding with reshape (Jes Sorensen) [1085530]
- [md] raid5: use seqcount to protect access to shape in make_request (Jes Sorensen) [1085530]
- [md] raid5: sysfs entry to control worker thread number (Jes Sorensen) [1085530]
- [md] raid5: offload stripe handle to workqueue (Jes Sorensen) [1085530]
- [md] raid5: fix stripe release order (Jes Sorensen) [1085530]
- [md] raid5: make release_stripe lockless (Jes Sorensen) [1085530]
- [md] Don't test all of mddev->flags at once (Jes Sorensen) [1085530]
- [md] Fix apparent cut-and-paste error in super_90_validate (Jes Sorensen) [1085530]
- [md] fix safe_mode buglet (Jes Sorensen) [1085530]
- [md] don't call md_allow_write in get_bitmap_file (Jes Sorensen) [1085530]
- [lib] raid6: add ARM-NEON accelerated syndrome calculation (Jes Sorensen) [1085530]
- [kernel] wait: Make the __wait_event*() interface more friendly (Jes Sorensen) [1085530]
- [kernel] sched/wait: Introduce ___wait_event() (Jes Sorensen) [1085530]

* Fri Oct 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-180.el7]
- [net] ethtool: Check that reserved fields of struct ethtool_rxfh are 0 (Ivan Vecera) [1138823]
- [net] ethtool: Replace ethtool_ops::{get, set}_rxfh_indir() with {get, set}_rxfh() (Ivan Vecera) [1138823]
- [net] ethtool: constify array pointer parameters to ethtool_ops::set_rxfh (Ivan Vecera) [1138823]
- [net] ethtool: Disallow ETHTOOL_SRSSH with both indir table and hash key unchanged (Ivan Vecera) [1138823]
- [net] ethtool: Expand documentation of ethtool_ops::{get, set}_rxfh() (Ivan Vecera) [1138823]
- [net] ethtool: Improve explanation of the two arrays following struct ethtool_rxfh (Ivan Vecera) [1138823]
- [net] ethtool: Name the 'no change' value for setting RSS hash key but not indir table (Ivan Vecera) [1138823]
- [net] ethtool: Return immediately on error in ethtool_copy_validate_indir() (Ivan Vecera) [1138823]
- [net] ethtool: exit the loop when invalid index occurs (Ivan Vecera) [1138823]
- [net] ethtool: Support for configurable RSS hash key (Ivan Vecera) [1138823]
- [lib] reciprocal_divide: update/correction of the algorithm (Jiri Benc) [1140665]
- [net] introduce reciprocal_scale helper and convert users (Jiri Benc) [1140665]
- [net] random32: add prandom_u32_max and convert open coded users (Jiri Benc) [1140665]
- [net] bpf: do not use reciprocal divide (Jiri Benc) [1140665]
- [net] genetlink: remove superfluous assignment (Jiri Benc) [1140656]
- [scsi] pmcraid: use proper genetlink multicast API (Jiri Benc) [1140656]
- [net] genetlink: Fix uninitialized variable in genl_validate_assign_mc_groups() (Jiri Benc) [1140656]
- [net] genetlink: fix genlmsg_multicast() bug (Jiri Benc) [1140656]
- [net] genetlink: make multicast groups const, prevent abuse (Jiri Benc) [1140656]
- [net] genetlink: pass family to functions using groups (Jiri Benc) [1140656]
- [net] genetlink: add and use genl_set_err() (Jiri Benc) [1140656]
- [net] genetlink: remove family pointer from genl_multicast_group (Jiri Benc) [1140656]
- [net] genetlink: remove genl_unregister_mc_group() (Jiri Benc) [1140656]
- [fs] quota: use proper genetlink multicast APIs (Jiri Benc) [1140656]
- [net] drop_monitor: use proper genetlink multicast APIs (Jiri Benc) [1140656]
- [net] genetlink: only pass array to genl_register_family_with_ops() (Jiri Benc) [1140656]
- [net] genetlink: rename shadowed variable (Jiri Benc) [1140656]
- [net] genetlink: unify registration functions (Jiri Benc) [1140656]
- [net] genetlink: make genl_ops flags a u8 and move to end (Jiri Benc) [1140656]
- [net] genetlink: make all genl_ops users const (Jiri Benc) [1140656]
- [net] genetlink: allow making ops const (Jiri Benc) [1140656]
- [net] genetlink: register family ops as array (Jiri Benc) [1140656]
- [net] genetlink: remove genl_register_ops/genl_unregister_ops (Jiri Benc) [1140656]
- [net] ieee802154: use genl_register_family_with_ops() (Jiri Benc) [1140656]
- [kernel] taskstats: use genl_register_family_with_ops() (Jiri Benc) [1140656]
- [net] genetlink: Remove extern from function prototypes (Jiri Benc) [1140656]
- [net] genetlink: fix usage of NLM_F_EXCL or NLM_F_REPLACE (Jiri Benc) [1140656]
- [net] udp: Fix inverted NAPI_GRO_CB(skb)->flush test (Florian Westphal) [1131999]
- [net] gre: gro: Fix a bug that breaks the forwarding path (Florian Westphal) [1131999]
- [net] gro: reset skb->truesize in napi_reuse_skb() (Florian Westphal) [1131999]
- [net] netdev_features: work around NETIF_F kabi breakage (Florian Westphal) [1131999]
- [net] l2tp: Enable checksum unnecessary conversions for l2tp/UDP sockets (Florian Westphal) [1131999]
- [net] vxlan: Enable checksum unnecessary conversions for vxlan/UDP sockets (Florian Westphal) [1131999]
- [net] gre: Add support for checksum unnecessary conversions (Florian Westphal) [1131999]
- [net] udp: Add support for doing checksum unnecessary conversion (Florian Westphal) [1131999]
- [net] Infrastructure for checksum unnecessary conversions (Florian Westphal) [1131999]
- [net] Support for csum_bad in skbuff (Florian Westphal) [1131999]
- [net] sctp: Change sctp to implement csum_levels (Florian Westphal) [1131999]
- [net] Allow GRO to use and set levels of checksum unnecessary (Florian Westphal) [1131999]
- [net] Clarification of CHECKSUM_UNNECESSARY (Florian Westphal) [1131999]
- [net] skbuff: improve comment on checksumming (Florian Westphal) [1131999]
- [net] skbuff: Use ALIGN macro instead of open coding it (Florian Westphal) [1131999]
- [net] Allocate a new 16 bits for flags in skbuff (Florian Westphal) [1131999]
- [net] gre: When GRE csum is present count as encap layer wrt csum (Florian Westphal) [1131999]
- [net] udp: additional GRO support (Florian Westphal) [1131999]
- [net] tcp: Call skb_gro_checksum_validate (Florian Westphal) [1131999]
- [net] ipv6: gro: fix CHECKSUM_COMPLETE support (Florian Westphal) [1131999]
- [net] gre: call skb_gro_checksum_simple_validate (Florian Westphal) [1131999]
- [net] add gro_compute_pseudo functions (Florian Westphal) [1131999]
- [net] skb_gro_checksum_* functions (Florian Westphal) [1131999]
- [net] fix setting csum_start in skb_segment() (Florian Westphal) [1131999]
- [net] vxlan: Checksum fixes (Florian Westphal) [1131999]
- [net] add skb_pop_rcv_encapsulation (Florian Westphal) [1131999]
- [net] udp: call __skb_checksum_complete when doing full checksum (Florian Westphal) [1131999]
- [net] Fix save software checksum complete (Florian Westphal) [1131999]
- [net] Fix GSO constants to match NETIF flags (Florian Westphal) [1131999]
- [net] Add skb_gro_postpull_rcsum to udp and vxlan (Florian Westphal) [1131999]
- [net] Save software checksum complete (Florian Westphal) [1131999]
- [net] Preserve CHECKSUM_COMPLETE at validation (Florian Westphal) [1131999]
- [net] vxlan: Add support for UDP checksums (v4 sending, v6 zero csums) (Florian Westphal) [1131999]
- [net] gre: Call gso_make_checksum (Florian Westphal) [1131999]
- [net] gre: simplify GRE header length calculation in gre_gso_segment() (Florian Westphal) [1131999]
- [net] Add GSO support for UDP tunnels with checksum (Florian Westphal) [1131999]
- [net] tcp: Call gso_make_checksum (Florian Westphal) [1131999]
- [net] Support for multiple checksums with gso (Florian Westphal) [1131999]
- [net] l2tp: call udp{6}_set_csum (Florian Westphal) [1131999]
- [net] udp: Generic functions to set checksum (Florian Westphal) [1131999]
- [net] l2tp: Add support for zero IPv6 checksums (Florian Westphal) [1131999]
- [net] udp: Make enabling of zero UDP6 csums more restrictive (Florian Westphal) [1131999]
- [net] Split sk_no_check into sk_no_check_{rx, tx} (Florian Westphal) [1131999]
- [net] Eliminate no_check from protosw (Florian Westphal) [1131999]
- [net] sunrpc: Remove sk_no_check setting (Florian Westphal) [1131999]
- [net] l2tp: Remove UDP checksum verification (Florian Westphal) [1131999]
- [net] udp: Verify UDP checksum before handoff to encap (Florian Westphal) [1131999]
- [net] icmp6: Call skb_checksum_validate (Florian Westphal) [1131999]
- [net] icmp: Call skb_checksum_simple_validate (Florian Westphal) [1131999]
- [net] igmp: Call skb_checksum_simple_validate (Florian Westphal) [1131999]
- [net] gre6: Call skb_checksum_simple_validate (Florian Westphal) [1131999]
- [net] gre: Call skb_checksum_simple_validate (Florian Westphal) [1131999]
- [net] ipv6: Need to sock_put on csum error (Florian Westphal) [1131999]
- [net] ipv6: Implmement RFC 6936 (zero RX csums for UDP/IPv6) (Florian Westphal) [1131999]
- [net] udp: Only allow busy read/poll on connected sockets (Florian Westphal) [1078978 1131999]
- [net] ipv6: log src and dst along with "udp checksum is 0" (Florian Westphal) [1131999]
- [net] ipv6: Call skb_checksum_init in IPv6 (Florian Westphal) [1131999]
- [net] ipv4: Call skb_checksum_init in IPv4 (Florian Westphal) [1131999]
- [net] Generalize checksum_init functions (Florian Westphal) [1131999]
- [net] Change x86_64 add32_with_carry to allow memory operand (Florian Westphal) [1131999]
- [x86_64] csum_add for x86_64 (Florian Westphal) [1131999]
- [net] Allow csum_add to be provided in arch (Florian Westphal) [1131999]
- [net] ipv4: add a sock pointer to dst->output() path (Jiri Pirko) [1081956]
- [net] iptunnels: remove net arg from iptunnel_xmit() (Jiri Pirko) [1081956]
- [net] vti: Use the tunnel mark for lookup in the error handlers (Jiri Pirko) [1091561]
- [net] xfrm4: Remove duplicate semicolon (Jiri Pirko) [1091561]
- [net] xfrm4: Properly handle unsupported protocols (Jiri Pirko) [1091561]
- [net] vti4: Don't count header length twice (Jiri Pirko) [1091561]
- [net] vti4: don't allow to add the same tunnel twice (Jiri Pirko) [1091561]
- [net] vti4: Enable namespace changing (Jiri Pirko) [1091561]
- [net] vti4: Check the tunnel endpoints of the xfrm state and the vti interface (Jiri Pirko) [1091561]
- [net] vti4: Support inter address family tunneling (Jiri Pirko) [1091561]
- [net] vti4: Use the on xfrm_lookup returned dst_entry directly (Jiri Pirko) [1091561]
- [net] vti4: Update the ipv4 side to use it's own receive hook (Jiri Pirko) [1091561]
- [net] skb: allow skb_scrub_packet() to be used by tunnels (Jiri Pirko) [1091561]
- [net] ipv4: xfrm: Introduce xfrm_tunnel_notifier for xfrm tunnel mode callback (Jiri Pirko) [1091561]
- [net] ip_tunnel: Remove double unregister of the fallback device (Jiri Pirko) [1091561]
- [net] ipip: add x-netns support (Jiri Pirko) [1091561]
- [net] vti4: switch to new ip tunnel code (Jiri Pirko) [1091561]
- [net] ip_tunnel: Make vti work with i_key set (Jiri Pirko) [1091561]
- [net] xfrm: Add xfrm_tunnel_skb_cb to the skb common buffer (Jiri Pirko) [1091561]
- [net] ipcomp4: Use the IPsec protocol multiplexer API (Jiri Pirko) [1091561]
- [net] ah4: Use the IPsec protocol multiplexer API (Jiri Pirko) [1091561]
- [net] esp4: Use the IPsec protocol multiplexer API (Jiri Pirko) [1091561]
- [net] xfrm4: Add IPsec protocol multiplexer (Jiri Pirko) [1091561]

* Fri Oct 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-179.el7]
- [drm] i915: don't crash if unable to setup stolen (Rob Clark) [1128939]
- [fs] nfs: Don't reset pg_moreio in __nfs_pageio_add_request (Steve Dickson) [1120728]
- [fs] nfs: Remove 2 unused variables (Steve Dickson) [1120728]
- [fs] nfs: handle multiple reqs in nfs_wb_page_cancel (Steve Dickson) [1120728]
- [fs] nfs: nfs_page should take a ref on the head req (Steve Dickson) [1120728]
- [fs] nfsv4: test SECINFO RPC_AUTH_GSS pseudoflavors for support (Steve Dickson) [1120728]
- [fs] nfs: Return -EPERM if no supported or matching SECINFO flavor (Steve Dickson) [1120728]
- [fs] nfs: check the return of nfs4_negotiate_security in nfs4_submount (Steve Dickson) [1120728]

* Fri Oct 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-178.el7]
- [crypto] drbg: fix maximum value checks on 32 bit systems (Herbert Xu) [1138311]
- [crypto] drbg: remove configuration of fixed values (Herbert Xu) [1138311]
- [crypto] drbg: fix failure of generating multiple of 2**16 bytes (Herbert Xu) [1011562]
- [crypto] drbg: drbg_exit() can be static (Herbert Xu) [1011562]
- [crypto] drbg: HMAC-SHA1 DRBG has crypto strength of 128 bits (Herbert Xu) [1011562]
- [crypto] drbg: Mix a time stamp into DRBG state (Herbert Xu) [1011562]
- [crypto] drbg: Select correct DRBG core for stdrng (Herbert Xu) [1011562]
- [crypto] drbg: Call CTR DRBG DF function only once (Herbert Xu) [1011562]
- [crypto] drbg: Fix format string for debugging statements (Herbert Xu) [1011562]
- [crypto] drbg: cleanup of preprocessor macros (Herbert Xu) [1011562]
- [crypto] drbg: Use Kconfig to ensure at least one RNG option is set (Herbert Xu) [1011562]
- [crypto] drbg: use of kernel linked list (Herbert Xu) [1011562]
- [crypto] drbg: fix memory corruption for AES192 (Herbert Xu) [1011562]
- [crypto] drbg: simplify ordering of linked list in drbg_ctr_df (Herbert Xu) [1011562]
- [crypto] drbg: Add DRBG test code to testmgr (Herbert Xu) [1011562]
- [crypto] drbg: DRBG testmgr test vectors (Herbert Xu) [1011562]
- [crypto] drbg: compile the DRBG code (Herbert Xu) [1011562]
- [crypto] drbg: DRBG kernel configuration options (Herbert Xu) [1011562]
- [crypto] drbg: header file for DRBG (Herbert Xu) [1011562]
- [crypto] drbg: SP800-90A Deterministic Random Bit Generator (Herbert Xu) [1011562]
- [virt] virtio_scsi: avoid cancelling uninitialized work items (Paolo Bonzini) [1050834]
- [net] macvtap: Fix race between device delete and open (Vlad Yasevich) [1075904]
- [video] offb: Little endian fixes (David Gibson) [1144937]
- [cpufreq] release policy->rwsem on error (Prarit Bhargava) [1140184]
- [char] ipmi: Turn off all activity on an idle ipmi interface (Tony Camuso) [1111214]
- [char] ipmi: Turn off default probing of interfaces (Tony Camuso) [1111214]
- [char] ipmi: Reset the KCS timeout when starting error recovery (Tony Camuso) [1111214]
- [char] ipmi: Fix a race restarting the timer (Tony Camuso) [1111214]
- [char] ipmi: ipmi_bt_sm, fix infinite loop (Tony Camuso) [1111214]
- [char] ipmi: delete non-required instances of include <linux/init.h> (Tony Camuso) [1111214]
- [char] ipmi: Cleanup error return (Tony Camuso) [1111214]
- [char] ipmi: fix timeout calculation when bmc is disconnected (Tony Camuso) [1111214]
- [char] ipmi: use USEC_PER_SEC instead of 1000000 for more meaningful (Tony Camuso) [1111214]
- [char] ipmi: remove deprecated IRQF_DISABLED (Tony Camuso) [1111214]
- [char] ipmi: Initialize locals to avoid warning (Tony Camuso) [1111214]
- [char] ipmi: info leak in compat_ipmi_ioctl() (Tony Camuso) [1111214]
- [char] ipmi: Convert use of typedef ctl_table to struct ctl_table (Tony Camuso) [1111214]

* Tue Sep 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-177.el7]
- [x86] uv: Set n_lshift based on GAM_GR_CONFIG MMR for UV3 (George Beshers) [1098325]
- [kernel] audit: correct AUDIT_GET_FEATURE return message type (Richard Guy Briggs) [1141791]
- [mm] fix the theoretical compound_lock() vs prep_new_page() race (Andrea Arcangeli) [1135506]
- [mm] hugetlb: call MMU notifiers when copying a hugetlb page range (Andrea Arcangeli) [1135506]
- [mm] page_alloc: convert hot/cold parameter and immediate callers to bool (Andrea Arcangeli) [1135506]
- [mm] introdule compound_head_by_tail() (Andrea Arcangeli) [1135506]
- [mm] swap: split put_compound_page() (Andrea Arcangeli) [1135506]
- [mm] slub: do not VM_BUG_ON_PAGE() for temporary on-stack pages (Andrea Arcangeli) [1135506]
- [mm] page_alloc: change mm debug routines back to EXPORT_SYMBOL (Andrea Arcangeli) [1135506]
- [mm] dump page when hitting a VM_BUG_ON using VM_BUG_ON_PAGE (Andrea Arcangeli) [1135506]
- [mm] thp: __get_page_tail_foll() can use get_huge_page_tail() (Andrea Arcangeli) [1135506]
- [mm] print more details for bad_page() (Andrea Arcangeli) [1135506]
- [mm] thp: turn compound_head() into BUG_ON(!PageTail) in get_huge_page_tail() (Andrea Arcangeli) [1135506]
- [mm] hugetlbfs: Add some VM_BUG_ON()s to catch non-hugetlbfs pages (Andrea Arcangeli) [1135506]
- [mm] swap: introduce put_[un]refcounted_compound_page helpers for splitting put_compound_page() (Andrea Arcangeli) [1135506]
- [mm] close PageTail race (Andrea Arcangeli) [1135506]
- [block] aoe: adjust ref of head for compound page tails (Andrea Arcangeli) [1135506]
- [mm] swap: reorganize put_compound_page() (Andrea Arcangeli) [1135506]
- [mm] hugetlbfs: use __compound_tail_refcounted in __get_page_tail too (Andrea Arcangeli) [1135506]
- [mm] tail page refcounting optimization for slab and hugetlbfs (Andrea Arcangeli) [1135506]
- [mm] hugetlbfs: move the put/get_page slab and hugetlbfs optimization in a faster path (Andrea Arcangeli) [1135506]
- [mm] hugetlbfs: fix hugetlbfs optimization (Andrea Arcangeli) [1135506]
- [mm] make lru_add_drain_all() selective (Andrea Arcangeli) [1135506]
- [mm] fix aio performance regression for database caused by THP (Andrea Arcangeli) [1135506]
- [powerpc] Add smp_mb()s to arch_spin_unlock_wait() (Gustavo Duarte) [1136528]
- [powerpc] Add smp_mb() to arch_spin_is_locked() (Gustavo Duarte) [1136528]
- [acpi] scan: not cache _SUN value in struct acpi_device_pnp (Prarit Bhargava) [1140567]
- [acpi] scan: ACPI device object sysfs attribute for _STA evaluation (Prarit Bhargava) [1140567]

* Tue Sep 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-176.el7]
- [alsa] hda: Set up initial pins for Acer Aspire V5 (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Replacing hex with #defines (Jaroslav Kysela) [1112200]
- [alsa] ctxfi: fix broken user-visible string (Jaroslav Kysela) [1112200]
- [alsa] ctxfi: prink replacement (Jaroslav Kysela) [1112200]
- [alsa] ctxfi: ctpcm.c printk replacement (Jaroslav Kysela) [1112200]
- [alsa] pcm: Fix the silence data for DSD formats (Jaroslav Kysela) [1112200]
- [alsa] ctxfi: ct20k1reg Fix typo in include guard (Jaroslav Kysela) [1112200]
- [alsa] hda: ca0132_regs.h Fix typo in include guard (Jaroslav Kysela) [1112200]
- [alsa] core: fix buffer overflow in snd_info_get_line() (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Use tables for batch COEF writes/updtes (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add alc_update_coef*_idx() helper (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Use alc_write_coef_idx() in alc269_quanta_automake() (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Optimize alc888_coef_init() (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove obsoleted EXPORT_SYMBOL_HDA() macro (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove obsoleted snd_hda_check_board_config() & co (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: apply Valleyview fix-ups to Cherryview display codec (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: set depop_delay for haswell plus (Jaroslav Kysela) [1112200]
- [alsa] hda: restore the gpio led after resume (Jaroslav Kysela) [1112200]
- [alsa] core: create write-only attribute macros for devices and drivers (Jaroslav Kysela) [1112200]
- [alsa] sysfs: create __ATTR_WO() (Jaroslav Kysela) [1112200]
- [alsa] dell-led: add mic mute led interface (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Avoid setting wrong COEF on ALC269 & co (Jaroslav Kysela) [1112200]
- [alsa] hda: Set TLV_DB_SCALE_MUTE bit for cx5051 vmaster (Jaroslav Kysela) [1112200]
- [alsa] pci: Remove DEFINE_PCI_DEVICE_TABLE macro use (Jaroslav Kysela) [1112200]
- [alsa] hda/ca0132: Don't try loading firmware at resume when already failed (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix pop noises on reboot for Dell XPS 13 9333 (Jaroslav Kysela) [1112200]
- [alsa] hda: Set internal mic as default input source on Dell XPS 13 9333 (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: fix BOSS ME-25 MIDI regression (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix parsing of CMI8888 codec (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix probing and stuttering on CMI8888 HD-audio controller (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Fixed ALC286/ALC288 recording delay for Headset Mic (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Whitespace cleanups for sound/usb/midi.* (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Respond to suspend and resume callbacks for MIDI input (Jaroslav Kysela) [1112200]
- [alsa] virtuoso: add Xonar Essence STX II support (Jaroslav Kysela) [1112200]
- [alsa] riptide: fix d confusingly prefixed with 0x in format strings (Jaroslav Kysela) [1112200]
- [alsa] hda: add codec ID for Braswell display audio codec (Jaroslav Kysela) [1112200]
- [alsa] hda: add PCI IDs for Intel Braswell (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Adjust Gamecom 780 volume level (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: improve dmesg source grepability (Jaroslav Kysela) [1112200]
- [alsa] hda: add mic mute led hook for dell machines (Jaroslav Kysela) [1112200]
- [alsa] hda: fix an external mic jack problem on a HP machine (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix loopback noise on Dell XPS 15 (Jaroslav Kysela) [1112200]
- [alsa] hda: Make vendor quirks lowest prio for ALC2xx (Jaroslav Kysela) [1112200]
- [alsa] hda: Refactor quirk picking and change quirk priority (Jaroslav Kysela) [1112200]
- [alsa] hda: Add mic fixup for Gigabyte BXBT-2807 (Jaroslav Kysela) [1112200]
- [alsa] hda: Add mute LED pin quirk for HP 15 touchsmart (Jaroslav Kysela) [1112200]
- [alsa] pcm: Add tstamp_type and proto to sw_params compat layer (Jaroslav Kysela) [1112200]
- [alsa] pcm: Introduce protocol version field to sw_params (Jaroslav Kysela) [1112200]
- [alsa] hda: Add NULL check to all PM ops in hda_intel.c (Jaroslav Kysela) [1112200]
- [alsa] hda: init_flag is in struct hda_intel (Jaroslav Kysela) [1112200]
- [alsa] compress: fix an integer overflow check (Jaroslav Kysela) [1112200]
- [alsa] hda: Add the pin fixup for HP Envy TS bass speaker (Jaroslav Kysela) [1112200]
- [alsa] control: Define SNDRV_CTL_TLV_OP_* constants (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix broken PM due to incomplete i915 initialization (Jaroslav Kysela) [1112200]
- [alsa] hda: Revert stream assignment order for Intel controllers (Jaroslav Kysela) [1112200]
- [alsa] pcm: Add timestamp type to sw_params (Jaroslav Kysela) [1112200]
- [alsa] pcm: simplify snd_pcm_tstamp() (Jaroslav Kysela) [1112200]
- [alsa] hda: add capture mute led support in led_power_filter (Jaroslav Kysela) [1112200]
- [alsa] hda: fix a typo by changing mute_led_nid to cap_mute_led_nid (Jaroslav Kysela) [1112200]
- [alsa] hda: Add new GPU codec ID 0x10de0070 to snd-hda (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix build warning (Jaroslav Kysela) [1112200]
- [alsa] hda: Add several entries for enabling HP mute led (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix and neaten print_nid_path/debug_badness (Jaroslav Kysela) [1112200]
- [alsa] pcm_dmaengine: Correct support for 24bits physical sample widths (Jaroslav Kysela) [1112200]
- [alsa] pcm_dmaengine: Use the available wrapper to get physical width (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Correcting/completing #defines for REGS (Jaroslav Kysela) [1112200]
- [alsa] hda: restore BCLK M/N value as per CDCLK for HSW/BDW display HDA controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove unused variable (Jaroslav Kysela) [1112200]
- [alsa] mixart: Remove unused variable (Jaroslav Kysela) [1112200]
- [alsa] echoaudio: Remove unused variable (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix build error in hda_tegra.c (Jaroslav Kysela) [1112200]
- [alsa] trident: Remove unused variable in trident_memory.c (Jaroslav Kysela) [1112200]
- [alsa] trident: Remove unused variable in trident_main.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix invalid function call in snd_hda_add_vmaster() (Jaroslav Kysela) [1112200]
- [alsa] hda: Add a fixup for Thinkpad T540p (Jaroslav Kysela) [1112200]
- [alsa] hda: Add another headset pin quirk for some Dell machines (Jaroslav Kysela) [1112200]
- [alsa] hda: Replace ICH6_ prefix (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove obsoleted SFX definitions (Jaroslav Kysela) [1112200]
- [alsa] hda: Move SD nums definitions to hda_intel.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Use common reboot notifier (Jaroslav Kysela) [1112200]
- [alsa] hda: Move more PCI-controller-specific stuff from generic code (Jaroslav Kysela) [1112200]
- [alsa] hda: Make position_fix as generic callback (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove superfluous MAX_AZX_DEV (Jaroslav Kysela) [1112200]
- [alsa] hda: restore BCLK M/N values when resuming HSW/BDW display controller (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Fix races at disconnection and PCM closing (Jaroslav Kysela) [1112200]
- [alsa] hda: Adjust speaker HPF and add LED support for HP Spectre 13 (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove the obsoleted static quirk codes from patch_cmedia.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove the obsoleted static quirk codes from patch_conexant.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Kill the rest of snd_print*() usages (Jaroslav Kysela) [1112200]
- [alsa] hda: Kill snd_printd*() in HDMI debug / info prints (Jaroslav Kysela) [1112200]
- [alsa] hda: Make the pin quirk tables use the SND_HDA_PIN_QUIRK macro (Jaroslav Kysela) [1112200]
- [alsa] hda: Make a SND_HDA_PIN_QUIRK macro (Jaroslav Kysela) [1112200]
- [alsa] hda: Add pin quirk for Dell XPS 15 (Jaroslav Kysela) [1112200]
- [alsa] seq/seq_memory: Fix closing brace followed by if (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: call overridden init on resume (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix usage of "model" module parameter (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Support HP mute led for output and input (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add more entry for enable HP mute led (Jaroslav Kysela) [1112200]
- [alsa] control: Make sure that id->index does not overflow (Jaroslav Kysela) [1112200 1117314] {CVE-2014-4656}
- [alsa] control: Handle numid overflow (Jaroslav Kysela) [1112200 1117314] {CVE-2014-4656}
- [alsa] control: Fix replacing user controls (Jaroslav Kysela) [1112200 1117324] {CVE-2014-4654 CVE-2014-4655}
- [alsa] control: Protect user controls against concurrent access (Jaroslav Kysela) [1112200 1117339] {CVE-2014-4652}
- [alsa] hd-audio: Don't continue probing i915 when nomodeset is given (Jaroslav Kysela) [1112200]
- [alsa] hda: Add quirk for external mic on Lifebook U904 (Jaroslav Kysela) [1112200]
- [alsa] hda: fix a fixup value for codec alc293 in the pin_quirk table (Jaroslav Kysela) [1112200]
- [alsa] intel8x0: Use ktime and ktime_get() (Jaroslav Kysela) [1112200]
- [alsa] core: Use ktime_get_ts() (Jaroslav Kysela) [1112200]
- [alsa] hda: verify pin-converter connection on unsol event for HSW and VLV (Jaroslav Kysela) [1112200]
- [alsa] hda: Add quirk for ABit AA8XE (Jaroslav Kysela) [1112200]
- [alsa] Revert: hda: mask buggy stream DMA0 for Broadwell display controller (Jaroslav Kysela) [1112200]
- [alsa] hda: using POS_FIX_LPIB on Broadwell HDMI Audio (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add support of ALC667 codec (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add more codec rename (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: New vendor ID for ALC233 (Jaroslav Kysela) [1112200]
- [alsa] hda: add two new pin tables (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add support of ALC891 codec (Jaroslav Kysela) [1112200]
- [alsa] seq: Continue broadcasting events to ports if one of them fails (Jaroslav Kysela) [1112200]
- [alsa] seq: correctly detect input buffer overflow (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Fix COEF widget NID for ALC260 replacer fixup (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Correction of fixup codes for PB V7900 laptop (Jaroslav Kysela) [1112200]
- [alsa] hda/analog: Fix silent output on ASUS A8JN (Jaroslav Kysela) [1112200]
- [alsa] hda: move some alc662 family machines to hda_pin_quirk table (Jaroslav Kysela) [1112200]
- [alsa] hda: move some alc269 family machines to hda_pin_quirk table (Jaroslav Kysela) [1112200]
- [alsa] Revert: hda: drop def association and sequence from pinconf comparing (Jaroslav Kysela) [1112200]
- [alsa] hda: fix tegra build (Jaroslav Kysela) [1112200]
- [alsa] hda: Pop noises fix for XPS13 9333 (Jaroslav Kysela) [1112200]
- [alsa] hda: add an instance to use snd_hda_pick_pin_fixup (Jaroslav Kysela) [1112200]
- [alsa] hda: drop def association and sequence from pinconf comparing (Jaroslav Kysela) [1112200]
- [alsa] hda: get subvendor from codec rather than pci_dev (Jaroslav Kysela) [1112200]
- [alsa] hda: Add a new quirk match based on default pin configuration (Jaroslav Kysela) [1112200]
- [alsa] hda: Add fixup_forced flag (Jaroslav Kysela) [1112200]
- [alsa] snd-usb/mixer: remove error messages on failed kmalloc() (Jaroslav Kysela) [1112200]
- [alsa] snd-usb/mixer: coding style fixups (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix onboard audio on Intel H97/Z97 chipsets (Jaroslav Kysela) [1112200]
- [alsa] Replace DEFINE_PCI_DEVICE_TABLE macro use (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add support headset mode for ALC233 (Jaroslav Kysela) [1112200]
- [alsa] lola: fix format type mismatch in sound/pci/lola/lola_proc.c (Jaroslav Kysela) [1112200]
- [alsa] hda: fix format type mismatch in sound/pci/hda/patch_sigmatel.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Disable AA-mix on Sony Vaio S13 (Jaroslav Kysela) [1112200]
- [alsa] hda: White noise fix for XPS13 9333 (Jaroslav Kysela) [1112200]
- [alsa] hda/tegra: Fix MODULE_DEVICE_TABLE typo (Jaroslav Kysela) [1112200]
- [alsa] hda: Add driver for Tegra SoC HDA (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: Add Nvidia Tegra124 HDMI support (Jaroslav Kysela) [1112200]
- [alsa] fm801: convert struct description to kernel-doc (Jaroslav Kysela) [1112200]
- [alsa] pcm_dmaengine: Add check during device suspend (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirk for a Dell laptop (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirks for three Dell laptops (Jaroslav Kysela) [1112200]
- [alsa] hda: Add new GPU codec ID to snd-hda (Jaroslav Kysela) [1112200]
- [alsa] hda: if statement not indented (Jaroslav Kysela) [1112200]
- [alsa] hda: mask buggy stream DMA0 for Broadwell display controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Add dock pin setups for Thinkpad T440 (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: Set infoframe and channel mapping even without sink (Jaroslav Kysela) [1112200]
- [alsa] fm801: introduce fm801_ac97_is_ready()/fm801_ac97_is_valid() helpers (Jaroslav Kysela) [1112200]
- [alsa] fm801: introduce macros to access the hardware (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: Set converter channel count even without sink (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: work around corrupted TEAC UD-H01 feedback data (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Fix deadlocks at resuming (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Save mixer status only once at suspend (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Prevent printk ratelimiting from spamming kernel log while DEBUG not defined (Jaroslav Kysela) [1112200]
- [alsa] hda: Suppress CORBRP clear on Nvidia controller chips (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add more entry for enable HP mute led (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirk for a Dell laptop (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Fix format string mismatch in mixer.c (Jaroslav Kysela) [1112200]
- [alsa] core: Fix format string mismatch in seq_midi.c (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add new codec ALC293/ALC3235 UAJ supported (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add two codecs alias name for Dell (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Translate comments from french to english (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Remove useless #if 0 .. #endif (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Remove dead code (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Fix dev_dbg typo (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Switch to using BIT macro (Jaroslav Kysela) [1112200]
- [alsa] lx_core: Remove unused defines (Jaroslav Kysela) [1112200]
- [alsa] pcm: BUG message unnecessarily triggers kerneloops (Jaroslav Kysela) [1112200]
- [alsa] MIDI driver for Behringer BCD2000 USB device (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add headset Mic support for Dell machine (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirk for a Dell laptop (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add support of ALC288 codec (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Suppress repetitive debug messages from retire_playback_urb() (Jaroslav Kysela) [1112200]
- [alsa] hda: Make full_reset boolean (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirk for a Dell laptop (Jaroslav Kysela) [1112200]
- [alsa] hda: Use runtime helper to check active state (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Fix boundary checks in PCM pointer ops (Jaroslav Kysela) [1112200]
- [alsa] hda: Do not assign streams in reverse order (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add eapd shutup to ALC283 (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Change model name alias for ChromeOS (Jaroslav Kysela) [1112200]
- [alsa] Kconfig: rename HAS_IOPORT to HAS_IOPORT_MAP (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Improve HP depop when system change power state on Chromebook (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Save/restore routing and rate registers (Jaroslav Kysela) [1112200]
- [alsa] ice1712: restore AK4xxx volumes on resume (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Add S/PDIF suspend support for ICE1712-based M-Audio cards (Jaroslav Kysela) [1112200]
- [alsa] cs8427: separate HW initialization (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix silent speaker output due to mute LED fixup (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Fixed single output machine get empty hp sense (Jaroslav Kysela) [1112200]
- [alsa] ice1712: Add suspend support for M-Audio ICE1712-based cards (Jaroslav Kysela) [1112200]
- [alsa] ice1712: add suspend support for ICE1712 chip (Jaroslav Kysela) [1112200]
- [alsa] hda: Enable beep for ASUS 1015E (Jaroslav Kysela) [1112200]
- [alsa] asihpi: fix some indenting in snd_card_asihpi_pcm_new() (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirks for three Dell laptops (Jaroslav Kysela) [1112200]
- [alsa] hda: Inform the unexpectedly ignored pins by auto-parser (Jaroslav Kysela) [1112200]
- [alsa] hda: verify pin-cvt connection on preparing a stream for Intel HDMI codec (Jaroslav Kysela) [1112200]
- [alsa] compress: Pass through return value of open ops callback (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Restore default value for ALC282 (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) fix Stereo Upmixing regression (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Fix the noise after suspend and resume on ALC282 codec (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Restore default value for ALC283 (Jaroslav Kysela) [1112200]
- [alsa] sis7019: Simplify dependencies (Jaroslav Kysela) [1112200]
- [alsa] cs5535audio: Also needed on MIPS (Jaroslav Kysela) [1112200]
- [alsa] hda: initialize audio InfoFrame to be all zero (Jaroslav Kysela) [1112200]
- [alsa] cs553*: Fix dependencies (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix loud click noise with IdeaPad 410Y (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Add quirk for Logitech Webcam C500 (Jaroslav Kysela) [1112200]
- [alsa] emu10k1: Fix possible NULL dereference (Jaroslav Kysela) [1112200]
- [alsa] echoaudio: use after free on error (Jaroslav Kysela) [1112200]
- [alsa] lola: NULL deref on allocation error (Jaroslav Kysela) [1112200]
- [alsa] hda: Use analog beep for Thinkpads with AD1984 codecs (Jaroslav Kysela) [1112200]
- [alsa] hda: Add missing loopback merge path for AD1884/1984 codecs (Jaroslav Kysela) [1112200]
- [alsa] hda: add automute fix for another dell AIO model (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add headset quirk for Dell DT (Jaroslav Kysela) [1112200]
- [alsa] hda: Added inverted digital-mic handling for Acer TravelMate 8371 (Jaroslav Kysela) [1112200]
- [alsa] hda: Mark reg op args as iomem (Jaroslav Kysela) [1112200]
- [alsa] hda: Rename reg access ops in hda_controller_ops (Jaroslav Kysela) [1112200]
- [alsa] hda: Make azx_attach_pcm_stream static (Jaroslav Kysela) [1112200]
- [alsa] hda: remove PCI dependency in Kconfig (Jaroslav Kysela) [1112200]
- [alsa] hda: Move codec create to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Move azx_interrupt to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Add position_check op (Jaroslav Kysela) [1112200]
- [alsa] hda: Move low level functions to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: move alloc_cmd_io to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Relocate RIRB/CORB interface to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Move the dsp loader to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Pull pages allocation to hda_controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Add hda_controller.c and move pcm ops from hda_intel (Jaroslav Kysela) [1112200]
- [alsa] hda: Add pcm_mmap_prepare op (Jaroslav Kysela) [1112200]
- [alsa] hda: Move snd page allocation to ops (Jaroslav Kysela) [1112200]
- [alsa] hda: Pass max_slots and power_save to codec_create (Jaroslav Kysela) [1112200]
- [alsa] hda: Add jackpoll_ms to struct azx (Jaroslav Kysela) [1112200]
- [alsa] hda: remove unused clear of STATESTS (Jaroslav Kysela) [1112200]
- [alsa] hda: Add function pointer for disabling MSI (Jaroslav Kysela) [1112200]
- [alsa] hda: Use device pointer from the card instead of pci (Jaroslav Kysela) [1112200]
- [alsa] hda: Keep pointer to bdl_pos_fix in chip struct (Jaroslav Kysela) [1112200]
- [alsa] hda: Allow different ops to read/write registers (Jaroslav Kysela) [1112200]
- [alsa] hda: Move some definitions to new hda_priv.h (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix CORB reset to follow specification (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix registration of beep input device (Jaroslav Kysela) [1112200]
- [alsa] hda/sigmatel: Allow auto-switching for dock line-in of HP laptops (Jaroslav Kysela) [1112200]
- [alsa] Move EXPORT_SYMBOL() in appropriate places (Jaroslav Kysela) [1112200]
- [alsa] hda: Make codec object as a parent for input beep devices (Jaroslav Kysela) [1112200]
- [alsa] 6fire: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ymfpci: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] vx222: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] trident: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] rme9652: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] hdspm: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] hdsp: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] pcxhr: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] nm256: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] mixart: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] lx6464es: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] lola: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ice17xx: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] emu10k1: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] emu10k1x: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] echoaudio: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] cs46xx: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] cs5535audio: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ca0106: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] aw2: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ali5451: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ac97: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] via82xx_modem: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] via82xx: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] sonicvibes: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] rme96: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] rme32: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] maestro3: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] intel8x0m: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] intel8x0: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] fm801: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] es1968: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] es1938: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] ens137x: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] cs5530: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] cs4281: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] cmipci: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] bt87x: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] azt3328: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] azt3328: Remove function debug prints (Jaroslav Kysela) [1112200]
- [alsa] atiixp-modem: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] atiixp: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] als4000: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] als300: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] als300: Remove function debug prints (Jaroslav Kysela) [1112200]
- [alsa] ad1889: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] rme96: Convert to the new pm_ops (Jaroslav Kysela) [1112200]
- [alsa] hda: Replace with standard printk (Jaroslav Kysela) [1112200]
- [alsa] hda: Enable sysfs attributes without CONFIG_SND_HDA_RECONFIG (Jaroslav Kysela) [1112200]
- [alsa] hda: Add sysfs to codec object, too (Jaroslav Kysela) [1112200]
- [alsa] hda: Create own device struct for each codec (Jaroslav Kysela) [1112200]
- [alsa] hda: Manage each codec instance individually (Jaroslav Kysela) [1112200]
- [alsa] Clean up snd_device_*() codes (Jaroslav Kysela) [1112200]
- [alsa] Use priority list for managing device list (Jaroslav Kysela) [1112200]
- [alsa] hwdep: Allow to assign the given parent (Jaroslav Kysela) [1112200]
- [alsa] hwdep: Take private_data as drvdata for sysfs (Jaroslav Kysela) [1112200]
- [alsa] Create sysfs attribute files via groups (Jaroslav Kysela) [1112200]
- [alsa] hda: Avoid codec D3 for keeping mute LED up on Lenovo Yxx0 (Jaroslav Kysela) [1112200]
- [alsa] hda: Add a fixup for HP Folio 13 mute LED (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Add more entry for enable HP mute led (Jaroslav Kysela) [1112200]
- [alsa] Export snd_pcm_constraint_mask64() (Jaroslav Kysela) [1112200]
- [alsa] hda: Enable front audio jacks on one HP desktop model (Jaroslav Kysela) [1112200]
- [alsa] core: Fix missing card sysfs contents (Jaroslav Kysela) [1112200]
- [alsa] hda: Add QEMU codec vendor ID (Jaroslav Kysela) [1112200]
- [alsa] hda/ca0132: Fix recording from mode id 0x8 (Jaroslav Kysela) [1112200]
- [alsa] hda/ca0132: setup/cleanup streams (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirks for two Dell laptops (Jaroslav Kysela) [1112200]
- [alsa] usx2y: Don't peep the card internal object (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: work around KEF X300A firmware bug (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove superfluous inclusion of linux/pci.h (Jaroslav Kysela) [1112200]
- [alsa] hda/realtek: Allow NULL bus->pci (Jaroslav Kysela) [1112200]
- [alsa] hda: Remove dependency on bus->pci in hda_beep.c (Jaroslav Kysela) [1112200]
- [alsa] ak4117: Do not free priv until timer handler hasn't actually stopped using it (Jaroslav Kysela) [1112200]
- [alsa] Drop __bitwise and typedefs for snd_device attributes (Jaroslav Kysela) [1112200]
- [alsa] i2c/ak413x: Use SNDRV_DEV_CODEC for ak413x codec objects (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Use SNDRV_DEV_CODEC for mixer objects (Jaroslav Kysela) [1112200]
- [alsa] seq_oss: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] seq: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] timer: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] oss: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] hwdep: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] rawmidi: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] core: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] pcm: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] control: Use standard printk helpers (Jaroslav Kysela) [1112200]
- [alsa] seq_oss: Drop debug prints (Jaroslav Kysela) [1112200]
- [alsa] Use standard device refcount for card accounting (Jaroslav Kysela) [1112200]
- [alsa] Use static groups for id and number card sysfs attr files (Jaroslav Kysela) [1112200]
- [alsa] Embed card device into struct snd_card (Jaroslav Kysela) [1112200]
- [alsa] Mandate to pass a device pointer at card creation time (Jaroslav Kysela) [1112200]
- [alsa] usb: Convert to snd_card_new() with a device pointer (Jaroslav Kysela) [1112200]
- [alsa] pci: Convert to snd_card_new() with a device pointer (Jaroslav Kysela) [1112200]
- [alsa] drivers: Convert to snd_card_new() with a device pointer (Jaroslav Kysela) [1112200]
- [alsa] Mandate to pass a device pointer at card creation time (Jaroslav Kysela) [1112200]
- [alsa] Drop unused name argument in snd_register_oss_device() (Jaroslav Kysela) [1112200]
- [alsa] hda: Make snd_hda_gen_spec_free() static (Jaroslav Kysela) [1112200]
- [alsa] hda: Disable static quirks for C-Media codecs (Jaroslav Kysela) [1112200]
- [alsa] hda: Move HDA_FIXUP_ACT_FREE call in snd_hda_gen_free() (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix undefined symbol due to builtin/module mixup (Jaroslav Kysela) [1112200]
- [alsa] Fix typos in alsa-driver-api.xml (Jaroslav Kysela) [1112200]
- [alsa] lx6464es: Remove unused function in pci/lx6464es/lx_core.c (Jaroslav Kysela) [1112200]
- [alsa] pcsp: Include appropriate header file in pcsp/pcsp_input.c (Jaroslav Kysela) [1112200]
- [alsa] hda: Add subwoofer quirks for Asus UX51VZH and N55SF (Jaroslav Kysela) [1112200]
- [alsa] hda: Rename ASUS subwoofer quirks (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix mic capture on Sony VAIO Pro 11 (Jaroslav Kysela) [1112200]
- [alsa] hda: Add a headset quirk for Dell XPS 13 (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix inconsistent Mic mute LED (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix leftover ifdef checks after modularization (Jaroslav Kysela) [1112200]
- [alsa] hda: Improve loopback path lookups for AD1983 (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix missing VREF setup for Mac Pro 1,1 (Jaroslav Kysela) [1112200]
- [alsa] hda: Add missing mixer widget for AD1983 (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix silent output on Toshiba Satellite L40 (Jaroslav Kysela) [1112200]
- [alsa] hda: Add mute LED support to Lenovo Ideapad (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Resume mixer values properly (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Add missing kconfig dependecy (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: allow PIN_OUT to be dynamically enabled (Jaroslav Kysela) [1112200]
- [alsa] hda: Do not accept responses from non-existing codecs (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Disable static quirks (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Enable stereo mix input for CX20549 and CX20551 (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Add analog loopback mixing to CX20549 (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Apply cap of mix amp volume on CX20551 codec (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Use generic parser for HP 530 (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Use generic parser for Toshiba P105 (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Apply the amp cap override for CX20549 mixer (Jaroslav Kysela) [1112200]
- [alsa] hda/conexant: Re-implement OLPC XO workarounds via fixup (Jaroslav Kysela) [1112200]
- [alsa] hda: Avoid unnecessary verbs write in snd_hda_activate_path() (Jaroslav Kysela) [1112200]
- [alsa] hda: Add fixup name lookup for CX5051 and 5066 codecs (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirks for another Dell laptop (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) cleanup and minor changes (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify high-pass filter control (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify input select functions (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify capture volume functions (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) use headphone volume control (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify playback output select (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) capture from I2S channel 1, not 2 (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) move the mixer code into another file (Jaroslav Kysela) [1112200]
- [alsa] oxygen: modify CS4245 register dumping function (Jaroslav Kysela) [1112200]
- [alsa] oxygen: modify adjust_dg_dac_routing function (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify DAC/ADC parameters function (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) modify initialization functions (Jaroslav Kysela) [1112200]
- [alsa] oxygen: Xonar DG(X) add new CS4245 SPI functions (Jaroslav Kysela) [1112200]
- [alsa] oxygen: additional definitions for the Xonar DG/DGX card (Jaroslav Kysela) [1112200]
- [alsa] oxygen: change description of the xonar_dg.c file (Jaroslav Kysela) [1112200]
- [alsa] oxygen: export oxygen_update_dac_routing symbol (Jaroslav Kysela) [1112200]
- [alsa] oxygen: add mute mask for the OXYGEN_PLAY_ROUTING register (Jaroslav Kysela) [1112200]
- [alsa] oxygen: modify the SPI writing function (Jaroslav Kysela) [1112200]
- [alsa] oxygen: add the separate SPI waiting function (Jaroslav Kysela) [1112200]
- [alsa] hda: Add parameter for dumping processing coefficients (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix silent output on MacBook Air 1,1 (Jaroslav Kysela) [1112200]
- [alsa] Refactor slot assignment code (Jaroslav Kysela) [1112200]
- [alsa] bits vs bytes bug in snd_card_create() (Jaroslav Kysela) [1112200]
- [alsa] hda: Apply +5dB output amp on ASUS Zenbook UX31A (Jaroslav Kysela) [1112200]
- [alsa] hda: add headset mic detect quirks for some Dell machines (Jaroslav Kysela) [1112200]
- [alsa] Add helper function for intersecting two rate masks (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix endless vmaster hook call in thinkpad_helper.c (Jaroslav Kysela) [1112200]
- [alsa] snd-usb: re-order some quirk entries (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Fix Creative VF0420 rate (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Add support for Focusrite Saffire 6 USB (Jaroslav Kysela) [1112200]
- [alsa] hda: automute via amp instead of pinctl on some AIO models (Jaroslav Kysela) [1112200]
- [alsa] hda: Apply codec power_filter to FG nodes (Jaroslav Kysela) [1112200]
- [alsa] hda: Don't set indep_hp flag for old AD codecs (Jaroslav Kysela) [1112200]
- [alsa] Enable CONFIG_ZONE_DMA for smaller PCI DMA masks (Jaroslav Kysela) [1112200]
- [alsa] pcm: Warn when buffer preallocation fails (Jaroslav Kysela) [1112200]
- [alsa] ctxfi: Work around emu20k1 glitch to prevent buffered sound data loss (Jaroslav Kysela) [1112200]
- [alsa] Merge memalloc code into snd-pcm module (Jaroslav Kysela) [1112200]
- [alsa] Remove superfluous header inclusions in memalloc.c (Jaroslav Kysela) [1112200]
- [alsa] Remove memory reservation code from memalloc helper (Jaroslav Kysela) [1112200]
- [alsa] Remove memory accounting in memalloc helper (Jaroslav Kysela) [1112200]
- [alsa] hda/hdmi: apply all Haswell fix-ups to Broadwell display codec (Jaroslav Kysela) [1112200]
- [alsa] hda: add codec ID for Broadwell display audio codec (Jaroslav Kysela) [1112200]
- [alsa] hda: add device ID for Broadwell display audio controller (Jaroslav Kysela) [1112200]
- [alsa] hda: Split Thinkpad ACPI-related code (Jaroslav Kysela) [1112200]
- [alsa] hda: Don't create duplicated ctls for loopback paths (Jaroslav Kysela) [1112200]
- [alsa] hda: Correct AD1986A 3stack pin configs (Jaroslav Kysela) [1112200]
- [alsa] hda: Add consistent tag names for firmware patch (Jaroslav Kysela) [1112200]
- [alsa] hda: firmware patch code cleanup (Jaroslav Kysela) [1112200]
- [alsa] hda: Increment default stream numbers for AMD HDMI controllers (Jaroslav Kysela) [1112200]
- [alsa] hda: Minor code optimization for patch_realtek.c (Jaroslav Kysela) [1112200]
- [alsa] compress: remove the sample rate check (Jaroslav Kysela) [1112200]
- [alsa] rme9652: fix a missing comma in channel_map_9636_ds (Jaroslav Kysela) [1112200]
- [alsa] cs5535audio: use named constants for pci_power_t values (Jaroslav Kysela) [1112200]
- [alsa] hda: Disable Front HP jack detection on Gigabyte Z87X-UD3H (Jaroslav Kysela) [1112200]
- [alsa] hiface: Fix typo in 352800 rate definition (Jaroslav Kysela) [1112200]
- [alsa] usb-audio: Add a quirk for Plantronics Gamecom 780 (Jaroslav Kysela) [1112200]
- [alsa] hda: Enable subwoofer on Dell Vostro 5460/5470 (Jaroslav Kysela) [1112200]
- [alsa] hda: Fix wrong <acpi/acpi.h> inclusion in Thinkpad ACPI users (Jaroslav Kysela) [1112200]
- [alsa] hda: Add warning texts when codec driver Kconfig doesn't match (Jaroslav Kysela) [1112200]
- [alsa] hda: Kill EXPORT_SYMBOL_HDA() (Jaroslav Kysela) [1112200]
- [alsa] hda: Make CONFIG_SND_HDA_CODEC_* tristate (Jaroslav Kysela) [1112200]
- [alsa] hda: Explicitly keep codec powered up in hdmi_present_sense (Jaroslav Kysela) [1112200]
- [alsa] hda: Add Dell headset detection quirk for one more laptop model (Jaroslav Kysela) [1112200]
- [alsa] Add SNDRV_PCM_STATE_PAUSED case in wait_for_avail function (Jaroslav Kysela) [1112200]

* Tue Sep 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-175.el7]
- [misc] mei: ignore client writing state during cb completion (Prarit Bhargava) [1088953]
- [misc] mei: don't use deprecated DEFINE_PCI_DEVICE_TABLE macro (Prarit Bhargava) [1088953]
- [misc] mei: amthif: fix checkpatch error (Prarit Bhargava) [1088953]
- [misc] mei: fix Unnecessary space after function pointer name (Prarit Bhargava) [1088953]
- [misc] mei: use cl_dbg where appropriate (Prarit Bhargava) [1088953]
- [misc] mei: client.h fix checkpatch errors (Prarit Bhargava) [1088953]
- [misc] mei: report consistently copy_from/to_user failures (Prarit Bhargava) [1088953]
- [misc] mei: drop pr_fmt macros (Prarit Bhargava) [1088953]
- [misc] mei: make me hw headers private to me hw (Prarit Bhargava) [1088953]
- [misc] mei: fix memory leak of pending write cb objects (Prarit Bhargava) [1088953]
- [misc] mei: me: do not reset when less than expected data is received (Prarit Bhargava) [1088953]
- [misc] mei: fix regressions caused by removing ext_msg (Prarit Bhargava) [1088953]
- [misc] mei: wd: fix stop completion failure (Prarit Bhargava) [1088953]
- [misc] mei: wd: simplify wd_send command (Prarit Bhargava) [1088953]
- [misc] mei: make return values consistent across the driver (Prarit Bhargava) [1088953]
- [misc] mei: revamp writing slot counting (Prarit Bhargava) [1088953]
- [misc] mei: add mei_hbuf_acquire wrapper (Prarit Bhargava) [1088953]
- [misc] mei: txe: include irqreturn.h for irqreturn_t etc (Prarit Bhargava) [1088953]
- [misc] mei: set client's read_cb to NULL when flow control fails (Prarit Bhargava) [1088953]
- [misc] mei: txe: put pm callbacks under PM_SLEEP ifdef (Prarit Bhargava) [1088953]
- [misc] mei: me: put pm callbacks under PM_SLEEP ifdef (Prarit Bhargava) [1088953]
- [misc] mei: don't of list_for_each_entry_safe when not deleting (Prarit Bhargava) [1088953]
- [misc] mei: use helper function to find me client by id (Prarit Bhargava) [1088953]
- [misc] mei: fix potential read outside of array bounds (Prarit Bhargava) [1088953]
- [misc] mei: wd and amthif use mei_cl_ api for dis/connection (Prarit Bhargava) [1088953]
- [misc] mei: hbm: revamp client connect and disconnection status (Prarit Bhargava) [1088953]
- [misc] mei: Remove all bus devices from the mei_dev list when stopping the MEI (Prarit Bhargava) [1088953]
- [misc] mei: get rid of ext_msg (Prarit Bhargava) [1088953]
- [misc] mei: rename MEI_FOP_IOCTL to MEI_FOP_CONNECT (Prarit Bhargava) [1088953]
- [misc] mei: fix compilation error with missing WATCHDOG_CORE (Prarit Bhargava) [1088953]
- [misc] mei: allow multiple retries if the hw reset has failed (Prarit Bhargava) [1088953]
- [misc] mei: export active connections to debugfs (Prarit Bhargava) [1088953]
- [misc] mei: txe: add Kbuild for TXE device (Prarit Bhargava) [1088953]
- [misc] mei: txe: add pci-txe.c (Prarit Bhargava) [1088953]
- [misc] mei: txe: add hw-txe-regs.h header file (Prarit Bhargava) [1088953]
- [misc] mei: txe: add hw-txe.c (Prarit Bhargava) [1088953]
- [misc] mei: txe: add hw-txe.h header file (Prarit Bhargava) [1088953]
- [misc] mei: don't unset read cb ptr on reset (Prarit Bhargava) [1088953]
- [misc] mei: clear write cb from waiting list on reset (Prarit Bhargava) [1088953]
- [misc] mei: limit the number of consecutive resets (Prarit Bhargava) [1088953]
- [misc] mei: revamp mei reset state machine (Prarit Bhargava) [1088953]
- [misc] mei: fix syntax in comments and debug output (Prarit Bhargava) [1088953]
- [misc] mei: nfc: mei_nfc_free has to be called under lock (Prarit Bhargava) [1088953]
- [misc] mei: use hbm idle state to prevent spurious resets (Prarit Bhargava) [1088953]
- [misc] mei: do not run reset flow from the interrupt thread (Prarit Bhargava) [1088953]
- [misc] mei: enable marking internal commands (Prarit Bhargava) [1088953]
- [misc] mei: me: set dma mask using DMA mapping API (Prarit Bhargava) [1088953]
- [misc] mei: cleanup mei_irq_read_handler (Prarit Bhargava) [1088953]
- [misc] mei: remove flash_work_queue (Prarit Bhargava) [1088953]
- [misc] mei: drop redundant list_del_init (Prarit Bhargava) [1088953]
- [misc] mei: bus: propagate error code returned by mei_me_cl_by_id (Prarit Bhargava) [1088953]
- [misc] mei: mei_cl_link remove duplicated check for open_handle_count (Prarit Bhargava) [1088953]
- [misc] mei: replace stray pr_debug with dev_dbg (Prarit Bhargava) [1088953]
- [misc] mei: wd: host_init propagate error codes from called functions (Prarit Bhargava) [1088953]
- [misc] mei: print correct device state during unexpected reset (Prarit Bhargava) [1088953]
- [misc] mei: nfc: fix memory leak in error path (Prarit Bhargava) [1088953]
- [misc] mei: move host_clients_map cleanup to device init (Prarit Bhargava) [1088953]
- [misc] mei: me: downgrade two errors to debug level (Prarit Bhargava) [1088953]
- [misc] mei: amthif: mei_amthif_host_init: propagate errors from called functions (Prarit Bhargava) [1088953]
- [misc] mei: revamp open handler counts (Prarit Bhargava) [1088953]
- [misc] mei: simplify mei_open error handling (Prarit Bhargava) [1088953]
- [misc] mei: remove unnecessary pci_set_drvdata() (Prarit Bhargava) [1088953]
- [misc] mei: mei_cl_unlink: no need to loop over dev list (Prarit Bhargava) [1088953]
- [misc] mei: push credentials inside the irq write handler (Prarit Bhargava) [1088953]
- [misc] mei: propagate error from write routines instead of ENODEV (Prarit Bhargava) [1088953]
- [misc] mei: fix function names in debug prints (Prarit Bhargava) [1088953]
- [misc] mei: prefix client log messages with client me and host ids (Prarit Bhargava) [1088953]
- [misc] mei: mei_release: drop redundant check if cb is NULL (Prarit Bhargava) [1088953]
- [misc] mei: fix format compilation warrning on 32 bit architecture (Prarit Bhargava) [1088953]
- [misc] mei: revamp read and write length checks (Prarit Bhargava) [1088953]
- [misc] mei: mei_write correct checks for copy_from_user (Prarit Bhargava) [1088953]
- [misc] mei: mei_cl_link protect open_handle_count from overflow (Prarit Bhargava) [1088953]
- [misc] mei: make sure that me_clients_map big enough before copying (Prarit Bhargava) [1088953]
- [misc] mei: convert bus code to use dev_groups (Prarit Bhargava) [1088953]
- [misc] mei: client.h cleanup (Prarit Bhargava) [1088953]
- [ethernet] e1000e: Fix Runtime PM blocks EEE link negotiation in S5 (John Greene) [1091119]
- [ethernet] e1000e: Fix EEE in S5 w/ Runtime PM enabled (John Greene) [1091119]
- [ethernet] e1000e: Add support for EEE in Sx states (John Greene) [1091119]
- [ethernet] e1000e: Add code to check return values on NVM accesses (John Greene) [1091119]
- [ethernet] e1000e: Fix CRC errors with jumbo traffic (John Greene) [1091119]
- [ethernet] e1000e: remove unnecessary break after return (John Greene) [1091119]
- [ethernet] e1000e: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (John Greene) [1091119]
- [ethernet] e1000e: Out of line __ew32_prepare/__ew32 (John Greene) [1091119]
- [ethernet] e1000e: Fix expand setting EEE link info to all affected parts (John Greene) [1091119]
- [ethernet] e1000e: Failure to write SHRA turns on PROMISC mode (John Greene) [1091119]
- [ethernet] e1000e: Restrict MDIO Slow Mode workaround to relevant parts (John Greene) [1091119]
- [ethernet] e1000e: Fix issue with link flap on 82579 (John Greene) [1091119]
- [ethernet] e1000e: Expand workaround for 10Mb HD throughput bug (John Greene) [1091119]
- [ethernet] e1000e: Workaround for dropped packets in Gig/100 speeds on 82579 (John Greene) [1091119]
- [ethernet] e1000e: fix message terminations (John Greene) [1091119]
- [ethernet] e1000e: Enclose e1000e_pm_thaw() with CONFIG_PM_SLEEP (John Greene) [1091119]
- [ethernet] e1000e: Correctly include VLAN_HLEN when changing interface MTU (John Greene) [1091119]
- [ethernet] e1000e: Fix no connectivity when driver loaded with cable out (John Greene) [1091119]
- [ethernet] e1000e: add timeout for TX HW time stamping work (John Greene) [1091119]
- [ethernet] e1000e: Fix Explicitly set Transmit Control Register (John Greene) [1091119]
- [ethernet] e1000e: Fix Hardware Unit Hang (John Greene) [1091119]
- [ethernet] e1000e: fix the build error when PM is disabled (John Greene) [1091119]
- [ethernet] e1000e: Fix ethtool offline tests for 82579 parts (John Greene) [1091119]
- [ethernet] e1000e: Fix not generating an error on invalid load parameter (John Greene) [1091119]
- [ethernet] e1000e: Feature Enable PHY Ultra Low Power Mode (ULP) (John Greene) [1091119]
- [ethernet] e1000e: Refactor of Runtime Power Management (John Greene) [1091119]
- [ethernet] e1000e: calls skb_set_hash (John Greene) [1091119]
- [ethernet] e1000e: Refactor PM flows (John Greene) [1091119]
- [ethernet] e1000e: Fix compilation warning when !CONFIG_PM_SLEEP (John Greene) [1091119]
- [ethernet] e1000e: Fix a compile flag mis-match for suspend/resume (John Greene) [1091119]
- [ethernet] e1000e: Remove extern from function prototypes (John Greene) [1091119]
- [ethernet] e1000e: Cleanup - Update GPL header and Copyright (John Greene) [1091119]
- [ethernet] e1000e: Fix 82579 sets LPI too early (John Greene) [1091119]
- [ethernet] e1000e: 82574/82583 TimeSync errata for SYSTIM read (John Greene) [1091119]
- [kernel] sched/fair: Stop searching for tasks in idle_balance if there are runnable tasks (Larry Woodman) [1103828]
- [kernel] sched/numa: Initialize new idle_balance stats in sd_numa_init() (Larry Woodman) [1103828]

* Mon Sep 29 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-174.el7]
- [kernel] tty: Add C_CMSPAR(tty) (Don Zickus) [1110939]
- [usb] pl2303: fixed handling of CS5 setting (Don Zickus) [1110939]
- [usb] pl2303: switch to generic TIOCMIWAIT implementation (Don Zickus) [1110939]
- [usb] pl2303: only wake up MSR queue on changes (Don Zickus) [1110939]
- [usb] pl2303: clean up line-status handling (Don Zickus) [1110939]
- [usb] pl2303: make type data const (Don Zickus) [1110939]
- [usb] pl2303: use C_CMSPAR macro (Don Zickus) [1110939]
- [usb] pl2303: use direct baud-rate encoding when possible (Don Zickus) [1110939]
- [usb] pl2303: add helper function for direct baud-rate encoding (Don Zickus) [1110939]
- [usb] pl2303: refactor baud-rate divisor handling (Don Zickus) [1110939]
- [usb] pl2303: enforce baud-rate limits before lookup (Don Zickus) [1110939]
- [usb] pl2303: refactor baud-rate table lookup (Don Zickus) [1110939]
- [usb] pl2303: rename pl2303_encode_baud_rate (Don Zickus) [1110939]
- [usb] pl2303: add device-type abstraction (Don Zickus) [1110939]
- [usb] pl2303: add quirk for legacy devices (Don Zickus) [1110939]
- [usb] pl2303: clean up type handling (Don Zickus) [1110939]
- [usb] pl2303: use speed_t for baud rates (Don Zickus) [1110939]
- [usb] pl2303: add line-status quirk for Siemens phones (Don Zickus) [1110939]
- [usb] pl2303: remove redundant line-request call (Don Zickus) [1110939]
- [usb] pl2303: add error handling to line requests (Don Zickus) [1110939]
- [usb] pl2303: fix data corruption on termios updates (Don Zickus) [1110939]
- [usb] pl2303: add error handling to set_control_lines (Don Zickus) [1110939]
- [usb] pl2303: add error handling to vendor read and write functions (Don Zickus) [1110939]
- [usb] Revert: pl2303: restrict the divisor based baud rate encoding method to the "HX" chip type (Don Zickus) [1110939]
- [usb] Revert: pl2303: fix+improve the divsor based baud rate encoding method (Don Zickus) [1110939]
- [usb] Revert: pl2303: do not round to the next nearest standard baud rate for the divisor based baud rate encoding method (Don Zickus) [1110939]
- [usb] Revert: pl2303: remove 500000 baud from the list of standard baud rates (Don Zickus) [1110939]
- [usb] Revert: pl2303: move the two baud rate encoding methods to separate functions (Don Zickus) [1110939]
- [usb] Revert: pl2303: increase the allowed baud rate range for the divisor based encoding method (Don Zickus) [1110939]
- [usb] Revert: pl2303: also use the divisor based baud rate encoding method for baud rates < 115200 with HX chips (Don Zickus) [1110939]
- [usb] Revert: pl2303: add two comments concerning the supported baud rates with HX chips (Don Zickus) [1110939]
- [usb] Revert: pl2303: simplify the else-if contruct for type_1 chips in pl2303_startup() (Don Zickus) [1110939]
- [usb] Revert: pl2303: improve the chip type information output on startup
- [usb] Revert: pl2303: improve the chip type detection/distinction
- [usb] Revert: pl2303: distinguish between original and cloned HX chips
- [usb] pl2303: clean up driver somewhat (Don Zickus) [1110939]
- [usb] pl2303: remove bogus delta_msr_wait wake up (Don Zickus) [1110939]
- [usb] core: let dynamic ids override static ids (Don Zickus) [1110939]
- [usb] core: Fix potential memory leak adding dyn USBdevice IDs (Don Zickus) [1110939]
- [usb] core: add sanity checks when using bInterfaceClass with new_id (Don Zickus) [1110939]
- [usb] core: check for valid id_table when using the RefId feature (Don Zickus) [1110939]
- [usb] core: bail out if user gives an unknown RefId when using new_id (Don Zickus) [1110939]
- [usb] core: allow a reference device for new_id (Don Zickus) [1110939]
- [lib] radix-tree: make radix_tree_node_alloc() work correctly within interrupt (Don Zickus) [1110939]
- [usb] Check if port status is equal to RxDetect (Don Zickus) [1110939]
- [usb] serial/ftdi_sio: Add Infineon Triboard (Don Zickus) [1110939]
- [usb] ftdi_sio: Add extra PID (Don Zickus) [1110939]
- [usb] option: Add ID for Telewell TW-LTE 4G v2 (Don Zickus) [1110939]
- [usb] cp210x: add support for Corsair usb dongle (Don Zickus) [1110939]
- [usb] storage/scsi: Add broken_fua blacklist flag (Don Zickus) [1110939]
- [usb] xhci: Fix runtime suspended xhci from blocking system suspend (Don Zickus) [1110939]
- [usb] xhci: clear root port wake on bits if controller isn't wake-up capable (Don Zickus) [1110939]
- [usb] xhci: correct burst count field for isoc transfers on 1.0 xhci hosts (Don Zickus) [1110939]
- [usb] xhci: Use correct SLOT ID when handling a reset device command (Don Zickus) [1110939]
- [usb] option: add/modify Olivetti Olicard modems (Don Zickus) [1110939]
- [usb] ftdi_sio: fix null deref at port probe (Don Zickus) [1110939]
- [usb] option: add device ID for SpeedUp SU9800 usb 3g modem (Don Zickus) [1110939]
- [usb] usbtest: add a timeout for scatter-gather tests (Don Zickus) [1110939]
- [usb] ehci: avoid BIOS handover on the HASEE E200 (Don Zickus) [1110939]
- [usb] fix hub-port pm_runtime_enable() vs runtime pm transitions (Don Zickus) [1110939]
- [usb] quiet peer failure warning, disable poweroff (Don Zickus) [1110939]
- [usb] improve "not suspended yet" message in hub_suspend() (Don Zickus) [1110939]
- [usb] xhci: Fix sleeping with IRQs disabled in xhci_stop_device() (Don Zickus) [1110939]
- [usb] fix ->update_hub_device() vs hdev->maxchild (Don Zickus) [1110939]
- [usb] hub_handle_remote_wakeup() only exists for CONFIG_PM=y (Don Zickus) [821903]
- [usb] qcserial: add additional Sierra Wireless QMI devices (Don Zickus) [1110939]
- [usb] qcserial: add Netgear AirCard 341U (Don Zickus) [1110939]
- [usb] xhci: delete endpoints from bandwidth list before freeing whole device (Don Zickus) [1110939]
- [usb] host/xhci-plat: add xhci_plat_start() (Don Zickus) [1110939]
- [usb] pci-quirks: Prevent Sony VAIO t-series from switching usb ports (Don Zickus) [1110939]
- [usb] resume child device when port is powered on (Don Zickus) [1110939]
- [usb] hub_handle_remote_wakeup() depends on CONFIG_PM_RUNTIME=y (Don Zickus) [1110939]
- [usb] introduce port status lock (Don Zickus) [1110939]
- [usb] synchronize port poweroff and khubd (Don Zickus) [1110939]
- [usb] refactor port handling in hub_events() (Don Zickus) [1110939]
- [usb] usb3 ports do not support FEAT_C_ENABLE (Don Zickus) [1110939]
- [usb] don't clear FEAT_C_ENABLE on usb_port_runtime_resume failure (Don Zickus) [1110939]
- [usb] block suspension of superspeed port while hispeed peer is active (Don Zickus) [1110939]
- [usb] make usb_port flags atomic, rename did_runtime_put to child_usage (Don Zickus) [1110939]
- [usb] sysfs link peer ports (Don Zickus) [1110939]
- [usb] find internal hub tier mismatch via acpi (Don Zickus) [1110939]
- [usb] assign usb3 external hub port peers (Don Zickus) [1110939]
- [usb] assign default peer ports for root hubs (Don Zickus) [1110939]
- [usb] cleanup setting udev->removable from port_dev->connect_type (Don Zickus) [1110939]
- [usb] rename usb_port device objects (Don Zickus) [1110939]
- [usb] disable port power control if not supported in wHubCharacteristics (Don Zickus) [1110939]
- [usb] mutual exclusion for resetting a hub and power-managing a port (Don Zickus) [1110939]
- [usb] pci_quirks: fix sparse 'symbol not declared' warning (Don Zickus) [1110939]
- [usb] storage/ene_ub6250: Use kmemdup instead of kmalloc + memcpy (Don Zickus) [1110939]
- [usb] usbtest: add pattern check on pipe in phase of unlink read (Don Zickus) [1110939]
- [usb] usbtest: fix unlink write error with pattern 1 (Don Zickus) [1110939]
- [usb] usb5303: add support for reference clock specified in device tree (Don Zickus) [1110939]
- [usb] separate usb_address0 mutexes for each bus (Don Zickus) [1110939]
- [usb] xhci: Switch only Intel Lynx Point-LP ports to EHCI on shutdown (Don Zickus) [1110939]
- [usb] yurex: fix race between probe() and read() (Don Zickus) [1110939]
- [usb] appledisplay: fix race between reading and writing from the device (Don Zickus) [1110939]
- [usb] usbtmc: fix DMA on stack (Don Zickus) [1110939]
- [usb] cdc-acm: use BIT macro (Don Zickus) [1110939]
- [usb] xhci: unified loggig of RESET_ON_RESUME (Don Zickus) [1110939]
- [usb] xhci: avoid warning for !PM_SLEEP (Don Zickus) [1110939]
- [usb] host/xhci-plat: add clock support (Don Zickus) [1110939]
- [usb] host/xhci-plat: sort the headers in alphabetic order (Don Zickus) [1110939]
- [usb] move usb/usb-common.c to usb/common/usb-common.c (Don Zickus) [1110939]
- [usb] core: remove the Kconfig entry for USB_DEBUG (Don Zickus) [1110939]
- [usb] remove redundant D0 power state set (Don Zickus) [1110939]
- [usb] keyspan: fix potential null pointer dereference (Don Zickus) [1110939]
- [usb] serial/option: add support for Novatel E371 PCIe card (Don Zickus) [1110939]
- [usb] ftdi_sio: add NovaTech OrionLXm product ID (Don Zickus) [1110939]
- [usb] io_ti: fix firmware download on big-endian machines (part 2) (Don Zickus) [1110939]
- [usb] cdc-acm: use tty-port dtr_rts (Don Zickus) [1110939]
- [usb] cdc-acm: remove redundant usb_mark_last_busy (Don Zickus) [1110939]
- [usb] cdc-acm: do not update PM busy on read errors (Don Zickus) [1110939]
- [usb] cdc-acm: minimise no-suspend window during shutdown (Don Zickus) [1110939]
- [usb] cdc-acm: remove redundant disconnected test from shutdown (Don Zickus) [1110939]
- [usb] cdc-acm: simplify runtime PM locking (Don Zickus) [1110939]
- [usb] cdc-acm: fix runtime PM imbalance at shutdown (Don Zickus) [1110939]
- [usb] cdc-acm: fix I/O after failed open (Don Zickus) [1110939]
- [usb] cdc-acm: fix failed open not being detected (Don Zickus) [1110939]
- [usb] cdc-acm: fix open and suspend race (Don Zickus) [1110939]
- [usb] cdc-acm: fix potential urb leak and PM imbalance in write (Don Zickus) [1110939]
- [usb] cdc-acm: fix shutdown and suspend race (Don Zickus) [1110939]
- [usb] cdc-acm: fix runtime PM for control messages (Don Zickus) [1110939]
- [usb] cdc-acm: fix broken runtime suspend (Don Zickus) [1110939]
- [usb] cdc-acm: fix write and resume race (Don Zickus) [1110939]
- [usb] cdc-acm: fix write and suspend race (Don Zickus) [1110939]
- [usb] kobil_sct: fix control requests without data stage (Don Zickus) [1110939]
- [usb] serial: remove overly defensive port tests (Don Zickus) [1110939]
- [usb] serial: fix potential runtime pm imbalance at device remove (Don Zickus) [1110939]
- [usb] usb_wwan: do not resume I/O on closing ports (Don Zickus) [1110939]
- [usb] usb_wwan: report failed submissions as errors (Don Zickus) [1110939]
- [usb] usb_wwan: remove bogus function prototype (Don Zickus) [1110939]
- [usb] usb_wwan: remove some superfluous comments (Don Zickus) [1110939]
- [usb] usb_wwan: remove comment from close (Don Zickus) [1110939]
- [usb] usb_wwan: clean up delayed-urb submission (Don Zickus) [1110939]
- [usb] usb_wwan: use interface-data accessors (Don Zickus) [1110939]
- [usb] usb_wwan: make resume error messages uniform (Don Zickus) [1110939]
- [usb] usb_wwan: kill interrupt urb explicitly at suspend (Don Zickus) [1110939]
- [usb] usb_wwan: remove redundant urb kill from port remove (Don Zickus) [1110939]
- [usb] usb_wwan: remove unimplemented set_termios (Don Zickus) [1110939]
- [usb] usb_wwan: remove redundant modem-control request (Don Zickus) [1110939]
- [usb] usb_wwan: fix remote wakeup (Don Zickus) [1110939]
- [usb] usb_wwan: fix discarded writes on resume errors (Don Zickus) [1110939]
- [usb] usb_wwan: fix potential blocked I/O after resume (Don Zickus) [1110939]
- [usb] usb_wwan: fix potential NULL-deref at resume (Don Zickus) [1110939]
- [usb] usb_wwan: fix urb leak at shutdown (Don Zickus) [1110939]
- [usb] usb_wwan: fix write and suspend race (Don Zickus) [1110939]
- [usb] usb_wwan: fix race between write and resume (Don Zickus) [1110939]
- [usb] usb_wwan: fix urb leak in write error path (Don Zickus) [1110939]
- [usb] option: add missing usb_mark_last_busy (Don Zickus) [1110939]
- [usb] option: fix line-control pipe direction (Don Zickus) [1110939]
- [usb] option: fix runtime PM handling (Don Zickus) [1110939]
- [usb] sierra: do not resume I/O on closing ports (Don Zickus) [1110939]
- [usb] sierra: minimise no-suspend window during close (Don Zickus) [1110939]
- [usb] sierra: refactor delayed-urb submission (Don Zickus) [1110939]
- [usb] sierra: clean up suspend (Don Zickus) [1110939]
- [usb] sierra: use interface-data accessors (Don Zickus) [1110939]
- [usb] sierra: remove redundant modem-control requests (Don Zickus) [1110939]
- [usb] sierra: do not resume I/O on closed ports (Don Zickus) [1110939]
- [usb] sierra: remove disconnected test from close (Don Zickus) [1110939]
- [usb] sierra: remove unimplemented set_termios (Don Zickus) [1110939]
- [usb] sierra: remove unused variable (Don Zickus) [1110939]
- [usb] sierra: remove bogus endpoint test (Don Zickus) [1110939]
- [usb] sierra: fix line-control pipe direction (Don Zickus) [1110939]
- [usb] sierra: fix resume error reporting (Don Zickus) [1110939]
- [usb] sierra: fix urbs not being killed on shutdown (Don Zickus) [1110939]
- [usb] sierra: fix characters being dropped at close (Don Zickus) [1110939]
- [usb] sierra: fix remote wakeup (Don Zickus) [1110939]
- [usb] sierra: fix urb and memory leak on disconnect (Don Zickus) [1110939]
- [usb] sierra: fix urb and memory leak in resume error path (Don Zickus) [1110939]
- [usb] sierra: fix use after free at suspend/resume (Don Zickus) [1110939]
- [usb] sierra: fix AA deadlock in open error path (Don Zickus) [1110939]
- [usb] iowarrior: Convert local dbg macro to dev_dbg (Don Zickus) [1110939]
- [usb] appledisplay: Convert /n to n (Don Zickus) [1110939]
- [usb] qcserial: remove interface number matching (Don Zickus) [1110939]
- [usb] qcserial: define and use Sierra Wireless layout (Don Zickus) [1110939]
- [usb] qcserial: refactor device layout selection (Don Zickus) [1110939]
- [usb] qcserial: fix multiline comment coding style (Don Zickus) [1110939]
- [usb] Avoid runtime suspend loops for HCDs that can't handle suspend/resume (Don Zickus) [1110939]
- [usb] xhci: rework command timeout and cancellation, (Don Zickus) [1110939]
- [usb] Revert: xhci: replace xhci_read_64() with readq() (Don Zickus) [1110939]
- [usb] Revert: xhci: replace xhci_write_64() with writeq() (Don Zickus) [1110939]
- [usb] Revert: core: set lpm_capable field for LPM capable root hubs (Don Zickus) [1110939]
- [usb] xhci: Use completion and status in global command queue (Don Zickus) [1110939]
- [usb] xhci: Add a global command queue (Don Zickus) [1110939]
- [usb] xhci: Use command structures when queuing commands on the command ring (Don Zickus) [1110939]
- [usb] xhci: Report max device limit when Enable Slot command fails (Don Zickus) [1110939]
- [usb] xhci: Use pci_enable_msix_exact() instead of pci_enable_msix() (Don Zickus) [1110939]
- [usb] xhci: Use IS_ENABLED() macro (Don Zickus) [1110939]
- [usb] catch attempts to submit urbs with a vmalloc'd transfer buffer (Don Zickus) [1110939]
- [usb] xhci: fix wrong port number reported when setting USB2.0 hardware LPM (Don Zickus) [1110939]
- [usb] Nokia 5300 should be treated as unusual dev (Don Zickus) [1110939]
- [usb] Nokia 305 should be treated as unusual dev (Don Zickus) [1110939]
- [usb] fsl: do not test for PHY_CLK_VALID bit on controller version 1.6 (Don Zickus) [1110939]
- [usb] storage/shuttle_usbat: fix discs being detected twice (Don Zickus) [1110939]
- [usb] qcserial: add a number of Dell devices (Don Zickus) [1110939]
- [usb] ohci: fix problem with global suspend on ATI controllers (Don Zickus) [1110939]
- [usb] option: add and update a number of CMOTech devices (Don Zickus) [1110939]
- [usb] option: add Alcatel L800MA (Don Zickus) [1110939]
- [usb] option: add Olivetti Olicard 500 (Don Zickus) [1110939]
- [usb] qcserial: add Sierra Wireless MC7305/MC7355 (Don Zickus) [1110939]
- [usb] qcserial: add Sierra Wireless MC73xx (Don Zickus) [1110939]
- [usb] qcserial: add Sierra Wireless EM7355 (Don Zickus) [1110939]
- [usb] io_ti: fix firmware download on big-endian machines (Don Zickus) [1110939]
- [usb] xhci: fix compilation warning when !CONFIG_PCI && !CONFIG_PM (Don Zickus) [1110939]
- [usb] xhci: extend quirk for Renesas cards (Don Zickus) [1110939]
- [usb] xhci: Switch Intel Lynx Point ports to EHCI on shutdown (Don Zickus) [1110939]
- [usb] xhci: Prefer endpoint context dequeue pointer over stopped_trb (Don Zickus) [1110939]
- [usb] ftdi-elan: Use pr_<level> (Don Zickus) [1110939]
- [usb] ftdi-elan: Coalesce string fragment (Don Zickus) [1110939]
- [usb] ftdi-elan: Coalesce formats (Don Zickus) [1110939]
- [usb] ftdi-elan: Convert leading spaces to tabs (Don Zickus) [1110939]
- [usb] ftdi-elan: Fix format fragments (Don Zickus) [1110939]
- [usb] serial: fix sysfs-attribute removal deadlock (Don Zickus) [1110939]
- [usb] uas: fix deadlocky memory allocations (Don Zickus) [1110939]
- [usb] uas: fix error handling during scsi_scan() (Don Zickus) [1110939]
- [usb] uas: fix GFP_NOIO under spinlock (Don Zickus) [1110939]
- [usb] cdc-acm: Remove Motorola/Telit H24 serial interfaces from ACM driver (Don Zickus) [1110939]
- [usb] ehci-platform: Return immediately from suspend if ehci_suspend fails (Don Zickus) [1110939]
- [usb] ehci-exynos: Return immediately from suspend if ehci_suspend fails (Don Zickus) [1110939]
- [usb] fix crash during hotplug of PCI USB controller card (Don Zickus) [1110939]
- [usb] cdc-acm: fix double usb_autopm_put_interface() in acm_port_activate() (Don Zickus) [1110939]
- [usb] usb_wwan: fix handling of missing bulk endpoints (Don Zickus) [1110939]
- [usb] pl2303: add ids for Hewlett-Packard HP POS pole displays (Don Zickus) [1110939]
- [usb] cp210x: Add 8281 (Nanotec Plug & Drive) (Don Zickus) [1110939]
- [usb] option driver, add support for Telit UE910v2 (Don Zickus) [1110939]
- [usb] Revert: serial: add usbid for dell wwan card to sierra.c (Don Zickus) [1110939]
- [usb] serial/ftdi_sio: add id for Brainboxes serial cards (Don Zickus) [1110939]
- [net] usb: include wait queue head in device structure (Don Zickus) [1110939]
- [usb] disable reset-resume when USB_QUIRK_RESET is set (Don Zickus) [1110939]
- [usb] unbind all interfaces before rebinding any (Don Zickus) [1110939]
- [usb] keyspan: remove dead debugging code (Don Zickus) [1110939]
- [usb] serial: add missing newlines to dev_<level> messages (Don Zickus) [1110939]
- [usb] serial: add missing braces (Don Zickus) [1110939]
- [usb] serial: continue to write on errors (Don Zickus) [1110939]
- [usb] serial: continue to read on errors (Don Zickus) [1110939]
- [usb] serial: make bulk_out_size a lower limit (Don Zickus) [1110939]
- [usb] cypress_m8: fix potential scheduling while atomic (Don Zickus) [1110939]
- [usb] Revert: xhci: Limit arbitrarily-aligned scatter gather (Don Zickus) [1110939]
- [usb] Make DELAY_INIT quirk wait 100ms between Get Configuration requests (Don Zickus) [1110939]
- [usb] Add device quirk for Logitech HD Pro Webcams C920 and C930e (Don Zickus) [1110939]
- [usb] xhci: add the meaningful IRQ description if it is empty (Don Zickus) [1110939]
- [usb] xhci: Prevent runtime pm from autosuspending during initialization (Don Zickus) [1110939]
- [usb] storage: accept some UAS devices if streams are unavailable (Don Zickus) [1110939]
- [usb] xhci: Kill streams URBs when the host dies (Don Zickus) [1110939]
- [usb] xhci: Refactor command watchdog and fix split string (Don Zickus) [1110939]
- [usb] uas: Remove comment about registering a uas scsi controller for each usb bus (Don Zickus) [1110939]
- [usb] uas: Add Hans de Goede as uas maintainer (Don Zickus) [1110939]
- [usb] uas: remove BROKEN (Don Zickus) [1110939]
- [usb] uas: Make sure sg elements are properly aligned (Don Zickus) [1110939]
- [usb] uas: Add some data in/out ready iu sanity checks (Don Zickus) [1110939]
- [usb] uas: Improve error reporting (Don Zickus) [1110939]
- [usb] uas: Use the right error codes for different kinds of errors (Don Zickus) [1110939]
- [usb] uas: Clear cmdinfo on command queue-ing (Don Zickus) [1110939]
- [usb] uas: Fix memory management (Don Zickus) [1110939]
- [usb] uas: Fix command / task mgmt submission racing with disconnect (Don Zickus) [1110939]
- [usb] uas: cmdinfo - use only one list head (Don Zickus) [1110939]
- [usb] uas: add uas_mark_cmd_dead helper function (Don Zickus) [1110939]
- [usb] uas: Properly complete inflight commands on bus-reset or disconnect (Don Zickus) [1110939]
- [usb] uas: uas_alloc_data_urb - Remove unnecessary use_streams check (Don Zickus) [1110939]
- [usb] uas: Fix task-management not working when connected over USB-2 (Don Zickus) [1110939]
- [usb] uas: Reset device on reboot (Don Zickus) [1110939]
- [usb] uas: Add suspend/resume support (Don Zickus) [1110939]
- [usb] uas: Use GFP_NOIO rather then GFP_ATOMIC where possible (Don Zickus) [1110939]
- [usb] uas: Don't allow more then one task to run at the same time (Don Zickus) [1110939]
- [usb] uas: task_mgmt - Kill the sense-urb if we fail to submit the cmd urb (Don Zickus) [1110939]
- [usb] uas: Not being able to alloc streams when connected through usb-3 is an error (Don Zickus) [1110939]
- [usb] uas: Verify endpoint descriptors from uas_use_uas_driver() (Don Zickus) [1110939]
- [usb] uas: Drop fixed endpoint config handling (Don Zickus) [1110939]
- [usb] uas: Move uas_find_endpoints to uas-detect.h (Don Zickus) [1110939]
- [usb] uas: Fix bounds check in uas_find_endpoints (Don Zickus) [1110939]
- [usb] uas: Add uas_find_endpoints() helper function (Don Zickus) [1110939]
- [usb] uas: Honor no-uas quirk set in usb-storage's quirks module parameter (Don Zickus) [1110939]
- [usb] storage: Modify and export adjust_quirks so that it can be used by uas (Don Zickus) [1110939]
- [usb] storage: Don't bind to uas devices if the uas driver is enabled (Don Zickus) [1110939]
- [usb] uas: Add the posibilty to blacklist uas devices from using the uas driver (Don Zickus) [1110939]
- [usb] Reset USB-3 devices on USB-3 link bounce (Don Zickus) [1110939]
- [usb] Clear host_endpoint->streams when implicitly freeing streams (Don Zickus) [1110939]
- [usb] xhci: Handle MaxPSASize == 0 (Don Zickus) [1110939]
- [usb] xhci: The trb_address_map radix tree expects 1KB segment memory aligment (Don Zickus) [1110939]
- [usb] xhci: xhci_mem_cleanup - make sure cmd_ring_reserved_trbs really is 0 (Don Zickus) [1110939]
- [usb] uas: Move uas detect code to uas-detect.h (Don Zickus) [1110939]
- [usb] uas: Add a uas_find_uas_alt_setting helper function (Don Zickus) [1110939]
- [usb] uas: Use all available stream ids (Don Zickus) [1110939]
- [usb] uas: Pack iu struct definitions (Don Zickus) [1110939]
- [usb] uas: Fix response iu struct definition (Don Zickus) [1110939]
- [usb] uas: s/response_ui/response_iu/ (Don Zickus) [1110939]
- [usb] uas: Fix reset handling for externally triggered reset (Don Zickus) [1110939]
- [usb] uas: Fix reset locking (Don Zickus) [1110939]
- [usb] uas: Fix uas not working when plugged into an ehci port (Don Zickus) [1110939]
- [usb] uas: uas_alloc_cmd_urb - drop unused stream_id parameter (Don Zickus) [1110939]
- [usb] uas: Avoid unnecessary unlock / lock calls around unlink_data_urbs (Don Zickus) [1110939]
- [usb] uas: Properly set interface to altsetting 0 on probe failure (Don Zickus) [1110939]
- [usb] uas: Urbs must be anchored before submitting them (Don Zickus) [1110939]
- [usb] uas: replace BUG_ON() + WARN_ON() with WARN_ON_ONCE() (Don Zickus) [1110939]
- [usb] uas: add dead request list (Don Zickus) [1110939]
- [usb] uas: make work list per-device (Don Zickus) [1110939]
- [usb] uas: properly reinitialize in uas_eh_bus_reset_handler (Don Zickus) [1110939]
- [usb] fs: Add support for allocating / freeing streams (Don Zickus) [1110939]
- [usb] fs: Add ep_to_host_endpoint helper function (Don Zickus) [1110939]
- [usb] fs: Add support for bulk stream ids (Don Zickus) [1110939]
- [usb] fs: proc_do_submiturb use a local variable for number_of_packets (Don Zickus) [1110939]
- [usb] usbfs: Kill urbs on interface before doing a set_interface (Don Zickus) [1110939]
- [usb] core: Free bulk streams on interface release (Don Zickus) [1110939]
- [usb] core: Track if an endpoint has streams (Don Zickus) [1110939]
- [usb] core: Move USB_MAXENDPOINTS definitions to usb.h (Don Zickus) [1110939]
- [usb] core: Fix usb_free_streams return value documentation (Don Zickus) [1110939]
- [usb] xhci: Remove segments from radix tree on failed insert (Don Zickus) [1110939]
- [usb] xhci: use usb_ss_max_streams in xhci_check_streams_endpoint (Don Zickus) [1110939]
- [usb] xhci: For streams the dequeue ptr must be read from the stream ctx (Don Zickus) [1110939]
- [usb] xhci: Set SCT field for Set TR dequeue on streams (Don Zickus) [1110939]
- [usb] xhci: For streams the css flag most be read from the stream-ctx on ep stop (Don Zickus) [1110939]
- [usb] xhci: Check size rather then number of streams when allocating stream ctxs (Don Zickus) [1110939]
- [usb] xhci: Free streams when they are still allocated on a set_interface call (Don Zickus) [1110939]
- [usb] xhci: fix usb3 streams (Don Zickus) [1110939]
- [usb] xhci: make warnings greppable (Don Zickus) [1110939]
- [usb] xhci: Change how we indicate a host supports Link PM (Don Zickus) [1110939]
- [usb] sisusb: Use static const, fix typo (Don Zickus) [1110939]
- [usb] hub: usb_ext_cap_descriptor.bmAttributes is le32 (Don Zickus) [1110939]
- [usb] hub: debug message for failing to enable device (Don Zickus) [1110939]
- [usb] ehci: fix deadlock when threadirqs option is used (Don Zickus) [1110939]
- [usb] ftdi_sio: add Cressi Leonardo PID (Don Zickus) [1110939]
- [usb] complain if userspace resets an active endpoint (Don Zickus) [1110939]
- [usb] serial/option: blacklist interface 4 for Cinterion PHS8 and PXS8 (Don Zickus) [1110939]
- [usb] ehci: add delay during suspend to prevent erroneous wakeups (Don Zickus) [1110939]
- [usb] xhci: Change compatible string from xhci-platform to generic-xhci (Don Zickus) [1110939]
- [usb] uhci-platform: Change compatible string from platform-uhci to generic-uhci (Don Zickus) [1110939]
- [usb] option: blacklist ZTE MF667 net interface (Don Zickus) [1110939]
- [usb] misc/usbled: Add Riso Kagaku Webmail Notifier (Don Zickus) [1110939]
- [usb] elan: Remove useless "default M" lines (Don Zickus) [1110939]
- [usb] Revert: xhci: Link TRB must not occur within a USB payload burst (Don Zickus) [1110939]
- [usb] Revert: xhci: Avoid infinite loop when sg urb requires too many trbs (Don Zickus) [1110939]
- [usb] Revert: xhci: Set scatter-gather limit to avoid failed block writes (Don Zickus) [1110939]
- [usb] xhci: Limit arbitrarily-aligned scatter gather (Don Zickus) [1110939]
- [usb] delete non-required instances of include <linux/init.h> (Don Zickus) [1110939]
- [usb] hub set hub->change_bits when over-current happens (Don Zickus) [1110939]
- [usb] xhci: Set scatter-gather limit to avoid failed block writes (Don Zickus) [1110939]
- [usb] xhci: Avoid infinite loop when sg urb requires too many trbs (Don Zickus) [1110939]
- [usb] ftdi_sio: added CS5 quirk for broken smartcard readers (Don Zickus) [1110939]
- [usb] core: correct spelling mistakes in comments and warning (Don Zickus) [1110939]
- [usb] fix race between hub_disconnect and recursively_mark_NOTATTACHED (Don Zickus) [1110939]
- [usb] oti6858: switch to generic TIOCMIWAIT implementation (Don Zickus) [1110939]
- [usb] oti6858: only wake up MSR queue on changes (Don Zickus) [1110939]
- [usb] ch341: clean up interrupt handler (Don Zickus) [1110939]
- [usb] ch341: switch to generic TIOCMIWAIT implementation (Don Zickus) [1110939]
- [usb] ch341: only wake up MSR queue on changes (Don Zickus) [1110939]
- [usb] ch341: fix ignored TIOCMIWAIT mask (Don Zickus) [1110939]
- [usb] ch341: clean up line-status handling (Don Zickus) [1110939]
- [usb] ch341: refactor line-status handling (Don Zickus) [1110939]
- [usb] cypress_m8: switch to generic TIOCMIWAIT implementation (Don Zickus) [1110939]
- [usb] cypress_m8: only wake up MSR queue on changes (Don Zickus) [1110939]
- [usb] cypress_m8: clean up protocol definitions (Don Zickus) [1110939]
- [usb] cypress_m8: fix ring-indicator detection and reporting (Don Zickus) [1110939]
- [usb] Nokia 502 is an unusual device (Don Zickus) [1110939]
- [usb] serial: add support for iBall 3.5G connect usb modem (Don Zickus) [1110939]
- [usb] serial: correct spelling mistakes in comments (Don Zickus) [1110939]
- [usb] misc/idmouse: correct spelling mistake in error string (Don Zickus) [1110939]
- [usb] yurex: fix spelling mistake in comment (Don Zickus) [1110939]
- [usb] iowarrior: fix spelling mistake in comment (Don Zickus) [1110939]
- [usb] serial: remove redundant OOM messages (Don Zickus) [1110939]
- [usb] serial: clean up ioctl debugging (Don Zickus) [1110939]
- [usb] serial: constify device-id tables (Don Zickus) [1110939]
- [usb] core: remove CONFIG_USB_DEBUG usage (Don Zickus) [1110939]
- [usb] cdc-wdm: avoid hanging on zero length reads (Don Zickus) [1110939]
- [usb] xhci: Check for XHCI_PLAT in xhci_cleanup_msix() (Don Zickus) [1110939]
- [usb] Mark function as static in metro-usb.c (Don Zickus) [1110939]
- [usb] Mark function as static in usbsevseg.c (Don Zickus) [1110939]
- [usb] option: add new zte 3g modem pids to option driver (Don Zickus) [1110939]
- [usb] usbtest: Always clear halt else further tests will fail (Don Zickus) [1110939]
- [usb] usbtest: Add timetout to simple_io() (Don Zickus) [1110939]
- [usb] xhci: Remove unused variable 'addr' in inc_deq() and inc_enq() (Don Zickus) [1110939]
- [usb] usbtest: Fix BOS control test for USB 2.01 devices (Don Zickus) [1110939]
- [usb] xhci: Add quirks module option (Don Zickus) [1069460]
- [usb] xhci: clarify logging in xhci_setup_device (Don Zickus) [1110939]
- [usb] xhci: change enumeration scheme to 'new scheme' by default (Don Zickus) [1069460]
- [usb] xhci: Limit the spurious wakeup fix only to HP machines (Don Zickus) [1069461]
- [usb] core: get config and string descriptors for unauthorized devices (Don Zickus) [1110939]
- [usb] core: allow isoc URBs for wireless devices with an interval < 6 (Don Zickus) [1110939]
- [usb] serial/zte_ev: move support for ZTE AC2726 from zte_ev back to option (Don Zickus) [1110939]
- [usb] cdc-wdm: manage_power should always set needs_remote_wakeup (Don Zickus) [1110939]
- [usb] Revert: quirks: add touchscreen that is dazzeled by remote wakeup (Don Zickus) [1110939]
- [usb] Use dev_is_pci() to check whether it is pci device (Don Zickus) [1110939]
- [usb] usbtest: update bos test coverage to usb 2.1 device (Don Zickus) [1110939]
- [usb] usbtest: fix the bit mask of usb 2.0 extension descriptor (Don Zickus) [1110939]
- [usb] usbtest: add a test case to support bos for queue control (Don Zickus) [1110939]
- [usb] fix coccinelle warnings (Don Zickus) [1110939]
- [usb] hub: Use correct reset for wedged USB3 devices that are NOTATTACHED (Don Zickus) [1110939]
- [usb] remove DEFINE_PCI_DEVICE_TABLE macro (Don Zickus) [1110939]
- [usb] host: Remove superfluous name casts (Don Zickus) [1110939]
- [usb] core: Remove superfluous name casts (Don Zickus) [1110939]
- [usb] kill #undef VERBOSE_DEBUG (Don Zickus) [1110939]
- [usb] kill DEBUG compile option (Don Zickus) [1110939]
- [usb] uhci: compile debugfs conditional on CONFIG_DYNAMIC_DEBUG (Don Zickus) [1110939]
- [usb] uhci: change dependency for debug parameter (Don Zickus) [1110939]
- [usb] ehci: Remove debugging at every interrupt (Don Zickus) [1110939]
- [usb] ehci: no conditional compilation for interestingness (Don Zickus) [1110939]
- [usb] ohci: no conditional debugging in root hub hadling (Don Zickus) [1110939]
- [usb] ohci: always register debug files (Don Zickus) [1110939]
- [usb] ohci: kill ohci_vdbg (Don Zickus) [1110939]
- [usb] ohci: remove conditional compilation (Don Zickus) [1110939]
- [usb] net/cdc-acm: fix power management in ioctl (Don Zickus) [1110939]
- [net] usb/cdc-acm: add TIOCGICOUNT (Don Zickus) [1110939]
- [usb] net/cdc-acm: add TIOCMIWAIT (Don Zickus) [1110939]
- [usb] option: support new huawei devices (Don Zickus) [1110939]
- [usb] serial/option: blacklist interface 1 for Huawei E173s-6 (Don Zickus) [1110939]
- [usb] xhci: replace xhci_write_64() with writeq() (Don Zickus) [1110939]
- [usb] xhci: replace xhci_read_64() with readq() (Don Zickus) [1110939]
- [usb] xhci: replace xhci_writel() with writel() (Don Zickus) [1110939]
- [usb] xhci: replace xhci_readl() with readl() (Don Zickus) [1110939]
- [usb] xhci: remove conversion from generic to pci device in xhci_mem.c (Don Zickus) [1110939]
- [usb] xhci: fix incorrect type in assignment in xhci_count_num_dropped_endpoints() (Don Zickus) [1110939]
- [usb] xhci: fix incorrect type in assignment in xhci_count_num_new_endpoints() (Don Zickus) [1110939]
- [usb] xhci: remove unnecessary check in xhci_free_stream_info() (Don Zickus) [1110939]
- [usb] xhci: fix SCT_FOR_CTX(p) macro (Don Zickus) [1110939]
- [usb] xhci: replace USB_MAXINTERFACES with config->desc.bNumInterface (Don Zickus) [1110939]
- [usb] xhci: fix incorrect type in assignment in xhci_address_device() (Don Zickus) [1110939]
- [usb] xhci: fix sparse warning in xhci-trace.h (Don Zickus) [1110939]
- [usb] xhci: fix derivation of TRB's DMA address in xhci_log_event Trace Event Class (Don Zickus) [1110939]
- [usb] r8a66597-hcd: Convert to clk_prepare/unprepare (Don Zickus) [1110939]
- [usb] serial: fix write memory-allocation flag (Don Zickus) [1110939]
- [usb] serial: fix race in generic write (Don Zickus) [1110939]
- [net] usb/cdc_ncm: Export cdc_ncm_{tx, rx}_fixup functions for re-use (Don Zickus) [1110939]
- [net] usb/cdc_ncm: drop "extern" from header declarations (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove descriptor pointers (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove ncm_parm field (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove tx_speed and rx_speed fields (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove unused udev field (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove redundant netdev field (Don Zickus) [1110939]
- [net] usb/cdc_ncm: simplify and optimize frame padding (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove redundant endpoint pointers (Don Zickus) [1110939]
- [net] usb/cdc_ncm: remove redundant "intf" field (Don Zickus) [1110939]
- [net] usb/cdc_ncm: add include protection to cdc_ncm.h (Don Zickus) [1110939]
- [usb] ssb-hcd: replace dma_set_mask()+dma_set_coherent_mask() with new helper (Don Zickus) [1110939]
- [usb] bcma: replace dma_set_mask()+dma_set_coherent_mask() with new helper (Don Zickus) [1110939]
- [usb] usbtest: support container id descriptor test (Don Zickus) [1110939]
- [usb] usbtest: support superspeed device capbility descriptor test (Don Zickus) [1110939]
- [usb] usbtest: support usb2 extension descriptor test (Don Zickus) [1110939]
- [usb] ehci-atmel: add usb_clk for transition to CCF (Don Zickus) [1110939]
- [usb] cdc-wdm: ignore speed change notifications (Don Zickus) [1110939]
- [usb] cdc-wdm: support back-to-back USB_CDC_NOTIFY_RESPONSE_AVAILABLE notifications (Don Zickus) [1110939]
- [usb] usbtest: support bos descriptor test for usb 3.0 (Don Zickus) [1110939]
- [usb] wusbcore: fix control-pipe directions (Don Zickus) [1110939]
- [usb] wusbcore: fix panic in wusbhc_chid_set (Don Zickus) [1110939]
- [usb] wusbcore: convert nested lock to use spin_lock instead of spin_lock_irq (Don Zickus) [1110939]
- [usb] wusbcore: use multiple urbs for HWA iso transfer result frame reads (Don Zickus) [1110939]
- [usb] wusbcore: combine iso transfer result frame reads when possible (Don Zickus) [1110939]
- [usb] wusbcore: disable transfer notifications for Alereon HWAs (Don Zickus) [1110939]
- [usb] wusbcore: don't mark WA_SEG_DTI_PENDING segs as done in urb_dequeue (Don Zickus) [1110939]
- [usb] wusbcore: fix potential double list_del on urb dequeue (Don Zickus) [1110939]
- [usb] wusbcore: fix compile warnings (Don Zickus) [1110939]
- [usb] wusbcore: add info to HWA debug prints (Don Zickus) [1110939]
- [usb] wusbcore: read actual_length bytes isoc in segments (Don Zickus) [1110939]
- [usb] wusbcore: adjust iterator correctly when searching for ep comp descriptor (Don Zickus) [1110939]
- [usb] wusbcore: add a convenience function for completing a transfer segment (Don Zickus) [1110939]
- [usb] wusbcore: prevent urb dequeue and giveback race (Don Zickus) [1110939]
- [usb] wusbcore: fix stranded URB after HWA unplug (Don Zickus) [1110939]
- [usb] wusbcore: fix kernel panic on HWA unplug (Don Zickus) [1110939]
- [usb] wusbcore: fix up coding style issues in wa-nep.c (Don Zickus) [1110939]
- [usb] wusbcore: fix up coding style issues in wa-rpipe.c (Don Zickus) [1110939]
- [usb] wusbcore: fix up coding style issues in wusbhc.c and wusbhc.h (Don Zickus) [1110939]
- [usb] wusbcore: fix up line break coding style issues in mmc.c (Don Zickus) [1110939]
- [usb] wusbcore: fix up line break coding style issues in security.c (Don Zickus) [1110939]
- [usb] wusbcore: fix up line break coding style issues in wa-hc.h (Don Zickus) [1110939]
- [usb] wusbcore: fix up minor coding style issues in cbaf.c (Don Zickus) [1110939]
- [usb] wusbcore: correct spelling mistakes in comments and error string (Don Zickus) [1110939]
- [usb] wusbcore: add debug prints to reservation and channel change (Don Zickus) [1110939]
- [usb] wusbcore: add isochronous IN support to HWA (Don Zickus) [1110939]
- [usb] wusbcore: set packet count correctly on isoc transfers (Don Zickus) [1110939]
- [usb] wusbcore: move isoc_frame_index from wa_xfer to wa_seg (Don Zickus) [1110939]
- [usb] wusbcore: use USB_CTRL_SET_TIMEOUT and USB_CTRL_GET_TIMEOUT (Don Zickus) [1110939]
- [usb] wusbcore: fix short transfers (Don Zickus) [1110939]
- [usb] wusbcore: return -ENOENT for unlinked URBs (Don Zickus) [1110939]
- [usb] wusbcore: add more info to debug prints in urb_unlink path (Don Zickus) [1110939]
- [usb] wusbcore: add calls to usb_hcd_link_urb_to_ep, usb_hcd_unlink_urb_from_ep, and (Don Zickus) [1110939]
- [usb] wusbcore: fix deadlock in wusbhc_gtk_rekey (Don Zickus) [1110939]
- [usb] wusbcore: do device lookup while holding the hc mutex (Don Zickus) [1110939]
- [usb] wusbcore: send keepalives to unauthenticated devices (Don Zickus) [1110939]
- [usb] wusbcore: change WA_SEGS_MAX to a legal value (Don Zickus) [1110939]
- [usb] wusbcore: add a quirk for Alereon HWA device isoc behavior (Don Zickus) [1110939]
- [usb] wusbcore: combine multiple isoc frames in a single transfer request (Don Zickus) [1110939]
- [usb] wusbcore: set the RPIPE wMaxPacketSize value correctly (Don Zickus) [1110939]
- [usb] wusbcore: fix usb_dev leaks (Don Zickus) [1110939]
- [usb] wusbcore: serialize access to the HWA data out endpoint (Don Zickus) [1110939]
- [usb] wusbcore: fix string formatting warnings on 64-bit builds (Don Zickus) [1110939]
- [usb] wusbcore: add support for isoc out transfers (Don Zickus) [1110939]
- [usb] wusbcore: set the RPIPE bOverTheAirInterval for isoc endpoints (Don Zickus) [1110939]
- [usb] wusbcore: avoid stack overflow in URB enqueue error path (Don Zickus) [1110939]
- [usb] wusbcore: fix build warning on 64-bit builds (Don Zickus) [1110939]
- [usb] wusbcore: clean up urb dequeue process (Don Zickus) [1110939]
- [usb] wusbcore: include the xfer_id in debug prints (Don Zickus) [1110939]
- [usb] wusbcore: fix endianess issues when using dwTransferID (Don Zickus) [1110939]
- [usb] wusbcore: set pointers to NULL after freeing in error cases (Don Zickus) [1110939]
- [usb] wusbcore: clean up the sg list that was created for out transfers (Don Zickus) [1110939]
- [usb] wusbcore: resource cleanup fix in __wa_xfer_setup_segs (Don Zickus) [1110939]
- [usb] wusbcore: allow wa_xfer_destroy to clean up partially constructed xfers (Don Zickus) [1110939]
- [usb] wusbcore: rename fields in struct wahc (Don Zickus) [1110939]
- [usb] wusbcore: rename urb to tr_urb in struct wa_seg (Don Zickus) [1110939]
- [usb] wusbcore: use list_move_tail instead of list_del/list_add_tail (Don Zickus) [1110939]
- [usb] usbtest: fix checkpatch warning as sizeof code style (Don Zickus) [1110939]
- [usb] uhci: check for wakeup/suspend race (Don Zickus) [1110939]
- [usb] ehci: add check for wakeup/suspend race (Don Zickus) [1110939]
- [usb] change dev_warn about missing reset-resume to dev_dbg (Don Zickus) [1110939]
- [usb] ohci: fix and explain sparse errors (Don Zickus) [1110939]
- [usb] ehci: fix sparse errors (Don Zickus) [1110939]
- [usb] ehci: fix type mismatch in check_intr_schedule (Don Zickus) [1110939]
- [usb] wusbcore: preserve endianness of cached descriptors (Don Zickus) [1110939]
- [usb] xhci: remove the unused ->address field (Don Zickus) [1032371]
- [usb] xhci: kill a conditional when toggling cycle (Don Zickus) [1032371]
- [usb] hub_activate kill an 'else' (Don Zickus) [1032371]
- [usb] hub: Clear Port Reset Change during init/resume (Don Zickus) [1110939]
- [usb] core/devio: Spaces to tabs for proc_control_compat() (Don Zickus) [1110939]
- [usb] core/devio: Spaces to tabs for proc_reapurbnonblock() (Don Zickus) [1110939]
- [usb] xhci: replace 'event' with 'cmd_comp_code' in set_deq and reset_ep handlers (Don Zickus) [1032371]
- [usb] xhci: add argument 'slot_id' in stop_ep, set_deq and reset_ep cmd handlers (Don Zickus) [1032371]
- [usb] xhci: replace 'xhci->cmd_ring->dequeue' with 'trb' in stop_ep cmd handler (Don Zickus) [1032371]
- [usb] xhci: add variable 'cmd_type' in handle_cmd_completion() (Don Zickus) [1032371]
- [usb] xhci: add variable 'cmd_trb' in handle_cmd_completion() (Don Zickus) [1032371]
- [usb] xhci: add variable 'cmd_comp_code' in handle_cmd_completion() (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_CONFIG_EP case into function (Don Zickus) [1032371]
- [usb] xhci: remove unused 'ep_ring' variable in handle_cmd_completion() (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_EVAL_CONTEXT case into function (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_NEC_GET_FW case into function (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_RESET_DEV case into function (Don Zickus) [1032371]
- [usb] xhci: use completion event's slot id rather than dig it out of command (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_ADDR_DEV case into function (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_DISABLE_SLOT case into function (Don Zickus) [1032371]
- [usb] xhci: refactor TRB_ENABLE_SLOT case into function (Don Zickus) [1032371]
- [usb] xhci: rename existing Command Completion Event handlers (Don Zickus) [1032371]
- [usb] xhci: remove unused argument from xhci_giveback_urb_in_irq() (Don Zickus) [1032371]
- [usb] xhci: correct the usage of USB_CTRL_SET_TIMEOUT (Don Zickus) [1032371]
- [usb] xhci: Staticize xhci_del_comp_mod_timer (Don Zickus) [1032371]
- [usb] Push USB2 LPM disable on disconnect into USB core (Don Zickus) [1032371]
- [usb] xhci: Enable LPM support only for hardwired or BESL devices (Don Zickus) [1032371]
- [usb] Don't enable USB 2.0 Link PM by default (Don Zickus) [1032371]
- [usb] xhci: Set L1 device slot on USB2 LPM enable/disable (Don Zickus) [1032371]
- [usb] Disable USB 2.0 Link PM before device reset (Don Zickus) [1110939]
- [usb] hcd: remove unnecessary local_irq_save (Don Zickus) [1110939]
- [usb] ehci: start new isochronous streams ASAP (Don Zickus) [1110939]
- [usb] ehci: create per-TT bandwidth tables (Don Zickus) [1110939]
- [usb] core/hub: Comments shouldnt be C99 // comment style (Don Zickus) [1110939]
- [usb] core/file: moved asterisk to variable name (Don Zickus) [1110939]
- [usb] core: {file, hub, sysfs, usb}.c - Whitespace fixes (Don Zickus) [1110939]
- [usb] mos7840: fix tiocmget error handling (Don Zickus) [1110939]
- [usb] serial: export usb_serial_generic_write_start (Don Zickus) [1110939]
- [usb] serial: add memory flags to usb_serial_generic_write_start (Don Zickus) [1110939]
- [usb] serial: clean up comments in generic driver (Don Zickus) [1110939]
- [usb] core/hcd: converted busmap from struct to bitmap (Don Zickus) [1110939]
- [usb] add a private-data pointer to struct usb_tt (Don Zickus) [1110939]
- [usb] ehci: use a bandwidth-allocation table (Don Zickus) [1110939]
- [usb] ehci: create a "periodic schedule info" struct (Don Zickus) [1110939]
- [usb] ehci: use consistent NO_FRAME value (Don Zickus) [1110939]
- [usb] ehci: change toggle only upon successful reset (Don Zickus) [1110939]
- [usb] ehci: No SSPLIT allowed in uframe 7 (Don Zickus) [1110939]
- [usb] ehci: compute full-speed bandwidth usage correctly (Don Zickus) [1110939]
- [usb] ehci: check the right uframes for CSPLIT (Don Zickus) [1110939]
- [usb] NS_TO_US should round up (Don Zickus) [1110939]
- [usb] anchor: Delay usb_wait_anchor_empty_timeout wake up till completion is done (Don Zickus) [1110939]
- [usb] anchor: Ensure poisened gets initialized to 0 (Don Zickus) [1110939]
- [usb] cyberjack: fix buggy integer overflow test (Don Zickus) [1110939]
- [usb] host: bugfix - Return length of copied buffer in uhci_hub_control() (Don Zickus) [1110939]
- [usb] host: uhci-platform - remove deprecated IRQF_DISABLED (Don Zickus) [1110939]
- [usb] core/hcd: if-else-braces fixed (Don Zickus) [1110939]
- [usb] core/hcd: removed braces for return statements (Don Zickus) [1110939]
- [usb] core/hcd: replaced C99 // comments (Don Zickus) [1110939]
- [usb] core/hcd: Whitespace fixes (Don Zickus) [1110939]
- [usb] core/hcd: moved asterix to variable (Don Zickus) [1110939]
- [usb] host: Use existing macros instead of hard-coded values in uhci-debug.c (Don Zickus) [1110939]
- [usb] remove intel_mid_otg.h (Don Zickus) [1110939]
- [usb] wusbcore: Add isoc transfer type enum and packet definitions (Don Zickus) [1110939]
- [usb] wusbcore: implement hwahc_op_get_frame_number (Don Zickus) [1110939]
- [usb] ohci: use amd_chipset_type to filter for SB800 prefetch (Don Zickus) [1110939]
- [usb] ehci: use amd_chipset_type to filter for usb subsystem hang bug (Don Zickus) [1110939]
- [usb] ohci: ohci_init_driver() - sanity check overrides (Don Zickus) [1110939]
- [usb] core: usb_amd_resume_quirk() can be static (Don Zickus) [1110939]
- [usb] pci-quirks: amd_chipset_sb_type_init() can be static (Don Zickus) [1110939]
- [usb] serial: invoke dcd_change ldisc's handler (Don Zickus) [1110939]
- [usb] serial: call handle_dcd_change in ftdi driver (Don Zickus) [1110939]
- [usb] correct the usb_disconnect() comment about usb_bus_list_lock (Don Zickus) [1110939]
- [usb] fix substandard locking for the sysfs files (Don Zickus) [1110939]
- [usb] usbtest: bmAttributes would better be masked (Don Zickus) [1110939]
- [usb] core: implement AMD remote wakeup quirk (Don Zickus) [1110939]
- [usb] pci-quirks: refactor AMD quirk to abstract AMD chipset types (Don Zickus) [1110939]
- [usb] host: delete chipidea dependency (Don Zickus) [1110939]
- [usb] ohci/uhci: add soft dependencies on ehci_pci (Don Zickus) [1110939]
- [usb] ehci: support running URB giveback in tasklet context"" (Don Zickus) [1110939]
- [usb] core: fix read of usbdevfs_ctrltransfer fields in proc_control() (Don Zickus) [1110939]
- [usb] core: fix incorrect type in assignment in usb_set_lpm_parameters() (Don Zickus) [1110939]
- [usb] core: Make usb_free_streams return an error (Don Zickus) [1110939]
- [usb] ehci: handle isochronous underruns with tasklets (Don Zickus) [1110939]
- [usb] ehci: code rearrangement in iso_stream_schedule() (Don Zickus) [1110939]
- [usb] see if URB comes from a completion handler (Don Zickus) [1110939]

* Mon Sep 29 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-173.el7]
- [crypto] pefile: Relax the check on the length of the PKCS#7 cert (Vivek Goyal) [852066]
- [kernel] kexec, purgatory: add clean-up for purgatory directory (Vivek Goyal) [852066]
- [x86] purgatory: use approprate -m64/-32 build flag for arch/x86/purgatory (Vivek Goyal) [852066]
- [kernel] kexec: remove CONFIG_KEXEC dependency on crypto (Vivek Goyal) [852066]
- [kernel] kexec: create a new config option CONFIG_KEXEC_FILE for new syscall (Vivek Goyal) [852066]
- [kernel] resource: fix the case of null pointer access (Vivek Goyal) [852066]
- [kernel] kexec: verify the signature of signed PE bzImage (Vivek Goyal) [852066]
- [kernel] kexec: support kexec/kdump on EFI systems (Vivek Goyal) [852066]
- [kernel] kexec: support for kexec on panic using new system call (Vivek Goyal) [852066]
- [x86] kexec-bzimage64: support for loading bzImage using 64bit entry (Vivek Goyal) [852066]
- [kernel] kexec: load and relocate purgatory at kernel load time (Vivek Goyal) [852066]
- [x86] purgatory: core purgatory functionality (Vivek Goyal) [852066]
- [x86] purgatory/sha256: provide implementation of sha256 in purgaotory context (Vivek Goyal) [852066]
- [kernel] kexec: implementation of new syscall kexec_file_load (Vivek Goyal) [852066]
- [kernel] kexec: new syscall kexec_file_load() declaration (Vivek Goyal) [852066]
- [kernel] kexec: make kexec_segment user buffer pointer a union (Vivek Goyal) [852066]
- [kernel] resource: provide new functions to walk through resources (Vivek Goyal) [852066]
- [kernel] kexec: use common function for kimage_normal_alloc() and kimage_crash_alloc() (Vivek Goyal) [852066]
- [kernel] kexec: move segment verification code in a separate function (Vivek Goyal) [852066]
- [kernel] kexec: rename unusebale_pages to unusable_pages (Vivek Goyal) [852066]
- [scripts] build bin2c based on config option CONFIG_BUILD_BIN2C (Vivek Goyal) [852066]
- [scripts] bin2c: move bin2c in scripts/basic (Vivek Goyal) [852066]
- [kernel] kexec: convert printk to pr_foo() (Vivek Goyal) [852066]
- [kernel] kexec/compat: convert to COMPAT_SYSCALL_DEFINE with changing parameter types (Vivek Goyal) [852066]
- [kernel] kexec: use vscnprintf() instead of vsnprintf() in vmcoreinfo_append_str() (Vivek Goyal) [852066]
- [kernel] kexec: add sysctl to disable kexec_load (Vivek Goyal) [852066]
- [kernel] kexec: Typo s/the/then/ (Vivek Goyal) [852066]
- [kernel] kexec: remove unnecessary return (Vivek Goyal) [852066]
- [asm] crash: Remove the original asm/crash.h files (Vivek Goyal) [852066]
- [asm] crash: Rename crash.h to crash-driver.h (Vivek Goyal) [852066]
- [x86] boot: Remove misc.h inclusion from compressed/string.c (Vivek Goyal) [852066]
- [x86] boot: Do not include boot.h in string.c (Vivek Goyal) [852066]
- [x86] boot: Move memset() definition in compressed/string.c (Vivek Goyal) [852066]
- [x86] boot: Move memcmp() into string.h and string.c (Vivek Goyal) [852066]
- [x86] boot: Move optimized memcpy() 32/64 bit versions to compressed/string.c (Vivek Goyal) [852066]
- [x86] boot: Create a separate string.h file to provide standard string functions (Vivek Goyal) [852066]
- [x86] boot: Undef memcmp before providing a new definition (Vivek Goyal) [852066]

* Mon Sep 29 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-172.el7]
- [fs] nfsd4: fix rd_dircount enforcement ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add some comments to the nfsd4 object definitions ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove the client_mutex and the nfs4_lock/unlock_state wrappers ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove nfs4_lock_state: nfs4_state_shutdown_net ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove nfs4_lock_state: nfs4_laundromat ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): reclaim_complete() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): setclientid, setclientid_confirm, renew ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): exchange_id, create/destroy_session() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_open and nfsd4_open_confirm ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_delegreturn() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_open_downgrade + nfsd4_close ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_lock/locku/lockt() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_release_lockowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfsd4_test_stateid/nfsd4_free_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove nfs4_lock_state(): nfs4_preprocess_stateid_op() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove old fault injection infrastructure ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add more granular locking to *_delegations fault injectors ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add more granular locking to forget_openowners fault injector ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add more granular locking to forget_locks fault injector ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add a list_head arg to nfsd_foreach_client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add nfsd_inject_forget_clients ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add a forget_client set_clnt routine ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add a forget_clients "get" routine with proper locking ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: abstract out the get and set routines into the fault injection ops ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: protect clid and verifier generation with client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: don't destroy clients that are busy ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Put the reference of nfs4_file when freeing stid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: don't destroy client if mark_client_expired_locked fails ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: move unhash_client_locked call into mark_client_expired_locked ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: protect the close_lru list and oo_last_closed_stid with client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add lockdep assertions to document the nfs4_client/session locking ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure lookup_clientid() takes client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect nfsd4_destroy_clientid using client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect session creation and client confirm using client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect unconfirmed client creation using client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Move create_client() call outside the lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Don't require client_lock in free_client ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure that the laundromat unhashes the client before releasing locks ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure struct nfs4_client is unhashed before we try to destroy it ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: fix out of date comment ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Decrease nfsd_users in nfsd_startup_generic fail ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: rename unhash_generic_stateid to unhash_ol_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: don't thrash the cl_lock while freeing an open stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: reduce cl_lock thrashing in release_openowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: close potential race in nfsd4_free_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: optimize destroy_lockowner cl_lock thrashing ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add locking to stateowner release ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up and reorganize release_lockowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Move the open owner hash table into struct nfs4_client ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect adding/removing lock owners using client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect adding/removing open state owners using client_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: don't allow CLOSE to proceed until refcount on stateid drops ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: make openstateids hold references to their openowners ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up refcounting for lockowners ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Make lock stateid take a reference to the lockowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add an operation for unhashing a stateowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up lockowner refcounting when finding them ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add a mutex to protect the NFSv4.0 open owner replay cache ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add reference counting to state owners ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Migrate the stateid reference into nfs4_find_stateid_by_type() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Migrate the stateid reference into nfs4_lookup_stateid() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Migrate the stateid reference into nfs4_preprocess_seqid_op ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add reference counting to nfs4_preprocess_confirmed_seqid_op ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfsd4_open_confirm() must reference the open stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Prepare nfsd4_close() for open stateid referencing ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfsd4_process_open2() must reference the open stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfsd4_process_open2() must reference the delegation stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure that nfs4_open_delegation() references the delegation stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfsd4_locku() must reference the lock stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add reference counting to lock stateids ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: ensure atomicity in nfsd4_free_stateid and nfsd4_validate_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up races in lock stateid searching and creation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add locking to protect the state owner lists ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: do filp_close in sc_free callback for lock stateids ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: use cl_lock to synchronize all stateid idr calls ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add a struct nfs4_file field to struct nfs4_stid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add reference counting to the lock and open stateids ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: print status when nfsd4_open fails to open file it just created ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] sunrpc: Allow svc_reserve() to notify TCP socket that space has been freed ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] sunrpc: svc_tcp_write_space: don't clear SOCK_NOSPACE prematurely ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] sunrpc: Reduce contention in svc_xprt_enqueue() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove dl_fh field from struct nfs4_delegation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: give block_delegation and delegation_blocked its own spinlock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up nfs4_set_delegation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up arguments to nfs4_open_delegation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: drop unused stp arg to alloc_init_deleg ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Convert delegation counter to an atomic_long_t type ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: ensure that clp->cl_revoked list is protected by clp->cl_lock ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: fully unhash delegations when revoking them ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: simplify stateid allocation and file handling ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Do not let nfs4_file pin the struct inode ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfs4_check_fh - make it actually check the filehandle ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Use the filehandle to look up the struct nfs4_file instead of inode ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Store the filehandle with the struct nfs4_file ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: convert comma to semicolon ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] svcrdma: Double the default credit limit ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: ensure that st_access_bmap and st_deny_bmap are initialized to 0 ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: bump dl_time when unhashing delegation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Move the delegation reference counter into the struct nfs4_stid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: fix race that grants unrecallable delegation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: CREATE_SESSION should update backchannel immediately ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] svcrdma: Select NFSv4.1 backchannel transport based on forward channel ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: zero op arguments beyond the 8th compound op ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: silence sparse warning about accessing credentials ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure stateids remain unique until they are freed ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfs4_alloc_init_lease should take a nfs4_file arg ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Avoid taking state_lock while holding inode lock in nfsd_break_one_deleg ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: eliminate nfsd4_init_callback ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Fix bad checking of space for padding in splice read ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: cleanup and rename nfs4_check_open ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: make deny mode enforcement more efficient and close races in it ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: always hold the fi_lock when bumping fi_access refcounts ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up reset_union_bmap_deny ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: set stateid access and deny bits in nfs4_get_vfs_file ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: shrink st_access_bmap and st_deny_bmap ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: remove nfs4_file_put_fd ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: refactor nfs4_file_get_access and nfs4_file_put_access ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up helper __release_lock_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add locking to the nfs4_file->fi_fds[] array ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Add fine grained protection for the nfs4_file->fi_stateids list ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: reduce some spinlocking in put_client_renew ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: close potential race between delegation break and laundromat ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Fix crash encoding lock reply on 32-bit ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Convert nfs4_check_open_reclaim() to work with lookup_clientid() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Always use lookup_clientid() in nfsd4_process_open1 ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Convert nfsd4_process_open1() to work with lookup_clientid() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Allow struct nfsd4_compound_state to cache the nfs4_client ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add a nfserrno mapping for -E2BIG to nfserr_fbig ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: properly convert return from commit_metadata to __be32 ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Cleanup - Let nfsd4_lookup_stateid() take a cstate argument ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Don't get a session reference without a client reference ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up nfsd4_release_lockowner ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: NFSv4 lock-owners are not associated to a specific file ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Allow lockowners to hold several stateids ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: lock owners are not per open stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up nfsd4_close_open_stateid ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: declare v4.1+ openowners confirmed on creation ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Cleanup nfs4svc_encode_compoundres ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfs4_preprocess_seqid_op should only set *stpp on success ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add a new /proc/fs/nfsd/max_connections file ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Ensure that nfsd_create_setattr commits files to stable storage ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Remove iattr parameter from nfsd_symlink() ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Protect addition to the file_hashtbl ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: fix file access refcount leak when nfsd4_truncate fails ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Avoid warning message when compile at i686 arch ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: replace defer_free by svcxdr_tmpalloc ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: remove nfs4_acl_new ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: define svcxdr_dupstr to share some common code ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: remove unused defer_free argument ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd4: rename cr_linkname->cr_data ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: let nfsd_symlink assume null-terminated data ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: make NFSv2 null terminate symlink data ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Fix bad reserving space for encoding rdattr_error ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfs: fix nfs4d readlink truncated packet ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: fix rare symlink decoding bug ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: properly handle embedded newlines in fault_injection input ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: fix return of nfs4_acl_write_who ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add appropriate __force directives to filehandle generation code ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: nfsd_splice_read and nfsd_readv should return __be32 ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: clean up sparse endianness warnings in nfscache.c ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: add __force to opaque verifier field casts ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Using exp_get for export getting ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Using path_get when assigning path for export ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] sunrpc/nfsd: Change to type of bool for rq_usedeferral and rq_splice_ok ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsd: Using min/max/min_t/max_t for calculate ("J. Bruce Fields") [1044798 1123721 1141932]
- [fs] nfsv4: Fix another bug in the close/open_downgrade code (Steve Dickson) [1111708]
- [fs] nfsv4: nfs4_state_manager() vs. nfs_server_remove_lists() (Steve Dickson) [1111708]
- [fs] nfs: remove BUG possibility in nfs4_open_and_get_state (Steve Dickson) [1111708]
- [fs] pnfs: fix filelayout_retry_commit when idx > 0 (Steve Dickson) [1111708]
- [fs] nfs: revert "nfs4: queue free_lock_state job submission to nfsiod" (Steve Dickson) [1111708]
- [fs] nfs: fix kernel warning when removing proc entry (Steve Dickson) [1111708]
- [fs] nfs: Fix /proc/fs/nfsfs/servers and /proc/fs/nfsfs/volumes (Steve Dickson) [1111708]
- [fs] nfsv3: Fix another acl regression (Steve Dickson) [1111708]
- [fs] nfsv4: Don't clear the open state when we just did an OPEN_DOWNGRADE (Steve Dickson) [1111708]
- [fs] nfsv4: Fix problems with close in the presence of a delegation (Steve Dickson) [1111708]
- [fs] nfs: Don't busy-wait on SIGKILL in __nfs_iocounter_wait (Steve Dickson) [1111708]
- [fs] nfs: can_coalesce_requests must enforce contiguity (Steve Dickson) [1111708]
- [fs] nfs: disallow duplicate pages in pgio page vectors (Steve Dickson) [1111708]
- [fs] nfs: don't sleep with inode lock in lock_and_join_requests (Steve Dickson) [1111708]
- [fs] nfs: fix error handling in lock_and_join_requests (Steve Dickson) [1111708]
- [fs] nfs: fix nonblocking calls to nfs_page_group_lock (Steve Dickson) [1111708]
- [fs] nfs: use blocking page_group_lock in add_request (Steve Dickson) [1111708]
- [fs] nfs: change nfs_page_group_lock argument (Steve Dickson) [1111708]
- [fs] nfs: reject changes to resvport and sharecache during remount (Steve Dickson) [1111708]
- [fs] nfs: Avoid infinite loop when RELEASE_LOCKOWNER getting expired error (Steve Dickson) [1111708]
- [fs] sunrpc: remove all refcounting of groupinfo from rpcauth_lookupcred (Steve Dickson) [1111708]
- [fs] nfs: fix two problems in lookup_revalidate in RCU-walk (Steve Dickson) [1111708]
- [fs] nfs: allow lockless access to access_cache (Steve Dickson) [1111708]
- [fs] nfs: teach nfs_lookup_verify_inode to handle LOOKUP_RCU (Steve Dickson) [1111708]
- [fs] nfs: teach nfs_neg_need_reval to understand LOOKUP_RCU (Steve Dickson) [1111708]
- [fs] nfs: support RCU_WALK in nfs_permission() (Steve Dickson) [1111708]
- [fs] sunrpc/auth: allow lockless (rcu) lookup of credential cache (Steve Dickson) [1111708]
- [fs] nfs: prepare for RCU-walk support but pushing tests later in code (Steve Dickson) [1111708]
- [fs] nfs: nfs4_lookup_revalidate: only evaluate parent if it will be used (Steve Dickson) [1111708]
- [fs] nfs: add checks for returned value of try_module_get() (Steve Dickson) [1111708]
- [fs] nfs: clear_request_commit while holding i_lock (Steve Dickson) [1111708]
- [fs] pnfs: add pnfs_put_lseg_async (Steve Dickson) [1111708]
- [fs] pnfs: find swapped pages on pnfs commit lists too (Steve Dickson) [1111708]
- [fs] nfs: fix comment and add warn_on for PG_INODE_REF (Steve Dickson) [1111708]
- [fs] nfs: mark nfs_page reqs with flag for extra ref (Steve Dickson) [1111708]
- [fs] nfs: check wait_on_bit_lock err in page_group_lock (Steve Dickson) [1111708]
- [fs] nfs: handle multiple reqs in nfs_page_async_flush (Steve Dickson) [1111708]
- [fs] nfs: change find_request to find_head_request (Steve Dickson) [1111708]
- [fs] sunrpc: remove "ec" argument from encrypt_v2 operation (Steve Dickson) [1111708]
- [fs] sunrpc: clean up sparse endianness warnings in gss_krb5_wrap.c (Steve Dickson) [1111708]
- [fs] sunrpc: clean up sparse endianness warnings in gss_krb5_seal.c (Steve Dickson) [1111708]
- [fs] sunrpc: fix RCU handling of gc_ctx field (Steve Dickson) [1111708]
- [fs] sunrpc: remove __rcu annotation from struct gss_cl_ctx->gc_gss_ctx (Steve Dickson) [1111708]
- [fs] nfs: nfs4_do_open should add negative results to the dcache (Steve Dickson) [1111708]
- [fs] xprtrdma: Handle additional connection events (Steve Dickson) [1111708]
- [fs] xprtrdma: Remove RPCRDMA_PERSISTENT_REGISTRATION macro (Steve Dickson) [1111708]
- [fs] xprtrdma: Make rpcrdma_ep_disconnect() return void (Steve Dickson) [1111708]
- [fs] xprtrdma: Schedule reply tasklet once per upcall (Steve Dickson) [1111708]
- [fs] xprtrdma: Allocate each struct rpcrdma_mw separately (Steve Dickson) [1111708]
- [fs] xprtrdma: Rename frmr_wr (Steve Dickson) [1111708]
- [fs] xprtrdma: Disable completions for LOCAL_INV Work Requests (Steve Dickson) [1111708]
- [fs] xprtrdma: Disable completions for FAST_REG_MR Work Requests (Steve Dickson) [1111708]
- [fs] xprtrdma: Don't post a LOCAL_INV in rpcrdma_register_frmr_external() (Steve Dickson) [1111708]
- [fs] xprtrdma: Reset FRMRs after a flushed LOCAL_INV Work Request (Steve Dickson) [1111708]
- [fs] xprtrdma: Reset FRMRs when FAST_REG_MR is flushed by a disconnect (Steve Dickson) [1111708]
- [fs] xprtrdma: Properly handle exhaustion of the rb_mws list (Steve Dickson) [1111708]
- [fs] xprtrdma: Chain together all MWs in same buffer pool (Steve Dickson) [1111708]
- [fs] xprtrdma: Back off rkey when FAST_REG_MR fails (Steve Dickson) [1111708]
- [fs] xprtrdma: Unclutter struct rpcrdma_mr_seg (Steve Dickson) [1111708]
- [fs] xprtrdma: Don't invalidate FRMRs if registration fails (Steve Dickson) [1111708]
- [fs] xprtrdma: On disconnect, don't ignore pending CQEs (Steve Dickson) [1111708]
- [fs] xprtrdma: Update rkeys after transport reconnect (Steve Dickson) [1111708]
- [fs] xprtrdma: Limit data payload size for ALLPHYSICAL (Steve Dickson) [1111708]
- [fs] xprtrdma: Protect ia->ri_id when unmapping/invalidating MRs (Steve Dickson) [1111708]
- [fs] xprtrdma: Fix panic in rpcrdma_register_frmr_external() (Steve Dickson) [1111708]
- [fs] xprtrdma: Fix DMA-API-DEBUG warning by checking dma_map result (Steve Dickson) [1111708]
- [fs] replace strict_strto calls (Steve Dickson) [1111708]
- [fs] nfs: use ARRAY_SIZE instead of sizeof/sizeof[0] (Steve Dickson) [1111708]
- [fs] nfsv4: Drop cast (Steve Dickson) [1111708]
- [fs] rpc_pipe: Drop memory allocation cast (Steve Dickson) [1111708]
- [fs] nfs_common/nfsacl: move EXPORT symbol after functions (Steve Dickson) [1111708]
- [fs] nfs4: copy acceptor name from context to nfs_client (Steve Dickson) [1111708]
- [fs] sunrpc: add a new "stringify_acceptor" rpc_credop (Steve Dickson) [1111708]
- [fs] auth_gss: fetch the acceptor name out of the downcall (Steve Dickson) [1111708]
- [fs] nfs4: turn free_lock_state into a void return operation (Steve Dickson) [1111708]
- [fs] nfs4: queue free_lock_state job submission to nfsiod (Steve Dickson) [1111708]
- [fs] nfs4: treat lock owners as opaque values (Steve Dickson) [1111708]
- [fs] nfs41: layout return on close in delegation return (Steve Dickson) [1111708]
- [fs] nfs41: return layout on last close (Steve Dickson) [1111708]
- [fs] nfs4: add nfs4_check_delegation (Steve Dickson) [1111708]
- [fs] pnfs/filelayout: retry ds commit if nfs_commitdata_alloc fails (Steve Dickson) [1111708]
- [fs] pnfs/filelayout: fix race between mark_request_commit and scan_commit_lists (Steve Dickson) [1111708]
- [fs] nfsv4: Fix OPEN w/create access mode checking (Steve Dickson) [1111708]
- [fs] nfs: check hostname in nfs_get_client (Steve Dickson) [1111708]
- [fs] nfsv4: set hostname when creating nfsv4 ds connection (Steve Dickson) [1111708]
- [fs] sunrpc: Handle EPIPE in xprt_connect_status (Steve Dickson) [1111708]
- [fs] sunrpc: Ensure that we handle ENOBUFS errors correctly (Steve Dickson) [1111708]
- [fs] nfs: replace count*size kzalloc by kcalloc (Steve Dickson) [1111708]
- [fs] nfs: get rid of duplicate dprintk (Steve Dickson) [1111708]
- [fs] nfs: Fix unused variable error (Steve Dickson) [1111708]
- [fs] nfs: remove unneeded EXPORTs (Steve Dickson) [1111708]
- [fs] pnfs: clean up *_resend_to_mds (Steve Dickson) [1111708]
- [fs] nfs: remove pgio_header refcount, related cleanup (Steve Dickson) [1111708]
- [fs] nfs: remove unused writeverf code (Steve Dickson) [1111708]
- [fs] nfs: merge nfs_pgio_data into _header (Steve Dickson) [1111708]
- [fs] nfs: rename members of nfs_pgio_data (Steve Dickson) [1111708]
- [fs] nfs: move nfs_pgio_data and remove nfs_rw_header (Steve Dickson) [1111708]

* Fri Sep 26 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-171.el7]
- [scsi] bnx2fc: Improve stats update mechanism (Neil Horman) [1096023]
- [security] have cap_dentry_init_security return error (Jeff Layton) [1070910]
- [mfd] lpc_ich: Change Avoton to iTCO v3 (Prarit Bhargava) [1084134]
- [watchdog] itco_wdt: Add support for v3 silicon (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Add support for iTCO v3 (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Remove lpc_ich_cfg struct use (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Fix ACPI enable bitmask (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Only configure watchdog or GPIO when present (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Add support for Intel Avoton GPIOs (Prarit Bhargava) [1084134]
- [mfd] lpc_ich: Convert ICH GPIOs IDs to enum (Prarit Bhargava) [1084134]
- [net] ceph: do not hard code max auth ticket len (Ilya Dryomov) [1142285] {CVE-2014-6416}
- [net] ceph: add process_one_ticket() helper (Ilya Dryomov) [1142285] {CVE-2014-6416}
- [net] ceph: gracefully handle large reply messages from the mon (Ilya Dryomov) [1142285] {CVE-2014-6416}
- [powercap] intel_rapl: add new CPU IDs (Steve Best) [1142597]
- [powercap] intel_rapl: spell out SoC names (Steve Best) [1142597]
- [powercap] intel_rapl: add support for ValleyView Soc (Steve Best) [1142597]
- [x86] smpboot: initialize secondary CPU only if master CPU will wait for it (Igor Mammedov) [968147]
- [x86] smpboot: Log error on secondary CPU wakeup failure at ERR level (Igor Mammedov) [968147]
- [x86] smpboot: Fix list/memory corruption on CPU hotplug (Igor Mammedov) [968147]
- [acpi] processor: do not mark present at boot but not onlined CPU as onlined (Igor Mammedov) [968147]
- [tools] thermal: Introduce tmon, a tool for thermal subsystem (Neil Horman) [1085101]
- [thermal] intel_powerclamp: add newer cpu ids (Steve Best) [1141895]
- [mm] swapfile: do not skip lowest_bit in scan_swap_map() scan loop (Seth Jennings) [1128277]
- [dma] ioatdma: disable RAID on non-Atom platforms and reenable unaligned copies (Prarit Bhargava) [1069441]
- [security] selinux: make the netif cache namespace aware (Paul Moore) [1112815]
- [kernel] sched: Fix clock_gettime(CLOCK_[PROCESS/THREAD]_CPUTIME_ID) monotonicity (Seth Jennings) [1113932]
- [kernel] hashtable: add hash_for_each_possible_rcu_notrace() (Steve Best) [1123126]
- [media] media-device: fix an information leakage (Jacob Tanenbaum) [1109777] {CVE-2014-1739}
- [fs] vfs: fix ref count leak in path_mountpoint() (Ian Kent) [1122376] {CVE-2014-5045}
- [kernel] ptrace: get_dumpable() incorrect tests (Jacob Tanenbaum) [1111606] {CVE-2013-2929}
- [fs] fanotify/compat: fix sys_fanotify_mark (Jan Stancek) [1119318]
- [target] rd: Refactor rd_build_device_space + rd_release_device_space (Denys Vlasenko) [1108755] {CVE-2014-4027}
- [ipc] fix compat msgrcv with negative msgtyp (Mateusz Guzik) [1042807]
- [Documentation] fix incorrect formula to calculate CommitLimit value (Petr Oros) [1060570]
- [acpi] apci_pad: in power_saving_thread(), call schedule() when need_resched is true (Tony Camuso) [1092076]

* Wed Sep 24 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-170.el7]
- [powerpc] Revert: Add iommu domain pointer to device archdata (David Gibson) [1123145 1123133 1123367]
- [powerpc] Enable IOMMU and VFIO for ppc64 (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s_32/pr - Access HTAB in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Rework SLB switching code (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Move little endian conflict to HV KVM (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Do dcbz32 patching with big endian instructions (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Fill pvinfo hcall instructions in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - PAPR - Access RTAS in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - PAPR - Access HTAB in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s_64/pr - Access shadow slb in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s_64/pr - Access HTAB in big endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - ifdef on CONFIG_KVM_book3s_32_HANDLER for 32bit (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Disable AIL mode with OPAL (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Use SLB entry 0 (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Graciously fail broken LE hypercalls (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Remove open coded make_dsisr in alignment handler (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Always use the saved DAR value (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Make NX bit available with magic page (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Disable NX for old magic page using guests (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Expose TM registers (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Expose EBB registers (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Expose TAR facility to guest (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Handle Facility interrupt and FSCR (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Emulate TIR register (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Ignore PMU SPRs (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Default to big endian guest (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Fix C/R bit setting (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Fix WARN_ON with debug options on (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Enable Little Endian PR guest (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Enable interrupts earlier (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Make svcpu -> vcpu store preempt savvy (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Ignore DABR register (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Ignore PIR writes (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: add PR mode KVM (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: Move more code under CONFIG_HAVE_KVM_IRQFD (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Enable IRQFD support for the XICS interrupt controller (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/s390: adapter interrupt sources (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: Move irq notifier implementation into eventfd.c (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: Move all accesses to kvm::irq_routing into irqchip.c (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/irqchip: Provide and use accessors for irq routing table (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: Don't keep reference to irq routing table in irqfd struct (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: IRQ disabling cleanup (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: use fdget (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Put huge-page HPTEs in rmap chain for base address (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Move KVM_REG_PPC_WORT to an unused register number (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Add ONE_REG register names that were missed (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Add missing code for transaction reclaim on guest exit (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - make _PAGE_NUMA take effect (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc/book3s: rename lookup_linux_pte() to lookup_linux_pte_and_update() (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Fix KVM hang with CONFIG_KVM_XICS=n (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Fix incorrect userspace exit on ioeventfd write (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Remove bogus duplicate code (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - use xics_wake_cpu only when defined (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: NULL return of kvmppc_mmu_hpte_cache_next should be handled (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Add devname:kvm aliases for modules (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Don't drop low-order page address bits (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Get rid of KVM_HPAGE defines (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Guard doorbell exception with CONFIG_PPC_DOORBELL (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Make shared struct aka magic page guest endian (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Use base page size when comparing against slb value (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Fix machine check delivery to guest (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Add mixed page-size support for guest (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: fix couple of memory leaks in MPIC/XICS devices (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Don't clobber our exit handler id (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Fix physical address calculations (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Take SRCU read lock around RTAS kvm_read_guest() call (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Add H_SET_MODE hcall handling (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Allow only implemented hcalls to be enabled or disabled (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Controls for in-kernel sPAPR hypercall handling (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s - Move vcore definition to end of kvm_arch struct (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Export kvmppc_copy_to (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Add CAP to indicate hcall fixes (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Prefer CMA region for hash page table allocation (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/hv - Add software abort codes for transactional memory (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Unify kvmppc_get_last_inst and sc (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: Load/save FP/VMX/VSX state directly to/from vcpu struct (David Gibson) [1123145 1123133 1123367]
- [virt] kvm/ppc: book3s/pr - Fix compilation without CONFIG_ALTIVEC (David Gibson) [1123145 1123133 1123367]
- [virt] kvm: Add per-vm capability enablement (David Gibson) [1123145 1123133 1123367]
- [iommu] vt-d: Exclude devices using RMRRs from IOMMU API domains (Myron Stowe) [1097907]
- [s390] uaccess: fix possible register corruption in strnlen_user_srst() (Hendrik Brueckner) [1099147]
- [s390] uaccess: rework uaccess code - fix locking issues (Hendrik Brueckner) [1099147]
- [s390] uaccess: introduce 'uaccesspt' kernel parameter (Hendrik Brueckner) [1099147]
- [s390] uaccess: remove dead kernel parameter 'user_mode=' (Hendrik Brueckner) [1099147]
- [s390] setup: get rid of MACHINE_HAS_MVCOS machine flag (Hendrik Brueckner) [1099147]
- [s390] uaccess: consistent types (Hendrik Brueckner) [1099147]
- [s390] uaccess: get rid of indirect function calls (Hendrik Brueckner) [1099147]
- [s390] uaccess: normalize order of parameters of indirect uaccess function calls (Hendrik Brueckner) [1099147]
- [s390] uaccess: remove dead extern declarations, make functions static (Hendrik Brueckner) [1099147]
- [s390] uaccess: test if current->mm is set before walking page tables (Hendrik Brueckner) [1099147]
- [s390] compat: fix PSW32_USER_BITS definition (Hendrik Brueckner) [1099147]
- [s390] compat: make psw32_user_bits a constant value again (Hendrik Brueckner) [1099147]
- [s390] uaccess: always run the kernel in home space (Hendrik Brueckner) [1099147]
- [s390] kernel: remove page table walk for user space accesses (Hendrik Brueckner) [1099147]
- [powerpc] start loop at section start of start in vmemmap_populated() (Gustavo Duarte) [1090174]
- [powerpc] implement vmemmap_free() (Gustavo Duarte) [1090174]
- [powerpc] implement vmemmap_remove_mapping() for BOOK3S (Gustavo Duarte) [1090174]
- [powerpc] implement vmemmap_list_free() (Gustavo Duarte) [1090174]
- [x86] Makefile: Add stack frame check (Prarit Bhargava) [1058753]
- [virt] kvm/x86: fix TSC matching (Marcelo Tosatti) [1115764]
- [drm] radeon: tweak ACCEL_WORKING2 query for hawaii (Jerome Glisse) [1140789]

* Tue Sep 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-169.el7]
- [lib] assoc_array: Fix termination condition in assoc array garbage collection (David Howells) [1139431] {CVE-2014-3631}
- [acpi] x86/ras: Fix build warnings in <linux/aer.h> (Rui Wang) [1085141]
- [acpi] ras/extlog: Adjust init flow (Rui Wang) [1085141]
- [acpi] trace/emca: Add a knob to adjust where to save event log (Rui Wang) [1085141]
- [ras] trace: Add eMCA trace event interface (Rui Wang) [1085141]
- [ras] debugfs: Add debugfs interface for RAS subsystem (Rui Wang) [1085141]
- [firmware] efi/cper: Adjust code flow of some functions (Rui Wang) [1085141]
- [trace] aer: Move trace into unified interface (Rui Wang) [1085141]
- [trace] ras: Add basic RAS trace event (Rui Wang) [1085141]
- [trace] Add __field_struct macro for TRACE_EVENT() (Rui Wang) [1085141]
- [trace] pci/aer: Fix severity usage in aer trace event (Rui Wang) [1085141]
- [acpi] emca: Combine eMCA/EDAC event reporting priority (Rui Wang) [1076655]
- [edac] sb_edac: Modify H/W event reporting policy (Rui Wang) [1076655]
- [edac] Add an edac_report parameter to EDAC (Rui Wang) [1076655]
- [acpi] Clean up inclusions of ACPI header files (Rui Wang) [1076655]
- [acpi] x86: Export 'boot_cpu_physical_apicid' to modules (Rui Wang) [1076655]
- [acpi] x86: Fix extended error log driver to depend on CONFIG_X86_LOCAL_APIC (Rui Wang) [1076655]
- [firmware] dmi: Avoid unaligned memory access in save_mem_devices() (Rui Wang) [1076655]
- [firmware] efi: Move cper.c from drivers/acpi/apei to drivers/firmware/efi (Rui Wang) [1076655]
- [edac] ghes: Update ghes error record info (Rui Wang) [1076655]
- [acpi] apei/cper: Cleanup CPER memory error output format (Rui Wang) [1076655]
- [acpi] apei/cper: Enhance memory reporting capability (Rui Wang) [1076655]
- [firmware] dmi: Parse memory device (type 17) in SMBIOS (Rui Wang) [1076655]
- [acpi] x86: Extended error log driver for x86 platform (Rui Wang) [1076655]
- [acpi] cper: Update cper info (Rui Wang) [1076655]
- [acpi] apei/cper: Fix status check during error printing (Rui Wang) [1076655]

* Tue Sep 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-168.el7]
- [ethernet] bnx2x: Configure device endianity on driver load and reset endianity on removal (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Be more forgiving toward SW GRO (Michal Schmidt) [1089402]
- [ethernet] bnx2x: VF clean statistics (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix stop-on-error (Michal Schmidt) [1089402]
- [ethernet] bnx2x: ethtool -d might cause timeout in log (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Use is_kdump_kernel() to detect kdump kernel (Michal Schmidt) [1059554 1089402]
- [ethernet] bnx2x: FW assertion changes (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Make BP_VF more robust (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Prevent pci_disable_sriov with assigned VFs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Prevent IOV if no entries in CAM (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix static checker warning regarding `txdata_ptr' (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Safe bnx2x_panic_dump() (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Update driver version to 1.710.51 (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Code cleanup (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix sparse warnings (Michal Schmidt) [1119861 1060671 1089402]
- [ethernet] bnx2x: Fix timesync endianity (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Add timestamping and PTP hardware clock support (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix tunneled GSO over IPv6 (Michal Schmidt) [1119861 1060671 1089402]
- [ethernet] bnx2x: prevent incorrect byte-swap in BE (Michal Schmidt) [1119861 1060671 1089402]
- [ethernet] bnx2x: Utilize FW 7.10.51 (Michal Schmidt) [1119861 1060671 1089402]
- [ethernet] bnx2x: Remove redundant #ifdef (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Revert UNDI flushing mechanism (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Remove DEFINE_PCI_DEVICE_TABLE macro use (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix set_setting for some PHYs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix possible panic under memory stress (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix the MSI flags (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fail probe of VFs using an old incompatible driver (Michal Schmidt) [1089402]
- [ethernet] bnx2x: enlarge minimal alignemnt of data offset (Michal Schmidt) [1089402]
- [ethernet] bnx2x: VF can report link speed (Michal Schmidt) [1089402]
- [ethernet] bnx2x: remove null test before kfree (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Enlarge the dorq threshold for VFs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Check for UNDI in uncommon branch (Michal Schmidt) [1094099 1089402]
- [ethernet] bnx2x: Fix 1G-baseT link (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix link for KR with swapped polarity lane (Michal Schmidt) [1123867 1089402]
- [ethernet] bnx2x: Remove useless return variables (Michal Schmidt) [1089402]
- [ethernet] bnx2x: update MAINTAINERS for bnx2x and e-mail addresses (Michal Schmidt) [1089402]
- [ethernet] bnx2x: get rid of SET_ETHTOOL_OPS (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix build when BNX2X_SRIOV is not enabled (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Convert return 0 to return rc (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix UNDI driver unload (Michal Schmidt) [1094099 1089402]
- [ethernet] bnx2x: Memory leak during VF removal (Michal Schmidt) [1089402]
- [ethernet] bnx2x: include irq.h for irqreturn_t definitions (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix possible memory leak on iov error flow (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix compilation when CONFIG_BNX2X_SRIOV is not set (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Don't allow VFs to become promiscuous (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Don't show port statistics for VFs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix failure to configure VF multicast filters (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix vlan credit issues for VFs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Remove the sriov VFOP mechanism (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Create workqueue for IOV related tasks (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Support mng. request for driver version (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Don't receive packets when the napi budget == 0 (Michal Schmidt) [1089402]
- [ethernet] bnx2x: save RAM in kdump kernel by disabling TPA (Michal Schmidt) [1059554 1089402]
- [ethernet] bnx2x: save RAM in kdump kernel by using a single queue (Michal Schmidt) [1059554 1089402]
- [ethernet] bnx2x: clamp num_queues to prevent passing a negative value (Michal Schmidt) [1059554 1089402]
- [ethernet] bnx2x: Remove hidden flow control goto from BNX2X_ALLOC macros (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Use pci_enable_msix_range() instead of pci_enable_msix() (Michal Schmidt) [1089402]
- [ethernet] bnx2x: (semantic) revise scheduling of sp_rtnl (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Fix bnx2x_panic_dump for VFs (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Revise IOV vlan/mac validation (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Add support in PF driver for RSC (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Semantic Validate vlan/mac changes (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Remove unnecessary internal mem config (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Remove unused iov code (Michal Schmidt) [1089402]
- [ethernet] bnx2x: Debug - change verbosity of some prints (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix L2-GRE TCP issues (Michal Schmidt) [1089402]
- [ethernet] bnx2x: fix sparse warning (Michal Schmidt) [1089402]
- [ethernet] bnx2x: prevent WARN during driver unload (Michal Schmidt) [1089402]
- [ethernet] bnx2x: slight optimization of addr compare (Michal Schmidt) [1089402]
- [kernel] crash_dump: Make is_kdump_kernel() accessible from modules (Michal Schmidt) [1089402 1059554]
- [ethernet] qlge: Fix TSO for non-accelerated vlan traffic (Vlad Yasevich) [1135619]
- [ethernet] mvneta: Fix TSO and checksum for non-acceleration vlan traffic (Vlad Yasevich) [1135619]
- [ethernet] i40evf: Fix TSO and hw checksums for non-accelerated vlan packets (Vlad Yasevich) [1135619]
- [ethernet] i40e: Fix TSO and hw checksums for non-accelerated vlan packets (Vlad Yasevich) [1135619]
- [ethernet] ehea: Fix TSO and hw checksums with non-accelerated vlan packets (Vlad Yasevich) [1135619]
- [ethernet] e1000: Fix TSO for non-accelerated vlan traffic (Vlad Yasevich) [1135619]
- [ethernet] e1000e: Fix TSO with non-accelerated vlans (Vlad Yasevich) [1135619]
- [net] macvlan: Initialize vlan_features to turn on offload support (Vlad Yasevich) [1135619]
- [net] macvtap: Fix checksum errors for non-gso packets in bridge mode (Vlad Yasevich) [1135619]
- [net] Revert: macvlan: fix checksums error when we are in bridge mode (Vlad Yasevich) [1135619]
- [net] Correctly set segment mac_len in skb_segment() (Vlad Yasevich) [1135619]
- [crypto] pkcs7: Fix the parser cleanup to drain parsed out X.509 certs (Vivek Goyal) [1129779]
- [crypto] pkcs7: Provide a single place to do signed info block freeing (Vivek Goyal) [1129779]
- [security] keys: Reinstate EPERM for a key type name beginning with a '.' (Vivek Goyal) [1129779]
- [crypto] pkcs7: Add a missing static (Vivek Goyal) [1129779]
- [crypto] x509: Need to export x509_request_asymmetric_key() (Vivek Goyal) [1129779]
- [crypto] pkcs7: X.509 certificate issuer and subject are mandatory fields in the ASN.1 (Vivek Goyal) [1129779]
- [crypto] pkcs7: Use x509_request_asymmetric_key() (Vivek Goyal) [1129779]
- [crypto] x509: x509_request_asymmetric_keys() doesn't need string length arguments (Vivek Goyal) [1129779]
- [crypto] pkcs7: fix sparse non static symbol warning (Vivek Goyal) [1129779]
- [crypto] pkcs7: Missing inclusion of linux/err.h (Vivek Goyal) [1129779]
- [security] ima: define '.ima' as a builtin 'trusted' keyring (Vivek Goyal) [1129779]
- [crypto] keys: validate certificate trust only with builtin keys (Vivek Goyal) [1129779]
- [crypto] keys: validate certificate trust only with selected key (Vivek Goyal) [1129779]
- [crypto] keys: make partial key id matching as a dedicated function (Vivek Goyal) [1129779]
- [crypto] keys: verify a certificate is signed by a 'trusted' key (Vivek Goyal) [1129779]
- [security] keys: special dot prefixed keyring name bug fix (Vivek Goyal) [1129779]
- [crypto] Revert: keys: verify a certificate is signed by a 'trusted' key (Vivek Goyal) [1129779]
- [crypto] pefile: Validate PKCS#7 trust chain (Vivek Goyal) [1129779]
- [crypto] pefile: Digest the PE binary and compare to the PKCS#7 data (Vivek Goyal) [1129779]
- [crypto] pefile: Handle pesign using the wrong OID (Vivek Goyal) [1129779]
- [crypto] pefile: Parse the "Microsoft individual code signing" data blob (Vivek Goyal) [1129779]
- [crypto] pefile: Parse the presumed PKCS#7 content of the certificate blob (Vivek Goyal) [1129779]
- [crypto] pefile: Strip the wrapper off of the cert data block (Vivek Goyal) [1129779]
- [crypto] pefile: Parse a PE binary to find a key and a signature contained therein (Vivek Goyal) [1129779]
- [misc] Provide PE binary definitions (Vivek Goyal) [1129779]
- [crypto] keys/x509: Fix a spelling mistake (Vivek Goyal) [1129779]
- [crypto] pkcs7: Provide a key type for testing PKCS#7 (Vivek Goyal) [1129779]
- [crypto] pkcs7: Find intersection between PKCS#7 message and known, trusted keys (Vivek Goyal) [1129779]
- [crypto] pkcs7: Verify internal certificate chain (Vivek Goyal) [1129779]
- [crypto] pkcs7: Find the right key in the PKCS#7 key list and verify the signature (Vivek Goyal) [1129779]
- [crypto] pkcs7: Digest the data in a signed-data message (Vivek Goyal) [1129779]
- [crypto] pkcs7: Implement a parser for RFC 2315 (Vivek Goyal) [1129779]
- [crypto] x509: Export certificate parse and free functions (Vivek Goyal) [1129779]
- [crypto] x509: Add bits needed for PKCS#7 (Vivek Goyal) [1129779]
- [crypto] keys: change asymmetric keys to use common hash definitions (Vivek Goyal) [1129779]
- [crypto] provide single place for hash algo information (Vivek Goyal) [1129779]

* Sun Sep 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-167.el7]
- [fs] ceph: remove extra definitions of U32_MAX (Sage Weil) [1122174]
- [fs] vfs: call d_op->d_prune() before unhashing dentry (Sage Weil) [1122174]
- [net] libceph: set last_piece in ceph_msg_data_pages_cursor_init() correctly (Sage Weil) [1122174]
- [block] rbd: remove extra newlines from rbd_warn() messages (Sage Weil) [1122174]
- [block] rbd: allocate img_request with GFP_NOIO instead GFP_ATOMIC (Sage Weil) [1122174]
- [block] rbd: rework rbd_request_fn() (Sage Weil) [1122174]
- [fs] ceph: fix kick_requests() (Sage Weil) [1122174]
- [fs] ceph: fix sizeof(struct tYpO *) typo (Sage Weil) [1122174]
- [fs] ceph: remove redundant memset(0) (Sage Weil) [1122174]
- [block] rbd: take snap_id into account when reading in parent info (Sage Weil) [1122174]
- [block] rbd: do not read in parent info before snap context (Sage Weil) [1122174]
- [block] rbd: update mapping size only on refresh (Sage Weil) [1122174]
- [block] rbd: harden rbd_dev_refresh() and callers a bit (Sage Weil) [1122174]
- [block] rbd: split rbd_dev_spec_update() into two functions (Sage Weil) [1122174]
- [block] rbd: remove unnecessary asserts in rbd_dev_image_probe() (Sage Weil) [1122174]
- [block] rbd: introduce rbd_dev_header_info() (Sage Weil) [1122174]
- [block] rbd: show the entire chain of parent images (Sage Weil) [1122174]
- [fs] ceph: replace comma with a semicolon (Sage Weil) [1122174]
- [block] rbd: use rbd_segment_name_free() instead of kfree() (Sage Weil) [1122174]
- [fs] ceph: check zero length in ceph_sync_read() (Sage Weil) [1122174]
- [fs] ceph: reset r_resend_mds after receiving -ESTALE (Sage Weil) [1122174]
- [fs] ceph: include time stamp in replayed MDS requests (Sage Weil) [1122174]
- [block] rbd: do not leak image_id in rbd_dev_v2_parent_info() (Sage Weil) [1122174]
- [fs] ceph: check unsupported fallocate mode (Sage Weil) [1122174]
- [net] libceph: drop osd ref when canceling con work (Sage Weil) [1122174]
- [net] libceph: nuke ceph_osdc_unregister_linger_request() (Sage Weil) [1122174]
- [block] rbd: use rbd_obj_watch_request_helper() helper (Sage Weil) [1122174]
- [block] rbd: add rbd_obj_watch_request_helper() helper (Sage Weil) [1122174]
- [block] rbd: rbd_obj_request_wait() should cancel the request if interrupted (Sage Weil) [1122174]
- [net] libceph: introduce ceph_osdc_cancel_request() (Sage Weil) [1122174]
- [net] libceph: fix linger request check in __unregister_request() (Sage Weil) [1122174]
- [net] libceph: unregister only registered linger requests (Sage Weil) [1122174]
- [net] libceph: assert both regular and lingering lists in __remove_osd() (Sage Weil) [1122174]
- [net] libceph: harden ceph_osdc_request_release() a bit (Sage Weil) [1122174]
- [net] libceph: move and add dout()s to ceph_osdc_request_{get, put}() (Sage Weil) [1122174]
- [net] libceph: move and add dout()s to ceph_msg_{get, put}() (Sage Weil) [1122174]
- [net] libceph: add maybe_move_osd_to_lru() and switch to it (Sage Weil) [1122174]
- [net] libceph: rename ceph_osd_request::r_linger_osd to r_linger_osd_item (Sage Weil) [1122174]
- [block] rbd: handle parent_overlap on writes correctly (Sage Weil) [1122174]
- [fs] ceph: remove bogus extern (Sage Weil) [1122174]
- [block] rbd: only set disk to read-only once (Sage Weil) [1122174]
- [block] rbd: move calls that may sleep out of spin lock range (Sage Weil) [1122174]
- [block] rbd: add ioctl for rbd (Sage Weil) [1122174]
- [fs] ceph: use truncate_pagecache() instead of truncate_inode_pages() (Sage Weil) [1122174]
- [fs] ceph: debugfs, replace seq_printf by seq_puts (Sage Weil) [1122174]
- [fs] ceph: replace pr_warning by pr_warn (Sage Weil) [1122174]
- [fs] ceph: include time stamp in every MDS request (Sage Weil) [1122174]
- [block] rbd: fix ida/idr memory leak (Sage Weil) [1122174]
- [block] rbd: use reference counts for image requests (Sage Weil) [1122174]
- [block] rbd: fix osd_request memory leak in __rbd_dev_header_watch_sync() (Sage Weil) [1122174]
- [block] rbd: make sure we have latest osdmap on 'rbd map' (Sage Weil) [1122174]
- [net] libceph: add ceph_monc_wait_osdmap() (Sage Weil) [1122174]
- [net] libceph: mon_get_version request infrastructure (Sage Weil) [1122174]
- [net] libceph: recognize poolop requests in debugfs (Sage Weil) [1122174]
- [fs] ceph: refactor readpage_nounlock() to make the logic clearer (Sage Weil) [1122174]
- [fs] ceph: mds - check cap ID when handling cap export message (Sage Weil) [1122174]
- [fs] ceph: remember subtree root dirfrag's auth MDS (Sage Weil) [1122174]
- [fs] ceph: introduce ceph_fill_fragtree() (Sage Weil) [1122174]
- [fs] ceph: handle cap import atomically (Sage Weil) [1122174]
- [fs] ceph: pre-allocate ceph_cap struct for ceph_add_cap() (Sage Weil) [1122174]
- [fs] ceph: update inode fields according to issued caps (Sage Weil) [1122174]
- [fs] ceph: queue vmtruncate if necessary when handing cap grant/revoke (Sage Weil) [1122174]
- [fs] ceph: ceph_get_parent() can be static (Sage Weil) [1122174]
- [net] crush: decode and initialize chooseleaf_vary_r (Sage Weil) [1122174]
- [net] libceph: fix corruption when using page_count 0 page in rbd (Sage Weil) [1122174]
- [fs] ceph: reserve caps for file layout/lock MDS requests (Sage Weil) [1122174]
- [fs] ceph: avoid releasing caps that are being used (Sage Weil) [1122174]
- [fs] ceph: clear directory's completeness when creating file (Sage Weil) [1122174]
- [net] libceph: fix non-default values check in apply_primary_affinity() (Sage Weil) [1122174]
- [fs] ceph: use fpos_cmp() to compare dentry positions (Sage Weil) [1122174]
- [fs] ceph: check directory's completeness before emitting directory entry (Sage Weil) [1122174]
- [fs] ceph: fix pr_fmt() redefinition (Sage Weil) [1122174]
- [fs] ceph: ceph_sync_{, direct_}write, fix an oops on ceph_osdc_new_request() failure (Sage Weil) [1122174]
- [fs] ceph: skip invalid dentry during dcache readdir (Sage Weil) [1122174]
- [net] libceph: dump pool {read,write}_tier to debugfs (Sage Weil) [1122174]
- [net] libceph: output primary affinity values on osdmap updates (Sage Weil) [1122174]
- [fs] ceph: flush cap release queue when trimming session caps (Sage Weil) [1122174]
- [fs] ceph: don't grabs open file reference for aborted request (Sage Weil) [1122174]
- [fs] ceph: drop extra open file reference in ceph_atomic_open() (Sage Weil) [1122174]
- [fs] ceph: preallocate buffer for readdir reply (Sage Weil) [1122174]
- [net] libceph: enable PRIMARY_AFFINITY feature bit (Sage Weil) [1122174]
- [net] libceph: redo ceph_calc_pg_primary() in terms of ceph_calc_pg_acting() (Sage Weil) [1122174]
- [net] libceph: add support for osd primary affinity (Sage Weil) [1122174]
- [net] libceph: add support for primary_temp mappings (Sage Weil) [1122174]
- [net] libceph: return primary from ceph_calc_pg_acting() (Sage Weil) [1122174]
- [net] libceph: switch ceph_calc_pg_acting() to new helpers (Sage Weil) [1122174]
- [net] libceph: introduce apply_temps() helper (Sage Weil) [1122174]
- [net] libceph: introduce pg_to_raw_osds() and raw_to_up_osds() helpers (Sage Weil) [1122174]
- [net] libceph: ceph_can_shift_osds(pool) and pool type defines (Sage Weil) [1122174]
- [net] libceph: ceph_osd_{exists, is_up, is_down}(osd) definitions (Sage Weil) [1122174]
- [net] libceph: enable OSDMAP_ENC feature bit (Sage Weil) [1122174]
- [net] libceph: primary_affinity decode bits (Sage Weil) [1122174]
- [net] libceph: primary_affinity infrastructure (Sage Weil) [1122174]
- [net] libceph: primary_temp decode bits (Sage Weil) [1122174]
- [net] libceph: primary_temp infrastructure (Sage Weil) [1122174]
- [net] libceph: generalize ceph_pg_mapping (Sage Weil) [1122174]
- [net] libceph: introduce get_osdmap_client_data_v() (Sage Weil) [1122174]
- [net] libceph: introduce decode{, _new}_pg_temp() and switch to them (Sage Weil) [1122174]
- [net] libceph: switch osdmap_set_max_osd() to krealloc() (Sage Weil) [1122174]
- [net] libceph: introduce decode{, _new}_pools() and switch to them (Sage Weil) [1122174]
- [net] libceph: rename __decode_pool{, _names}() to decode_pool{, _names}() (Sage Weil) [1122174]
- [net] libceph: fix and clarify ceph_decode_need() sizes (Sage Weil) [1122174]
- [net] libceph: nuke bogus encoding version check in osdmap_apply_incremental() (Sage Weil) [1122174]
- [net] libceph: fixup error handling in osdmap_apply_incremental() (Sage Weil) [1122174]
- [net] libceph: fix crush_decode() call site in osdmap_decode() (Sage Weil) [1122174]
- [net] libceph: check length of osdmap osd arrays (Sage Weil) [1122174]
- [net] libceph: safely decode max_osd value in osdmap_decode() (Sage Weil) [1122174]
- [net] libceph: fixup error handling in osdmap_decode() (Sage Weil) [1122174]
- [net] libceph: split osdmap allocation and decode steps (Sage Weil) [1122174]
- [net] libceph: dump osdmap and enhance output on decode errors (Sage Weil) [1122174]
- [net] libceph: dump pg_temp mappings to debugfs (Sage Weil) [1122174]
- [net] libceph: do not prefix osd lines with t in debugfs output (Sage Weil) [1122174]
- [net] libceph: refer to osdmap directly in osdmap_show() (Sage Weil) [1122174]
- [net] crush: support chooseleaf_vary_r tunable (tunables3) by default (Sage Weil) [1122174]
- [net] crush: add SET_CHOOSELEAF_VARY_R step (Sage Weil) [1122174]
- [net] crush: add chooseleaf_vary_r tunable (Sage Weil) [1122174]
- [net] crush: allow crush rules to set (re)tries counts to 0 (Sage Weil) [1122174]
- [net] crush: fix off-by-one errors in total_tries refactor (Sage Weil) [1122174]
- [fs] ceph: don't include ceph.{file, dir}.layout vxattr in listxattr() (Sage Weil) [1122174]
- [fs] ceph: check buffer size in ceph_vxattrcb_layout() (Sage Weil) [1122174]
- [fs] ceph: fix null pointer dereference in discard_cap_releases() (Sage Weil) [1122174]
- [net] libceph: fix oops in ceph_msg_data_{pages, pagelist}_advance() (Sage Weil) [1122174]
- [fs] ceph: set mds_wanted when MDS reply changes a cap to auth cap (Sage Weil) [1122174]
- [fs] ceph: use fl->fl_file as owner identifier of flock and posix lock (Sage Weil) [1122174]
- [fs] ceph: forbid mandatory file lock (Sage Weil) [1122174]
- [fs] ceph: use fl->fl_type to decide flock operation (Sage Weil) [1122174]
- [fs] ceph: update i_max_size even if inode version does not change (Sage Weil) [1122174]
- [fs] ceph: make sure write caps are registered with auth MDS (Sage Weil) [1122174]
- [fs] ceph: print inode number for LOOKUPINO request (Sage Weil) [1122174]
- [fs] ceph: add get_name() NFS export callback (Sage Weil) [1122174]
- [fs] ceph: fix ceph_fh_to_parent() (Sage Weil) [1122174]
- [fs] ceph: add get_parent() NFS export callback (Sage Weil) [1122174]
- [fs] ceph: simplify ceph_fh_to_dentry() (Sage Weil) [1122174]
- [fs] ceph: do not set r_old_dentry_dir on link() (Sage Weil) [1122174]
- [fs] ceph: do not assume r_old_dentry[_dir] always set together (Sage Weil) [1122174]
- [fs] ceph: do not chain inode updates to parent fsync (Sage Weil) [1122174]
- [fs] ceph: avoid useless ceph_get_dentry_parent_inode() in ceph_rename() (Sage Weil) [1122174]
- [fs] ceph: let MDS adjust readdir 'frag' (Sage Weil) [1122174]
- [block] rbd: prefix rbd writes with CEPH_OSD_OP_SETALLOCHINT osd op (Sage Weil) [1122174]
- [block] rbd: num_ops parameter for rbd_osd_req_create() (Sage Weil) [1122174]
- [net] libceph: bump CEPH_OSD_MAX_OP to 3 (Sage Weil) [1122174]
- [net] libceph: add support for CEPH_OSD_OP_SETALLOCHINT osd op (Sage Weil) [1122174]
- [net] libceph: encode CEPH_OSD_OP_FLAG_* op flags (Sage Weil) [1122174]
- [block] rbd: fix error paths in rbd_img_request_fill() (Sage Weil) [1122174]
- [block] rbd: remove out_partial label in rbd_img_request_fill() (Sage Weil) [1122174]
- [net] libceph: a per-osdc crush scratch buffer (Sage Weil) [1122174]
- [block] rbd: drop an unsafe assertion (Sage Weil) [1122174]
- [fs] ceph: fix reset_readdir() (Sage Weil) [1122174]
- [fs] ceph: fix ceph_dir_llseek() (Sage Weil) [1122174]
- [fs] ceph: fix __dcache_readdir() (Sage Weil) [1122174]
- [fs] ceph: fix ceph_removexattr() (Sage Weil) [1122174]
- [fs] ceph: remove xattr when null value is given to setxattr() (Sage Weil) [1122174]
- [fs] ceph: properly handle XATTR_CREATE and XATTR_REPLACE (Sage Weil) [1122174]
- [net] libceph: take map_sem for read in handle_reply() (Sage Weil) [1122174]
- [net] libceph: factor out logic from ceph_osdc_start_request() (Sage Weil) [1122174]
- [net] libceph: fix error handling in ceph_osdc_init() (Sage Weil) [1122174]
- [fs] ceph: cast PAGE_SIZE to size_t in ceph_sync_write() (Sage Weil) [1122174]
- [fs] ceph: fix dout() compile warnings in ceph_filemap_fault() (Sage Weil) [1122174]
- [net] libceph: support CEPH_FEATURE_OSD_CACHEPOOL feature (Sage Weil) [1122174]
- [net] libceph: follow redirect replies from osds (Sage Weil) [1122174]
- [net] libceph: rename ceph_osd_request::r_{oloc, oid} to r_base_{oloc, oid} (Sage Weil) [1122174]
- [net] libceph: follow {read, write}_tier fields on osd request submission (Sage Weil) [1122174]
- [net] libceph: add ceph_pg_pool_by_id() (Sage Weil) [1122174]
- [net] libceph: CEPH_OSD_FLAG_* enum update (Sage Weil) [1122174]
- [net] libceph: replace ceph_calc_ceph_pg() with ceph_oloc_oid_to_pg() (Sage Weil) [1122174]
- [net] libceph: introduce and start using oid abstraction (Sage Weil) [1122174]
- [net] libceph: move ceph_file_layout helpers to ceph_fs.h (Sage Weil) [1122174]
- [net] libceph: rename MAX_OBJ_NAME_SIZE to CEPH_MAX_OID_NAME_LEN (Sage Weil) [1122174]
- [net] libceph: start using oloc abstraction (Sage Weil) [1122174]
- [net] libceph: dout() is missing a newline (Sage Weil) [1122174]
- [net] libceph: add ceph_kv{malloc, free}() and switch to them (Sage Weil) [1122174]
- [net] libceph: support CEPH_FEATURE_EXPORT_PEER (Sage Weil) [1122174]
- [fs] ceph: add imported caps when handling cap export message (Sage Weil) [1122174]
- [fs] ceph: add open export target session helper (Sage Weil) [1122174]
- [fs] ceph: remove exported caps when handling cap import message (Sage Weil) [1122174]
- [fs] ceph: handle session flush message (Sage Weil) [1122174]
- [fs] ceph: check inode caps in ceph_d_revalidate (Sage Weil) [1122174]
- [fs] ceph: handle -ESTALE reply (Sage Weil) [1122174]
- [fs] ceph: fix trim caps (Sage Weil) [1122174]
- [fs] ceph: fix cache revoke race (Sage Weil) [1122174]
- [fs] ceph: use ceph_seq_cmp() to compare migrate_seq (Sage Weil) [1122174]
- [fs] ceph: handle cap export race in try_flush_caps() (Sage Weil) [1122174]
- [fs] ceph: trivial comment fix (Sage Weil) [1122174]
- [net] libceph: fix preallocation check in get_reply() (Sage Weil) [1122174]
- [net] libceph: rename front to front_len in get_reply() (Sage Weil) [1122174]
- [net] libceph: rename ceph_msg::front_max to front_alloc_len (Sage Weil) [1122174]
- [net] libceph: use CEPH_MON_PORT when the specified port is 0 (Sage Weil) [1122174]
- [net] crush: support new indep mode and SET_* steps (crush v2) by default (Sage Weil) [1122174]
- [net] crush: fix crush_choose_firstn comment (Sage Weil) [1122174]
- [net] crush: attempts -> tries (Sage Weil) [1122174]
- [net] crush: add set_choose_local_[fallback_]tries steps (Sage Weil) [1122174]
- [net] crush: generalize descend_once (Sage Weil) [1122174]
- [net] crush: CHOOSE_LEAF -> CHOOSELEAF throughout (Sage Weil) [1122174]
- [net] crush: add SET_CHOOSE_TRIES rule step (Sage Weil) [1122174]
- [net] crush: apply chooseleaf_tries to firstn mode too (Sage Weil) [1122174]
- [net] crush: new SET_CHOOSE_LEAF_TRIES command (Sage Weil) [1122174]
- [net] crush: pass parent r value for indep call (Sage Weil) [1122174]
- [net] crush: clarify numrep vs endpos (Sage Weil) [1122174]
- [net] crush: strip firstn conditionals out of crush_choose, rename (Sage Weil) [1122174]
- [net] crush: add note about r in recursive choose (Sage Weil) [1122174]
- [net] crush: use breadth-first search for indep mode (Sage Weil) [1122174]
- [net] crush: return CRUSH_ITEM_UNDEF for failed placements with indep (Sage Weil) [1122174]
- [net] crush: eliminate CRUSH_MAX_SET result size limitation (Sage Weil) [1122174]
- [net] crush: fix some comments (Sage Weil) [1122174]
- [net] crush: reduce scope of some local variables (Sage Weil) [1122174]
- [net] crush: factor out (trivial) crush_destroy_rule() (Sage Weil) [1122174]
- [net] crush: pass weight vector size to map function (Sage Weil) [1122174]
- [net] libceph: update ceph_features.h (Sage Weil) [1122174]
- [net] libceph: all features fields must be u64 (Sage Weil) [1122174]
- [block] rbd: tear down watch request if rbd_dev_device_setup() fails (Sage Weil) [1122174]
- [block] rbd: introduce rbd_dev_header_unwatch_sync() and switch to it (Sage Weil) [1122174]
- [block] rbd: enable extended devt in single-major mode (Sage Weil) [1122174]
- [fs] ceph: check caps in filemap_fault and page_mkwrite (Sage Weil) [1122174]
- [block] rbd: add support for single-major device number allocation scheme (Sage Weil) [1122174]
- [block] rbd: add 'minor' sysfs rbd device attribute (Sage Weil) [1122174]
- [block] rbd: switch to ida for rbd id assignments (Sage Weil) [1122174]
- [block] rbd: refactor rbd_init() a bit (Sage Weil) [1122174]
- [block] rbd: tweak "loaded" message and module description (Sage Weil) [1122174]
- [block] rbd: rbd_device::dev_id is an int, format it as such (Sage Weil) [1122174]
- [net] libceph: resend all writes after the osdmap loses the full flag (Sage Weil) [1122174]
- [net] libceph: block I/O when PAUSE or FULL osd map flags are set (Sage Weil) [1122174]
- [fs] ceph: new helper, file_inode(file) (Sage Weil) [1122174]
- [fs] ceph: Add necessary clean up if invalid reply received in handle_reply() (Sage Weil) [1122174]
- [fs] ceph: Clean up if error occurred in finish_read() (Sage Weil) [1122174]
- [fs] ceph: implement readv/preadv for sync operation (Sage Weil) [1122174]
- [fs] ceph: Implement writev/pwritev for sync operation (Sage Weil) [1122174]
- [fs] ceph: drop unconnected inodes (Sage Weil) [1122174]
- [fs] ceph: Avoid data inconsistency due to d-cache aliasing in readpage() (Sage Weil) [1122174]
- [fs] ceph: initialize inode before instantiating dentry (Sage Weil) [1122174]
- [fs] ceph: allocate non-zero page to fscache in readpage() (Sage Weil) [1122174]
- [fs] ceph: wake up 'safe' waiters when unregistering request (Sage Weil) [1122174]
- [fs] ceph: cleanup aborted requests when re-sending requests (Sage Weil) [1122174]
- [fs] ceph: handle race between cap reconnect and cap release (Sage Weil) [1122174]
- [fs] ceph: set caps count after composing cap reconnect message (Sage Weil) [1122174]
- [fs] ceph: queue cap release in __ceph_remove_cap() (Sage Weil) [1122174]
- [fs] ceph: handle frag mismatch between readdir request and reply (Sage Weil) [1122174]
- [fs] ceph: remove outdated frag information (Sage Weil) [1122174]
- [block] rbd: fix error handling from rbd_snap_name() (Sage Weil) [1122174]
- [block] rbd: ignore unmapped snapshots that no longer exist (Sage Weil) [1122174]
- [block] rbd: fix use-after free of rbd_dev->disk (Sage Weil) [1122174]
- [block] rbd: make rbd_obj_notify_ack() synchronous (Sage Weil) [1122174]
- [block] rbd: complete notifies before cleaning up osd_client and rbd_dev (Sage Weil) [1122174]
- [net] libceph: add function to ensure notifies are complete (Sage Weil) [1122174]
- [fs] ceph: use d_invalidate() to invalidate aliases (Sage Weil) [1122174]
- [fs] ceph: remove ceph_lookup_inode() (Sage Weil) [1122174]
- [block] rbd: fix null dereference in dout (Sage Weil) [1122174]
- [block] rbd: fix buffer size for writes to images with snapshots (Sage Weil) [1122174]
- [fs] ceph: use vfs __set_page_dirty_nobuffers interface instead of doing it inside filesystem (Sage Weil) [1122174]
- [fs] ceph: allow sync_read/write return partial successed size of read/write (Sage Weil) [1122174]
- [fs] ceph: fix bugs about handling short-read for sync read mode (Sage Weil) [1122174]
- [fs] ceph: remove useless variable revoked_rdcache (Sage Weil) [1122174]
- [net] libceph: create_singlethread_workqueue() doesn't return ERR_PTRs (Sage Weil) [1122174]
- [net] libceph: potential NULL dereference in ceph_osdc_handle_map() (Sage Weil) [1122174]
- [net] libceph: fix error handling in handle_reply() (Sage Weil) [1122174]
- [fs] ceph: fix fallocate division (Sage Weil) [1122174]
- [fs] ceph: punch hole support (Sage Weil) [1122174]
- [fs] ceph: fix request max size (Sage Weil) [1122174]
- [fs] ceph: introduce i_truncate_mutex (Sage Weil) [1122174]
- [fs] ceph: cleanup the logic in ceph_invalidatepage (Sage Weil) [1122174]
- [fs] ceph: Remove bogus check in invalidatepage (Sage Weil) [1122174]
- [fs] ceph: replace hold_mutex flag with goto (Sage Weil) [1122174]
- [fs] ceph: Move the place for EOLDSNAPC handle in ceph_aio_write to easily understand (Sage Weil) [1122174]
- [block] rbd: use NULL instead of 0 (Sage Weil) [1122174]
- [fs] ceph: fix freeing inode vs removing session caps race (Sage Weil) [1122174]
- [fs] ceph: Add check returned value on func ceph_calc_ceph_pg (Sage Weil) [1122174]
- [fs] ceph: Don't use ceph-sync-mode for synchronous-fs (Sage Weil) [1122174]
- [fs] ceph: cleanup types in striped_read() (Sage Weil) [1122174]
- [fs] ceph: trim deleted inode (Sage Weil) [1122174]
- [fs] ceph: wake up writer if vmtruncate work get blocked (Sage Weil) [1122174]
- [fs] ceph: drop CAP_LINK_SHARED when sending "link" request to MDS (Sage Weil) [1122174]
- [fs] ceph: fix null pointer dereference (Sage Weil) [1122174]
- [net] libceph: call r_unsafe_callback when unsafe reply is received (Sage Weil) [1122174]
- [fs] ceph: fix race between cap issue and revoke (Sage Weil) [1122174]
- [fs] ceph: fix cap revoke race (Sage Weil) [1122174]
- [fs] ceph: fix pending vmtruncate race (Sage Weil) [1122174]
- [fs] ceph: avoid accessing invalid memory (Sage Weil) [1122174]
- [fs] ceph: Reconstruct the func ceph_reserve_caps (Sage Weil) [1122174]
- [fs] ceph: Free mdsc if alloc mdsc->mdsmap failed (Sage Weil) [1122174]
- [fs] ceph: remove sb_start/end_write in ceph_aio_write (Sage Weil) [1122174]
- [fs] ceph: avoid meaningless calling ceph_caps_revoking if sync_mode == WB_SYNC_ALL (Sage Weil) [1122174]
- [fs] ceph: move inode to proper flushing list when auth MDS changes (Sage Weil) [1122174]
- [block] rbd: fix a couple warnings (Sage Weil) [1122174]
- [fs] ceph: clear migrate seq when MDS restarts (Sage Weil) [1122174]
- [fs] ceph: check migrate seq before changing auth cap (Sage Weil) [1122174]
- [fs] ceph: fix race between page writeback and truncate (Sage Weil) [1122174]
- [fs] ceph: reset iov_len when discarding cap release messages (Sage Weil) [1122174]
- [fs] ceph: fix cap release race (Sage Weil) [1122174]
- [net] libceph: fix truncate size calculation (Sage Weil) [1122174]
- [net] libceph: fix safe completion (Sage Weil) [1122174]
- [block] rbd: take a little credit (Sage Weil) [1122174]
- [block] rbd: use rwsem to protect header updates (Sage Weil) [1122174]
- [block] rbd: don't hold ctl_mutex to get/put device (Sage Weil) [1122174]
- [block] rbd: protect against concurrent unmaps (Sage Weil) [1122174]
- [block] rbd: set removing flag while holding list lock (Sage Weil) [1122174]
- [net] libceph: print more info for short message header (Sage Weil) [1122174]
- [block] rbd: protect against duplicate client creation (Sage Weil) [1122174]
- [block] rbd: clean up a few things in the refresh path (Sage Weil) [1122174]
- [block] rbd: flush dcache after zeroing page data (Sage Weil) [1122174]
- [net] libceph: add lingering request reference when registered (Sage Weil) [1122174]
- [fs] ceph: tidy ceph_mdsmap_decode() a little (Sage Weil) [1122174]
- [fs] ceph: improve error handling in ceph_mdsmap_decode (Sage Weil) [1122174]
- [block] rbd: drop original request earlier for existence check (Sage Weil) [1122174]
- [fs] ceph: fix up comment for ceph_count_locks() as to which lock to hold (Sage Weil) [1122174]
- [block] rbd: Use min_t() to fix comparison of distinct pointer types warning (Sage Weil) [1122174]

* Sun Sep 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-166.el7]
- [scsi] megaraid_sas: Driver version update (06.805.06.00-rc1) (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: MFI MPT linked list corruption fix (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: N-drive primary raid level 1 load balancing (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Add module parameter to disable IRQ-CPU affinity hint (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Round down max sge supported by controller to power of two (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Host lock less mode to enabled asynchronous IO submission (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Extended VD support (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Firmware crash dump feature support (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Update threshold based reply post host index register (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Use writeq for 64bit pci write to avoid spinlock overhead (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Do not scan non syspd drives (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Version and Changelog update (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Fix reset_mutex leak (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Remove unused variables in megasas_instance (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Add missing initial call to megasas_get_ld_vf_affiliation() (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Fix LD/VF affiliation parsing (Tomas Henzl) [1088523]
- [scsi] megaraid: Fail resume if MSI-X re-initialization failed (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Version and Changelog update (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Add Dell PowerEdge VRTX SR-IOV VF support (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Return leaked MPT frames to MPT frame pool (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Fix megasas_ioc_init_fusion (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: Load correct raid context timeout (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: check return value for megasas_get_pd_list() (Tomas Henzl) [1088523]
- [scsi] megaraid_sas_fusion: Return correct error value in megasas_get_ld_map_info() (Tomas Henzl) [1088523]
- [scsi] megaraid_sas_fusion: correctly pass queue info pointer (Tomas Henzl) [1088523]
- [scsi] megaraid: Use resource_size_t for PCI resources, not long (Tomas Henzl) [1088523]
- [scsi] megaraid: minor cut and paste error fixed (Tomas Henzl) [1088523]
- [scsi] megaraid_sas: fix a bug for 64 bit arches (Tomas Henzl) [1088523]

* Fri Sep 19 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-165.el7]
- [virt] virtio_scsi: fix various bad behavior on aborted requests (Paolo Bonzini) [1098506]
- [x86] perf/intel: ignore CondChgd bit to avoid false NMI handling (Don Zickus) [1110264]
- [lib] cmdline: add size unit t/p/e to memparse (Eric Sandeen) [1058608]
- [virt] virtio_net: fix packets dropping issue (Marcel Apfelbaum) [1131733]
- [pci] hotplug: Prevent NULL dereference during pciehp probe (Myron Stowe) [1133107]
- [security] selinux: fix a problem with IPv6 traffic denials in selinux_ip_postroute() (Paul Moore) [1102641]
- [platform] toshiba: re-enable acpi hotkeys after suspend to disk (Benjamin Tissoires) [1107814]
- [ethernet] cxgb4: use remove handler as shutdown handler (Steve Best) [1123146]
- [idle] intel_idle: Broadwell support (Steve Best) [1086453]
- [s390] dasd: fix unresponsive device during format (Hendrik Brueckner) [1132370]
- [s390] dasd: validate request size before building CCW/TCW request (Hendrik Brueckner) [1132386]
- [s390] dasd: fix error recovery for alias devices during format (Hendrik Brueckner) [1132372]
- [s390] pci: introduce lazy IOTLB flushing for DMA unmap (Hendrik Brueckner) [1132382]
- [s390] dasd: use aliases for formatted devices during format (Hendrik Brueckner) [1132369]
- [s390] dasd: fix list_del corruption during format (Hendrik Brueckner) [1132371]
- [s390] con3215: fix hanging console issue (Hendrik Brueckner) [1132345]
- [mm] hugetlb: improve page-fault scalability (Larry Woodman) [1087955]
- [s390] spinlock: fix system hang with spin_retry <= 0 (Hendrik Brueckner) [1096329]
- [s390] qeth: Accurate ethtool output (Hendrik Brueckner) [1088581]
- [s390] smp: limit number of cpus in possible cpu mask (Hendrik Brueckner) [1103711]
- [scsi] isci: fix needless ata reset escalation (David Milburn) [1074984]
- [idle] intel_idle: close avn_cstates array with correct marker (Steve Best) [1048050]
- [idle] intel_idle: Fixed C6 state on Avoton/Rangeley processors (Steve Best) [1048050]
- [idle] intel_idle: Support Intel Atom Processor C2000 Product Family (Steve Best) [1048050]
- [ethernet] i40e: Bump i40e/i40evf versions (Stefan Assmann) [1140994]
- [ethernet] i40e: fix panic due to too-early Tx queue enable (Stefan Assmann) [1140994]
- [ethernet] i40e: Fix an issue when PF reset fails (Stefan Assmann) [1140994]
- [ethernet] i40e: make warning less verbose (Stefan Assmann) [1140994]
- [ethernet] i40e: Tell OS link is going down when calling set_phy_config (Stefan Assmann) [1140994]
- [ethernet] i40e: Remove unnecessary assignment (Stefan Assmann) [1140994]
- [ethernet] i40e: Change wording to be more consistent (Stefan Assmann) [1140994]
- [ethernet] i40e: Allow user to change link settings if link is down (Stefan Assmann) [1140994]
- [ethernet] i40e: Add dual speed module support (Stefan Assmann) [1140994]
- [mm] memory-failure: support use of a dedicated thread to handle SIGBUS(BUS_MCEERR_AO) (Rui Wang) [1108357]
- [mm] memory-failure: don't let collect_procs() skip over processes for MF_ACTION_REQUIRED (Rui Wang) [1108357]
- [mm] memory-failure: send right signal code to correct thread (Rui Wang) [1108357]
- [crypto] qat: Use pci_enable_msix_exact() instead of pci_enable_msix() (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fix return value check in adf_chr_drv_create() (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fixed SKU1 dev issue (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Use hweight for bit counting (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Updated print outputs (Nikolay Aleksandrov) [1091130]
- [crypto] qat: change ae_num to ae_id (Nikolay Aleksandrov) [1091130]
- [crypto] qat: change slice->regions to slice->region (Nikolay Aleksandrov) [1091130]
- [crypto] qat: use min_t macro (Nikolay Aleksandrov) [1091130]
- [crypto] qat: remove unnecessary parentheses (Nikolay Aleksandrov) [1091130]
- [crypto] qat: remove unneeded header (Nikolay Aleksandrov) [1091130]
- [crypto] qat: checkpatch blank lines (Nikolay Aleksandrov) [1091130]
- [crypto] qat: remove unnecessary return codes (Nikolay Aleksandrov) [1091130]
- [crypto] qat: remove an unneeded cast (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fix error path crash when no firmware is present (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fixed new checkpatch warnings (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Updated Firmware Info Metadata (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fix random config build warnings (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Fix build problem with O= (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Update to makefiles (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT DH895xcc accelerator (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT accelengine part of fw loader (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT ucode part of fw loader (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT crypto interface (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT FW interface (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT transport code (Nikolay Aleksandrov) [1091130]
- [crypto] qat: Intel(R) QAT driver framework (Nikolay Aleksandrov) [1091130]
- [crypto] Sort drivers/crypto/Makefile (Nikolay Aleksandrov) [1091130]
- [crypto] authenc: Export key parsing helper function (Nikolay Aleksandrov) [1091130]

* Thu Sep 18 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-164.el7]
- [drm] mst: rework payload table allocation to conform better (Dave Airlie) [1140440]
- [drm] dp: Staticize a couple of DP utility functions (Dave Airlie) [1140440]
- [drm] dp-mst-helper: Don't use uninitialized fields of the sideband message header (Dave Airlie) [1140440]
- [drm] dp-mst-helper: Avoid reading uninitialized value (Dave Airlie) [1140440]
- [drm] mst: fix build with debugfs off (Dave Airlie) [1140440]
- [drm] i915: handle G45/GM45 pulse detection connected state (Dave Airlie) [1140440]
- [drm] i915: take display port power domain in DP HPD handler (Dave Airlie) [1140440]
- [drm] i915: only hook up hpd pulse for DP outputs (Dave Airlie) [1140440]
- [drm] i915: lock around link status and link training (Dave Airlie) [1140440]
- [drm] i915: mst topology dumper in debugfs (v0.2) (Dave Airlie) [1140440]
- [drm] i915: add DP 1.2 MST support (v0.7) (Dave Airlie) [1140440]
- [drm] i915: split some conversion functions out into separate functions (Dave Airlie) [1140440]
- [drm] i915: check connector->encoder before using it (Dave Airlie) [1140440]
- [drm] i915: split some DP modesetting code into a separate function (Dave Airlie) [1140440]
- [drm] helper: add Displayport multi-stream helper (v0.6) (Dave Airlie) [1140440]
- [drm] i915: rework digital port IRQ handling (v2) (Dave Airlie) [1140440]
- [drm] add a path blob property (Dave Airlie) [1140440]
- [drm] fb_helper: allow adding/removing connectors later (Dave Airlie) [1140440]
- [drm] crtc: add interface to reinitialise the legacy mode group (Dave Airlie) [1140440]
- [drm] i915: add some registers need for displayport MST support (Dave Airlie) [1140440]
- [drm] i915: silence some scary new warnings (Rob Clark) [1128915]
- [drm] upstream sync to v3.16.0 (Rob Clark) [1128915]
- [drm] upstream sync to v3.15.0 (Rob Clark) [1101269]
- [lib] Export interval_tree (Rob Clark) [1101269]
- [mm] introduce helper function mem_init_print_info() to simplify mem_init() (Rob Clark) [1101269]
- [kernel] bitops: Introduce a more generic BITMASK macro (Rob Clark) [1101269]
- [drm] upstream sync to v3.14.2 (Rob Clark) [1119341]
- [drm] upstream sync to v3.13.11 (Rob Clark) [1119339]
- [fs] dcache: missing EXPORT_SYMBOL(simple_dname) (Rob Clark) [1119339]
- [kernel] define u8, s8, u32, etc. limits (Rob Clark) [1119339]
- [fs] consolidate the reassignments of ->f_op in ->open() instances (Rob Clark) [1119339]
- [kernel] sched: replace INIT_COMPLETION with reinit_completion (Rob Clark) [1119339]

* Wed Sep 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-163.el7]
- [fs] gfs2: Request demote when a "try" flock fails (Robert S Peterson) [1132154]
- [fs] gfs2: Change maxlen variables to size_t (Robert S Peterson) [1127251]
- [fs] gfs2: Fix return value in slot_get() (Abhijith Das) [1026406]
- [fs] gfs2: replace kmalloc - __vmalloc / memset 0 (Abhijith Das) [1026406]
- [fs] gfs2: Fix kbuild test robot reported warning (Abhijith Das) [1026406]
- [fs] gfs2: Move quota bitmap operations under their own lock (Abhijith Das) [1026406]
- [fs] gfs2: Clean up quota slot allocation (Abhijith Das) [1026406]
- [fs] gfs2: Only run logd and quota when mounted read/write (Abhijith Das) [1026406]
- [fs] gfs2: Use RCU/hlist_bl based hash for quotas (Abhijith Das) [1026406]
- [fs] gfs2: Remove gfs2_quota_change_host structure (Abhijith Das) [1026406]
- [fs] gfs2: Use generic list_lru for quota (Abhijith Das) [1026406]
- [fs] list: add a new LRU list type (Abhijith Das) [1026406]
- [fs] gfs2: Rename quota qd_lru_lock qd_lock (Abhijith Das) [1026406]
- [fs] gfs2: Use reflink for quota data cache (Abhijith Das) [1026406]
- [fs] gfs2: Protect quota sync generation (Abhijith Das) [1026406]
- [fs] gfs2: Inline qd_trylock into gfs2_quota_unlock (Abhijith Das) [1026406]
- [fs] gfs2: Make two similar quota code fragments into a function (Abhijith Das) [1026406]
- [fs] gfs2: Remove obsolete quota tunable (Abhijith Das) [1026406]
- [fs] gfs2: Move gfs2_icbit_munge into quota.c (Abhijith Das) [1026406]

* Wed Sep 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-162.el7]
- [powerpc] powernv: Fix permissions on sysparam sysfs entries (Don Zickus) [1127366]
- [pci] rphahp: Fix endianess issues (Don Zickus) [1127366]
- [scripts] modpost: handle non ABS crc symbols (Don Zickus) [1127366]
- [ethernet] ibmveth: Fix endian issues with MAC addresses (Don Zickus) [1127366]
- [ethernet] ibmveth: Fix little endian issues (Don Zickus) [1127366]
- [scsi] ibmvscsi: Fix little endian issues (Don Zickus) [1127366]
- [powerpc] pseries: Add H_SET_MODE to change exception endianness (Don Zickus) [1127366]
- [powerpc] Move precessing of MCE queued event out from syscall exit path (Don Zickus) [1127366]
- [powerpc] of: compiles fixes (Don Zickus) [1127366]
- [fs] pstore: Introduce new argument 'compressed' in the read callback (Don Zickus) [1127366]
- [cpufreq] powernv: make local function static (Don Zickus) [1127366]
- [cpufreq] powernv: Fix build failure on UP (Don Zickus) [1127366]
- [cpufreq] powernv: Use cpufreq_frequency_table.driver_data to store pstate ids (Don Zickus) [1127366]
- [cpufreq] powernv: cpufreq driver for powernv platform (Don Zickus) [1127366]
- [fs] pstore: Add new argument 'compressed' in pstore write callback (Don Zickus) [1127366]
- [powerpc] of: implement pci_address_to_pio as weak function (Don Zickus) [1127366]
- [kernel] panic: Make panic_timeout configurable (Don Zickus) [1127366]
- [pci] Add new pci_is_bridge() interface (Don Zickus) [1127366]
- [pci] Rename pci_is_bridge() to pci_has_subordinate() (Don Zickus) [1127366]
- [powerpc] of: device_node kobject lifecycle fixes (Don Zickus) [1127366]
- [powerpc] Fix endianness of flash_block_list in rtas_flash (Don Zickus) [1127366]
- [powerpc] powernv: Change BUG_ON to WARN_ON in elog code (Don Zickus) [1127366]
- [powerpc] perf: Fix MMCR2 handling for EBB (Don Zickus) [1127366]
- [powerpc] use _GLOBAL_TOC for memmove (Don Zickus) [1127366]
- [powerpc] pseries: dynamically added OF nodes need to call of_node_init (Don Zickus) [1127366]
- [powerpc] subpage_protect: Increase the array size to take care of 64TB (Don Zickus) [1127366]
- [powerpc] Fix bugs in emulate_step() (Don Zickus) [1127366]
- [powerpc] Disable doorbells on Power8 DD1.x (Don Zickus) [1127366]
- [powerpc] perf: Never program book3s PMCs with values >= 0x80000000 (Don Zickus) [1127366]
- [powerpc] perf: Clear MMCR2 when enabling PMU (Don Zickus) [1127366]
- [powerpc] perf: Add PPMU_ARCH_207S define (Don Zickus) [1127366]
- [powerpc] kvm: Remove redundant save of SIER AND MMCR2 (Don Zickus) [1127366]
- [powerpc] powernv: Check for IRQHAPPENED before sleeping (Don Zickus) [1127366]
- [powerpc] bpf: Fix the broken LD_VLAN_TAG_PRESENT test (Don Zickus) [1127366]
- [powerpc] bpf: Use correct mask while accessing the VLAN tag (Don Zickus) [1127366]
- [powerpc] module: Fix TOC symbol CRC (Don Zickus) [1127366]
- [powerpc] powernv: Remove OPAL v1 takeover (Don Zickus) [1127366]
- [powerpc] kprobes: Fix jprobes on ABI v2 (LE) (Don Zickus) [1127366]
- [powerpc] ftrace: Use pr_fmt() to namespace error messages (Don Zickus) [1127366]
- [powerpc] ftrace: Fix nop of modules on 64bit LE (ABIv2) (Don Zickus) [1127366]
- [powerpc] ftrace: Fix inverted check of create_branch() (Don Zickus) [1127366]
- [powerpc] ftrace: Fix typo in mask of opcode (Don Zickus) [1127366]
- [powerpc] Add ppc_global_function_entry() (Don Zickus) [1127366]
- [powerpc] Remove __arch_swab* (Don Zickus) [1127366]
- [powerpc] Remove ancient DEBUG_SIG code (Don Zickus) [1127366]
- [powerpc] kerenl: Enable EEH for IO accessors (Don Zickus) [1127366]
- [powerpc] Avoid circular dependency with zImage. (Don Zickus) [1127366]
- [powerpc] book3s: Fix some ABIv2 issues in machine check code (Don Zickus) [1127366]
- [powerpc] book3s: Fix guest MC delivery mechanism to avoid soft lockups in guest (Don Zickus) [1127366]
- [powerpc] book3s: Increment the mce counter during machine_check_early call (Don Zickus) [1127366]
- [powerpc] book3s: Add stack overflow check in machine check handler (Don Zickus) [1127366]
- [powerpc] book3s: Fix machine check handling for unhandled errors (Don Zickus) [1127366]
- [powerpc] eeh: Dump PE location code (Don Zickus) [1127366]
- [powerpc] powernv: Enable POWER8 doorbell IPIs (Don Zickus) [1127366]
- [powerpc] powernv: Fix killed EEH event (Don Zickus) [1127366]
- [powerpc] fix typo 'CONFIG_PMAC' (Don Zickus) [1127366]
- [powerpc] fix typo 'CONFIG_PPC_CPU' (Don Zickus) [1127366]
- [powerpc] powernv: Don't escalate non-existing frozen PE (Don Zickus) [1127366]
- [powerpc] eeh: Report frozen parent PE prior to child PE (Don Zickus) [1127366]
- [powerpc] eeh: Clear frozen state for child PE (Don Zickus) [1127366]
- [powerpc] powernv: Reduce panic timeout from 180s to 10s (Don Zickus) [1127366]
- [powerpc] xmon: avoid format string leaking to printk (Don Zickus) [1127366]
- [powerpc] perf: Ensure all EBB register state is cleared on fork() (Don Zickus) [1127366]
- [powerpc] powernv: Fix reading of OPAL msglog (Don Zickus) [1127366]
- [powerpc] powernv: Fix endianness problems in EEH (Don Zickus) [1127366]
- [powerpc] powernv: Disable subcore for UP configs (Don Zickus) [1127366]
- [powerpc] powernv: Include asm/smp.h to fix UP build failure (Don Zickus) [1127366]
- [powerpc] Don't setup CPUs with bad status (Don Zickus) [1127366]
- [powerpc] Add AT_HWCAP2 to indicate V.CRYPTO category support (Don Zickus) [1127366]
- [powerpc] update comments for generic idle conversion (Don Zickus) [1127366]
- [powerpc] powernv: Add missing include to LPC code (Don Zickus) [1127366]
- [powerpc] powernv: Pass buffer size to OPAL validate flash call (Don Zickus) [1127366]
- [powerpc] pseries: hcall functions are exported to modules, need _GLOBAL_TOC() (Don Zickus) [1127366]
- [powerpc] Exported functions __clear_user and copy_page use r2 so need _GLOBAL_TOC() (Don Zickus) [1127366]
- [powerpc] powernv: Set memory_block_size_bytes to 256MB (Don Zickus) [1127366]
- [powerpc] Allow ppc_md platform hook to override memory_block_size_bytes (Don Zickus) [1127366]
- [powerpc] powernv: Fix endian issues in memory error handling code (Don Zickus) [1127366]
- [powerpc] eeh: Skip eeh sysfs when eeh is disabled (Don Zickus) [1127366]
- [powerpc] powernv: Provide debugfs access to the LPC bus via OPAL (Don Zickus) [1127366]
- [powerpc] serial: Use saner flags when creating legacy ports (Don Zickus) [1127366]
- [powerpc] Add cpu family documentation (Don Zickus) [1127366]
- [powerpc] xmon: Fix up xmon format strings (Don Zickus) [1127366]
- [powerpc] powernv: Add calls to support little endian host (Don Zickus) [1127366]
- [powerpc] Document sysfs DSCR interface (Don Zickus) [1127366]
- [powerpc] Fix regression of per-CPU DSCR setting (Don Zickus) [1127366]
- [powerpc] Split __SYSFS_SPRSETUP macro (Don Zickus) [1127366]
- [powerpc] fadump: Cleaning up inconsistent NULL checks (Don Zickus) [1127366]
- [powerpc] powernv: Add support for POWER8 split core on powernv (Don Zickus) [1127366]
- [powerpc] kvm/book3s_hv: Use threads_per_subcore in KVM (Don Zickus) [1127366]
- [powerpc] Check cpu_thread_in_subcore() in __cpu_up() (Don Zickus) [1127366]
- [powerpc] Add threads_per_subcore (Don Zickus) [1127366]
- [powerpc] powernv: Make it possible to skip the IRQHAPPENED check in power7_nap() (Don Zickus) [1127366]
- [powerpc] kvm/book3s_hv: Rework the secondary inhibit code (Don Zickus) [1127366]
- [powerpc] numa: Enable CONFIG_HAVE_MEMORYLESS_NODES (Don Zickus) [1127366]
- [powerpc] numa: Enable USE_PERCPU_NUMA_NODE_ID (Don Zickus) [1127366]
- [powerpc] Fix 64 bit builds with binutils 2.24 (Don Zickus) [1127366]
- [powerpc] pci: Use pci_is_bridge() to simplify code (Don Zickus) [1127366]
- [powerpc] module: Fix stubs for BE (Don Zickus) [1127366]
- [powerpc] Clear ELF personality flag if ELFv2 is not requested (Don Zickus) [1127366]
- [powerpc] Fix smp_processor_id() in preemptible splat in set_breakpoint (Don Zickus) [1127366]
- [powerpc] Drop return value from set_breakpoint as it is unused (Don Zickus) [1127366]
- [powerpc] Remove non-uapi linkage.h export (Don Zickus) [1127366]
- [powerpc] irq work racing with timer interrupt can result in timer interrupt hang (Don Zickus) [1127366]
- [powerpc] mm: use macro PGTABLE_EADDR_SIZE instead of digital (Don Zickus) [1127366]
- [powerpc] le: Show the endianess of the LPAR under PowerVM (Don Zickus) [1127366]
- [powerpc] Use 64k io pages when we never see an HEA (Don Zickus) [1127366]
- [powerpc] use libfdt accessors for header data (Don Zickus) [1127366]
- [powerpc] memcpy optimization for 64bit LE (Don Zickus) [1127366]
- [powerpc] tm: Add checking to treclaim/trechkpt (Don Zickus) [1127366]
- [powerpc] tm: Remove unnecessary r1 save (Don Zickus) [1127366]
- [powerpc] powernv: Implement ppc_md.get_proc_freq() (Don Zickus) [1127366]
- [cpuidle] powernv: Remove redundant cpuidle_idle_call() (Don Zickus) [1127366]
- [powerpc] powernv: Framework to show the correct clock in /proc/cpuinfo (Don Zickus) [1127366]
- [powerpc] powernv: Return secondary CPUs to firmware before FW update (Don Zickus) [1127366]
- [powerpc] boot: Add support for 64bit little endian wrapper (Don Zickus) [1127366]
- [powerpc] boot: Add a global entry point for pseries (Don Zickus) [1127366]
- [powerpc] boot: Modify entry point for 64bit (Don Zickus) [1127366]
- [powerpc] boot: Define a routine to enter prom (Don Zickus) [1127366]
- [powerpc] boot: Add little endian support to elf utils (Don Zickus) [1127366]
- [powerpc] boot: Add 64bit and little endian support to addnote (Don Zickus) [1127366]
- [powerpc] boot: Define byteswapping routines for little endian (Don Zickus) [1127366]
- [powerpc] boot: Fix compile warning in 64bit (Don Zickus) [1127366]
- [powerpc] boot: Define typedef ihandle as u32 (Don Zickus) [1127366]
- [powerpc] boot: Rework of_claim() to make it 64bit friendly (Don Zickus) [1127366]
- [powerpc] boot: Add PROM_ERROR define in oflib (Don Zickus) [1127366]
- [powerpc] boot: Add byteswapping routines in oflib (Don Zickus) [1127366]
- [powerpc] boot: Use prom_arg_t in oflib (Don Zickus) [1127366]
- [powerpc] boot: Use a common prom_args struct in oflib (Don Zickus) [1127366]
- [powerpc] boot: Fix do_div for 64bit wrapper (Don Zickus) [1127366]
- [powerpc] prom: Stop scanning dev-tree for fdump early (Don Zickus) [1127366]
- [powerpc] powernv: Don't use pe->pbus to get the domain number (Don Zickus) [1127366]
- [powerpc] powernv: Fix VFIO support with PHB3 (Don Zickus) [1127366]
- [powerpc] powernv: Missed IOMMU table type (Don Zickus) [1127366]
- [powerpc] eeh: Can't recover from non-PE-reset case (Don Zickus) [1127366]
- [powerpc] pci: Mask linkDown on resetting PCI bus (Don Zickus) [1127366]
- [powerpc] powernv: Reset root port in firmware (Don Zickus) [1127366]
- [powerpc] pseries: Fix overwritten PE state (Don Zickus) [1127366]
- [powerpc] powernv: Fix endless reporting frozen PE (Don Zickus) [1127366]
- [powerpc] eeh: No hotplug on permanently removed dev (Don Zickus) [1127366]
- [powerpc] eeh: Allow to disable EEH (Don Zickus) [1127366]
- [powerpc] eeh: Cleanup EEH subsystem variables (Don Zickus) [1127366]
- [powerpc] eeh: Use cached capability for log dump (Don Zickus) [1127366]
- [powerpc] eeh: Cleanup eeh_gather_pci_data() (Don Zickus) [1127366]
- [powerpc] eeh: Avoid I/O access during PE reset (Don Zickus) [1127366]
- [powerpc] powernv: Use EEH PCI config accessors (Don Zickus) [1127366]
- [powerpc] eeh: Block PCI-CFG access during PE reset (Don Zickus) [1127366]
- [powerpc] eeh: EEH_PE_ISOLATED not reflect HW state (Don Zickus) [1127366]
- [powerpc] powernv: Remove fields in PHB diag-data dump (Don Zickus) [1127366]
- [powerpc] powernv: Move PNV_EEH_STATE_ENABLED around (Don Zickus) [1127366]
- [powerpc] powernv: Remove PNV_EEH_STATE_REMOVED (Don Zickus) [1127366]
- [powerpc] eeh: Remove EEH_PE_PHB_DEAD (Don Zickus) [1127366]
- [powerpc] pseries: Protect remove_memory() with device hotplug lock (Don Zickus) [1127366]
- [powerpc] Fix error return in rtas_flash module init (Don Zickus) [1127366]
- [powerpc] Bump BOOT_COMMAND_LINE_SIZE to 2048 (Don Zickus) [1127366]
- [powerpc] Bump COMMAND_LINE_SIZE to 2048 (Don Zickus) [1127366]
- [powerpc] Rename duplicate COMMAND_LINE_SIZE define (Don Zickus) [1127366]
- [powerpc] mm: Fix tlbie to add AVAL fields for 64K pages (Don Zickus) [1127366]
- [powerpc] powernv: Fix little endian issues in OPAL dump code (Don Zickus) [1127366]
- [powerpc] powernv: Create OPAL sglist helper functions and fix endian issues (Don Zickus) [1127366]
- [powerpc] powernv: Fix little endian issues in OPAL error log code (Don Zickus) [1127366]
- [powerpc] powernv: Fix little endian issues with opal_do_notifier calls (Don Zickus) [1127366]
- [powerpc] powernv: Remove some OPAL function declaration duplication (Don Zickus) [1127366]
- [powerpc] powernv: Use uint64_t instead of size_t in OPAL APIs (Don Zickus) [1127366]
- [powerpc] powernv: Release the refcount for pci_dev (Don Zickus) [1127366]
- [powerpc] powernv: Reduce multi-hit of iommu_add_device() (Don Zickus) [1127366]
- [powerpc] powernv: Fix little endian issues in OPAL flash code (Don Zickus) [1127366]
- [powerpc] powernv: Fix kexec races going back to OPAL (Don Zickus) [1127366]
- [powerpc] powernv: Check sysparam size before creation (Don Zickus) [1127366]
- [powerpc] powernv: Fix typos in sysparam code (Don Zickus) [1127366]
- [powerpc] powernv: Check sysfs size before copying (Don Zickus) [1127366]
- [powerpc] powernv: Use ssize_t for sysparam return values (Don Zickus) [1127366]
- [powerpc] powernv: Fix sysparam sysfs error handling (Don Zickus) [1127366]
- [powerpc] Fix Oops in rtas_stop_self() (Don Zickus) [1127366]
- [powerpc] Export flush_icache_range (Don Zickus) [1127366]
- [powerpc] Build little endian ppc64 kernel with ABIv2 (Don Zickus) [1127366]
- [powerpc] ftrace: Fix ABIv2 issues with __ftrace_make_call (Don Zickus) [1127366]
- [powerpc] ftrace: Use module loader helpers to parse trampolines (Don Zickus) [1127366]
- [powerpc] modules: Create module_trampoline_target() (Don Zickus) [1127366]
- [powerpc] modules: Create is_module_trampoline() (Don Zickus) [1127366]
- [powerpc] kprobes: Fix ABIv2 issues with kprobe_lookup_name (Don Zickus) [1127366]
- [powerpc] ftrace_caller, _mcount is exported to modules so needs _GLOBAL_TOC() (Don Zickus) [1127366]
- [powerpc] Add _GLOBAL_TOC for ABIv2 assembly functions exported to modules (Don Zickus) [1127366]
- [powerpc] modules: implement stubs for ELFv2 ABI (Don Zickus) [1127366]
- [powerpc] modules: skip r2 setup for ELFv2 (Don Zickus) [1127366]
- [powerpc] modules: use r12 for stub jump address (Don Zickus) [1127366]
- [powerpc] modules: change r2 save/restore offset for ELFv2 ABI (Don Zickus) [1127366]
- [powerpc] modules: comment about de-dotifying symbols when using the ELFv2 ABI (Don Zickus) [1127366]
- [powerpc] Handle new ELFv2 module relocations (Don Zickus) [1127366]
- [powerpc] Fix up TOC. for modules (Don Zickus) [1127366]
- [powerpc] module: handle MODVERSION for .TOC (Don Zickus) [1127366]
- [powerpc] EXPORT_SYMBOL(.TOC.) (Don Zickus) [1127366]
- [powerpc] modules implement R_PPC64_TOCSAVE relocation (Don Zickus) [1127366]
- [powerpc] make module stub code endian independent (Don Zickus) [1127366]
- [powerpc] Fix ABIv2 issue with dereference_function_descriptor (Don Zickus) [1127366]
- [powerpc] Fix SMP issues with ppc64le ABIv2 (Don Zickus) [1127366]
- [powerpc] tracing: TRACE_WITH_FRAME_BUFFER creates invalid stack frames (Don Zickus) [1127366]
- [powerpc] tm: Fix GOT save offset for ABIv2 (Don Zickus) [1127366]
- [powerpc] tm: Use STK_PARAM (Don Zickus) [1127366]
- [powerpc] Fix unsafe accesses to parameter area in ELFv2 (Don Zickus) [1127366]
- [powerpc] Fix ABIv2 issues with stack offsets in assembly code (Don Zickus) [1127366]
- [powerpc] Fix kernel thread creation on ABIv2 (Don Zickus) [1127366]
- [powerpc] Fix branch patching code for ABIv2 (Don Zickus) [1127366]
- [powerpc] Use ppc_function_entry instead of open coding it (Don Zickus) [1127366]
- [powerpc] Add ABIv2 support to ppc_function_entry (Don Zickus) [1127366]
- [powerpc] Ignore .TOC. relocations (Don Zickus) [1127366]
- [powerpc] ABIv2 function calls must place target address in r12 (Don Zickus) [1127366]
- [powerpc] Remove function descriptors and dot symbols on new ABI (Don Zickus) [1127366]
- [powerpc] Create DOTSYM to wrap dot symbol usage (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Introduce hypervisor call H_GET_TCE (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add support for DABRX register on POWER7 (Don Zickus) [1127366]
- [powerpc] Remove dot symbol usage in exception macros (Don Zickus) [1127366]
- [powerpc] Remove _INIT_GLOBAL(), _STATIC() and _INIT_STATIC() (Don Zickus) [1127366]
- [powerpc] Remove some unnecessary uses of _GLOBAL() and _STATIC() (Don Zickus) [1127366]
- [powerpc] Don't use a function descriptor for system call table (Don Zickus) [1127366]
- [powerpc] Remove superflous function descriptors in assembly only code (Don Zickus) [1127366]
- [powerpc] No need to use dot symbols when branching to a function (Don Zickus) [1127366]
- [powerpc] Don't build assembly files with ABIv2 (Don Zickus) [1127366]
- [powerpc] Don't try to set LPCR unless we're in hypervisor mode (Don Zickus) [1127366]
- [powerpc] le: Avoid creatng R_PPC64_TOCSAVE relocations for modules (Don Zickus) [1127366]
- [powerpc] opal: Add missing include (Don Zickus) [1127366]
- [powerpc] Convert last uses of __FUNCTION__ to __func__ (Don Zickus) [1127366]
- [powerpc] Add lq/stq emulation (Don Zickus) [1127366]
- [powerpc] powernv: Add invalid OPAL call (Don Zickus) [1127366]
- [powerpc] powernv: Add OPAL message log interface (Don Zickus) [1127366]
- [powerpc] book3s: Fix mc_recoverable_range buffer overrun issue (Don Zickus) [1127366]
- [powerpc] Remove dead code in sycall entry (Don Zickus) [1127366]
- [powerpc] Use of_node_init() for the fakenode in msi_bitmap.c (Don Zickus) [1127366]
- [powerpc] of: Make device nodes kobjects so they show up in sysfs (Don Zickus) [1127366]
- [powerpc] mm: NUMA pte should be handled via slow path in get_user_pages_fast() (Don Zickus) [1127366]
- [powerpc] powernv: Fix endian issues with sensor code (Don Zickus) [1127366]
- [powerpc] powernv: Fix endian issues with OPAL async code (Don Zickus) [1127366]
- [powerpc] powernv: Add opal_notifier_unregister() and export to modules (Don Zickus) [1127366]
- [powerpc] ppc64: Do not turn AIL (reloc-on interrupts) too early (Don Zickus) [1127366]
- [powerpc] ppc64: Gracefully handle early interrupts (Don Zickus) [1127366]
- [powerpc] prom: early_init_dt_scan_cpus() updates cpu features only once (Don Zickus) [1127366]
- [powerpc] Make boot_cpuid common between 32 and 64-bit (Don Zickus) [1127366]
- [powerpc] Adjust CPU_FTR_SMT on all platforms (Don Zickus) [1127366]
- [powerpc] le: Enable RTAS events support (Don Zickus) [1127366]
- [powerpc] book3s: Fix CFAR clobbering issue in machine check handler (Don Zickus) [1127366]
- [powerpc] compat: 32-bit little endian machine name is ppcle, not ppc (Don Zickus) [1127366]
- [powerpc] le: Big endian arguments for ppc_rtas() (Don Zickus) [1127366]
- [powerpc] mm: Make sure a local_irq_disable prevent a parallel THP split (Don Zickus) [1127366]
- [powerpc] Rate-limit users spamming kernel log buffer (Don Zickus) [1127366]
- [powerpc] perf: Fix handling of L3 events with bank == 1 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Work around POWER8 performance monitor bugs (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Make sure we don't miss dirty pages (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add transactional memory support (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Fix dirty map for hugepages (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Fix check for running inside guest in global_invalidates() (Don Zickus) [1127366]
- [powerpc] powernv: Reset PHB in kdump kernel (Don Zickus) [1127366]
- [powerpc] eeh: Make the delay for PE reset unified (Don Zickus) [1127366]
- [virt] kvm/ppc: Clear the runlatch bit of a vcpu before napping (Don Zickus) [1127366]
- [virt] kvm/ppc: Set the runlatch bit of a CPU just before starting guest (Don Zickus) [1127366]
- [powerpc] powernv: Set the runlatch bits correctly for offline cpus (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Save/restore host PMU registers that are new in POWER8 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Fix decrementer timeouts with non-zero TB offset (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Don't use kvm_memslots() in real mode (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Return ENODEV error rather than EIO (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Trim top 4 bits of physical address in RTAS code (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add get/set_one_reg for new TM state (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Basic little-endian guest support (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Fix register usage when loading/saving VRSAVE (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Cope with doorbell interrupts (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add new state for transactional memory (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Prepare for host using hypervisor doorbells (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Handle new LPCR bits on POWER8 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Handle guest using doorbells for IPIs (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Consolidate code that checks reason for wake from nap (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Implement architecture compatibility modes for POWER8 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add handler for HV facility unavailable (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Flush the correct number of TLB sets on POWER8 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Context-switch new POWER8 SPRs (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Align physical and virtual CPU thread numbers (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Don't set DABR on POWER8 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - MMIO emulation support for little endian guests (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Use load/store_fp_state functions in HV guest entry/exit (Don Zickus) [1127366]
- [virt] kvm/ppc: Store FP/VSX/VMX state in thread_fp/vr_state structures (Don Zickus) [1127366]
- [virt] kvm/ppc: Use load_fp/vr_state rather than load_up_fpu/altivec (Don Zickus) [1127366]
- [powerpc] powernv/eeh: Add buffer for P7IOC hub error data (Don Zickus) [1127366]
- [powerpc] powernv: Remove get/set_rtc_time when they are not present (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Take SRCU read lock around kvm_read_guest() call (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Make tbacct_lock irq-safe (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Refine barriers in guest entry/exit (Don Zickus) [1127366]
- [virt] kvm: Add struct kvm arg to memslot APIs (Don Zickus) [1127366]
- [powerpc] perf: Define perf_event_print_debug() to print PMU register values (Don Zickus) [1127366]
- [powerpc] perf: Make some new raw event codes available in sysfs (Don Zickus) [1127366]
- [powerpc] powernv: Enable fetching of platform sensor data (Don Zickus) [1127366]
- [powerpc] powernv: Enable reading and updating of system parameters (Don Zickus) [1127366]
- [powerpc] powernv: Infrastructure to support OPAL async completion (Don Zickus) [1127366]
- [powerpc] powernv Platform dump interface (Don Zickus) [1127366]
- [powerpc] powernv: Read OPAL error log and export it through sysfs (Don Zickus) [1127366]
- [powerpc] Add "force config cmd line" Kconfig option (Don Zickus) [1127366]
- [powerpc] pseries: Use remove_memory() to remove memory (Don Zickus) [1127366]
- [powerpc] book3s: Recover from MC in sapphire on SCOM read via MMIO (Don Zickus) [1127366]
- [powerpc] pseries: Don't try to register pseries cpu hotplug on non-pseries (Don Zickus) [1127366]
- [powerpc] Fix xmon disassembler for little-endian (Don Zickus) [1127366]
- [powerpc] Revert c6102609 and replace it with the correct fix for vio dma mask setting (Don Zickus) [1127366]
- [powerpc] Kill CONFIG_MTD_PARTITIONS (Don Zickus) [1127366]
- [powerpc] Align p_dyn, p_rela and p_st symbols (Don Zickus) [1127366]
- [powerpc] powernv: Add OPAL call to resync timebase on wakeup (Don Zickus) [1127366]
- [powerpc] powernv: Add context management for Fast Sleep (Don Zickus) [1127366]
- [powerpc] Split timer_interrupt() into timer handling and interrupt handling routines (Don Zickus) [1127366]
- [powerpc] Implement tick broadcast IPI as a fixed IPI message (Don Zickus) [1127366]
- [powerpc] Free up the slot of PPC_MSG_CALL_FUNC_SINGLE IPI message (Don Zickus) [1127366]
- [powerpc] eeh: Fixup the brown paperbag fallout of the "cleanup" (Don Zickus) [1127366]
- [powerpc] eeh: Kill another abuse of irq_desc (Don Zickus) [1127366]
- [powerpc] irq: Use generic_handle_irq (Don Zickus) [1127366]
- [powerpc] powernv: Fix indirect XSCOM unmangling (Don Zickus) [1127366]
- [powerpc] powernv: Fix opal_xscom_{read, write} prototype (Don Zickus) [1127366]
- [powerpc] powernv: Refactor PHB diag-data dump (Don Zickus) [1127366]
- [powerpc] powernv: Dump PHB diag-data immediately (Don Zickus) [1127366]
- [powerpc] Increase stack redzone for 64-bit userspace to 512 bytes (Don Zickus) [1127366]
- [powerpc] ftrace: bugfix for test_24bit_addr (Don Zickus) [1127366]
- [powerpc] crashdump: Fix page frame number check in copy_oldmem_page (Don Zickus) [1127366]
- [powerpc] le: Ensure that the 'stop-self' RTAS token is handled correctly (Don Zickus) [1127366]
- [powerpc] eeh: Disable EEH on reboot (Don Zickus) [1127366]
- [powerpc] eeh: Cleanup on eeh_subsystem_enabled (Don Zickus) [1127366]
- [powerpc] powernv: Rework EEH reset (Don Zickus) [1127366]
- [powerpc] powernv: Add iommu DMA bypass support for IODA2 (Don Zickus) [1127366]
- [powerpc] Fix endian issues in kexec and crash dump code (Don Zickus) [1127366]
- [powerpc] perf: Configure BHRB filter before enabling PMU interrupts (Don Zickus) [1127366]
- [powerpc] pseries: Select ARCH_RANDOM on pseries (Don Zickus) [1127366]
- [powerpc] perf: Add Power8 cache & TLB events (Don Zickus) [1127366]
- [powerpc] relocate fix relocate processing in LE mode (Don Zickus) [1127366]
- [powerpc] hugetlb: Replace __get_cpu_var with get_cpu_var (Don Zickus) [1127366]
- [powerpc] Make sure "cache" directory is removed when offlining cpu (Don Zickus) [1127366]
- [powerpc] powernv/cpuidle: Back-end cpuidle driver for powernv platform (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: smt-snooze-delay cleanup (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: Remove MAX_IDLE_STATE macro (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: Make cpuidle-pseries backend driver a non-module (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: Use cpuidle_register() for initialisation (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: Move processor_idle.c to drivers/cpuidle (Don Zickus) [1127366]
- [powerpc] numa: Fix decimal permissions (Don Zickus) [1127366]
- [powerpc] Fix hw breakpoints on !HAVE_HW_BREAKPOINT configurations (Don Zickus) [1127366]
- [powerpc] Implement arch_spin_is_locked() using arch_spin_value_unlocked() (Don Zickus) [1127366]
- [powerpc] Add support for the optimised lockref implementation (Don Zickus) [1127366]
- [powerpc] Kconfig: Make TM select VSX and VMX (Don Zickus) [1127366]
- [powerpc] powernv: Call OPAL sync before kexec'ing (Don Zickus) [1127366]
- [powerpc] eeh: Escalate error on non-existing PE (Don Zickus) [1127366]
- [powerpc] eeh: Handle multiple EEH errors (Don Zickus) [1127366]
- [powerpc] Fix races with irq_work (Don Zickus) [1127366]
- [powerpc] Make add_system_ram_resources() __init (Don Zickus) [1127366]
- [powerpc] add SATA_MV to ppc64_defconfig (Don Zickus) [1127366]
- [powerpc] powernv: Increase candidate fw image size (Don Zickus) [1127366]
- [powerpc] iommu: Don't detach device without IOMMU group (Don Zickus) [1127366]
- [powerpc] eeh: Hotplug improvement (Don Zickus) [1127366]
- [powerpc] eeh: Call opal_pci_reinit() on powernv for restoring config space (Don Zickus) [1127366]
- [powerpc] eeh: Add restore_config operation (Don Zickus) [1127366]
- [powerpc] powernv: Remove unnecessary assignment (Don Zickus) [1127366]
- [powerpc] Delete non-required instances of include <linux/init.h> (Don Zickus) [1127366]
- [powerpc] Add vr save/restore functions (Don Zickus) [1127366]
- [powerpc] Check return value of instance-to-package OF call (Don Zickus) [1127366]
- [powerpc] add barrier after writing kernel PTE (Don Zickus) [1127366]
- [powerpc] introduce macro LOAD_REG_ADDR_PIC (Don Zickus) [1127366]
- [virt] kvm/ppc: define a linux pte lookup function (Don Zickus) [1127366]
- [powerpc] Fix endian issues in power7/8 machine check handler (Don Zickus) [1127366]
- [powerpc] iommu: Update the generic code to use dynamic iommu page sizes (Don Zickus) [1127366]
- [powerpc] iommu: Add it_page_shift field to determine iommu page size (Don Zickus) [1127366]
- [powerpc] iommu: Update constant names to reflect their hardcoded page size (Don Zickus) [1127366]
- [powerpc] powernv: move iommu_add_device earlier (Don Zickus) [1127366]
- [powerpc] vfio: Enable on pSeries platform (Don Zickus) [1127366]
- [powerpc] vfio: Implement IOMMU driver for VFIO (Don Zickus) [1127366]
- [powerpc] vfio: Enable on PowerNV platform (Don Zickus) [1127366]
- [powerpc] Fix "attempt to move .org backwards" error (Don Zickus) [1127366]
- [powerpc] Fix alignment of secondary cpu spin vars (Don Zickus) [1127366]
- [powerpc] Align p_end (Don Zickus) [1127366]
- [powerpc] Make 64-bit non-VMX __copy_tofrom_user bi-endian (Don Zickus) [1127366]
- [powerpc] Make unaligned accesses endian-safe for powerpc (Don Zickus) [1127366]
- [powerpc] Fix bad stack check in exception entry (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Don't abuse host r2 in exit path (Don Zickus) [1127366]
- [powerpc] Full barrier for smp_mb__after_unlock_lock() (Don Zickus) [1127366]
- [powerpc] powernv: Fix OPAL LPC access in Little Endian (Don Zickus) [1127366]
- [powerpc] powernv: Fix endian issue in opal_xscom_read (Don Zickus) [1127366]
- [powerpc] pseries: Fix endian issues in /proc/ppc64/lparcfg (Don Zickus) [1127366]
- [powerpc] Fix up the kdump base cap to 128M (Don Zickus) [1127366]
- [powerpc] Fix PTE page address mismatch in pgtable ctor/dtor (Don Zickus) [1127366]
- [powerpc] powernv: Get FSP memory errors and plumb into memory poison infrastructure (Don Zickus) [1127366]
- [powerpc] powernv: Add config option for hwpoisoning (Don Zickus) [1127366]
- [powerpc] Dynamically allocate slb_shadow from memblock (Don Zickus) [1127366]
- [powerpc] Make slb_shadow a local (Don Zickus) [1127366]
- [powerpc] Add real mode cache inhibited IO accessors (Don Zickus) [1127366]
- [powerpc] Increase EEH recovery timeout for SR-IOV (Don Zickus) [1127366]
- [powerpc] eeh: Output PHB diag-data (Don Zickus) [1127366]
- [powerpc] powernv: Move PHB-diag dump functions around (Don Zickus) [1127366]
- [powerpc] powernv: Move SG list structure to header file (Don Zickus) [1127366]
- [powerpc] powernv: Infrastructure to read opal messages in generic format (Don Zickus) [1127366]
- [powerpc] powernv: Machine check exception handling (Don Zickus) [1127366]
- [powerpc] powernv: Remove machine check handling in OPAL (Don Zickus) [1127366]
- [powerpc] book3s: Queue up and process delayed MCE events (Don Zickus) [1127366]
- [powerpc] book3s: Decode and save machine check event (Don Zickus) [1127366]
- [powerpc] book3s: Flush SLB/TLBs if we get SLB/TLB machine check errors on power8 (Don Zickus) [1127366]
- [powerpc] book3s: Flush SLB/TLBs if we get SLB/TLB machine check errors on power7 (Don Zickus) [1127366]
- [powerpc] book3s: Add flush_tlb operation in cpu_spec (Don Zickus) [1127366]
- [powerpc] book3s: Introduce a early machine check hook in cpu_spec (Don Zickus) [1127366]
- [powerpc] book3s: Return from interrupt if coming from evil context (Don Zickus) [1127366]
- [powerpc] book3s: handle machine check in Linux host (Don Zickus) [1127366]
- [powerpc] book3s: Introduce exclusive emergency stack for machine check exception (Don Zickus) [1127366]
- [powerpc] book3s: Split the common exception prolog logic into two section (Don Zickus) [1127366]
- [powerpc] powernv: Replace CONFIG_POWERNV_MSI with just CONFIG_PPC_POWERNV (Don Zickus) [1127366]
- [powerpc] pseries: CONFIG_PSERIES_MSI should depend on PPC_PSERIES (Don Zickus) [1127366]
- [powerpc] kernel/sysfs: Cleanup set up macros for PMC/non-PMC SPRs (Don Zickus) [1127366]
- [powerpc] Make irq_stat.timers_irqs counting more specific (Don Zickus) [1127366]
- [powerpc] purge all the prefetched instructions for the coherent icache flush (Don Zickus) [1127366]
- [powerpc] kernel: remove useless code which related with 'max_cpus' (Don Zickus) [1127366]
- [powerpc] boot: Ignore .dtb files (Don Zickus) [1127366]
- [powerpc] Clean up panic_timeout usage (Don Zickus) [1127366]
- [powerpc] kernel: Use 12.12s instead of 12s to avoid memory overflow (Don Zickus) [1127366]
- [powerpc] kvm: optimize "sc 1" as fast return (Don Zickus) [1127366]
- [powerpc] pseries: Fix SMP=n build of rng.c (Don Zickus) [1127366]
- [powerpc] Make cpu_to_chip_id() available when SMP=n (Don Zickus) [1127366]
- [powerpc] vio: Fix a dma_mask issue of vio (Don Zickus) [1127366]
- [powerpc] Only print PACATMSCRATCH in oops when TM is active (Don Zickus) [1127366]
- [powerpc] pseries: Duplicate dtl entries sometimes sent to userspace (Don Zickus) [1127366]
- [powerpc] Remove a few lines of oops output (Don Zickus) [1127366]
- [powerpc] Print DAR and DSISR on machine check oopses (Don Zickus) [1127366]
- [powerpc] Fix __get_user_pages_fast() irq handling (Don Zickus) [1127366]
- [powerpc] eeh: More accurate log (Don Zickus) [1127366]
- [powerpc] eeh: Enable PCI_COMMAND_MASTER for PCI bridges (Don Zickus) [1127366]
- [powerpc] Add pseries_le_defconfig (Don Zickus) [1127366]
- [kernel] uprobes/powerpc: Kill arch_uprobe->ainsn (Don Zickus) [1127366]
- [powerpc] kvm: fix rare but potential deadlock scene (Don Zickus) [1127366]
- [powerpc] add missing explicit OF includes for ppc (Don Zickus) [1127366]
- [powerpc] powernv: Add support for indirect XSCOM via debugfs (Don Zickus) [1127366]
- [powerpc] scom: Improve debugfs interface (Don Zickus) [1127366]
- [powerpc] scom: Enable 64-bit addresses (Don Zickus) [1127366]
- [powerpc] boot: Properly handle the base "of" boot wrapper (Don Zickus) [1127366]
- [powerpc] bpf: Support MOD operation (Don Zickus) [1127366]
- [powerpc] bpf: Fix DIVWU instruction opcode (Don Zickus) [1127366]
- [powerpc] tm: Remove interrupt disable in __switch_to() (Don Zickus) [1127366]
- [powerpc] nvram: Scan partitions only once (Don Zickus) [1127366]
- [powerpc] powernv: Code update interface (Don Zickus) [1127366]
- [powerpc] powernv: Create opal sysfs directory (Don Zickus) [1127366]
- [powerpc] Add VMX optimised xor for RAID5 (Don Zickus) [1127366]
- [powerpc] kexec: kexec_sequence() is in misc_64.S (Don Zickus) [1127366]
- [powerpc] Use 32 bit loads and stores when operating on condition register values (Don Zickus) [1127366]
- [powerpc] Enable multipath modules on ppc64 and pseries (Don Zickus) [1127366]
- [powerpc] pseries: Fix dedicated processor partition detection (Don Zickus) [1127366]
- [powerpc] vio: use strcpy in modalias_show (Don Zickus) [1127366]
- [powerpc] FA_DUMP depends on KEXEC (Don Zickus) [1127366]
- [powerpc] Fix a typo in comments of va to pa conversion (Don Zickus) [1127366]
- [powerpc] Move local setup.h declarations to arch includes (Don Zickus) [1127366]
- [powerpc] Fix warnings for arch/powerpc/mm/numa.c (Don Zickus) [1127366]
- [powerpc] boot: Don't change link address for OF-based platforms (Don Zickus) [1127366]
- [powerpc] Add includes to fix powernv/rng.c build (Don Zickus) [1127366]
- [powerpc] Fix PPC_EMULATED_STATS build break with sync patch (Don Zickus) [1127366]
- [powerpc] select ARCH_MIGHT_HAVE_PC_PARPORT (Don Zickus) [1127366]
- [powerpc] Don't corrupt user registers on 32-bit (Don Zickus) [1127366]
- [powerpc] kgdb: use DEFINE_PER_CPU to allocate kgdb's thread_info (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - drop is_hv_enabled (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Allow the HV and PR selection per virtual machine (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Support building HV and PR KVM as module (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - move PR related tracepoints to a separate header (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Add is_hv_enabled to kvmppc_ops (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Cleanup interrupt handling code (Don Zickus) [1127366]
- [virt] kvm/ppc: Add kvmppc_ops callback (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Add a new config variable CONFIG_KVM_BOOK3S_HV_POSSIBLE (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s/pr - Rename KVM_BOOK3S_PR to KVM_BOOK3S_PR_POSSIBLE (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - move book3s_64_vio_hv.c into the main kernel binary (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - remove kvmppc_handler_highmem label (Don Zickus) [1127366]
- [powerpc] export debug registers save function for KVM (Don Zickus) [1127366]
- [powerpc] move debug registers in a structure (Don Zickus) [1127366]
- [powerpc] remove unnecessary line continuations (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Fix vcore leak (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Better handling of exceptions that happen in real mode (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Reduce number of shadow PTEs invalidated by MMU notifiers (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Mark pages accessed, and dirty if being written (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Use mmu_notifier_retry() in kvmppc_mmu_map_page() (Don Zickus) [1127366]
- [virt] kvm/ppc: Book3S PR - Better handling of host-side read-only pages (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Move skip-interrupt handlers to common code (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Allocate kvm_vcpu structs from kvm_vcpu_cache (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Make HPT accesses and updates SMP-safe (Don Zickus) [1127366]
- [virt] kvm/ppc: Book3S PR - Correct errors in H_ENTER implementation (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Handle PP0 page-protection bit in guest HPTEs (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Use 64k host pages where possible (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Allow guest to use 64k pages (Don Zickus) [1127366]
- [virt] kvm/ppc: Book3S PR - Keep volatile reg values in vcpu rather than shadow_vcpu (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Don't crash host on unknown guest interrupt (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Support POWER6 compatibility mode on POWER7 (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Add support for guest Program Priority Register (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Store LPCR value for each virtual core (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Avoid unbalanced increments of VPA yield count (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Pull out interrupt-reading code into a subroutine (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Restructure kvmppc_hv_entry to be a subroutine (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Implement H_CONFER (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s - Add GET/SET_ONE_REG interface for VRSAVE (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Implement timebase offset for guests (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Save/restore SIAR and SDAR along with other PMU registers (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Reserve POWER8 space in get/set_one_reg (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Rework kvmppc_mmu_book3s_64_xlate() (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Make instruction fetch fallback work for system calls (Don Zickus) [1127366]
- [powerpc] pseries: Move plpar_wrapper.h to powerpc common include/asm location (Don Zickus) [1127366]
- [powerpc] pseries/cpuidle: Remove dependency of pseries.h file (Don Zickus) [1127366]
- [virt] kvm/ppc: use anon_inode_getfd() with O_CLOEXEC flag (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Load up SPRG3 register with guest value on guest entry (Don Zickus) [1127366]
- [virt] kvm/ppc: Call trace_hardirqs_on before entry (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Allow negative offsets to real-mode hcall handlers (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s hv - Correct tlbie usage (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Invalidate SLB entries properly (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Allow guest to use 1TB segments (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Don't keep scanning HPTEG after we find a match (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Fix invalidation of SLB entry 0 on guest entry (Don Zickus) [1127366]
- [virt] kvm/ppc: book3s pr - Fix proto-VSID calculations (Don Zickus) [1127366]
- [powerpc] Remove the unneeded trigger of decrementer interrupt in decrementer_check_overflow (Don Zickus) [1127366]
- [virt] kvm/ppc: fix imbalance srcu_read_[un]lock() (Don Zickus) [1127366]
- [powerpc] Emulate sync instruction variants (Don Zickus) [1127366]
- [powerpc] eeh: Reorder output messages (Don Zickus) [1127366]
- [powerpc] scom: Use "devspec" rather than "path" in debugfs entries (Don Zickus) [1127366]
- [powerpc] scom: CONFIG_SCOM_DEBUGFS should depend on CONFIG_DEBUG_FS (Don Zickus) [1127366]
- [powerpc] powernv: Add scom support under OPALv3 (Don Zickus) [1127366]
- [powerpc] scom: Create debugfs files using ibm, chip-id if available (Don Zickus) [1127366]
- [powerpc] scom: Add support for "reg" property (Don Zickus) [1127366]
- [powerpc] scom: Change scom_read() and scom_write() to return errors (Don Zickus) [1127366]
- [powerpc] Enable /dev/port when isa_io_special is set (Don Zickus) [1127366]
- [powerpc] Make ftrace endian-safe (Don Zickus) [1127366]
- [powerpc] pseries: Implement arch_get_random_long() based on H_RANDOM (Don Zickus) [1127366]
- [powerpc] Implement arch_get_random_long/int() for powernv (Don Zickus) [1127366]
- [powerpc] Added __cmpdi2 for signed 64bit comparision (Don Zickus) [1127366]
- [powerpc] Fix section mismatch warning in free_lppacas (Don Zickus) [1127366]
- [powerpc] ppc64: Remove the unneeded load of ti_flags in resume_kernel (Don Zickus) [1127366]
- [powerpc] legacy_serial: Fix incorrect placement of __initdata tag (Don Zickus) [1127366]
- [serial] tty/hvc_opal: powerpc - Make OPAL HVC device tree accesses endian safe (Don Zickus) [1127366]
- [powerpc] powernv: Fix some PCI sparse errors and one LE bug (Don Zickus) [1127366]
- [powerpc] add explicit OF includes (Don Zickus) [1127366]
- [powerpc] clean-up include ordering in prom.h (Don Zickus) [1127366]
- [powerpc] Tell about irq stack coverage (Don Zickus) [1127366]
- [powerpc] Fix section mismatch warning for prom_rtas_call (Don Zickus) [1127366]
- [powerpc] Export cpu_to_chip_id() to fix build error (Don Zickus) [1127366]
- [powerpc] xmon: Fix printing of set of CPUs in xmon (Don Zickus) [1127366]
- [powerpc] pseries: Move lparcfg.c to platforms/pseries (Don Zickus) [1127366]
- [powerpc] powernv: Return secondary CPUs to firmware on kexec (Don Zickus) [1127366]
- [powerpc] Cleanup handling of the DSCR bit in the FSCR register (Don Zickus) [1127366]
- [powerpc] Skip emulating & leave interrupts off for kernel program checks (Don Zickus) [1127366]
- [powerpc] Add more exception trampolines for hypervisor exceptions (Don Zickus) [1127366]
- [powerpc] Fix location and rename exception trampolines (Don Zickus) [1127366]
- [powerpc] Add more trap names to xmon (Don Zickus) [1127366]
- [powerpc] pseries: Add a warning in the case of cross-cpu VPA registration (Don Zickus) [1127366]
- [powerpc] Update the 00-Index in Documentation/powerpc (Don Zickus) [1127366]
- [powerpc] Never handle VSX alignment exceptions from kernel (Don Zickus) [1127366]
- [powerpc] Unaligned stores and stmw are broken in emulation code (Don Zickus) [1127366]
- [powerpc] kvm: Copy the pvr value after memset (Don Zickus) [1127366]
- [powerpc] refactor of_get_cpu_node to support other architectures (Don Zickus) [1127366]
- [powerpc] Convert some mftb/mftbu into mfspr (Don Zickus) [1127366]
- [powerpc] pseries: Read and write to the 'compressed' flag of pstore (Don Zickus) [1127366]
- [powerpc] pseries: Remove (de)compression in nvram with pstore enabled (Don Zickus) [1127366]
- [powerpc] Make device tree accesses in HVC VIO console endian safe (Don Zickus) [1127366]
- [powerpc] Make chip-id information available to userspace (Don Zickus) [1127366]
- [powerpc] Use ibm, chip-id property to compute cpu_core_mask if available (Don Zickus) [1127366]
- [powerpc] Pull out cpu_core_mask updates into a separate function (Don Zickus) [1127366]
- [powerpc] Fix denormalized exception handler (Don Zickus) [1127366]
- [powerpc] Remove the redundant flush_fp_to_thread() in setup_sigcontext() (Don Zickus) [1127366]
- [powerpc] powernv: Enable detection of legacy UARTs (Don Zickus) [1127366]
- [powerpc] Check "status" property before adding legacy ISA serial ports (Don Zickus) [1127366]
- [powerpc] Cleanup udbg_16550 and add support for LPC PIO-only UARTs (Don Zickus) [1127366]
- [powerpc] powernv: Add PIO accessors for Power8 LPC bus (Don Zickus) [1127366]
- [powerpc] powernv: Add helper to get ibm, chip-id of a node (Don Zickus) [1127366]
- [powerpc] powernv: Update opal.h to add new LPC and XSCOM functions (Don Zickus) [1127366]
- [powerpc] Better split CONFIG_PPC_INDIRECT_PIO and CONFIG_PPC_INDIRECT_MMIO (Don Zickus) [1127366]
- [powerpc] ppc64: Rename SOFT_DISABLE_INTS with RECONCILE_IRQ_STATE (Don Zickus) [1127366]
- [powerpc] Implement __get_user_pages_fast() (Don Zickus) [1127366]
- [powerpc] Convert platforms to smp_generic_cpu_bootable (Don Zickus) [1127366]
- [powerpc] Add smp_generic_cpu_bootable (Don Zickus) [1127366]
- [powerpc] Remove the symbol __flush_icache_range (Don Zickus) [1127366]
- [powerpc] Move the testing of CPU_FTR_COHERENT_ICACHE into __flush_icache_range (Don Zickus) [1127366]
- [powerpc] pci: Don't use bitfield for force_32bit_msi (Don Zickus) [1127366]
- [powerpc] Remove SAVE_VSRU and REST_VSRU macros (Don Zickus) [1127366]
- [powerpc] Align p_toc (Don Zickus) [1127366]
- [powerpc] kvm/book3s_pr: Return appropriate error when allocation fails (Don Zickus) [1127366]
- [virt] kvm/ppc: Add signed type cast for comparation (Don Zickus) [1127366]
- [powerpc] eeh: Add missing procfs entry for PowerNV (Don Zickus) [1127366]
- [powerpc] pci: fix PCI-e check link issue (Don Zickus) [1127366]
- [powerpc] perf: increase the perf HW events to 6 (Don Zickus) [1127366]
- [powerpc] perf: correct typos in counter enumeration (Don Zickus) [1127366]
- [powerpc] Rename PMU interrupts from CNT to PMI (Don Zickus) [1127366]
- [powerpc] Move opcode definitions from kvm/emulate.c to asm/ppc-opcode.h (Don Zickus) [1127366]
- [powerpc] powernv: Mark pnv_pci_init_ioda2_phb() as __init (Don Zickus) [1127366]
- [powerpc] pseries: Fix a typo in pSeries_lpar_hpte_insert() (Don Zickus) [1127366]
- [powerpc] Fix the corrupt r3 error during MCE handling (Don Zickus) [1127366]
- [powerpc] Access local paca after hard irq disabled (Don Zickus) [1127366]
- [powerpc] Revert: hw_breakpoints: Fix racy access to ptrace breakpoints (Don Zickus) [1127366]
- [powerpc] kvm: Use 256K chunk to track both RMA and hash page table allocation (Don Zickus) [1127366]
- [powerpc] kvm: Contiguous memory allocator based RMA allocation (Don Zickus) [1127366]
- [powerpc] kvm: Contiguous memory allocator based hash page table allocation (Don Zickus) [1127366]
- [powerpc] Remove savemaxmem parameter setup (Don Zickus) [1127366]
- [powerpc] Handle both new style and old style reserve maps (Don Zickus) [1127366]
- [powerpc] prom: Scan reserved-ranges node for memory reservations (Don Zickus) [1127366]
- [powerpc] perf: Drop MMCRA from thread_struct (Don Zickus) [1127366]
- [powerpc] Remove unreachable relocation on exception handlers (Don Zickus) [1127366]
- [powerpc] eeh: Update MAINTAINERS (Don Zickus) [1127366]
- [powerpc] nvram64: Need return the related error code on failure occurs (Don Zickus) [1127366]
- [powerpc] Set cpu sibling mask before online cpu (Don Zickus) [1127366]
- [powerpc] idle: Convert use of typedef ctl_table to struct ctl_table (Don Zickus) [1127366]
- [powerpc] iommu: Remove unused pci_iommu_init() and pci_direct_iommu_init() (Don Zickus) [1127366]
- [powerpc] Don't flush/invalidate the d/icache for an unknown relocation type (Don Zickus) [1127366]
- [powerpc] Fix string instr. emulation for 32-bit processes on ppc64 (Don Zickus) [1127366]
- [powerpc] Fix typo in ioei_interrupt() description (Don Zickus) [1127366]
- [powerpc] proc: switch to fixed_size_llseek() (Don Zickus) [1127366]
- [powerpc] eeh: Remove eeh_mutex (Don Zickus) [1127366]
- [powerpc] pseries: Enable PSTORE in pseries_defconfig (Don Zickus) [1127366]
- [powerpc] pseries: Use 'true' instead of '1' for orderly_poweroff (Don Zickus) [1127366]
- [powerpc] smp: Use '==' instead of '<' for system_state (Don Zickus) [1127366]
- [cpufreq] Various RHEL cleanups (Prarit Bhargava) [1134369]
- [cpufreq] move policy kobj to update_policy_cpu() (Prarit Bhargava) [1134369]
- [cpufreq] propagate error returned by kobject_move() (Prarit Bhargava) [1134369]
- [cpufreq] don't restore policy->cpus on failure to move kobj (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove core_pct rounding (Prarit Bhargava) [1134369]
- [cpufreq] ondemand: Eliminate the deadband effect (Prarit Bhargava) [1134369]
- [cpufreq] Introduce new relation for freq selection (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Simplify P state adjustment logic (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Align multiple lines to open parenthesis (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Keep values in aperf/mperf in full precision (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove unnecessary intermediate variable sample_time (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Add missing blank lines after declarations (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Disable interrupts during MSRs reading (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Fit code in a single line where possible (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Cleanup parentheses (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove unnecessary type casting in div_s64() call (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Make intel_pstate_kobject and debugfs_parent locals (Prarit Bhargava) [1134369]
- [cpufreq] move policy kobj to policy->cpu at resume (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Set CPU number before accessing MSRs (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: don't touch turbo bit if turbo disabled or unavailable (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Fix setting VID (Prarit Bhargava) [1134369]
- [cpufreq] unlock when failing cpufreq_update_policy() (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Correct rounding in busy calculation (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Correct rounding in busy calculation (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove duplicate CPU ID check (Prarit Bhargava) [1134369]
- [cpufreq] governor: remove copy_prev_load from 'struct cpu_dbs_common_info' (Prarit Bhargava) [1134369]
- [cpufreq] governor: Be friendly towards latency-sensitive bursty workloads (Prarit Bhargava) [1134369]
- [cpufreq] add support for intermediate (stable) frequencies (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Improve initial busy calculation (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: add sample time scaling (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove C0 tracking (Prarit Bhargava) [1134369]
- [cpufreq] handle calls to ->target_index() in separate routine (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove unused member name of cpudata (Prarit Bhargava) [1134369]
- [cpufreq] Break out early when frequency equals target_freq (Prarit Bhargava) [1134369]
- [cpufreq] remove race while accessing cur_policy (Prarit Bhargava) [1134369]
- [cpufreq] powernow-k8: Suppress checkpatch warnings (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: remove setting P state to MAX on init (Prarit Bhargava) [1134369]
- [cpufreq] Use cpufreq_for_each_* macros for frequency table iteration (Prarit Bhargava) [1134369]
- [cpufreq] don't print value of .driver_data from core (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Set turbo VID for BayTrail (Prarit Bhargava) [1134369]
- [cpufreq] Fix build error on some platforms that use cpufreq_for_each_* (Prarit Bhargava) [1134369]
- [cpufreq] Catch double invocations of cpufreq_freq_transition_begin/end (Prarit Bhargava) [1134369]
- [cpufreq] Kconfig: Fix spelling errors (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove sample parameter in intel_pstate_calc_busy (Prarit Bhargava) [1134369]
- [cpufreq] Introduce macros for cpufreq_frequency_table iteration (Prarit Bhargava) [1134369]
- [cpufreq] use kzalloc() to allocate memory for cpufreq_frequency_table (Prarit Bhargava) [1134369]
- [cpufreq] create another field .flags in cpufreq_frequency_table (Prarit Bhargava) [1134369]
- [cpufreq] Use sizeof(*ptr) convetion for computing sizes (Prarit Bhargava) [1134369]
- [cpufreq] Convert existing drivers to use cpufreq_freq_transition_{begin|end} (Prarit Bhargava) [1134369]
- [cpufreq] Make cpufreq_notify_transition & cpufreq_notify_post_transition static (Prarit Bhargava) [1134369]
- [cpufreq] Make sure frequency transitions are serialized (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Use del_timer_sync in intel_pstate_cpu_stop (Prarit Bhargava) [1134369]
- [cpufreq] resume drivers before enabling governors (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Set core to min P state during core offline (Prarit Bhargava) [1134369]
- [cpufreq] Add stop CPU callback to cpufreq_driver interface (Prarit Bhargava) [1134369]
- [cpufreq] Remove unnecessary braces (Prarit Bhargava) [1134369]
- [cpufreq] Fix checkpatch errors and warnings (Prarit Bhargava) [1134369]
- [cpufreq] remove unused notifier CPUFREQ_{SUSPENDCHANGE|RESUMECHANGE} (Prarit Bhargava) [1134369]
- [cpufreq] Do not allow ->setpolicy drivers to provide ->target (Prarit Bhargava) [1134369]
- [cpufreq] Skip current frequency initialization for ->setpolicy drivers (Prarit Bhargava) [1134369]
- [cpufreq] Remove unnecessary variable/parameter 'frozen' (Prarit Bhargava) [1134369]
- [cpufreq] Remove cpufreq_generic_exit() (Prarit Bhargava) [1134369]
- [cpufreq] add 'freq_table' in struct cpufreq_policy (Prarit Bhargava) [1134369]
- [cpufreq] Reformat printk() statements (Prarit Bhargava) [1134369]
- [cpufreq] Implement cpufreq_generic_suspend() (Prarit Bhargava) [1134369]
- [cpufreq] suspend governors on system suspend/hibernate (Prarit Bhargava) [1134369]
- [cpufreq] move call to __find_governor() to cpufreq_init_policy() (Prarit Bhargava) [1134369]
- [cpufreq] Initialize governor for a new policy under policy->rwsem (Prarit Bhargava) [1134369]
- [cpufreq] Initialize policy before making it available for others to use (Prarit Bhargava) [1134369]
- [cpufreq] use cpufreq_cpu_get() to avoid cpufreq_get() race conditions (Prarit Bhargava) [1134369]
- [cpufreq] stats: Remove redundant cpufreq_cpu_get() call (Prarit Bhargava) [1134369]
- [cpufreq] stats: Refactor common code into __cpufreq_stats_create_table() (Prarit Bhargava) [1134369]
- [cpufreq] stats: Fix error handling in __cpufreq_stats_create_table() (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: fix pid_reset to use fixed point values (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: remove unneeded sample buffers (Prarit Bhargava) [1134369]
- [cpufreq] Return error if ->get() failed in cpufreq_update_policy() (Prarit Bhargava) [1134369]
- [cpufreq] Mark function as static in cpufreq.c (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Change busy calculation to use fixed point math (Prarit Bhargava) [1134369]
- [cpufreq] Refactor cpufreq_set_policy() (Prarit Bhargava) [1134369]
- [cpufreq] don't call cpufreq_update_policy() on CPU addition (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Add support for Baytrail turbo P states (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Use LFM bus ratio as min ratio/P state (Prarit Bhargava) [1134369]
- [cpufreq] powernow-k8: Initialize per-cpu data-structures properly (Prarit Bhargava) [1134369]
- [cpufreq] remove sysfs link when a cpu != policy->cpu, is removed (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove energy reporting from pstate_sample tracepoint (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Take core C0 time into account for core busy calculation (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: De-register CPU notifier and free struct msr on error (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: Adjust the code to use the common boost attribute (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Add trace point to report internal state (Prarit Bhargava) [1134369]
- [cpufreq] stats: create sysfs entries when cpufreq_stats is a module (Prarit Bhargava) [1134369]
- [cpufreq] Add boost frequency support in core (Prarit Bhargava) [1134369]
- [cpufreq] introduce cpufreq_generic_get() routine (Prarit Bhargava) [1134369]
- [cpufreq] stats: free table and remove sysfs entry in a single routine (Prarit Bhargava) [1134369]
- [cpufreq] stats: remove hotplug notifiers (Prarit Bhargava) [1134369]
- [cpufreq] stats: handle cpufreq_unregister_driver() and suspend/resume properly (Prarit Bhargava) [1134369]
- [cpufreq] Make sure CPU is running on a freq from freq-table (Prarit Bhargava) [1134369]
- [cpufreq] Introduce cpufreq_notify_post_transition() (Prarit Bhargava) [1134369]
- [cpufreq] send new set of notification for transition failures (Prarit Bhargava) [1134369]
- [cpufreq] Fix timer/workqueue corruption by protecting reading governor_enabled (Prarit Bhargava) [1134369]
- [cpufreq] preserve user_policy across suspend/resume (Prarit Bhargava) [1134369]
- [cpufreq] Clean up after a failing light-weight initialization (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Remove periodic P state boost (Prarit Bhargava) [1134369]
- [cpufreq] intel_pstate: Add setting voltage value for baytrail P states (Prarit Bhargava) [1134369]
- [cpufreq] remove sysfs files for CPUs which failed to come back after resume (Prarit Bhargava) [1134369]
- [cpufreq] governor: Remove fossil comment in the cpufreq_governor_dbs() (Prarit Bhargava) [1134369]
- [cpufreq] conservative: set requested_freq to policy max when it is over policy max (Prarit Bhargava) [1134369]
- [cpufreq] conservative: fix requested_freq reduction issue (Prarit Bhargava) [1134369]
- [cpufreq] move freq change notifications to cpufreq core (Prarit Bhargava) [1134369]
- [cpufreq] distinguish drivers that do asynchronous notifications (Prarit Bhargava) [1134369]
- [cpufreq] create per policy rwsem instead of per CPU cpu_policy_rwsem (Prarit Bhargava) [1134369]
- [cpufreq] Implement light weight ->target_index() routine (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: Fail initialization if driver cannot be registered (Prarit Bhargava) [1134369]
- [cpufreq] Detect spurious invocations of update_policy_cpu() (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: Add comment under ACPI_ADR_SPACE_SYSTEM_IO case (Prarit Bhargava) [1134369]
- [cpufreq] remove CONFIG_CPU_FREQ_TABLE (Prarit Bhargava) [1134369]
- [cpufreq] create cpufreq_generic_init() routine (Prarit Bhargava) [1134369]
- [cpufreq] powernow: don't initialize part of policy set by core (Prarit Bhargava) [1134369]
- [cpufreq] p4: don't initialize part of policy set by core (Prarit Bhargava) [1134369]
- [cpufreq] pcc: don't initialize part of policy set by core (Prarit Bhargava) [1134369]
- [cpufreq] call cpufreq_driver->get() after calling ->init() (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: don't initialize part of policy set by core (Prarit Bhargava) [1134369]
- [cpufreq] powernow: Use generic cpufreq routines (Prarit Bhargava) [1134369]
- [cpufreq] p4-clockmod: Use generic cpufreq routines (Prarit Bhargava) [1134369]
- [cpufreq] acpi: Use generic cpufreq routines (Prarit Bhargava) [1134369]
- [cpufreq] define generic .attr, .exit() and .verify() routines (Prarit Bhargava) [1134369]
- [cpufreq] use cpufreq_driver->flags to mark CPUFREQ_HAVE_GOVERNOR_PER_POLICY (Prarit Bhargava) [1134369]
- [cpufreq] rename __cpufreq_set_policy() as cpufreq_set_policy() (Prarit Bhargava) [1134369]
- [cpufreq] Remove extra blank line (Prarit Bhargava) [1134369]
- [cpufreq] don't break string in print statements (Prarit Bhargava) [1134369]
- [cpufreq] remove __cpufreq_remove_dev() (Prarit Bhargava) [1134369]
- [cpufreq] remove invalid comment from __cpufreq_remove_dev() (Prarit Bhargava) [1134369]
- [cpufreq] make return type of lock_policy_rwsem_{read|write}() as void (Prarit Bhargava) [1134369]
- [cpufreq] powernow: use cpufreq_table_validate_and_show() (Prarit Bhargava) [1134369]
- [cpufreq] p4-clockmod: use cpufreq_table_validate_and_show() (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: use cpufreq_table_validate_and_show() (Prarit Bhargava) [1134369]
- [cpufreq] Add new helper cpufreq_table_validate_and_show() (Prarit Bhargava) [1134369]
- [cpufreq] pcc_freq: convert acpi_get_handle() to acpi_has_method() (Prarit Bhargava) [1134369]
- [cpufreq] return EEXIST instead of EBUSY for second registering (Prarit Bhargava) [1134369]
- [cpufreq] unlock correct rwsem while updating policy->cpu (Prarit Bhargava) [1134369]
- [cpufreq] Clear policy->cpus bits in __cpufreq_remove_dev_finish() (Prarit Bhargava) [1134369]
- [cpufreq] Acquire the lock in cpufreq_policy_restore() for reading (Prarit Bhargava) [1134369]
- [cpufreq] Prevent problems in update_policy_cpu() if last_cpu == new_cpu (Prarit Bhargava) [1134369]
- [cpufreq] Restructure if/else block to avoid unintended behavior (Prarit Bhargava) [1134369]
- [cpufreq] Fix crash in cpufreq-stats during suspend/resume (Prarit Bhargava) [1134369]
- [cpufreq] Revert: make sure frequency transitions are serialized (Prarit Bhargava) [1134369]
- [cpufreq] Use signed type for 'ret' variable, to store negative error values (Prarit Bhargava) [1134369]
- [cpufreq] Remove temporary fix for race between CPU hotplug and sysfs-writes (Prarit Bhargava) [1134369]
- [cpufreq] Synchronize the cpufreq store_*() routines with CPU hotplug (Prarit Bhargava) [1134369]
- [cpufreq] Invoke __cpufreq_remove_dev_finish() after releasing cpu_hotplug.lock (Prarit Bhargava) [1134369]
- [cpufreq] Split __cpufreq_remove_dev() into two parts (Prarit Bhargava) [1134369]
- [cpufreq] Fix wrong time unit conversion (Prarit Bhargava) [1134369]
- [cpufreq] serialize calls to __cpufreq_governor() (Prarit Bhargava) [1134369]
- [cpufreq] don't allow governor limits to be changed when it is disabled (Prarit Bhargava) [1134369]
- [cpufreq] Don't use smp_processor_id() in preemptible context (Prarit Bhargava) [1134369]
- [cpufreq] governor: Fix typos in comments (Prarit Bhargava) [1134369]
- [cpufreq] governors: Remove duplicate check of target freq in supported range (Prarit Bhargava) [1134369]
- [cpufreq] Fix timer/workqueue corruption due to double queueing (Prarit Bhargava) [1134369]
- [cpufreq] fix bad unlock balance on !CONFIG_SMP (Prarit Bhargava) [1134369]
- [cpufreq] Fix white space in __cpufreq_remove_dev() (Prarit Bhargava) [1134369]
- [cpufreq] remove unnecessary check in __cpufreq_governor() (Prarit Bhargava) [1134369]
- [cpufreq] remove policy from cpufreq_policy_list during suspend (Prarit Bhargava) [1134369]
- [cpufreq] remove cpufreq_policy_cpu per-cpu variable (Prarit Bhargava) [1134369]
- [cpufreq] Use cpufreq_policy_list for iterating over policies (Prarit Bhargava) [1134369]
- [cpufreq] acpi-cpufreq: Use cpufreq_freq_attr_rw to define the cpb attribute (Prarit Bhargava) [1134369]
- [cpufreq] ondemand: Remove redundant return statement (Prarit Bhargava) [1134369]
- [cpufreq] improve error checking on return values of __cpufreq_governor() (Prarit Bhargava) [1134369]
- [cpufreq] Fix broken usage of governor->owner's refcount (Prarit Bhargava) [1134369]
- [cpufreq] Store cpufreq policies in a list (Prarit Bhargava) [1134369]
- [cpufreq] Give consistent names to cpufreq_policy objects (Prarit Bhargava) [1134369]
- [cpufreq] Clean up header files included in the core (Prarit Bhargava) [1134369]
- [cpufreq] Pass policy to cpufreq_add_policy_cpu() (Prarit Bhargava) [1134369]
- [cpufreq] Avoid double kobject_put() for the same kobject in error code path (Prarit Bhargava) [1134369]
- [cpufreq] Preserve policy structure across suspend/resume (Prarit Bhargava) [1134369]
- [cpufreq] Perform light-weight init/teardown during suspend/resume (Prarit Bhargava) [1134369]
- [cpufreq] Do not hold driver module references for additional policy CPUs (Prarit Bhargava) [1134369]
- [cpufreq] Don't pass CPU to cpufreq_add_dev_{symlink|interface}() (Prarit Bhargava) [1134369]
- [cpufreq] Introduce a flag ('frozen') to separate full vs temporary init/teardown (Prarit Bhargava) [1134369]
- [cpufreq] Extract the handover of policy cpu to a helper function (Prarit Bhargava) [1134369]
- [cpufreq] Add helper to perform alloc/free of policy structure (Prarit Bhargava) [1134369]
- [cpufreq] Extract non-interface related stuff from cpufreq_add_dev_interface (Prarit Bhargava) [1134369]
- [cpufreq] Fix misplaced call to cpufreq_update_policy() (Prarit Bhargava) [1134369]
- [cpufreq] Remove unused function __cpufreq_driver_getavg() (Prarit Bhargava) [1134369]
- [cpufreq] ondemand: Change the calculation of target frequency (Prarit Bhargava) [1134369]
- [cpufreq] Remove unused APERF/MPERF support (Prarit Bhargava) [1134369]
- [char] hwrng: Add a driver for the hwrng found in power7+ systems (Steve Best) [1123116]

* Tue Sep 16 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-161.el7]
- [target] iscsi: Explicily clear login response PDU in exception path (Andy Grover) [1129387]
- [target] iscsi: Avoid rejecting incorrect ITT for Data-Out (Andy Grover) [1129387]
- [target] Fix left-over se_lun->lun_sep pointer OOPs (Andy Grover) [1129387]
- [infiniband] ulp/isert: Wait for proper cleanup before unloading (Andy Grover) [1129387]
- [infiniband] ulp/isert: Improve cm events handling (Andy Grover) [1129387]
- [target] Explicitly clear ramdisk_mcp backend pages (Andy Grover) [1129387]
- [target] Report correct response length for some commands (Andy Grover) [1129387]
- [target] iscsi: Fix ABORT_TASK + connection reset iscsi_queue_req memory leak (Andy Grover) [1129387]
- [target] Use complete_all for se_cmd->t_transport_stop_comp (Andy Grover) [1129387]
- [target] lio: Set CMD_T_ACTIVE bit for Task Management Requests (Andy Grover) [1129387]
- [target] iscsi, iser: Fix hangs in connection teardown (Andy Grover) [1129387]
- [infiniband] iser: Bail from accept_np if np_thread is trying to close (Andy Grover) [1129387]
- [target] iscsi: Reject mutual authentication with reflected CHAP_C (Andy Grover) [1129387]
- [target] Fix alua_access_state attribute OOPs for un-configured devices (Andy Grover) [1129387]
- [infiniband] iser: Add missing target_put_sess_cmd for ImmedateData failure (Andy Grover) [1129387]
- [target] Don't allow setting WC emulation if device doesn't support (Andy Grover) [1129387]
- [infiniband] iser: Add missing se_cmd put for WRITE_PENDING in tx_comp_err (Andy Grover) [1129387]
- [target] iscsi: Fix ERL=2 ASYNC_EVENT connection pointer bug (Andy Grover) [1129387]
- [infiniband] ib_srpt: Use correct ib_sg_dma primitives (Andy Grover) [1129387]
- [infiniband] iser: Fix post_send_buf_count for RDMA READ/WRITE (Andy Grover) [1129387]
- [target] iscsi, iser: Fix isert_conn->state hung shutdown issues (Andy Grover) [1129387]
- [target] iscsi, iser:  Use list_del_init for ->i_conn_node (Andy Grover) [1129387]
- [target] iscsi: Fix iscsit_get_tpg_from_np tpg_state bug (Andy Grover) [1129387]
- [target] Update hw_max_sectors based on current block_size (Andy Grover) [1129387]
- [target] iscsi: Fix-up all zero data-length CDBs with R/W_BIT set (Andy Grover) [1129387]
- [target] Allow READ_CAPACITY opcode in ALUA Standby access state (Andy Grover) [1129387]
- [target] iscsi: Fix wrong buffer / buffer overrun in iscsi_change_param_value() (Andy Grover) [1129387]
- [target] iscsi: Fix multi network portal shutdown regression (Andy Grover) [1129387]
- [target] iscsi, iser: Avoid accepting transport connections during stop stage (Andy Grover) [1129387]
- [infiniband] ulp/isert: Fix iscsit_accept_np and rdma_cm racy flow (Andy Grover) [1129387]
- [infiniband] ulp/isert: Fix wrong connection requests list addition (Andy Grover) [1129387]
- [scsi] hpsa: do not require board "not ready" status after hard reset (Tomas Henzl) [1069185]
- [scsi] hpsa: make tech preview info more verbose (Tomas Henzl) [1083556]
- [scsi] hpsa: fix bad -ENOMEM return value in hpsa_big_passthru_ioctl (Tomas Henzl) [1069185]
- [scsi] hpsa: remove online devices from offline device list (Tomas Henzl) [1069185]
- [scsi] hpsa: fix non-x86 builds (Tomas Henzl) [1069185]
- [scsi] hpsa: do not unconditionally copy sense data (Tomas Henzl) [1069185]
- [scsi] hpsa: fix 6-byte READ/WRITE with 0 length data xfer (Tomas Henzl) [1069185]
- [scsi] hpsa: make hpsa_init_one return -ENOMEM if allocation of h->lockup_detected fails (Tomas Henzl) [1069185]
- [scsi] hpsa: fix handling of hpsa_volume_offline return value (Tomas Henzl) [1069185]
- [scsi] hpsa: return -ENOMEM not -1 on kzalloc failure in hpsa_get_device_id (Tomas Henzl) [1069185]
- [scsi] hpsa: remove messages about volume status VPD inquiry page not supported (Tomas Henzl) [1069185]
- [scsi] hpsa: report check condition even if no sense data present for ioaccel2 mode (Tomas Henzl) [1069185]
- [scsi] hpsa: remove bad unlikely annotation from device list updating code (Tomas Henzl) [1069185]
- [scsi] hpsa: fix event filtering to prevent excessive rescans with old firmware (Tomas Henzl) [1069185]
- [scsi] hpsa: kill annoying messages about SSD Smart Path retries (Tomas Henzl) [1069185]
- [scsi] hpsa: define extended_report_lun_entry data structure (Tomas Henzl) [1069185]
- [scsi] hpsa: Rearrange start_io to avoid one unlock/lock sequence in main io path (Tomas Henzl) [1069185]
- [scsi] hpsa: avoid unnecessary readl on every command submission (Tomas Henzl) [1069185]
- [scsi] hpsa: use per-cpu variable for lockup_detected (Tomas Henzl) [1069185]
- [scsi] hpsa: remove unnecessary pci_set_drvdata() (Tomas Henzl) [1069185]
- [scsi] hpsa: set irq affinity hints to route MSI-X vectors across CPUs (Tomas Henzl) [1069185]
- [scsi] hpsa: allocate reply queues individually (Tomas Henzl) [1069185]
- [scsi] hpsa: choose number of reply queues more intelligently (Tomas Henzl) [1069185]
- [scsi] hpsa: remove dev_dbg() calls from hot paths (Tomas Henzl) [1069185]
- [scsi] hpsa: use gcc aligned attribute instead of manually padding structs (Tomas Henzl) [1069185]
- [scsi] hpsa: change doorbell reset delay to ten seconds (Tomas Henzl) [1069185]
- [scsi] hpsa: allow passthru ioctls to work with bidirectional commands (Tomas Henzl) [1069185]
- [scsi] hpsa: remove unused fields from struct ctlr_info (Tomas Henzl) [1069185]
- [scsi] hpsa: fix bad comparison of signed with unsigned in hpsa_update_scsi_devices (Tomas Henzl) [1069185]
- [scsi] hpsa: do not ignore failure of sense controller parameters command (Tomas Henzl) [1069185]
- [scsi] hpsa: fix memory leak in hpsa_hba_mode_enabled (Tomas Henzl) [1069185]
- [scsi] hpsa: Checking for a NULL return from a kzalloc call (Tomas Henzl) [1069185]
- [scsi] hpsa: fix NULL dereference in hpsa_put_ctlr_into_performant_mode() (Tomas Henzl) [1069185]
- [scsi] hpsa: update driver version to 3.4.4-1 (Tomas Henzl) [1069185]
- [scsi] hpsa: fix bad endif placement in RAID 5 mapper code (Tomas Henzl) [1069185]
- [scsi] hpsa: Do not zero fields of ioaccel2 command structure twice (Tomas Henzl) [1069185]
- [scsi] hpsa: Add hba mode to the hpsa driver (Tomas Henzl) [1069185]
- [scsi] hpsa: remove unused struct request from CommandList (Tomas Henzl) [1069185]
- [scsi] hpsa: increase the probability of a reported success after a device reset (Tomas Henzl) [1069185]
- [scsi] hpsa: bring format-in-progress drives online when ready (Tomas Henzl) [1069185]
- [scsi] hpsa: remove unused kthread.h header (Tomas Henzl) [1069185]
- [scsi] hpsa: Add support for a few HP Storage controllers (Tomas Henzl) [1069185]
- [scsi] hpsa: add HP/3PAR vendor id to pci_ids.h (Tomas Henzl) [1069185]
- [scsi] hpsa: add sysfs debug switch for raid map debugging messages (Tomas Henzl) [1069185]
- [scsi] hpsa: improve error messages for driver initiated commands (Tomas Henzl) [1069185]
- [scsi] hpsa: only do device rescan for certain events (Tomas Henzl) [1069185]
- [scsi] hpsa: when switching out of accel mode await only accel command completions (Tomas Henzl) [1069185]
- [scsi] hpsa: add controller base data-at-rest encryption compatibility ioaccel2 (Tomas Henzl) [1069185]
- [scsi] hpsa: update source file copyrights (Tomas Henzl) [1069185]
- [scsi] hpsa: retry certain ioaccel error cases on the RAID path (Tomas Henzl) [1069185]
- [scsi] hpsa: do not inquire for unsupported ioaccel status vpd page (Tomas Henzl) [1069185]
- [scsi] hpsa: allow VPD page zero to be queried (Tomas Henzl) [1069185]
- [scsi] hpsa: rescan devices on ioaccel2 error (Tomas Henzl) [1069185]
- [scsi] hpsa: allow user to disable accelerated i/o path (Tomas Henzl) [1069185]
- [scsi] hpsa: complete the ioaccel raidmap code (Tomas Henzl) [1069185]
- [scsi] hpsa: make device update copy the raid map also (Tomas Henzl) [1069185]
- [scsi] hpsa: add task management for ioaccel mode 2 (Tomas Henzl) [1069185]
- [scsi] hpsa: teach hpsa_device_reset to do either target or lun reset (Tomas Henzl) [1069185]
- [scsi] hpsa: get ioaccel mode 2 i/o working (Tomas Henzl) [1069185]
- [scsi] hpsa: initialize controller to perform io accelerator mode 2 (Tomas Henzl) [1069185]
- [scsi] hpsa: get physical device handles for io accel mode 2 as well as mode 1 (Tomas Henzl) [1069185]
- [scsi] hpsa: do ioaccel mode 2 resource allocations (Tomas Henzl) [1069185]
- [scsi] hpsa: Acknowledge controller events in ioaccell mode 2 as well as mode 1 (Tomas Henzl) [1069185]
- [scsi] hpsa: add ioaccel mode 2 structure definitions (Tomas Henzl) [1069185]
- [scsi] hpsa: complain if physical or logical aborts are not supported (Tomas Henzl) [1069185]
- [scsi] hpsa: add hp_ssd_smart_path_enabled sysfs attribute (Tomas Henzl) [1069185]
- [scsi] hpsa: do not rescan controllers known to be locked up (Tomas Henzl) [1069185]
- [scsi] hpsa: poll controller to detect device change event (Tomas Henzl) [1069185]
- [scsi] hpsa: update raid offload status on device rescan (Tomas Henzl) [1069185]
- [scsi] hpsa: add ioaccell mode 1 RAID offload support (Tomas Henzl) [1069185]
- [scsi] hpsa: fix task management for mode-1 ioaccell path (Tomas Henzl) [1069185]
- [scsi] hpsa: only allow REQ_TYPE_FS to use fast path (Tomas Henzl) [1069185]
- [scsi] hpsa: add support for 'fastpath' i/o (Tomas Henzl) [1069185]
- [scsi] hpsa: mark last scatter gather element as the last (Tomas Henzl) [1069185]
- [scsi] hpsa: use extended report luns command for HP SSD SmartPath (Tomas Henzl) [1069185]
- [scsi] hpsa: fixup MSI-X registration (Tomas Henzl) [1069185]
- [scsi] hpsa: prevent stalled i/o (Tomas Henzl) [1069185]
- [scsi] hpsa: cap CCISS_PASSTHRU at 20 concurrent commands (Tomas Henzl) [1069185]
- [scsi] hpsa: add MSA 2040 to list of external target devices (Tomas Henzl) [1069185]
- [scsi] hpsa: fix memory leak in CCISS_BIG_PASSTHRU ioctl (Tomas Henzl) [1069185]
- [scsi] hpsa: remove unneeded include of seq_file.h (Tomas Henzl) [1069185]
- [scsi] hpsa: add 5 second delay after doorbell reset (Tomas Henzl) [1069185]
- [scsi] hpsa: do not attempt to flush the cache on locked up controllers (Tomas Henzl) [1069185]
- [scsi] bnx2i: Make boot_nic entry visible in the sysfs session objects (Maurizio Lombardi) [1139139]
- [scsi] bnx2fc: fix incorrect DMA memory mapping in bnx2fc_unmap_sg_list() (Maurizio Lombardi) [1102526]
- [ethernet] cnic: Replace rcu_dereference() with rcu_access_pointer() (Maurizio Lombardi) [1089401]
- [ethernet] cnic: Rebranding cnic driver (Maurizio Lombardi) [1089401]
- [ethernet] cnic: Fix missing ISCSI_KEVENT_IF_DOWN message (Maurizio Lombardi) [1089401]
- [ethernet] cnic: Update version to 2.5.20 and copyright year (Maurizio Lombardi) [1089401]
- [ethernet] cnic: Use proper ulp_ops for per device operations (Maurizio Lombardi) [1089401]
- [ethernet] broadcom: Remove extern from function prototypes (Maurizio Lombardi) [1089401]
- [scsi] bnx2i: Update driver version to 2.7.10.1 (Maurizio Lombardi) [1089400]
- [scsi] bnx2i: Rebranding bnx2i driver (Maurizio Lombardi) [1089400]
- [scsi] bnx2i, be2iscsi: fix custom stats length (Maurizio Lombardi) [1089400]
- [ethernet] cnic, bnx2i, bnx2fc: Fix inconsistent use of page size (Maurizio Lombardi) [1089400 1089399 1089401]
- [scsi] bnx2fc: Rebranding bnx2fc driver (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: do not scan uninitialized lists in case of error (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: fix memory leak in bnx2fc_allocate_hash_table() (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: fix memory leak and potential NULL pointer dereference (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: remove unused variable hash_table_size (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: Updated version to 2.4.2 (Maurizio Lombardi) [1089399]
- [scsi] bnx2fc: Fixed the handling for the SCSI retry delay (Maurizio Lombardi) [1089399]
- [scsi] be2iscsi: Bump driver version (Rob Evers) [1130072]
- [scsi] be2iscsi: Fix processing CQE before connection resources are freed (Rob Evers) [1130072]
- [scsi] be2iscsi: Fix updating the boot enteries in sysfs (Rob Evers) [1130072]
- [scsi] be2iscsi: Fix the copyright year (Rob Evers) [1130072]
- [scsi] be2iscsi: Fix the sparse warning introduced in previous submission (Rob Evers) [1130072]

* Mon Sep 15 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-160.el7]
- [x86] module: work around kabi module breakage when 16K stacks are enabled (Kyle McMartin) [1108378]
- [kernel] redhat: bump RHEL_MINOR to 1 (Kyle McMartin) [1108378]
- [kernel] modules: export check_module_rhelversion (Kyle McMartin) [1108378]
- [kernel] modules: Add module_ext struct (Prarit Bhargava) [1110315]
- [kernel] modules: add rhelversion MODULE_INFO tag (Kyle McMartin) [1110315]
- [x86] expand 64-bit kernel stack to 16K (Johannes Weiner) [1108378]

* Mon Sep 15 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-159.el7]
- [ethernet] bna: Support TSO and partial checksum with non-accelerated vlans (Ivan Vecera) [1136912]
- [ethernet] bna: Remove DEFINE_PCI_DEVICE_TABLE macro use (Ivan Vecera) [1136912]
- [ethernet] bna: fix performance regression (Ivan Vecera) [1136912]
- [ethernet] bna: fill the magic in bnad_get_eeprom() instead of validating (Ivan Vecera) [1136912]
- [ethernet] bna: remove unnecessary break after return (Ivan Vecera) [1136912]
- [ethernet] bna: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Ivan Vecera) [1136912]
- [ethernet] bna: get rid of SET_ETHTOOL_OPS (Ivan Vecera) [1136912]
- [ethernet] bna: remove open-coded skb_cow_head (Ivan Vecera) [1136912]
- [ethernet] bna: Call dev_kfree_skb_any instead of dev_kfree_skb (Ivan Vecera) [1136912]
- [ethernet] bna: Convert uses of __constant_<foo> to <foo> (Ivan Vecera) [1136912]
- [ethernet] bna: Replace large udelay() with mdelay() (Ivan Vecera) [1136912]
- [ethernet] bna: Use pci_enable_msix_range() instead of pci_enable_msix() (Ivan Vecera) [1136912]
- [ethernet] bna: bnad code cleanup (Ivan Vecera) [1136912]
- [ethernet] e1000: fix possible reset_task running after adapter down (John Greene) [1091129]
- [ethernet] e1000: prevent oops when adapter is being closed and reset simultaneously (John Greene) [1091129]
- [ethernet] r8169: add missing MODULE_FIRMWARE (Ivan Vecera) [1139247]
- [ethernet] r8169: add support for RTL8168H and RTL8107E (Ivan Vecera) [1139247]
- [ethernet] r8169: Remove DEFINE_PCI_DEVICE_TABLE macro use (Ivan Vecera) [1139247]
- [ethernet] r8169: Enable RX_MULTI_EN for RTL_GIGA_MAC_VER_40 (Ivan Vecera) [1139247]
- [ethernet] r8169: support IPv6 (Ivan Vecera) [1139247]
- [ethernet] r8169: use Giant Send (Ivan Vecera) [1139247]
- [ethernet] r8169: split rtl8169_tso_csum (Ivan Vecera) [1139247]
- [ethernet] r8169: disable L23 (Ivan Vecera) [1139247]
- [ethernet] r8169: get rid of SET_ETHTOOL_OPS (Ivan Vecera) [1139247]
- [ethernet] r8169: Call dev_kfree_skby_any instead of dev_kfree_skb (Ivan Vecera) [1139247]
- [ethernet] r8169: fix the incorrect tx descriptor version (Ivan Vecera) [1139247]
- [ethernet] r8169: initialize rtl8169_stats seqlock (Ivan Vecera) [1139247]
- [ethernet] r8169: delete non-required instances of include <linux/init.h> (Ivan Vecera) [1139247]
- [ethernet] bnx2: Remove DEFINE_PCI_DEVICE_TABLE macro use (Michal Schmidt) [1092495]
- [ethernet] bnx2: Rebranding bnx2 driver (Michal Schmidt) [1092495]
- [ethernet] bnx2: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Michal Schmidt) [1092495]
- [ethernet] bnx2: Don't build unused suspend/resume functions not enabled (Michal Schmidt) [1092495]
- [ethernet] bnx2: Don't receive packets when the napi budget == 0 (Michal Schmidt) [1092495]
- [ethernet] bnx2: Call dev_kfree_skby_any instead of dev_kfree_skb (Michal Schmidt) [1092495]
- [ethernet] bnx2: Use pci_enable_msix_range() instead of pci_enable_msix() (Michal Schmidt) [1092495]
- [ethernet] bnx2: delete non-required instances of include <linux/init.h> (Michal Schmidt) [1092495]
- [ethernet] ixgbevf: Remove unused get_supported_physical_layer pointer (John Greene) [1091124]
- [ethernet] ixgbevf: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (John Greene) [1091124]
- [ethernet] ixgbevf: get rid of SET_ETHTOOL_OPS (John Greene) [1091124]
- [ethernet] ixgbevf: remove 82599 from the module description (John Greene) [1091124]
- [ethernet] ixgbevf: remove open-coded skb_cow_head (John Greene) [1091124]
- [ethernet] ixgbevf: Add bit to mark work queue initialization (John Greene) [1091124]
- [ethernet] ixgbevf: Fix rcu warnings induced by LER (John Greene) [1091124]
- [ethernet] ixgbevf: Change ixgbe_read_reg to ixgbevf_read_reg (John Greene) [1091124]
- [ethernet] ixgbevf: Additional adapter removal checks (John Greene) [1091124]
- [ethernet] ixgbevf: Check for adapter removal on register writes (John Greene) [1091124]
- [ethernet] ixgbevf: Check register reads for adapter removal (John Greene) [1091124]
- [ethernet] ixgbevf: Make the ethtool register test use accessors (John Greene) [1091124]
- [ethernet] ixgbevf: Use static inlines instead of macros (John Greene) [1091124]
- [ethernet] ixgbevf: Convert uses of __constant_<foo> to <foo> (John Greene) [1091124]
- [ethernet] ixgbevf: Protect ixgbevf_down with __IXGBEVF_DOWN bit (John Greene) [1091124]
- [ethernet] ixgbevf: Indicate removal state explicitly (John Greene) [1091124]
- [ethernet] ixgbevf: delete unneeded call to pci_set_power_state (John Greene) [1091124]
- [ethernet] ixgbevf: fix skb->pkt_type checks (John Greene) [1091124]
- [ethernet] ixgbevf: add check for CHECKSUM_PARTIAL when doing TSO (John Greene) [1091124]
- [ethernet] ixgbevf: fix handling of tx checksumming (John Greene) [1091124]
- [ethernet] ixgbevf: Use pci_enable_msix_range() instead of pci_enable_msix() (John Greene) [1091124]
- [ethernet] ixgbevf: merge ixgbevf_tx_map and ixgbevf_tx_queue into a single function (John Greene) [1091124]
- [ethernet] ixgbevf: redo dma mapping using the tx buffer info (John Greene) [1091124]
- [ethernet] ixgbevf: make the first tx_buffer a repository for most of the skb info (John Greene) [1091124]
- [ethernet] ixgbevf: add tx counters (John Greene) [1091124]
- [ethernet] ixgbevf: remove counters for Tx/Rx checksum offload (John Greene) [1091124]
- [ethernet] ixgbevf: move ring specific stats into ring specific structure (John Greene) [1091124]
- [ethernet] ixgbevf: make use of the dev pointer in the ixgbevf_ring struct (John Greene) [1091124]
- [ethernet] ixgbevf: bump version (John Greene) [1091124]
- [ethernet] ixgbevf: create function for all of ring init (John Greene) [1091124]
- [ethernet] ixgbevf: Convert ring storage form pointer to an array to array of pointers (John Greene) [1091124]
- [ethernet] ixgbevf: use pci drvdata correctly in ixgbevf_suspend() (John Greene) [1091124]
- [ethernet] ixgbevf: set the disable state when ixgbevf_qv_disable is called (John Greene) [1091124]
- [ethernet] ixgbevf: add DCB configuration into queue setup (John Greene) [1091124]
- [ethernet] ixgbe: Focus config of head, tail ntc, and ntu all into a single function (John Greene) [1091124]
- [ethernet] ixgbe: cleanup IXGBE_DESC_UNUSED (John Greene) [1091124]
- [ethernet] ixgbevf: remove redundant workaround (John Greene) [1091124]
- [ethernet] ixgbevf: Add zero_base handler to network statistics (John Greene) [1091124]
- [ethernet] ixgbevf: add BP_EXTENDED_STATS for CONFIG_NET_RX_BUSY_POLL (John Greene) [1091124]
- [ethernet] ixgbevf: implement CONFIG_NET_RX_BUSY_POLL (John Greene) [1091124]
- [ethernet] ixgbevf: have clean_rx_irq return total_rx_packets cleaned (John Greene) [1091124]
- [ethernet] ixgbevf: add ixgbevf_rx_skb (John Greene) [1091124]
- [ethernet] ixgbevf: bump driver version (John Greene) [1091124]
- [ethernet] ixgbevf: Remove extern from function prototypes (John Greene) [1091124]
- [ethernet] ixgbevf: Adds function to set PSRTYPE register (John Greene) [1091124]
- [ethernet] ixgbevf: Miscellaneous conversions to ETH_ALEN (John Greene) [1091124]
- [ethernet] ixgbevf: add wait for Rx queue disable (John Greene) [1091123]
- [ethernet] ixgbevf: fix 32-bit DMA mask handling (John Greene) [1091123]
- [ethernet] ixgbe: fix message terminations (John Greene) [1091123]
- [ethernet] ixgbe: clean up Rx time stamping code (John Greene) [1091123]
- [ethernet] ixgbe: remove open-coded skb_cow_head (John Greene) [1091123]
- [ethernet] ixgbe: Add bit to mark service task initialization (John Greene) [1091123]
- [ethernet] ixgbe: Fix rcu warnings induced by LER (John Greene) [1091123]
- [ethernet] ixgbe: Indicate removal state explicitly (John Greene) [1091123]
- [ethernet] ixgbe: fix ixgbe_check_reset_blocked() declaration (John Greene) [1091123]
- [ethernet] ixgbe: fix race conditions on queuing skb for HW time stamp (John Greene) [1091123]
- [ethernet] ixgbe: never generate both software and hardware timestamps (John Greene) [1091123]
- [ethernet] ixgbe: remove redundant if clause from PTP work (John Greene) [1091123]
- [ethernet] ixgbe: Break recursion in case of removal (John Greene) [1091123]
- [ethernet] ixgbe: Stop cacheing if the MNG FW enabled (John Greene) [1091123]
- [ethernet] ixgbe: clean up ixgbe_atr_compute_perfect_hash_82599 (John Greene) [1091123]
- [ethernet] ixgbe: use ixgbe_read_pci_cfg_word (John Greene) [1091123]
- [ethernet] ixgbe: remove unused media type (John Greene) [1091123]
- [ethernet] ixgbe: fix ixgbe_setup_mac_link_82599 autoc variables (John Greene) [1091123]
- [ethernet] ixgbe: fix ixgbe_stop_mac_link_on_d3_82599 to check mng correctly (John Greene) [1091123]
- [ethernet] ixgbe: check Core Clock Disable bit (John Greene) [1091123]
- [ethernet] ixgbe: fix errors related to protected AUTOC calls (John Greene) [1091123]
- [ethernet] ixgbe: Convert uses of __constant_<foo> to <foo> (John Greene) [1091123]
- [ethernet] ixgbe: Don't receive packets when the napi budget == 0 (John Greene) [1091123]
- [ethernet] ixgbe: add ixgbe_write_pci_cfg_word with ixgbe_removed check (John Greene) [1091123]
- [ethernet] ixgbe: fix some multiline hw_dbg prints (John Greene) [1091123]
- [ethernet] ixgbe: fixup header for ixgbe_set_rxpba_82598 (John Greene) [1091123]
- [ethernet] ixgbe: add Linux NICS mailing list to contact info (John Greene) [1091123]
- [ethernet] ixgbe: move setting rx_pb_size into get_invariants (John Greene) [1091123]
- [ethernet] ixgbe: Fix format string in ixgbe_fcoe.c (John Greene) [1091123]
- [ethernet] ixgbe: ixgbe calls skb_set_hash (John Greene) [1091123]
- [ethernet] ixgbe: implement SIOCGHWTSTAMP ioctl (John Greene) [1091123]
- [ethernet] ixgbe: Check config reads for removal (John Greene) [1091123]
- [ethernet] ixgbe: Fix up some ethtool results when adapter is removed (John Greene) [1091123]
- [ethernet] ixgbe: Restore hw_addr in LER recovery paths (John Greene) [1091123]
- [ethernet] ixgbe: Additional adapter removal checks (John Greene) [1091123]
- [ethernet] ixgbe: Check for adapter removal on register writes (John Greene) [1091123]
- [ethernet] ixgbe: Check register reads for adapter removal (John Greene) [1091123]
- [ethernet] ixgbe: Use static inlines instead of macros (John Greene) [1091123]
- [ethernet] ixgbe: Add check for FW veto bit (John Greene) [1091123]
- [ethernet] ixgbe: fix bit toggled for 82599 reset fix (John Greene) [1091123]
- [ethernet] ixgbe: collect all 82599 AUTOC code in one function (John Greene) [1091123]
- [ethernet] ixgbe: Remove extern from function prototypes (John Greene) [1091123]
- [ethernet] ixgbe: fix to use correct timeout interval for memory read completion (John Greene) [1091123]
- [ethernet] ixgbe: Add WoL support for a new device (John Greene) [1091123]
- [ethernet] ixgbe: don't use magic size number to assign ptp_caps.name (John Greene) [1091123]
- [ethernet] ixgbe: modify behavior on receiving a HW ECC error (John Greene) [1091123]
- [ethernet] ixgbe: Use pci_enable_msix_range() instead of pci_enable_msix() (John Greene) [1091123]
- [ethernet] ixgbe: bump version number (John Greene) [1091123]
- [ethernet] ixgbe: add braces around else condition in ixgbe_qv_lock_* calls (John Greene) [1091123]
- [ethernet] ixgbe: fix qv_lock_napi call in ixgbe_napi_disable_all (John Greene) [1091123]
- [ethernet] ixgbe: Reduce memory consumption with larger page sizes (John Greene) [1091123]
- [ethernet] ixgbe: Cleanup the use of tabs and spaces (John Greene) [1091124 1091123]

* Fri Sep 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-158.el7]
- [net] ipv4: implement igmp_qrv sysctl to tune igmp robustness variable (Hannes Frederic Sowa) [1110118]
- [net] ipv6: add sysctl_mld_qrv to configure query robustness variable (Hannes Frederic Sowa) [1110118]
- [net] rtnetlink: wait for unregistering devices in rtnl_link_unregister() (Florian Westphal) [1133741]
- [net] netns: Delay default_device_exit_batch until no devices are unregistering (Florian Westphal) [1133741]
- [net] netfilter: ctnetlink: fix refcnt leak in dying/unconfirmed list dumper (Florian Westphal) [1043012]
- [net] netfilter: ctnetlink: fix dumping of dying/unconfirmed conntracks (Florian Westphal) [1043012]
- [net] netfilter: nf_conntrack: initialize net.ct.generation (Florian Westphal) [1043012]
- [net] netfilter: conntrack: Fix UP builds (Florian Westphal) [1043012]
- [net] netfilter: conntrack: remove central spinlock nf_conntrack_lock (Florian Westphal) [1043012]
- [net] netfilter: conntrack: seperate expect locking from nf_conntrack_lock (Florian Westphal) [1043012]
- [net] netfilter: avoid race with exp->master ct (Florian Westphal) [1043012]
- [net] netfilter: conntrack: spinlock per cpu to protect special lists (Florian Westphal) [1043012]
- [net] netfilter: trivial code cleanup and doc changes (Florian Westphal) [1043012]
- [net] sctp: fix ABI mismatch through sctp_assoc_to_state helper (Daniel Borkmann) [1135389]
- [net] tcp: tsq: fix nonagle handling (Jiri Pirko) [1134402]
- [netdrv] veth: extend features to support tunneling (Florian Westphal) [1098138]
- [net] openvswitch: fix panic with multiple vlan headers (Jiri Benc) [1133109]
- [net] netfilter: synproxy target: restrict to INPUT/FORWARD (Jesper Brouer) [1081339]
- [net] fix rtnl notification in atomic context (Jiri Pirko) [1113925]
- [net] always advertise rx_flags changes via netlink (Jiri Pirko) [1113925]
- [net] update __dev_notify_flags() to send rtnl msg (Jiri Pirko) [1113925]

* Fri Sep 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-157.el7]
- [scsi] fusion: Remove use of DEF_SCSI_QCMD (Tomas Henzl) [1041675]
- [scsi] fusion: Add free msg frames to the head, not tail of list (Tomas Henzl) [1041675]
- [scsi] mpt2sas: Add free smids to the head, not tail of list (Tomas Henzl) [1041675]
- [scsi] mpt2sas: Remove use of DEF_SCSI_QCMD (Tomas Henzl) [1041675]
- [scsi] mpt2sas: Remove uses of serial_number (Tomas Henzl) [1041675]
- [scsi] mpt3sas: Remove use of DEF_SCSI_QCMD (Tomas Henzl) [1041675]
- [scsi] mpt3sas: Remove uses of serial_number (Tomas Henzl) [1041675]
- [scsi] qla4xxx: 5.04.00.04.07.01-k0 (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Improve loopback failure messages (Chad Dupuis) [1089349]
- [scsi] qla4xxx: from treewide: fix comments and printk msgs (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Use kmemdup instead of kmalloc + memcpy (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Fix smatch warning in func qla4xxx_conn_get_param (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Fix smatch warning in func qla4xxx_get_ep_param (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Fix memory leak for ha->saved_acb (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Export sysfs DDBs from DPC handler (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Disable INTx interrupt for ISP82XX (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Check for correct return status (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Move qla4_8xxx_ms_mem_write_128b to ql4_nx.c (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Added PEX DMA Support for ISP8022 Adapter (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Added new opcodes for 84XX Minidump template (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Add support of 0xFF capture mask for minidump (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Change default capture to firmware defined capture mask (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Add support for ISCSI_PARAM_LOCAL_IPADDR sysfs attr (Chad Dupuis) [1089349]
- [scsi] scsi_transport_iscsi: Export ISCSI_PARAM_LOCAL_IPADDR attr for iscsi_connection (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Add host statistics support (Chad Dupuis) [1089349]
- [scsi] scsi_transport_iscsi: Add host statistics support (Chad Dupuis) [1089349]
- [scsi] qla4xxx: Added support for Diagnostics MBOX command (Chad Dupuis) [1089349]
- [scsi] qla2xxx: Update version number to 8.07.00.08.07.1-k (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove wait for online from host reset handler (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Do logins from a chip reset in DPC thread instead of the error handler thread (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove mapped vp index iterator macro dead code (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add MBC option for fast SFP data access (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix beacon blink logic for ISP26xx/83xx (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Delay driver unload if there is any pending activity going on (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Check the QLA8044_CRB_DRV_ACTIVE_INDEX register when we are not the owner of the reset (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Adjust adapter reset routine to the changes in firmware specification for ISPFx00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: IOCB data should be copied to I/O mem using memcpy_toio (Chad Dupuis) [1089346]
- [scsi] qla2xxx: ISP8044 poll ipmdio bus timeout improvement (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove unnecessary printk_ratelimited from qla_nx2.c (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Include <delay.h> file for msleep declartion in qla_nx2.c file (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Use proper log message for flash lock failed error (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Decrease pci access for response queue processing for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Change copyright year to 2014 in all the source files (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Enable fw_dump_size for ISP8044 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Introduce fw_dump_flag to track fw dump progress (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove unnecessary delays from fw dump code path (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Track the process when the ROM_LOCK failure happens (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add ISP8044 serdes bsg interface (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Check for peg alive counter and clear any outstanding mailbox command (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Support of new firmware dump opcodes QLA8044_RDDFE(38), QLA8044_RDMDIO(39), QLA8044_POLLWR(40) (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Allow the next firmware dump if the previous dump capture fails for ISP8044 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Log when device state is moved to failed state (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Do not schedule reset when one is already active when receiving an invalid status handle (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Wait for reset completion without lock for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Re-sync module parameter descriptions with the code (Chad Dupuis) [1089346]
- [scsi] qla2xxx: fix error handling of qla2x00_mem_alloc() (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add IOCB Abort command asynchronous handling (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix Task Management command asynchronous handling (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Correct the port no assignment for ISP82XX (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Read capture firmware dump on mailbox timeout for ISP8044 and ISP82XX (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Simplify the ISPFX00 interrupt handler code for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Avoid poisoning in the response queue for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove ISP_ABORT_NEEDED and ISP_ABORT_RETRY checks from watchdog function for ISP8044 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove Marker type IOCB logic for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Properly handle 32 bit mailbox register for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Enable the Flash Access Control (FAC) mailbox command (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Select correct request queue for error type IOCB for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Remove init control block related dead code for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Use proper message for Non owner reset ACK Timeout (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Replace constant value for IOCTL IOCB abort execution status with a macro for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add handling for boot indication progress AENs for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add mutex around optrom calls to serialize accesses (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Poll during initialization for ISP25xx and ISP83xx (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix multiqueue MSI-X registration (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix warning reported by smatch (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Replace a constant with a macro definition for host->canqueue assigmnment (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Reset nic_core_reset_owner on moving from COLD to READY for ISP8044 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Only complete dcbx_comp and lb_portup_comp for virtual port index 0 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Use scnprintf() instead of snprintf() in the sysfs handlers (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Use the correct mailbox registers when acknowledging an IDC request on ISP8044 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add changes to obtain ISPFX00 adapters product information in accordance with firmware update (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add logic to abort BSG commands for ISPFX00 (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Clear RISC INT reg only for an event and not always while polling (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix undefined behavior in call to snprintf() (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add BSG interface for read/write serdes register (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Fix issue with not displaying node name after system reboot (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Don't consider the drivers knocked out of IDC participation for future reset recovery process (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add BPM support for ISP25xx (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Correctly set mailboxes for extended init control block (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Disable INTx interrupt for ISP82XX (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Honor execute firmware failures (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Print proper QLAFX00 product name at probe (Chad Dupuis) [1089346]
- [scsi] qla2xxx: print MAC via pMR (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Correction to message ids (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Correctly print out/in mailbox registers (Chad Dupuis) [1089346]
- [scsi] qla2xxx: Add a new interface to update versions (Chad Dupuis) [1089346]

* Fri Sep 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-156.el7]
- [tty] hvc_console: Fix wakeup of HVC thread on hvc_kick() (Steve Best) [1123045]
- [tty] hvc_opal: Kick the HVC thread on OPAL console events (Steve Best) [1123045]
- [powerpc] perf/hv-24x7: Catalog version number is be64, not be32 (Gustavo Duarte) [947159]
- [powerpc] perf/hv-24x7: Remove [static 4096], sparse chokes on it (Gustavo Duarte) [947159]
- [powerpc] perf/hv-24x7: Use (unsigned long) not (u32) values when calling plpar_hcall_norets() (Gustavo Duarte) [947159]
- [powerpc] perf/hv-gpci: Make device attr static (Gustavo Duarte) [947159]
- [powerpc] perf/hv_gpci: Probe failures use pr_debug(), and padding reduced (Gustavo Duarte) [947159]
- [powerpc] perf/hv_24x7: Probe errors changed to pr_debug(), padding fixed (Gustavo Duarte) [947159]
- [Documentation] powerpc/perf/hv_{gpci, 24x7}: Add documentation of device attributes (Gustavo Duarte) [947159]
- [powerpc] perf: Add kconfig option for hypervisor provided counters (Gustavo Duarte) [947159]
- [powerpc] perf: Add support for the hv 24x7 interface (Gustavo Duarte) [947159]
- [powerpc] perf: Add support for the hv gpci (get performance counter info) interface (Gustavo Duarte) [947159]
- [powerpc] perf: Add macros for defining event fields & formats (Gustavo Duarte) [947159]
- [powerpc] perf: Add a shared interface to get gpci version and capabilities (Gustavo Duarte) [947159]
- [powerpc] perf: Add 24x7 interface headers (Gustavo Duarte) [947159]
- [powerpc] perf: Add hv_gpci interface header (Gustavo Duarte) [947159]
- [powerpc] Add hvcalls for 24x7 and gpci (Get Performance Counter Info) (Gustavo Duarte) [947159]
- [ethernet] sfc: Remove DEFINE_PCI_DEVICE_TABLE macro use (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Use __iowrite64_copy instead of a slightly different local function (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Add support for busy polling (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Add per-queue statistics in ethtool (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: add extra RX drop counters for nodesc_trunc and noskb_drop (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Add 40G link capability decoding (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Adding PCI ID for Solarflare 7000 series 40G network adapter (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: fix calling of free_irq with already free vector (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: get rid of SET_ETHTOOL_OPS (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: On MCDI timeout, issue an FLR (and mark MCDI to fail-fast) (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Call efx_set_channels() before efx->type->dimension_resources() (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Don't receive packets when the napi budget == 0 (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: check for NULL efx->ptp_data in efx_ptp_event (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Use pci_enable_msix_range() instead of pci_enable_msix() (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Add/remove blank lines to taste (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Fail self-test with -EBUSY, not -EIO, if the device is busy (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Cosmetic changes to self-test from the out-of-tree driver (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Update product naming (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Use canonical pointer type for MAC address in efx_set_mac_address() (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Rename 'use_options' variable in tso_start() to clearer 'use_opt_desc' (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Preserve rx_frm_trunc counters when resizing DMA rings (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Correct comment about number of TX queues used on EF10 (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Remove unused definitions of EF10 user-mode DMA descriptors (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Replace TSOH_OFFSET with the equivalent NET_IP_ALIGN (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Rewrite adjustment of PPS event in a clearer way (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Cache skb->data in local variable in efx_ptp_rx() (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Removed adhoc scheme to rate limit PTP event queue overflow message (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: fix build warning in ethernet/sfc/tx.c (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Use the correct maximum TX DMA ring size for SFC9100 (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Fix transposed ptp_{under, over}size_sync_windows statistics (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: Change efx_mcdi_reset_port to use ENTITY_RESET MC command (Nikolay Aleksandrov) [1110888]
- [ethernet] sfc: calls skb_set_hash (Nikolay Aleksandrov) [1110888]
- [iommu] vt-d: Use correct domain id to flush virtual machine domains (Myron Stowe) [1136539]
- [iommu] Fix IOMMU sysfs stubs (Myron Stowe) [1136539]
- [iommu] Fix compile error in iommu-sysfs.c (Myron Stowe) [1136539]
- [pci] Add bridge DMA alias quirk for Intel 82801 bridge (Myron Stowe) [1136539]
- [iommu] amd: Add sysfs support (Myron Stowe) [1136539]
- [iommu] vt-d: Make use of IOMMU sysfs support (Myron Stowe) [1136539]
- [iommu] Add sysfs support for IOMMUs (Myron Stowe) [1136539]
- [iommu] core: Make iommu_group_get_for_dev() more robust (Myron Stowe) [1136537]
- [iommu] Remove pci.h (Myron Stowe) [1136537]
- [iommu] vt-d: Update to use PCI DMA aliases (Myron Stowe) [1136537]
- [iommu] vt-d: Use iommu_group_get_for_dev() (Myron Stowe) [1136537]
- [iommu] amd: Use iommu_group_get_for_dev() (Myron Stowe) [1136537]
- [iommu] amd: Update to use PCI DMA aliases (Myron Stowe) [1136537]
- [iommu] core: Create central IOMMU group lookup/creation interface (Myron Stowe) [1136537]
- [iommu] vt-d: Suppress compiler warnings (Myron Stowe) [1136537]
- [iommu] vt-d: Fix reference count in iommu_prepare_isa (Myron Stowe) [1136537]
- [iommu] vt-d: fix bug in handling multiple RMRRs for the same PCI device (Myron Stowe) [1136537]
- [pci] Add bridge DMA alias quirk for ITE bridge (Myron Stowe) [1136537]
- [pci] Add bridge DMA alias quirk for ASMedia and Tundra bridges (Myron Stowe) [1136537]
- [pci] Add support for PCIe-to-PCI bridge DMA alias quirks (Myron Stowe) [1136537]
- [pci] Add function 1 DMA alias quirk for Marvell devices (Myron Stowe) [1136537]
- [pci] Add function 0 DMA alias quirk for Ricoh devices (Myron Stowe) [1136537]
- [pci] Add support for DMA alias quirks (Myron Stowe) [1136537]
- [pci] Convert pci_dev_flags definitions to bit shifts (Myron Stowe) [1136537]
- [pci] Add DMA alias iterator (Myron Stowe) [1136537]
- [iommu] amd: fix enabling exclusion range for an exact device (Myron Stowe) [1129880 1087643]
- [iommu] amd: Take mmap_sem when calling get_user_pages (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: fix bug in matching PCI devices with DRHD/RMRR descriptors (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Fix get_domain_for_dev() handling of upstream PCIe bridges (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: fix memory leakage caused by commit ea8ea46 (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Fix error handling in ANDD processing (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: returning free pointer in get_domain_for_dev() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Only call dmar_acpi_dev_scope_init() if DRHD units present (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Check for NULL pointer in dmar_acpi_dev_scope_init() (Myron Stowe) [1129880 1087643]
- [iommu] amd: Fix logic to determine and checking max PASID (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Include ACPI devices in iommu=pt (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Finally enable translation for non-PCI devices (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove to_pci_dev() in intel_map_page() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove pdev from intel_iommu_attach_device() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove pdev from iommu_no_mapping() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make domain_add_dev_info() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make domain_remove_one_dev_info() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Rename 'hwdev' variables to 'dev' now that that's the norm (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove some pointless to_pci_dev() calls (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make get_valid_domain_for_dev() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make iommu_should_identity_map() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Handle RMRRs for non-PCI devices (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make get_domain_for_dev() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make domain_context_mapp{ed, ing}() take struct device (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make device_to_iommu() cope with non-PCI devices (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make identity_mapping() take struct device not struct pci_dev (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove segment from struct device_domain_info() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Store PCI segment number in struct intel_iommu (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Remove device_to_iommu() call from domain_remove_dev_info() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Simplify iommu check in domain_remove_one_dev_info() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Always store iommu in device_domain_info (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Use domain_remove_one_dev_info() in domain_add_dev_info() error path (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: use dmar_insert_dev_info() from dma_add_dev_info() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Stop dmar_insert_dev_info() freeing domains on losing race (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Pass iommu to domain_context_mapping_one() and iommu_support_dev_iotlb() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Use struct device in device_domain_info, not struct pci_dev (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make dmar_insert_dev_info() take struct device instead of struct pci_dev (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Make iommu_dummy() take struct device instead of struct pci_dev (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Add ACPI devices into dmaru->devices[] array (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Change scope lists to struct device, bus, devfn (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Allocate space for ACPI devices (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Parse ANDD records (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Add ACPI namespace device reporting structures (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Be less pessimistic about domain coherency where possible (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Honour intel_iommu=sp_off for non-VMM domains (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Clean up and fix page table clear/free behaviour (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Clean up size handling for intel_iommu_unmap() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Update IOMMU state when memory hotplug happens (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Unify the way to process DMAR device scope array (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Update DRHD/RMRR/ATSR device scope caches when PCI hotplug happe (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Use RCU to protect global resources in interrupt context (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Introduce a rwsem to protect global data structures (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Introduce macro for_each_dev_scope() to walk device scope entrie (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Fix error in detect ATS capability (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Check for NULL pointer when freeing IOMMU data structure (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Fix incorrect iommu_count for si_domain (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Reduce duplicated code to handle virtual machine domains (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Free resources if failed to create domain for PCIe endpoint (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Simplify function get_domain_for_dev() (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Move private structures and variables into intel-iommu.c (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Factor out dmar_alloc_dev_scope() for later reuse (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Avoid caching stale domain_device_info when hot-removing PCI dev (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Avoid caching stale domain_device_info and fix memory leak (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Avoid double free of g_iommus on error recovery path (Myron Stowe) [1129880 1087643]
- [iommu] amd: Fix PASID format in INVALIDATE_IOTLB_PAGES command (Myron Stowe) [1129880 1087643]
- [iommu] vt-d: Fix signedness bug in alloc_irte() (Myron Stowe) [1129808]
- [iommu] vt-d: free all resources if failed to initialize DMARs (Myron Stowe) [1129808]
- [iommu] vt-d: clean sparse warnings (Myron Stowe) [1129808]
- [iommu] vt-d: fix wrong return value of dmar_table_init() (Myron Stowe) [1129808]
- [iommu] vt-d: release invalidation queue when destroying IOMMU unit (Myron Stowe) [1129808]
- [iommu] vt-d: fix access after free issue in function free_dmar_iommu() (Myron Stowe) [1129808]
- [iommu] vt-d: keep shared resources when failed to initialize iommu devices (Myron Stowe) [1129808]
- [iommu] vt-d: fix invalid memory access when freeing DMAR irq (Myron Stowe) [1129808]
- [iommu] vt-d: simplify code with existing macros (Myron Stowe) [1129808]
- [iommu] vt-d: use defined macro instead of hardcoding (Myron Stowe) [1129808]
- [iommu] vt-d: mark internal functions as static (Myron Stowe) [1129808]
- [iommu] vt-d: clean up unused code (Myron Stowe) [1129808]
- [iommu] vt-d: check suitable flag in function detect_intel_iommu() (Myron Stowe) [1129808]
- [iommu] vt-d: print correct domain id of static identity domain (Myron Stowe) [1129808]
- [iommu] vt-d: refine support of 64bit guest address (Myron Stowe) [1129808]
- [iommu] vt-d: fix resource leakage on error recovery path in iommu_init_domain (Myron Stowe) [1129808]
- [iommu] vt-d: fix a race window in allocating domain ID for virtual machines (Myron Stowe) [1129808]
- [iommu] vt-d: fix PCI device reference leakage on error recovery path (Myron Stowe) [1129808]
- [iommu] vt-d: use dedicated bitmap to track remapping entry allocation status (Myron Stowe) [1129808]
- [iommu] Rename domain_has_cap to iommu_domain_has_cap (Myron Stowe) [1129808]
- [iommu] vt-d: Use dev_is_pci() to check whether it is pci device (Myron Stowe) [1129808]
- [iommu] amd: Use dev_is_pci() to check whether it is pci device (Myron Stowe) [1129808]
- [iommu] add missing include (Myron Stowe) [1129808]
- [iommu] vt-d: Mark function eoi_ioapic_pin_remapped() as static in irq_remappi (Myron Stowe) [1129808]
- [iommu] vt-d: Mark functions as static in intel_irq_remapping.c (Myron Stowe) [1129808]
- [iommu] vt-d: Mark functions as static in dmar.c (Myron Stowe) [1129808]
- [iommu] add IOMMU_EXEC flag for safely allowing XN mappings (Myron Stowe) [1129808]
- [iommu] acpica: Update DMAR table definitions (Myron Stowe) [1129808]

* Wed Sep 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-155.el7]
- [tools] perf/bench: Fix NULL pointer dereference in "perf bench all" (Jiri Olsa) [1133083]
- [tools] perf/bench/numa: Make no args mean 'run all tests' (Jiri Olsa) [1133083]
- [tools] perf/machine: Use map as success in ip__resolve_ams (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix crash in elf_section_by_name (Jiri Olsa) [1133083]
- [tools] perf/trace: Decode architecture-specific signal numbers (Jiri Olsa) [1133083]
- [tools] perf: Fix strict alias issue for find_first_bit (Jiri Olsa) [1133083]
- [tools] perf: fix BFD detection on opensuse (Jiri Olsa) [1133083]
- [tools] perf/symbols: Destroy unused symsrcs (Jiri Olsa) [1133083]
- [tools] perf/annotate: Check availability of annotate when processing samples (Jiri Olsa) [1133083]
- [tools] perf/trace: Fix ioctl 'request' beautifier build problems on !(i386 (Jiri Olsa) [1133083]
- [tools] perf/trace: Add fallback definition of EFD_SEMAPHORE (Jiri Olsa) [1133083]
- [tools] perf/list: Fix checking for supported events on older kernels (Jiri Olsa) [1133083]
- [tools] perf: Handle PERF_RECORD_HEADER_EVENT_TYPE properly (Jiri Olsa) [1133083]
- [tools] perf/probe: Do not add offset twice to uprobe address (Jiri Olsa) [1133083]
- [tools] perf/buildid-cache: Check relocation when checking for existing kcore (Jiri Olsa) [1133083]
- [tools] perf: Adjust kallsyms for relocated kernel (Jiri Olsa) [1133083]
- [tools] perf/tests: No need to set up ref_reloc_sym (Jiri Olsa) [1133083]
- [tools] perf/symbols: Prevent the use of kcore if the kernel has moved (Jiri Olsa) [1133083]
- [tools] perf/record: Get ref_reloc_sym from kernel map (Jiri Olsa) [1133083]
- [tools] perf/machine: Set up ref_reloc_sym in machine__create_kernel_maps() (Jiri Olsa) [1133083]
- [tools] perf/machine: Add machine__get_kallsyms_filename() (Jiri Olsa) [1133083]
- [tools] perf: Add kallsyms__get_function_start() (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix symbol annotation for relocated kernel (Jiri Olsa) [1133083]
- [tools] perf: Fix AAAAARGH64 memory barriers (Jiri Olsa) [1133083]
- [tools] perf: Demangle kernel and kernel module symbols too (Jiri Olsa) [1133083]
- [tools] perf/doc: Remove mention of non-existent set_perf_event_pending() from design.txt (Jiri Olsa) [1133083]
- [tools] perf/symbols: Load map before using map->map_ip() (Jiri Olsa) [1133083]
- [tools] perf: Fix traceevent plugin path definitions (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix JIT symbol resolution on heap (Jiri Olsa) [1133083]
- [tools] perf/stat: Fix memory corruption of xyarray when cpumask is used (Jiri Olsa) [1133083]
- [tools] perf/evsel: Remove duplicate member zeroing after free (Jiri Olsa) [1133083]
- [tools] perf: Ensure sscanf does not overrun the "mem" field (Jiri Olsa) [1133083]
- [tools] perf/stat: fix NULL pointer reference bug with event unit (Jiri Olsa) [1133083]
- [tools] perf: Add support for the xtensa architecture (Jiri Olsa) [1133083]
- [tools] perf/session: Free cpu_map in perf_session__cpu_bitmap (Jiri Olsa) [1133083]
- [tools] perf/timechart: Fix wrong SVG height (Jiri Olsa) [1133083]
- [tools] perf: Remove unnecessary callchain cursor state restore on unmatch (Jiri Olsa) [1133083]
- [tools] perf/callchain: Spare double comparison of callchain first entry (Jiri Olsa) [1133083]
- [tools] perf: Do proper comm override error handling (Jiri Olsa) [1133083]
- [tools] perf/symbols: Export elf_section_by_name and reuse (Jiri Olsa) [1133083]
- [tools] perf/probe: Release all dynamically allocated parameters (Jiri Olsa) [1133083]
- [tools] perf/probe: Release allocated probe_trace_event if failed (Jiri Olsa) [1133083]
- [tools] perf: Add 'build-test' make target (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when xen plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when scsi plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when jbd2 plugin is is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when cfg80211 plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when mac80211 plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when sched_switch plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when kvm plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when kmem plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when hrtimer plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Unregister handler when function plugin is unloaded (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add pevent_unregister_print_function() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add pevent_unregister_event_handler() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: fix pointer-integer size mismatch (Jiri Olsa) [1133083]
- [tools] perf/hists: Convert hist entry functions to use struct he_stat (Jiri Olsa) [1133083]
- [tools] perf: Factor out sample__resolve_callchain() (Jiri Olsa) [1133083]
- [tools] perf: Remove symbol_conf.use_callchain check (Jiri Olsa) [1133083]
- [tools] perf: Fix cross building (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Make plugin unload function receive pevent (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() finally!! (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in trace_seq_init() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Check return value of realloc() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add state member to struct trace_seq (Jiri Olsa) [1133083]
- [tools] perf: Fix build error due to zfree() cast (Jiri Olsa) [1133083]
- [tools] perf/record: Rename --initial-delay to --delay (Jiri Olsa) [1133083]
- [tools] perf/record: Rename --no-delay to --no-buffering (Jiri Olsa) [1133083]
- [tools] perf: Remove unused test-volatile-register-var.c (Jiri Olsa) [1133083]
- [tools] perf/probe: Fix build when DWARF support libraries not present (Jiri Olsa) [1133083]
- [tools] perf/diff: Color the Weighted Diff column (Jiri Olsa) [1133083]
- [tools] perf/diff: Color the Ratio column (Jiri Olsa) [1133083]
- [tools] perf/diff: Color the Delta column (Jiri Olsa) [1133083]
- [tools] perf: Generalize percent_color_snprintf() (Jiri Olsa) [1133083]
- [tools] include: Include <linux/compiler.h> from asm/bug.h (Jiri Olsa) [1133083]
- [tools] perf/record: Add --initial-delay option (Jiri Olsa) [1133083]
- [tools] perf: Use the DWARF unwind info only if loaded (Jiri Olsa) [1133083]
- [tools] perf: Add test for building detached source tarballs (Jiri Olsa) [1133083]
- [tools] perf: Include tools/lib/api/ in MANIFEST (Jiri Olsa) [1133083]
- [tools] include: Move perf's bug.h to a generic place (Jiri Olsa) [1133083]
- [tools] include: Define likely/unlikely in linux/compiler.h (Jiri Olsa) [1133083]
- [tools] include: Move perf's linux/compiler.h to a generic place (Jiri Olsa) [1133083]
- [tools] perf/evlist: Introduce evlist__for_each() & friends (Jiri Olsa) [1133083]
- [tools] perf/report: Move histogram entries collapsing to separate function (Jiri Olsa) [1133083]
- [tools] perf/report: Move hist browser selection code to separate function (Jiri Olsa) [1133083]
- [tools] perf/report: Move logic to warn about kptr_restrict'ed kernels to separate function (Jiri Olsa) [1133083]
- [tools] perf: Comment typo fix (Jiri Olsa) [1133083]
- [tools] perf/stat: Fix --delay option in man page (Jiri Olsa) [1133083]
- [tools] perf: Make perf_event__synthesize_mmap_events global (Jiri Olsa) [1133083]
- [tools] perf/machine: Fix id_hdr_size initialization (Jiri Olsa) [1133083]
- [tools] perf: Automate setup of FEATURE_CHECK_(C (Jiri Olsa) [1133083]
- [tools] perf/trace: Pack 'struct trace' (Jiri Olsa) [1133083]
- [tools] perf/header: Pack 'struct perf_session_env' (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Shut up plugins make message (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Replace tabs with spaces for all non-commands statements (Jiri Olsa) [1133083]
- [tools] perf/tests: Fix installation tests path setup (Jiri Olsa) [1133083]
- [tools] perf: Move arch setup into seprate Makefile (Jiri Olsa) [1133083]
- [tools] perf/stat: Remove misplaced __maybe_unused (Jiri Olsa) [1133083]
- [tools] perf/tests: Fixup leak on error path in parse events test (Jiri Olsa) [1133083]
- [tools] perf/evlist: Auto unmap on destructor (Jiri Olsa) [1133083]
- [tools] perf/evlist: Close fds on destructor (Jiri Olsa) [1133083]
- [tools] perf/evlist: Move destruction of maps to evlist destructor (Jiri Olsa) [1133083]
- [tools] perf/record: Remove old evsel_list usage (Jiri Olsa) [1133083]
- [tools] perf/evlist: Move the SIGUSR1 error reporting logic to prepare_workload (Jiri Olsa) [1133083]
- [tools] perf/evlist: Send the errno in the signal when workload fails (Jiri Olsa) [1133083]
- [tools] perf/stat: Don't show counter information when workload fails (Jiri Olsa) [1133083]
- [tools] perf: Use zfree to help detect use after free bugs (Jiri Olsa) [1133083]
- [tools] perf: Introduce zfree (Jiri Olsa) [1133083]
- [tools] perf: No need to test against NULL before calling free() (Jiri Olsa) [1133083]
- [tools] perf/ui/tui: Implement header window (Jiri Olsa) [1133083]
- [tools] perf/ui/tui: Split help message for perf top and report (Jiri Olsa) [1133083]
- [tools] perf/ui/tui: Protect windows by ui__lock (Jiri Olsa) [1133083]
- [tools] perf/probe: Support basic dwarf-based operations on uprobe events (Jiri Olsa) [1133083]
- [tools] perf/probe: Expand given path to absolute path (Jiri Olsa) [1133083]
- [tools] perf/config: Ignore generated files in feature-checks (Jiri Olsa) [1133083]
- [tools] perf: Do not synthesize the treads of default guest (Jiri Olsa) [1133083]
- [tools] perf: Use machine->pid for tgid if machine is guest (Jiri Olsa) [1133083]
- [tools] perf: Set event->header.misc to PERF_RECORD_MISC_GUEST_USER if machine is guest (Jiri Olsa) [1133083]
- [tools] perf: Find the proc info under machine->root_dir (Jiri Olsa) [1133083]
- [tools] perf: Add support for PERF_RECORD_MISC_GUEST_USER in thread__find_addr_map() (Jiri Olsa) [1133083]
- [tools] perf/report: Print session information only if --stdio is given (Jiri Olsa) [1133083]
- [tools] perf/report: Use pr_*() functions where applicable (Jiri Olsa) [1133083]
- [tools] perf/symbols: Add 'machine' member to struct addr_location (Jiri Olsa) [1133083]
- [tools] perf/mem: Remove unused parameter from dump_raw_samples() (Jiri Olsa) [1133083]
- [tools] perf/scripting/perl: Shorten function signatures (Jiri Olsa) [1133083]
- [tools] perf/scripting/python: Shorten function signatures (Jiri Olsa) [1133083]
- [tools] perf/ui/browser: Remove misplaced __maybe_unused (Jiri Olsa) [1133083]
- [tools] perf/report: Rename 'perf_report' to 'report' (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use global 'O' processing code (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use global QUIET_CLEAN build output (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use global QUIET_INSTALL build output (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use global QUIET_LINK build output (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add global QUIET_CC_FPIC build output (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use global QUIET_CC build output (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Remove print_app_build variable (Jiri Olsa) [1133083]
- [tools] perf: Making QUIET_(CLEAN (Jiri Olsa) [1133083]
- [tools] perf/tests: Factor make install tests (Jiri Olsa) [1133083]
- [tools] perf: Rename 'perf_record_opts' to 'record_opts (Jiri Olsa) [1133083]
- [tools] perf/record: Rename 'perf_record' to plain 'record' (Jiri Olsa) [1133083]
- [tools] perf/record: Simplify perf_record__write (Jiri Olsa) [1133083]
- [tools] perf/record: Use perf_data_file__write for output file (Jiri Olsa) [1133083]
- [tools] perf/inject: Handle output file via perf_data_file object (Jiri Olsa) [1133083]
- [tools] perf: Get rid of a duplicate va_end() in error reporting routine (Jiri Olsa) [1133083]
- [tools] perf/report: Introduce helpers for processing callchains (Jiri Olsa) [1133083]
- [tools] perf/annotate: Make symbol__inc_addr_samples private (Jiri Olsa) [1133083]
- [tools] perf/annotate: Adopt methods from hists (Jiri Olsa) [1133083]
- [tools] perf/top: Use hist_entry__inc_addr_sample (Jiri Olsa) [1133083]
- [tools] perf/annotate: Add inc_samples method to addr_map_symbol (Jiri Olsa) [1133083]
- [tools] perf/hists: Leave symbol addr hist bucket auto alloc to symbol layer (Jiri Olsa) [1133083]
- [tools] perf/annotate: Auto allocate symbol per addr hist buckets (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Introduce pevent_filter_strerror() (Jiri Olsa) [1133083]
- [tools] perf/hists: Do not pass period and weight to add_hist_entry() (Jiri Olsa) [1133083]
- [tools] perf/sort: Do not compare dso again (Jiri Olsa) [1133083]
- [tools] perf/sort: Compare addresses if no symbol info (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() in some string conversion functions (Jiri Olsa) [1133083]
- [tools] perf/symbols: Use consistent name for the DSO binary type member (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add --highlight option (Jiri Olsa) [1133083]
- [tools] perf/symbols: Clarify method to get DSO binary_type filename (Jiri Olsa) [1133083]
- [tools] perf/symbols: Remove needless static binary_type array (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add support for topology (Jiri Olsa) [1133083]
- [tools] perf/timechart: Get number of CPUs from perf header (Jiri Olsa) [1133083]
- [tools] perf/timechart: Print pid along the name (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add backtrace support to CPU info (Jiri Olsa) [1133083]
- [tools] Convert to new topic libraries (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Refactor pevent_filter_match() to get rid of die() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Make pevent_filter_add_filter_str() return pevent_errno (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Refactor process_filter() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Refactor create_arg_item() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() in reparent_op_arg() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Make add_left() return pevent_errno (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() in add_right() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in find_event() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in read_token() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() allocate_arg() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die in add_filter_type() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in show_error() (Jiri Olsa) [1133083]
- [tools] perf/completion: Complete 'perf kvm' (Jiri Olsa) [1133083]
- [tools] perf/evlist: Add perf_evlist__to_front() (Jiri Olsa) [1133083]
- [tools] perf: Fix inverted error verification bug in thread__fork (Jiri Olsa) [1133083]
- [tools] perf: Move mem_bswap32/64 to util.c (Jiri Olsa) [1133083]
- [tools] perf/evlist: Add can_select_event() method (Jiri Olsa) [1133083]
- [tools] perf/header: Allow header->data_offset to be predetermined (Jiri Olsa) [1133083]
- [tools] perf: Add perf_event_paranoid() (Jiri Olsa) [1133083]
- [tools] lib/symbol: Start carving out symbol parsing routines from perf (Jiri Olsa) [1133083]
- [tools] perf/unwinding: Use the per-feature check flags (Jiri Olsa) [1133083]
- [tools] perf: Add per-feature check flags (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix bug in usage of the basename() function (Jiri Olsa) [1133083]
- [tools] perf/symbols: Rename filename argument (Jiri Olsa) [1133083]
- [tools] perf/symbols: Constify some DSO methods parameters (Jiri Olsa) [1133083]
- [tools] perf/symbols: Set freed members to NULL in dso destructor (Jiri Olsa) [1133083]
- [tools] perf/symbols: Constify dso->long_name (Jiri Olsa) [1133083]
- [tools] perf/symbols: Remove open coded management of long_name_allocated member (Jiri Olsa) [1133083]
- [tools] perf/symbols: Set alloc flag close to setting the long_name (Jiri Olsa) [1133083]
- [tools] perf/symbols: Remove open coded management of short_name_allocated member (Jiri Olsa) [1133083]
- [tools] perf/machine: Don't open code assign dso->short_name (Jiri Olsa) [1133083]
- [tools] perf/symbols: Rename [sl]name_alloc to match the members they refer to (Jiri Olsa) [1133083]
- [tools] perf/script: Add --header/--header-only options (Jiri Olsa) [1133083]
- [tools] perf/report: Add --header/--header-only options (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() in pevent_filter_clear_trivial() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in pevent_filter_add_filter_str() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of die() in create_arg_item() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in add_event() (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Get rid of malloc_or_die() in pevent_filter_alloc() (Jiri Olsa) [1133083]
- [tools] perf/kvm: Make perf kvm diff support --guestmount (Jiri Olsa) [1133083]
- [tools] perf/kvm: Move code to generate filename for perf-kvm to function (Jiri Olsa) [1133083]
- [tools] perf/annotate: Fix typo (Jiri Olsa) [1133083]
- [tools] perf/archive: Remove duplicated 'runs' in man page (Jiri Olsa) [1133083]
- [tools] perf/kvm: Fix bug in 'stat report' (Jiri Olsa) [1133083]
- [tools] perf/kvm: Introduce option -v for perf kvm command (Jiri Olsa) [1133083]
- [tools] perf/evlist: Fix mmap pages rounding to power of 2 (Jiri Olsa) [1133083]
- [tools] perf/evlist: Fix max mmap_pages (Jiri Olsa) [1133083]
- [tools] perf/evlist: Remove unnecessary parentheses (Jiri Olsa) [1133083]
- [tools] perf/record: Fix display of incorrect mmap pages (Jiri Olsa) [1133083]
- [tools] perf/script: Add an option to print the source line number (Jiri Olsa) [1133083]
- [tools] perf/script: Fix symoff printing in callchains (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Report better error message on bad function args (Jiri Olsa) [1133083]
- [tools] perf/trace: Fix summary percentage when processing files (Jiri Olsa) [1133083]
- [tools] perf/trace: Add support for syscalls vs raw_syscalls (Jiri Olsa) [1133083]
- [tools] perf/build: Fix install dependency (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Update kvm plugin with is_writable_pte helper (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Remove malloc_or_die from plugin_function.c (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Several cleanups for function plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use pevent_print_func_field in hrtimer_start handler (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use static functions in jbd2 plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Remove malloc_or_die from event-plugin.c (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add cfg80211 plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add scsi plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add xen plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add function plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add sched_switch plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add mac80211 plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add kvm plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add kmem plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add hrtimer plugin (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add jbd2 plugin (Jiri Olsa) [1133083]
- [tools] perf: Overload pr_stat traceevent print function (Jiri Olsa) [1133083]
- [tools] perf: Add trace-event global object for tracepoint interface (Jiri Olsa) [1133083]
- [tools] perf: Add trace-event object (Jiri Olsa) [1133083]
- [tools] perf: Add filename__read_str util function (Jiri Olsa) [1133083]
- [tools] perf: Add build and install plugins targets (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Harmonize the install messages in lib-traceevent (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Change pevent_parse_format to include pevent handle (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add traceevent_host_bigendian function (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add plugin build support (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Add plugin support (Jiri Olsa) [1133083]
- [tools] perf/script: Do not call perf_event__preprocess_sample() twice) (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix random fd closing with no libelf (Jiri Olsa) [1133083]
- [tools] perf/kvm: Update the 'record' man page entry for new --guest/--host behavior (Jiri Olsa) [1133083]
- [tools] perf/kvm: Fix spurious '=' use in man page (Jiri Olsa) [1133083]
- [tools] perf/kvm: Add more detail about buildid-list in man page (Jiri Olsa) [1133083]
- [tools] perf/target: Move the checking of which map function to call into function (Jiri Olsa) [1133083]
- [tools] perf: Remove condition in machine__get_kernel_start_addr (Jiri Olsa) [1133083]
- [tools] perf: Remove stackprotector feature check (Jiri Olsa) [1133083]
- [tools] perf: Do not disable source line lookup just because of 1 failure (Jiri Olsa) [1133083]
- [tools] perf/symbols: Retain symbol source file name to lookup source line numbers (Jiri Olsa) [1133083]
- [tools] perf/symbols: Retain bfd reference to lookup source line numbers (Jiri Olsa) [1133083]
- [tools] perf: Use asprintf instead of malloc plus snprintf (Jiri Olsa) [1133083]
- [tools] perf/trace: Honour -m option (Jiri Olsa) [1133083]
- [tools] perf: Include test-stackprotector-all.c in test-all (Jiri Olsa) [1133083]
- [tools] perf: Correct the message in feature-libnuma checking (Jiri Olsa) [1133083]
- [tools] perf/timechart: Move wake_events list to 'struct timechart' (Jiri Olsa) [1133083]
- [tools] perf/timechart: Move power_events list to 'struct timechart' (Jiri Olsa) [1133083]
- [tools] perf/timechart: Move all_data per_pid list to 'struct timechart' (Jiri Olsa) [1133083]
- [tools] perf/timechart: Introduce tool struct (Jiri Olsa) [1133083]
- [tools] perf: Add perf_data_file__write interface (Jiri Olsa) [1133083]
- [tools] perf: Add writen function (Jiri Olsa) [1133083]
- [tools] perf: Fine tune readn function (Jiri Olsa) [1133083]
- [tools] perf: Use correct return type for readn function (Jiri Olsa) [1133083]
- [tools] perf/record: Unify data output code into perf_record__write function (Jiri Olsa) [1133083]
- [tools] perf: Fix tags/TAGS targets rebuilding (Jiri Olsa) [1133083]
- [tools] perf/timechart: Remove misplaced __maybe_unused (Jiri Olsa) [1133083]
- [tools] perf/timechart: Remove some needless struct forward declarations (Jiri Olsa) [1133083]
- [tools] perf/timechart: dynamically determine event fields offset (Jiri Olsa) [1133083]
- [tools] perf/symbols: Fix not finding kcore in buildid cache (Jiri Olsa) [1133083]
- [tools] perf/script: Print mmap[2] events also (Jiri Olsa) [1133083]
- [tools] perf/script: Print comm, fork and exit events also (Jiri Olsa) [1133083]
- [tools] perf/script: Print callchains and symbols if they exist (Jiri Olsa) [1133083]
- [tools] perf: Export setup_list (Jiri Olsa) [1133083]
- [tools] perf/thread: Move comm_list check into function (Jiri Olsa) [1133083]
- [tools] perf/symbols: Move idle syms check from top to generic function (Jiri Olsa) [1133083]
- [tools] perf/evsel: Skip ignored symbols while printing callchain (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add backtrace support (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add support for -P and -T in timechart recording (Jiri Olsa) [1133083]
- [tools] perf/timechart: Group figures and add title with details (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add support for displaying only tasks related data (Jiri Olsa) [1133083]
- [tools] perf/timechart: Use proc_num to implement --power-only (Jiri Olsa) [1133083]
- [tools] perf/timechart: Add option to limit number of tasks (Jiri Olsa) [1133083]
- [tools] perf/timechart: Always try to print at least 15 tasks (Jiri Olsa) [1133083]
- [tools] perf/record: Default -t option to no inheritance (Jiri Olsa) [1133083]
- [tools] perf: Add option macro OPT_BOOLEAN_SET (Jiri Olsa) [1133083]
- [tools] perf: Allow '--inherit' as the negation of '--no-inherit' (Jiri Olsa) [1133083]
- [tools] perf/record: Make per-cpu mmaps the default (Jiri Olsa) [1133083]
- [tools] perf/script: Move evname print code to process_event() (Jiri Olsa) [1133083]
- [tools] perf/completion: Rename file to reflect zsh support (Jiri Olsa) [1133083]
- [tools] perf/completion: Introduce zsh support (Jiri Olsa) [1133083]
- [tools] perf/completion: Factor out call to __ltrim_colon_completions (Jiri Olsa) [1133083]
- [tools] perf/completion: Factor out compgen stuff (Jiri Olsa) [1133083]
- [tools] perf/completion: Introduce a layer of indirection (Jiri Olsa) [1133083]
- [tools] perf/top: Make -g refer to callchains (Jiri Olsa) [1133083]
- [tools] perf/trace: Remove thread summary coloring (Jiri Olsa) [1133083]
- [tools] lib/traceevent: Use helper trace-seq in print functions like kernel does (Jiri Olsa) [1133083]
- [tools] perf/stat: Add event unit and scale support (Jiri Olsa) [1133083]
- [kernel] perf: Optimize ring-buffer write by depending on control dependencies (Jiri Olsa) [1133083]
- [x86] perf: Fix leak in uncore_type_init failure paths (Jiri Olsa) [1133083]
- [kernel] perf: Fix hotplug splat (Jiri Olsa) [1133083]
- [x86] perf: Fix event scheduling (Jiri Olsa) [1133083]
- [x86] perf: Fix IVT/SNB-EP uncore CBOX NID filter table (Jiri Olsa) [1133083]
- [x86] perf: Correctly use FEATURE_PDCM (Jiri Olsa) [1133083]
- [x86] perf: Fix unknown NMI warning (Jiri Olsa) [1133083]
- [x86] perf: Fix Userspace RDPMC switch (Jiri Olsa) [1133083]
- [x86] perf: Add userspace RDPMC quirk for PPro (Jiri Olsa) [1133083]
- [kernel] uapi: convert u64 to __u64 in exported headers (Jiri Olsa) [1133083]
- [kernel] perf: Document the new transaction sample type (Jiri Olsa) [1133083]
- [kernel] perf: Introduce a flag to enable close-on-exec in perf_event_open() (Jiri Olsa) [1133083]
- [x86] perf: Add Intel RAPL PP1 energy counter support (Jiri Olsa) [1133083]
- [kernel] perf: Fix PERF_EVENT_IOC_PERIOD to force-reset the period (Jiri Olsa) [1133083]
- [x86] perf: Add RAPL hrtimer support (Jiri Olsa) [1133083]
- [x86] perf: Add Intel RAPL PMU support (Jiri Olsa) [1133083]
- [kernel] perf: Add active_entry list head to struct perf_event (Jiri Olsa) [1133083]
- [kernel] perf: Fix perf_pmu_migrate_context (Jiri Olsa) [1133083]
- [kernel] ktime: add ms_to_ktime() and ktime_add_ms() helpers (Jiri Olsa) [1133083]
- [tools] perf/traceevent: Fix conversion of pointer to integer of different size (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Fix use of multiple options in processing field (Jiri Olsa) [1131394]
- [tools] perf/header: Fix possible memory leaks in process_group_desc() (Jiri Olsa) [1131394]
- [tools] perf/header: Fix bogus group name (Jiri Olsa) [1131394]
- [tools] perf: Tag thread comm as overriden (Jiri Olsa) [1131394]
- [tools] perf/record: Add an option to force per-cpu mmaps (Jiri Olsa) [1131394]
- [tools] perf/probe: Add '--demangle'/'--no-demangle' (Jiri Olsa) [1131394]
- [tools] perf/ui/browser: Fix segfault caused by off by one handling END key (Jiri Olsa) [1131394]
- [tools] perf/symbols: Limit max callchain using max_stack on DWARF unwinding too (Jiri Olsa) [1131394]
- [tools] perf/evsel: Introduce perf_evsel__prev() method (Jiri Olsa) [1131394]
- [tools] perf: Use perf_evlist__{first, last}, perf_evsel__next (Jiri Olsa) [1131394]
- [tools] perf: Synthesize anon MMAP records again (Jiri Olsa) [1131394]
- [tools] perf/top: Add missing newline if the 'uid' is invalid (Jiri Olsa) [1131394]
- [tools] perf: Remove trivial extra semincolon (Jiri Olsa) [1131394]
- [tools] perf/trace: Tweak summary output (Jiri Olsa) [1131394]
- [tools] perf/build: Fix feature-libunwind-debug-frame handling (Jiri Olsa) [1131394]
- [tools] perf/build: Fix timerfd feature check (Jiri Olsa) [1131394]
- [tools] perf: parse the .debug_frame section in case .eh_frame is not present (Jiri Olsa) [1131394]
- [tools] perf: Check libunwind for availability of dwarf parsing feature (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Add direct access to dynamic arrays (Jiri Olsa) [1131394]
- [tools] perf/target: Shorten perf_target__ to target__ (Jiri Olsa) [1131394]
- [tools] perf/tests: Handle throttle events in 'object code reading' test (Jiri Olsa) [1131394]
- [tools] perf/evlist: Refactor mmap_pages parsing (Jiri Olsa) [1131394]
- [tools] perf/evlist: Round mmap pages to power 2 - v2 (Jiri Olsa) [1131394]
- [tools] perf/record: Fix segfault with --no-mmap-pages (Jiri Olsa) [1131394]
- [tools] perf/trace: Add summary only option (Jiri Olsa) [1131394]
- [tools] perf/trace: Simplify '--summary' output (Jiri Olsa) [1131394]
- [tools] perf/trace: Change syscall summary duration order (Jiri Olsa) [1131394]
- [tools] perf/tests: Compensate lower sample freq with longer test loop (Jiri Olsa) [1131394]
- [tools] perf/trace: Fix segfault on perf trace -i perf.data (Jiri Olsa) [1131394]
- [tools] perf/trace: Separate tp syscall field caching into init routine to be reused (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify fifth argument of mmap() as fd (Jiri Olsa) [1131394]
- [tools] perf/tests: Use lower sample_freq in sw clock event period test (Jiri Olsa) [1131394]
- [tools] perf/tests: Check return of perf_evlist__open sw clock event period test (Jiri Olsa) [1131394]
- [tools] perf/record: Move existing write_output into helper function (Jiri Olsa) [1131394]
- [tools] perf/record: Use correct return type for write() (Jiri Olsa) [1131394]
- [tools] perf: Prevent condition that all sort keys are elided (Jiri Olsa) [1131394]
- [tools] perf/machine: Simplify synthesize_threads method (Jiri Olsa) [1131394]
- [tools] perf/machine: Introduce synthesize_threads method out of open coded equivalent (Jiri Olsa) [1131394]
- [tools] perf/record: Synthesize non-exec MMAP records when --data used (Jiri Olsa) [1131394]
- [tools] perf/evsel: Remove idx parm from constructor (Jiri Olsa) [1131394]
- [tools] perf/ui/tui/progress: Don't force a refresh during progress update (Jiri Olsa) [1131394]
- [tools] perf: Remove unneeded include (Jiri Olsa) [1131394]
- [tools] perf/record: Remove post_processing_offset variable (Jiri Olsa) [1131394]
- [tools] perf/record: Remove advance_output function (Jiri Olsa) [1131394]
- [tools] perf/record: Refactor feature handling into a separate function (Jiri Olsa) [1131394]
- [tools] perf/trace: Don't relookup fields by name in each sample (Jiri Olsa) [1131394]
- [tools] perf: Fix version when building out of tree (Jiri Olsa) [1131394]
- [tools] perf/evsel: Ditch evsel->handler.data field (Jiri Olsa) [1131394]
- [tools] perf: Add required memory barriers (Jiri Olsa) [1131394]
- [tools] perf: Finish the removal of 'self' arguments (Jiri Olsa) [1131394]
- [tools] perf: Check maximum frequency rate for record/top (Jiri Olsa) [1131394]
- [tools] perf/fs: Add procfs support (Jiri Olsa) [1131394]
- [tools] perf/fs: Rename NAME_find_mountpoint() to NAME__mountpoint() (Jiri Olsa) [1131394]
- [tools] perf: Factor sysfs code into generic fs object (Jiri Olsa) [1131394]
- [tools] perf/list: Add usage (Jiri Olsa) [1131394]
- [tools] perf/list: Remove a level of indentation (Jiri Olsa) [1131394]
- [tools] perf/build: Fix detection of non-core features (Jiri Olsa) [1131394]
- [tools] perf/kvm: Disable live command if timerfd is not supported (Jiri Olsa) [1131394]
- [tools] perf/hists: Consolidate __hists__add_*entry() (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Add pevent_print_func_field() helper function (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Add flags NOHANDLE and PRINTRAW to individual events (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Check for spaces in character array (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Have bprintk output the same as the kernel does (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Handle __print_hex(__get_dynamic_array(fieldname), len) (Jiri Olsa) [1131394]
- [tools] perf/traceevent: If s is a pointer, check printk formats (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Update printk formats when entered (Jiri Olsa) [1131394]
- [tools] perf/traceevent: Add support for extracting trace_clock in report (Jiri Olsa) [1131394]
- [tools] perf/stat: Enhance option parse error message (Jiri Olsa) [1131394]
- [tools] perf/top: Use parse_options_usage() for -s option failure (Jiri Olsa) [1131394]
- [tools] perf/report: Use parse_options_usage() for -s option failure (Jiri Olsa) [1131394]
- [tools] perf/report: Postpone setting up browser after parsing options (Jiri Olsa) [1131394]
- [tools] perf: Show single option when failed to parse (Jiri Olsa) [1131394]
- [tools] perf/evsel: Synthesize PERF_SAMPLE_TRANSACTION (Jiri Olsa) [1131394]
- [tools] perf/test: Update "sample parsing" test for PERF_SAMPLE_TRANSACTION (Jiri Olsa) [1131394]
- [tools] perf/evsel: Add missing overflow check for TRANSACTION (Jiri Olsa) [1131394]
- [tools] perf/evsel: Always use perf_evsel__set_sample_bit() (Jiri Olsa) [1131394]
- [tools] perf/evlist: Add a debug print if event buffer mmap fails (Jiri Olsa) [1131394]
- [tools] perf: Fix libunwind build and feature detection for 32-bit build (Jiri Olsa) [1131394]
- [tools] perf: Fix 32-bit cross build (Jiri Olsa) [1131394]
- [tools] perf/script: Set up output options for in-stream attributes (Jiri Olsa) [1131394]
- [tools] perf/evsel: Add a debug print if perf_event_open fails (Jiri Olsa) [1131394]
- [tools] perf: Get current comm instead of last one (Jiri Olsa) [1131394]
- [tools] perf: Compare hists comm by addresses (Jiri Olsa) [1131394]
- [tools] perf: Add new COMM infrastructure (Jiri Olsa) [1131394]
- [tools] perf: Add time argument on COMM setting (Jiri Olsa) [1131394]
- [tools] perf: Use an accessor to read thread comm (Jiri Olsa) [1131394]
- [tools] perf: Add missing data.h into LIB_H headers (Jiri Olsa) [1131394]
- [tools] perf/probe: Fix typo (Jiri Olsa) [1131394]
- [tools] perf/bench: Fix two warnings (Jiri Olsa) [1131394]
- [tools] perf: Show progress on histogram collapsing (Jiri Olsa) [1131394]
- [tools] perf/ui/progress: Per progress bar state (Jiri Olsa) [1131394]
- [tools] perf/ui: Rename ui_progress to ui_progress_ops (Jiri Olsa) [1131394]
- [tools] perf: Fix non-debug build (Jiri Olsa) [1131394]
- [tools] perf/evlist: Validate that mmap_pages is not too big (Jiri Olsa) [1131394]
- [tools] perf: Do not accept parse_tag_value() overflow (Jiri Olsa) [1131394]
- [tools] perf/inject: Do not repipe attributes to a perf.data file (Jiri Olsa) [1131394]
- [tools] perf/script: Make perf_script a local variable (Jiri Olsa) [1131394]
- [tools] perf/sched: Optimize build time (Jiri Olsa) [1131394]
- [tools] perf/sched: Make struct perf_sched sched a local variable (Jiri Olsa) [1131394]
- [tools] perf/bench: Change the procps visible command-name of invididual benchmark tests plus cleanups (Jiri Olsa) [1131394]
- [tools] perf/probe: Find fentry mcount fuzzed parameter location (Jiri Olsa) [1131394]
- [tools] perf/probe: Support "$vars" meta argument syntax for local variables (Jiri Olsa) [1131394]
- [tools] perf: Stop using 'self' in some more places (Jiri Olsa) [1131394]
- [tools] perf/test: Consider PERF_SAMPLE_TRANSACTION in the "sample parsing" test (Jiri Olsa) [1131394]
- [tools] perf/test: Clarify the "sample parsing" test entry (Jiri Olsa) [1131394]
- [tools] perf/top: Add --max-stack option to limit callchain stack scan (Jiri Olsa) [1131394]
- [tools] perf/report: Add --max-stack option to limit callchain stack scan (Jiri Olsa) [1131394]
- [tools] perf/session: Separating data file properties from session (Jiri Olsa) [1131394]
- [tools] perf: Add perf_data_file__open interface to data object (Jiri Olsa) [1131394]
- [tools] perf: Add data object to handle perf data file (Jiri Olsa) [1131394]
- [tools] perf: Compare dso's also when comparing symbols (Jiri Olsa) [1131394]
- [tools] perf/callchain: Convert children list to rbtree (Jiri Olsa) [1131394]
- [tools] perf/list: Show error if tracepoints not available (Jiri Olsa) [1131394]
- [tools] perf/script: Print addr by default for BTS (Jiri Olsa) [1131394]
- [tools] perf/evlist: Factor out duplicated mmap code (Jiri Olsa) [1131394]
- [tools] perf/evlist: Fix perf_evlist__mmap comments (Jiri Olsa) [1131394]
- [tools] perf: Fix bench/numa.c for 32-bit build (Jiri Olsa) [1131394]
- [tools] perf: Fix test_on_exit for 32-bit build (Jiri Olsa) [1131394]
- [tools] perf/evlist: Fix 32-bit build error (Jiri Olsa) [1131394]
- [tools] perf/session: Add missing members to perf_event__attr_swap() (Jiri Olsa) [1131394]
- [tools] perf/session: Add missing sample flush for piped events (Jiri Olsa) [1131394]
- [tools] perf/record: Improve write_output error message (Jiri Olsa) [1131394]
- [tools] perf/evsel: Add missing decrement in id sample parsing (Jiri Olsa) [1131394]
- [tools] perf/evsel: Add missing 'mmap2' from debug print (Jiri Olsa) [1131394]
- [tools] perf/trace: Improve messages related to /proc/sys/kernel/perf_event_paranoid (Jiri Olsa) [1131394]
- [tools] perf: Introduce filename__read_int helper (Jiri Olsa) [1131394]
- [tools] perf/evlist: Introduce perf_evlist__strerror_tp method (Jiri Olsa) [1131394]
- [tools] perf/trace: Improve event processing exit (Jiri Olsa) [1131394]
- [tools] perf/trace: Use vfs_getname hook if available (Jiri Olsa) [1131394]
- [tools] perf/trace: Split fd -> pathname array handling (Jiri Olsa) [1131394]
- [tools] perf/symbols: Fix a mmap and munmap mismatched bug (Jiri Olsa) [1131394]
- [tools] perf/symbols: Fix a memory leak due to symbol__delete not being used (Jiri Olsa) [1131394]
- [tools] perf/annotate: Another fix for annotate_browser__callq() (Jiri Olsa) [1131394]
- [tools] perf/buildid-cache: Add ability to add kcore to the cache (Jiri Olsa) [1131394]
- [tools] perf/annotate: Fix annotate_browser__callq() (Jiri Olsa) [1131394]
- [tools] perf/symbols: Add ability to find kcore in build-id cache (Jiri Olsa) [1131394]
- [tools] perf: Add copyfile_mode() (Jiri Olsa) [1131394]
- [tools] perf/annotate: Find kcore symbols on other maps (Jiri Olsa) [1131394]
- [tools] perf/build: Simplify the autodep inclusion rule (Jiri Olsa) [1131394]
- [tools] perf/build: Improve the 'stackprotector' feature test (Jiri Olsa) [1131394]
- [tools] perf/build: Remove the volatile-register-var feature check (Jiri Olsa) [1131394]
- [tools] perf/build: Simplify the libelf logic (Jiri Olsa) [1131394]
- [tools] perf/build: Fix DPACKAGE definitions for the libbfd et al testcases (Jiri Olsa) [1131394]
- [tools] perf/build: Pass through DEBUG parameter (Jiri Olsa) [1131394]
- [tools] perf/build: Fix non-existent build directory handling (Jiri Olsa) [1131394]
- [tools] perf/symbols: Add map_groups__find_ams() (Jiri Olsa) [1131394]
- [tools] perf/symbols: Workaround objdump difficulties with kcore (Jiri Olsa) [1131394]
- [tools] perf/symbols: Validate kcore module addresses (Jiri Olsa) [1131394]
- [tools] perf: Separate lbfd check out of NO_DEMANGLE condition (Jiri Olsa) [1131394]
- [tools] perf/tests: Fix memory leak in dso-data.c (Jiri Olsa) [1131394]
- [tools] perf: Fix old GCC build error in 'get_srcline' (Jiri Olsa) [1131394]
- [tools] perf/trace: Add summary option to dump syscall statistics (Jiri Olsa) [1131394]
- [tools] perf/util: Add findnew method to intlist (Jiri Olsa) [1131394]
- [tools] perf/trace: Improve the error messages (Jiri Olsa) [1131394]
- [tools] perf/timechart: Add example in the documentation (Jiri Olsa) [1131394]
- [tools] perf: Implement summary output for 'make install' (Jiri Olsa) [1131394]
- [tools] perf: Align perf version output to other build messages (Jiri Olsa) [1131394]
- [tools] perf: Harmonize the various build messages in perf, lib-traceevent, lib-lk (Jiri Olsa) [1131394]
- [tools] perf: Implement summary output for 'make clean' (Jiri Olsa) [1131394]
- [tools] perf: Fix redirection printouts (Jiri Olsa) [1131394]
- [tools] perf/trace: Initial beautifier for ioctl's 'cmd' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Prepare the strarray scnprintf method for reuse (Jiri Olsa) [1131394]
- [tools] perf/trace: Allow specifying index offset in strarrays (Jiri Olsa) [1131394]
- [tools] perf/symbols: Make a separate function to parse /proc/modules (Jiri Olsa) [1131394]
- [tools] perf/intlist: Add priv member (Jiri Olsa) [1131394]
- [tools] perf/trace: Use new machine method to loop over threads (Jiri Olsa) [1131394]
- [tools] perf/machine: Add method to loop over threads and invoke handler (Jiri Olsa) [1131394]
- [tools] perf/trace: Add record option (Jiri Olsa) [1131394]
- [tools] perf/trace: Fix comm resolution when reading events from file (Jiri Olsa) [1131394]
- [tools] perf/stat: Add units to nanosec-based counters (Jiri Olsa) [1131394]
- [tools] perf/stat: Don't require a workload when using system wide or CPU options (Jiri Olsa) [1131394]
- [tools] perf/stat: Fix misleading message when specifying cpu list or system wide (Jiri Olsa) [1131394]
- [tools] perf/evlist: Fix perf_evlist__mmap_read event overflow (Jiri Olsa) [1131394]
- [tools] perf: Ignore 'perf timechart' output file (Jiri Olsa) [1131394]
- [tools] perf/stat: Don't print bogus data on -e instructions (Jiri Olsa) [1131394]
- [tools] perf/stat: Don't print bogus data on -e cycles (Jiri Olsa) [1131394]
- [tools] perf: Move start conditions to start of the flex file (Jiri Olsa) [1131394]
- [tools] perf: Add missing -ldl for gtk build (Jiri Olsa) [1131394]
- [tools] perf/machine: Use snprintf instead of sprintf (Jiri Olsa) [1131394]
- [tools] perf/bench sched: Add --threaded option (Jiri Olsa) [1131394]
- [tools] perf/trace: Add 'trace' alias to 'perf trace' (Jiri Olsa) [1131394]
- [tools] perf/trace: Show path associated with fd in live sessions (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify mlock & friends 'addr' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Handle MSG_WAITFORONE not defined (Jiri Olsa) [1131394]
- [tools] perf/trace: Add beautifier for clock_gettime's clk_id argument (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify pipe2 'flags' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Use socket's beautifiers in socketpair (Jiri Olsa) [1131394]
- [tools] perf/trace: Don't supress zeroed args when there is an strarray entry for it (Jiri Olsa) [1131394]
- [tools] perf/trace: Add helper for syscalls with a single strarray arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify flock 'cmd' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify epoll_ctl 'op' arg (Jiri Olsa) [1131394]
- [tools] perf: Fix srcline sort key behavior (Jiri Olsa) [1131394]
- [tools] perf: Implement addr2line directly using libbfd (Jiri Olsa) [1131394]
- [tools] perf: Save failed result of get_srcline() (Jiri Olsa) [1131394]
- [tools] perf/annotate: Pass dso instead of dso_name to get_srcline() (Jiri Olsa) [1131394]
- [tools] perf: Do not try to call addr2line on non-binary files (Jiri Olsa) [1131394]
- [tools] perf/annotate: Factor out get/free_srcline() (Jiri Olsa) [1131394]
- [tools] perf/hists: Free srcline when freeing hist_entry (Jiri Olsa) [1131394]
- [tools] perf/annotate: Reuse path from the result of addr2line (Jiri Olsa) [1131394]
- [tools] perf/sort: Fix a memory leak on srcline (Jiri Olsa) [1131394]
- [tools] perf: Separate out GTK codes to libperf-gtk.so (Jiri Olsa) [1131394]
- [tools] perf/symbols: Add new option --ignore-vmlinux for perf top (Jiri Olsa) [1131394]
- [tools] perf: Adding throttle event data struct support (Jiri Olsa) [1131394]
- [tools] perf/evlist: Introduce perf_evlist__new_default function (Jiri Olsa) [1131394]
- [tools] perf: Add possibility to specify mmap size (Jiri Olsa) [1131394]
- [tools] perf: Check mmap pages value early (Jiri Olsa) [1131394]
- [tools] perf/lock: Account for lock average wait time (Jiri Olsa) [1131394]
- [tools] perf/lock: Limit bad rate precision (Jiri Olsa) [1131394]
- [tools] perf/lock: Redo __cmd_report (Jiri Olsa) [1131394]
- [tools] perf/lock: Plug some memleaks (Jiri Olsa) [1131394]
- [tools] perf/lock: Return proper code in report_lock_*_event (Jiri Olsa) [1131394]
- [tools] perf/lock: Remove dead code (Jiri Olsa) [1131394]
- [tools] perf: Unify page_size usage (Jiri Olsa) [1131394]
- [tools] perf: Remove unused trace-event-* code (Jiri Olsa) [1131394]
- [tools] perf/symbols: Support for Openembedded/Yocto -dbg packages (Jiri Olsa) [1131394]
- [tools] perf/completion: Use more comp words (Jiri Olsa) [1131394]
- [tools] perf/completion: Strip dependency on bash-completion (Jiri Olsa) [1131394]
- [tools] perf/completion: Strip function_exists () (Jiri Olsa) [1131394]
- [tools] perf/completion: Strip dependency on _filedir (Jiri Olsa) [1131394]
- [tools] perf/completion: Update __ltrim_colon_completions (Jiri Olsa) [1131394]
- [tools] perf/completion: Don't dictate perf install location (Jiri Olsa) [1131394]
- [tools] perf/trace: Add option to show process COMM (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify eventfd2 'flags' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify send/recv syscall 'flags' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Don't print zeroed args (Jiri Olsa) [1131394]
- [tools] perf/trace: Remove duplicate mmap entry in syscall_fmts array (Jiri Olsa) [1131394]
- [tools] perf/trace: Add option to show full timestamp (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify rlmimit resources (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify access 'mode' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify socket 'type' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify socket 'family' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify signal number arg in several syscalls (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify rt_sigprocmask 'how' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Beautify fcntl 'cmd' arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Use strarray for ltrace's whence arg (Jiri Olsa) [1131394]
- [tools] perf/trace: Allow passing parms to arg formatters (Jiri Olsa) [1131394]
- [tools] perf/trace: Put syscall formatter parms into struct (Jiri Olsa) [1131394]
- [tools] perf/build: Clean up feature_print_code() (Jiri Olsa) [1131394]
- [tools] perf/build: Pass through LDFLAGS to feature tests (Jiri Olsa) [1131394]
- [tools] perf/build: Harmonize the style of the feature testcases (Jiri Olsa) [1131394]
- [tools] perf/build: Fix O=/some/dir perf.o type of targets (Jiri Olsa) [1131394]
- [tools] perf/build: Fix non-canonical directory names in O= (Jiri Olsa) [1131394]
- [tools] perf/build: Exclude MAKEFLAGS from nested invocation (Jiri Olsa) [1131394]
- [tools] perf/build: Make sure autodep feature binaries honor the O= setting (Jiri Olsa) [1131394]
- [tools] perf/build: Pass through all targets to Makefile.perf (Jiri Olsa) [1131394]
- [tools] perf/build: Collapse the test-all.c testcase (Jiri Olsa) [1131394]
- [tools] perf/build: Clean up various testcases (Jiri Olsa) [1131394]
- [tools] perf/build: Remove unused config/feature-tests.mak (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature checks 'liberty', 'liberty-z', 'cplus-demangle' (Jiri Olsa) [1131394]
- [tools] perf/build: Standardize the various messages output by parallel make (Jiri Olsa) [1131394]
- [tools] perf/build: Flip Makefile.parallel and Makefile.perf (Jiri Olsa) [1131394]
- [tools] perf/build: Automatically build in parallel, based on number of CPUs in the system (Jiri Olsa) [1131394]
- [tools] perf/build: Improve printout-of auto-detected features (Jiri Olsa) [1131394]
- [tools] perf/build: Speed up auto-detection (Jiri Olsa) [1131394]
- [tools] perf/build: Invoke feature-checks 'clean' target from the main Makefile (Jiri Olsa) [1131394]
- [tools] perf: Fix double/triple-build of the feature detection logic during 'make install' et al (Jiri Olsa) [1131394]
- [tools] perf/build: Speed up the final link (Jiri Olsa) [1131394]
- [tools] perf/build: Speed up git-version test on re-make (Jiri Olsa) [1131394]
- [tools] perf/build: Speed up auto-detection of features by adding a 'test-all' target (Jiri Olsa) [1131394]
- [tools] perf: Turn strlcpy() into a __weak function (Jiri Olsa) [1131394]
- [tools] perf: Clean up util/include/linux/compiler.h (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'backtrace' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'on-exit' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'strlcpy' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libbfd' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libpython-version' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libpython' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libperl' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'gtk2-infobar' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'gtk2' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libslang' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libaudit' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libunwind' (Jiri Olsa) [1131394]
- [tools] perf/build: Clean up the libunwind logic in config/Makefile (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libelf-getphdrnum' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libelf-mmap' (Jiri Olsa) [1131394]
- [tools] perf/build: Clean up the mmap logic in config/Makefile (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'dwarf' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'glibc' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libelf' (Jiri Olsa) [1131394]
- [tools] perf/build: Clean up the libelf logic in config/Makefile (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'bionic' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'fortify-source' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'volatile-register-var' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'stackprotector' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'stackprotector-all' (Jiri Olsa) [1131394]
- [tools] perf/build: split out feature check 'libnuma' (Jiri Olsa) [1131394]
- [tools] perf/build: Add 'autodep' functionality, generate feature test dependencies automatically (Jiri Olsa) [1131394]
- [tools] perf/build: Add feature check core code (Jiri Olsa) [1131394]
- [tools] perf: standardize feature support define names to HAVE_{FEATURE}_SUPPORT (Jiri Olsa) [1131394]
- [tools] perf: Add support for record transaction flags (Jiri Olsa) [1131394]
- [tools] perf/record: Add abort_tx, no_tx, in_tx branch filter options to perf record -j (Jiri Olsa) [1131394]
- [tools] perf: Support sorting by in_tx or abort branch flags (Jiri Olsa) [1131394]
- [tools] perf: Fix sorting for 64bit entries (Jiri Olsa) [1131394]
- [tools] perf: Disable all pmus on unthrottling and rescheduling (Jiri Olsa) [1131394]
- [x86] perf: Fix constraint table end marker bug (Jiri Olsa) [1131394]
- [tools] perf: Remove fragile swevent hlist optimization (Jiri Olsa) [1131394]
- [tools] perf: Factor out strncpy() in perf_event_mmap_event() (Jiri Olsa) [1131394]
- [tools] perf: Update a stale comment (Jiri Olsa) [1131394]
- [tools] perf: Optimize perf_output_begin() -- address calculation (Jiri Olsa) [1131394]
- [tools] perf: Optimize perf_output_begin() -- lost_event case (Jiri Olsa) [1131394]
- [tools] perf: Optimize perf_output_begin() (Jiri Olsa) [1131394]
- [tools] perf: Add unlikely() to the ring-buffer code (Jiri Olsa) [1131394]
- [tools] perf: Simplify the ring-buffer code (Jiri Olsa) [1131394]
- [tools] perf: Fix the perf context switch optimization (Jiri Olsa) [1131394]
- [tools] perf: Change zero-padding of strings in perf_event_mmap_event() (Jiri Olsa) [1131394]
- [tools] perf: Do not waste PAGE_SIZE bytes for ALIGN(8) in perf_event_mmap_event() (Jiri Olsa) [1131394]
- [tools] perf: Kill the dead !vma->vm_mm code in perf_event_mmap_event() (Jiri Olsa) [1131394]
- [tools] perf: Remove useless atomic_t (Jiri Olsa) [1131394]
- [x86] perf: Optimize intel_pmu_pebs_fixup_ip() (Jiri Olsa) [1131394]
- [x86] perf: Suppress duplicated abort LBR records (Jiri Olsa) [1131394]
- [x86] perf: Add Haswell specific transaction flag reporting (Jiri Olsa) [1131394]
- [tools] perf: Add generic transaction flags (Jiri Olsa) [1131394]
- [tools] perf: Enforce 1 as lower limit for perf_event_max_sample_rate (Jiri Olsa) [1131394]
- [x86] perf/intel: Fix build warning in intel_pmu_drain_pebs_nhm() (Jiri Olsa) [1131394]
- [x86] perf/intel: Remove division from the intel_pmu_drain_pebs_nhm() hot path (Jiri Olsa) [1131394]
- [x86] perf/intel: Clean up EVENT_ATTR_STR() muck (Jiri Olsa) [1131394]
- [x86] perf/intel: Clean-up/reduce PEBS code (Jiri Olsa) [1131394]
- [x86] perf/intel: Clean up checkpoint-interrupt bits (Jiri Olsa) [1131394]
- [x86] perf/intel: Add Haswell TSX event aliases (Jiri Olsa) [1131394]
- [x86] perf: Report TSX transaction abort cost as weight (Jiri Olsa) [1131394]
- [x86] perf/intel: Avoid checkpointed counters causing excessive TSX aborts (Jiri Olsa) [1131394]

* Wed Sep 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-154.el7]
- [scsi] ipr: Add new CCIN definition for Grand Canyon support (Gustavo Duarte) [1088561]
- [scsi] ipr: Format HCAM overlay ID 0x21 (Gustavo Duarte) [1088561]
- [scsi] ipr: Handle early EEH (Gustavo Duarte) [1088561]
- [scsi] ipr: Add new CCIN definition for new hardware support (Gustavo Duarte) [1088561]
- [scsi] ipr: Remove extended delay bit on GSCSI reads/writes ops (Gustavo Duarte) [1088561]
- [scsi] ipr: increase dump size in ipr driver (Gustavo Duarte) [1088561]
- [kernel] trace: Remove function_trace_stop and HAVE_FUNCTION_TRACE_MCOUNT_TEST (Josh Poimboeuf) [1113829]
- [s390] ftrace: remove check of obsolete variable function_trace_stop (Josh Poimboeuf) [1113829]
- [x86] ftrace: Remove check of obsolete variable function_trace_stop (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Remove check for HAVE_FUNCTION_TRACE_MCOUNT_TEST (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Remove function_trace_stop check from list func (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Do no disable function tracing on enabling function tracing (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Remove ftrace_start/stop() (Josh Poimboeuf) [1113829]
- [kernel] ftrace-graph: Remove usage of ftrace_stop() in ftrace_graph_stop() (Josh Poimboeuf) [1113829]
- [powerpc] kernel/ftrace: Add call to ftrace_graph_is_dead() in function graph code (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Add call to ftrace_graph_is_dead() in function graph code (Josh Poimboeuf) [1113829]
- [kernel] ftrace-graph: Remove dependency of ftrace_stop() from ftrace_graph_stop() (Josh Poimboeuf) [1113829]
- [kernel] trace: Remove ftrace_stop/start() from reading the trace file (Josh Poimboeuf) [1113829]
- [kernel] power: Remove ftrace_stop/start() from suspend and hibernate (Josh Poimboeuf) [1113829]
- [x86] power/cpu: Annotate restore_processor_state() with notrace (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Move the mcount/fentry code out of entry_64.S (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Load ftrace_ops in parameter not the variable holding it (Josh Poimboeuf) [1113829]
- [kernel] trace: Remove unused function ftrace_off_permanent() (Josh Poimboeuf) [1113829]
- [kernel] ftrace: BUG when ftrace recovery fails (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Have ftrace_write() return -EPERM and clean up callers (Josh Poimboeuf) [1113829]
- [kernel] ftrace: One more missing sync after fixup of function modification failure (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Run a sync after fixup on failure (Josh Poimboeuf) [1113829]
- [kernel] ftrace: Use breakpoints for converting function graph caller (Josh Poimboeuf) [1113829]
- [kernel] ftrace: skip over the breakpoint for ftrace caller (Josh Poimboeuf) [1113829]
- [s390] kprobes: add support for pc-relative long displacement instructions (Hendrik Brueckner) [1123429]
- [kernel] kprobes: allow to specify custom allocator for insn caches (Hendrik Brueckner) [1123429]
- [kernel] kprobes: unify insn caches (Hendrik Brueckner) [1123429]
- [kernel] uprobes: Rename arch_uprobe->def to ->defparam, minor comment updates (Oleg Nesterov) [1073627]
- [kernel] uprobes: Fix scratch register selection for rip-relative fixups (Oleg Nesterov) [1073627]
- [kernel] uprobes: Simplify rip-relative handling (Oleg Nesterov) [1073627]
- [kernel] uprobes: Simplify riprel_{pre,post}_xol() and make them similar (Oleg Nesterov) [1073627]
- [kernel] uprobes: Kill the "autask" arg of riprel_pre_xol() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Rename *riprel* helpers to make the naming consistent (Oleg Nesterov) [1073627]
- [kernel] uprobes: Cleanup the usage of UPROBE_FIX_IP/UPROBE_FIX_CALL (Oleg Nesterov) [1073627]
- [kernel] uprobes: Kill adjust_ret_addr(), simplify UPROBE_FIX_CALL logic (Oleg Nesterov) [1073627]
- [kernel] uprobes: Introduce push_ret_address() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Cleanup the usage of arch_uprobe->def.fixups, make it u8 (Oleg Nesterov) [1073627]
- [kernel] uprobes: Move default_xol_ops's data into arch_uprobe->def (Oleg Nesterov) [1073627]
- [kernel] uprobes: Move UPROBE_FIX_SETF logic from arch_uprobe_post_xol() to default_post_xol_op() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Don't use arch_uprobe_abort_xol() in arch_uprobe_post_xol() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Introduce uprobe_xol_ops->abort() and default_abort_op() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Don't change the task's state if ->pre_xol() fails (Oleg Nesterov) [1073627]
- [kernel] uprobes: Fix is_64bit_mm() with CONFIG_X86_X32 (Oleg Nesterov) [1073627]
- [kernel] uprobes: Make good_insns_* depend on CONFIG_X86_* (Oleg Nesterov) [1073627]
- [kernel] uprobes: Shift "insn_complete" from branch_setup_xol_ops() to uprobe_init_insn() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Add is_64bit_mm(), kill validate_insn_bits() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Add uprobe_init_insn(), kill validate_insn_{32,64}bits() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Refuse to attach uprobe to "word-sized" branch insns (Oleg Nesterov) [1073627]
- [kernel] uprobes: Emulate relative conditional "near" jmp's (Oleg Nesterov) [1073627]
- [kernel] uprobes: Emulate relative conditional "short" jmp's (Oleg Nesterov) [1073627]
- [kernel] uprobes: Emulate relative call's (Oleg Nesterov) [1073627]
- [kernel] uprobes: Emulate nop's using ops->emulate() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Emulate unconditional relative jmp's (Oleg Nesterov) [1073627]
- [kernel] uprobes: Introduce sizeof_long(), cleanup adjust_ret_addr() and arch_uretprobe_hijack_return_addr() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Teach arch_uprobe_post_xol() to restart if possible (Oleg Nesterov) [1073627]
- [kernel] uprobes: Send SIGILL if arch_uprobe_post_xol() fails (Oleg Nesterov) [1073627]
- [kernel] uprobes: Conditionalize the usage of handle_riprel_insn() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Introduce uprobe_xol_ops and arch_uprobe->ops (Oleg Nesterov) [1073627]
- [kernel] uprobes: move the UPROBE_FIX_{RIP,IP,CALL} code at the end of pre/post hooks (Oleg Nesterov) [1073627]
- [kernel] uprobes: Gather "riprel" functions together (Oleg Nesterov) [1073627]
- [kernel] uprobes: Kill the "ia32_compat" check in handle_riprel_insn(), remove "mm" arg (Oleg Nesterov) [1073627]
- [kernel] uprobes: Fold prepare_fixups() into arch_uprobe_analyze_insn() (Oleg Nesterov) [1073627]
- [kernel] uprobes: Kill UPROBE_SKIP_SSTEP and can_skip_sstep() (Oleg Nesterov) [1073627]

* Fri Sep 05 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-153.el7]
- [ethernet] enic: Add ethtool support to show classifier filters added by the driver (Stefan Assmann) [1107934]
- [ethernet] enic: remove #ifdef CONFIG_RFS_ACCEL around filter structures (Stefan Assmann) [1107934]
- [ethernet] enic: fix return values in enic_set_coalesce (Stefan Assmann) [1107934]
- [ethernet] enic: Make dummy rfs functions inline to fix !CONFIG_RFS_ACCEL build (Stefan Assmann) [1107934]
- [ethernet] enic: do tx cleanup in napi poll (Stefan Assmann) [1107934]
- [ethernet] enic: add low latency socket busy_poll support (Stefan Assmann) [1107934]
- [ethernet] enic: fix lockdep around devcmd_lock (Stefan Assmann) [1107934]
- [ethernet] enic: Add Accelerated RFS support (Stefan Assmann) [1107934]
- [net] Add skb_get_hash_raw (Stefan Assmann) [1107934]
- [net] flow_keys: Record IP layer protocol in skb_flow_dissect() (Stefan Assmann) [1107934]
- [ethernet] enic: alloc/free rx_cpu_rmap (Stefan Assmann) [1107934]
- [ethernet] enic: devcmd for adding IP 5 tuple hardware filters (Stefan Assmann) [1107934]
- [ethernet] enic: fix return value in _vnic_dev_cmd (Stefan Assmann) [1107934]
- [ethernet] enic: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Stefan Assmann) [1107934]
- [ethernet] enic: Fix 64 bit divide on 32bit system (Stefan Assmann) [1107934]
- [ethernet] enic: Add support for adaptive interrupt coalescing (Stefan Assmann) [1107934]
- [ethernet] enic: get rid of SET_ETHTOOL_OPS (Stefan Assmann) [1107934]
- [ethernet] enic: include irq.h for irqreturn_t definitions (Stefan Assmann) [1107934]
- [ethernet] enic: Call dev_kfree_skb_any instead of dev_kfree_skb (Stefan Assmann) [1107934]
- [ethernet] enic: Don't receive packets when the napi budget == 0 (Stefan Assmann) [1107934]
- [ethernet] enic: Use pci_enable_msix_range() instead of pci_enable_msix() (Stefan Assmann) [1107934]
- [ethernet] enic: slight optimization of addr compare (Stefan Assmann) [1107934]
- [ethernet] enic: cisco-enic calls skb_set_hash (Stefan Assmann) [1107934]
- [ethernet] enic: remove unnecessary pci_set_drvdata() (Stefan Assmann) [1107934]
- [ethernet] i40e/i40evf: Bump i40e & i40evf version (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Ignore a driver perceived Tx hang if the number of desc pending < 4 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add max buf len to aq debug print helper (Stefan Assmann) [1091127]
- [ethernet] i40evf: Remove DEFINE_PCI_DEVICE_TABLE macro use (Stefan Assmann) [1091127]
- [ethernet] i40evf: Fixed guest OS panic when removing vf driver (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix memory leak on unused interfaces (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't leak queue vectors (Stefan Assmann) [1091127]
- [ethernet] i40evf: do not re-arm watchdog after remove (Stefan Assmann) [1091127]
- [ethernet] i40evf: future-proof vfr_stat state check (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix scan warning on sprintf (Stefan Assmann) [1091127]
- [ethernet] i40e: always print aqtx answer (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: ARQ copy desc data even for failed commands (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't wait so long (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: fix extension header csum logic (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add nvmupdate support (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Clean up code (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove unnecessary break after goto (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.21 and i40evf to 0.9.40 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add set_fc and init of FC settings (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add new HW link info variable an_enabled and function update_link_info (Stefan Assmann) [1091127]
- [ethernet] i40evf: invite vector 0 to the interrupt party (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Force a shifted '1' to be unsigned (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't violate scope (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Do not free the dummy packet buffer synchronously (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.19 and i40evf to 0.9.38 (Stefan Assmann) [1091127]
- [ethernet] i40evf: change branding string (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: initialize context descriptor (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add ASQ write back timeout variable to AQ structure (Stefan Assmann) [1091127]
- [ethernet] i40evf: set flags before sending message (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: clear aq bah-bal on shutdown (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add base address registers to aq struct (Stefan Assmann) [1091127]
- [ethernet] i40evf: resend FW request if no response (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix typo (Stefan Assmann) [1091127]
- [ethernet] i40evf: return more useful error information (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't stop watchdog if it hasn't started (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Big endian fixes for handling HMC (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.17 and i40evf to 0.9.36 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove reserved type (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.13 and i40evf to 0.9.35 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: modify debug prints to avoid seg faults (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Update RSS configuration (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix off-by-one (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Reset Head and Tail on AQ initialization (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: i40e_register.h update (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e to version 0.4.10 and i40evf to 0.9.34 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add Flow director stats to PF stats (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove FTYPE (Stefan Assmann) [1091127]
- [ethernet] i40evf: check admin queue error bits (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: User ether_addr_copy instead of memcpy (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't go further down (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: AdminQ API update for new FW (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: set headwb Tx context flags and use them (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: bump version to 0.4.7 for i40e and 0.9.31 for i40evf (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add PPRS bit to error bits and fix bug in Rx checksum (Stefan Assmann) [1091127]
- [ethernet] i40evf: Fix function header (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove deprecated device IDs (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: fix poll weight (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: fix TSO accounting (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove chatty reset messages (Stefan Assmann) [1091127]
- [ethernet] i40evf: use correct format for printing MAC addresses (Stefan Assmann) [1091127]
- [ethernet] i40evf: clean up log message formatting (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove bogus comment (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove unnecessary log messages (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Clean up a few things (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Fix code to accommodate i40e_register.h changes (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: fix rx descriptor status (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add Tx pre queue disable function (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: check AQ register for valid data (Stefan Assmann) [1091127]
- [ethernet] i40evf: make messages less dire (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove rx_errors and rx_missed (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: VEB structure added, GTIME macro update (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix crash when changing ring sizes (Stefan Assmann) [1091127]
- [ethernet] i40evf: set descriptor multiple to 32 (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove unused RX_LRO define (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't use RESETTING state during reinit (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Change type to u32 to avoid sparse error (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: remove storm control (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Remove reserved PCTYPE defines (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Update check for AQ aliveness (Stefan Assmann) [1091127]
- [ethernet] i40evf: Use is_multicast_ether_addr helper (Stefan Assmann) [1091127]
- [ethernet] i40e: remove usless return statements (Stefan Assmann) [1091127]
- [ethernet] i40evf: Use pci_enable_msix_range() instead of pci_enable_msix() (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: control auto ITR through ethtool (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: set proper default for ITR registers (Stefan Assmann) [1091127]
- [ethernet] i40evf: make ethtool_ops const (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't lie to ethtool (Stefan Assmann) [1091127]
- [ethernet] i40evf: Use macro param for ethtool stats (Stefan Assmann) [1091127]
- [ethernet] i40evf: Fix the headers and update copyright year (Stefan Assmann) [1091127]
- [ethernet] i40evf: Remove unused defines (Stefan Assmann) [1091127]
- [ethernet] i40evf: Update AdminQ interface (Stefan Assmann) [1091127]
- [ethernet] i40evf: get rid of SET_ETHTOOL_OPS (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Retrieve and store missing link config information (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove debugging message (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix panic on PF driver fail (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add driver version string to driver version command (Stefan Assmann) [1091127]
- [ethernet] i40evf: support ethtool RSS options (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: update AdminQ API (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: add tracking to NVM busy state (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: unhide and enable to one prefena field (Stefan Assmann) [1091127]
- [ethernet] i40evf: program RSS LUT correctly (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove open-coded skb_cow_head (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Remove addressof casts to same type (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: fix error checking path (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add an FD message level (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove double space after return (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix oops in watchdog handler (Stefan Assmann) [1091127]
- [ethernet] i40evf: clean up init error messages (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't shut down admin queue on error (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Add EEE LPI stats (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: reduce context descriptors (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: enable hardware feature head write back (Stefan Assmann) [1091127]
- [ethernet] i40evf: use min_t (Stefan Assmann) [1091127]
- [ethernet] i40evf: correctly program RSS HLUT table (Stefan Assmann) [1091127]
- [ethernet] i40evf: Rename i40e_ptype_lookup i40evf_ptype_lookup (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Use dma_set_mask_and_coherent (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Use correct number of VF vectors (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Some flow director HW definition fixes (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump pf&vf build versions (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: carefully fill tx ring (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: i40e implementation for skb_set_hash (Stefan Assmann) [1091127]
- [ethernet] i40evf: Enable the ndo_set_features netdev op (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump driver versions (Stefan Assmann) [1091127]
- [ethernet] i40e: Change MSIX to MSI-X (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove errant space (Stefan Assmann) [1091127]
- [ethernet] i40evf: update version and copyright date (Stefan Assmann) [1091127]
- [ethernet] i40evf: store ring size in ring structs (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't guess device name (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove bogus comment (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix up strings in init task (Stefan Assmann) [1091127]
- [ethernet] i40evf: get rid of pci_using_dac (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix multiple crashes on remove (Stefan Assmann) [1091127]
- [ethernet] i40evf: remove VLAN filters on close (Stefan Assmann) [1091127]
- [ethernet] i40evf: request reset on tx hang (Stefan Assmann) [1091127]
- [ethernet] i40evf: Remove duplicate include (Stefan Assmann) [1091127]
- [ethernet] i40evf: refactor reset handling (Stefan Assmann) [1091127]
- [ethernet] i40evf: change type of flags variable (Stefan Assmann) [1091127]
- [ethernet] i40evf: don't store unnecessary array of strings (Stefan Assmann) [1091127]
- [ethernet] i40evf: fix bogus comment (Stefan Assmann) [1091127]
- [ethernet] i40evf: clean up adapter struct (Stefan Assmann) [1091127]
- [ethernet] i40evf: trivial fixes (Stefan Assmann) [1091127]
- [ethernet] i40e: spelling error (Stefan Assmann) [1091127]
- [ethernet] i40e: Fix device ID define names to align to standard (Stefan Assmann) [1091127]
- [ethernet] i40e/i40evf: Bump i40e & i40evf version (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Ignore a driver perceived Tx hang if the number of desc pending < 4 (Stefan Assmann) [1091126]
- [ethernet] i40e: quiet complaints when removing default MAC VLAN filter and make set_mac reversible (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add max buf len to aq debug print helper (Stefan Assmann) [1091126]
- [ethernet] i40e: Add checks and message for Qualified Module info (Stefan Assmann) [1091126]
- [ethernet] i40e: set num_queue_pairs to num configured by VF (Stefan Assmann) [1091126]
- [ethernet] i40e: Enable l2tsel bit for VLAN tag control (Stefan Assmann) [1091126]
- [ethernet] i40e: Add a FD flush counter to ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e: ATR policy change to flush the table to clean stale ATR rules (Stefan Assmann) [1091126]
- [ethernet] i40e: Some FD message fixes (Stefan Assmann) [1091126]
- [ethernet] i40e: Update flow director error messages to reduce user confusion (Stefan Assmann) [1091126]
- [ethernet] i40e: fix PTP bug (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix a few potential VF dereferences (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix for recent kernel panic (Stefan Assmann) [1091126]
- [ethernet] i40e: Remove DEFINE_PCI_DEVICE_TABLE macro use (Stefan Assmann) [1091126]
- [ethernet] i40e: Cleaning up missing null-terminate in conjunction with strncpy (Stefan Assmann) [1091126]
- [ethernet] i40e: use correct structure type name in sizeof (Stefan Assmann) [1091126]
- [ethernet] i40e: fix sparse non static symbol warning (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix missing uapi/linux/dcbnl.h include in i40e_fcoe.c (Stefan Assmann) [1091126]
- [ethernet] i40e: remove support for vf unicast promiscuous mode (Stefan Assmann) [1091126]
- [ethernet] i40e: Minor comment changes (Stefan Assmann) [1091126]
- [ethernet] i40e: disable local loopback on vmdq vsi (Stefan Assmann) [1091126]
- [ethernet] i40e: use correct vf_id offset for virtchnl message (Stefan Assmann) [1091126]
- [ethernet] i40e: expose debug_write_register request (Stefan Assmann) [1091126]
- [ethernet] i40e: adds FCoE to build and updates its documentation (Stefan Assmann) [1091126]
- [ethernet] i40e: Adds FCoE related code to i40e core driver (Stefan Assmann) [1091126]
- [ethernet] i40e: adds FCoE code to the i40e driver (Stefan Assmann) [1091126]
- [ethernet] i40e: always print aqtx answer (Stefan Assmann) [1091126]
- [ethernet] i40e: Give link more time after setting flow control (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix firmware API version errors (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: ARQ copy desc data even for failed commands (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: fix extension header csum logic (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add nvmupdate support (Stefan Assmann) [1091126]
- [ethernet] i40e: fix format mismatch in drivers/net/ethernet/intel/i40e/i40e_debugfs.c (Stefan Assmann) [1091126]
- [ethernet] i40e: (ptp) warn when PF_ID does not match in PRTTSYN_CTL0 (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Clean up code (Stefan Assmann) [1091126]
- [ethernet] i40e: fix race conditions on queuing skb for HW time stamp (Stefan Assmann) [1091126]
- [ethernet] i40e: never generate both software and hardware timestamps (Stefan Assmann) [1091126]
- [ethernet] i40e: Add ndo_get_phys_port_id() callback support (Stefan Assmann) [1091126]
- [ethernet] i40e: remove unnecessary break after goto (Stefan Assmann) [1091126]
- [net] bridge: fdb dumping takes a filter device (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.21 and i40evf to 0.9.40 (Stefan Assmann) [1091126]
- [ethernet] i40e: Implement set_settings for ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e: Add set_pauseparam to ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add set_fc and init of FC settings (Stefan Assmann) [1091126]
- [ethernet] i40e: move nway reset (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add new HW link info variable an_enabled and function update_link_info (Stefan Assmann) [1091126]
- [ethernet] i40e: Finish implementation of ethtool get settings (Stefan Assmann) [1091126]
- [ethernet] i40e: disable TPH (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix a boundary condition and turning off of ntuple (Stefan Assmann) [1091126]
- [ethernet] i40e: tolerate lost interrupts (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Force a shifted '1' to be unsigned (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Do not free the dummy packet buffer synchronously (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.19 and i40evf to 0.9.38 (Stefan Assmann) [1091126]
- [ethernet] i40e: remove linux/export.h header from i40e_ptp.c (Stefan Assmann) [1091126]
- [ethernet] i40e: limit GLLAN_TXPRE_QDIS to QINDX 0-127 (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: initialize context descriptor (Stefan Assmann) [1091126]
- [ethernet] i40e: FD filter replay logic bug fix (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add ASQ write back timeout variable to AQ structure (Stefan Assmann) [1091126]
- [ethernet] i40e: Correct mask assignment value (Stefan Assmann) [1091126]
- [ethernet] i40e: clear all queues and interrupts (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: clear aq bah-bal on shutdown (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add base address registers to aq struct (Stefan Assmann) [1091126]
- [ethernet] i40e: fix fdir programming (Stefan Assmann) [1091126]
- [ethernet] i40e: Add debugfs hooks to print current total FD filter count (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix the FD sideband logic to detect a FD table full condition (Stefan Assmann) [1091126]
- [ethernet] i40e: Avoid adding the TCP-IPv4 filter twice (Stefan Assmann) [1091126]
- [ethernet] i40e: only create PTP device node once (Stefan Assmann) [1091126]
- [ethernet] i40e: don't store user requested mode until we've validated it (Stefan Assmann) [1091126]
- [ethernet] i40e: break PTP hardware control from ioctl command for timestamp mode (Stefan Assmann) [1091126]
- [ethernet] i40e: rename i40e_ptp_enable to i40e_ptp_feature_enable (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Big endian fixes for handling HMC (Stefan Assmann) [1091126]
- [ethernet] i40e: do not take NVM ownership for SR read (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.17 and i40evf to 0.9.36 (Stefan Assmann) [1091126]
- [ethernet] i40e: Bypass timeout recovery level 0 so as to not cause MDD (Stefan Assmann) [1091126]
- [ethernet] i40e: no pf reset at pci remove (Stefan Assmann) [1091126]
- [ethernet] i40e: reapply LAA after reset (Stefan Assmann) [1091126]
- [ethernet] i40e: allow user to set LAA again (Stefan Assmann) [1091126]
- [ethernet] i40e: use WoL flag when setting LAA (Stefan Assmann) [1091126]
- [ethernet] i40e: Add ablitity to enable/disable link from set_link_restart_an (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove reserved type (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix ethtool coalesce settings (Stefan Assmann) [1091126]
- [ethernet] i40e: fix a stray print message (Stefan Assmann) [1091126]
- [ethernet] i40e: warn on newer/older firmware API rev (Stefan Assmann) [1091126]
- [ethernet] i40e: Add PF reset when Malicious driver event for PF (Stefan Assmann) [1091126]
- [ethernet] i40e: make prep_for_reset void (Stefan Assmann) [1091126]
- [ethernet] i40e: Stop the VF device after setting its MAC address (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump i40e to 0.4.13 and i40evf to 0.9.35 (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: modify debug prints to avoid seg faults (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Update RSS configuration (Stefan Assmann) [1091126]
- [ethernet] i40e: keep service tasks out of reset process (Stefan Assmann) [1091126]
- [ethernet] i40e: clear VEB stats when pf stats are cleared (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix scheduling while atomic bug during NAPI (Stefan Assmann) [1091126]
- [ethernet] i40e: debugfs fix to dump remote LLDPDU (Stefan Assmann) [1091126]
- [ethernet] i40e: Helper routine for Rx/Tx queue enable/disable wait (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix dangling ring pointers upon driver removal (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Reset Head and Tail on AQ initialization (Stefan Assmann) [1091126]
- [ethernet] i40e: workaround NVM GLQF_HKEY (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: i40e_register.h update (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump i40e to version 0.4.10 and i40evf to 0.9.34 (Stefan Assmann) [1091126]
- [ethernet] i40e: use stored base_queue value (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix a bug in ethtool for FD drop packet filter action (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add Flow director stats to PF stats (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove FTYPE (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: User ether_addr_copy instead of memcpy (Stefan Assmann) [1091126]
- [net] etherdevice: Use ether_addr_copy to copy an Ethernet address (Stefan Assmann) [1091126]
- [ethernet] i40e: Do not accept tagged packets by default (Stefan Assmann) [1091126]
- [ethernet] i40e: Separate out DCB capability and enabled flags (Stefan Assmann) [1091126]
- [ethernet] i40e: Change the notion of src and dst for FD_SB in ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: AdminQ API update for new FW (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: set headwb Tx context flags and use them (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: bump version to 0.4.7 for i40e and 0.9.31 for i40evf (Stefan Assmann) [1091126]
- [ethernet] i40e: Allow RSS table entry range and GPS to be any number, not necessarily power of 2 (Stefan Assmann) [1091126]
- [ethernet] i40e: Delete stale MAC filters after change (Stefan Assmann) [1091126]
- [ethernet] i40e: Do not fall back to one queue model if the only feature enabled is ATR (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add PPRS bit to error bits and fix bug in Rx checksum (Stefan Assmann) [1091126]
- [ethernet] i40e: keep SR-IOV enabled in the case that RSS, VMDQ, FD_SB and DCB are disabled (Stefan Assmann) [1091126]
- [ethernet] i40e: Changes to Interrupt distribution policy (Stefan Assmann) [1091126]
- [ethernet] i40e: implement anti-spoofing for VFs (Stefan Assmann) [1091126]
- [ethernet] i40e: don't complain about removing non-existent addresses (Stefan Assmann) [1091126]
- [ethernet] i40e: remove unused variable and memory allocation (Stefan Assmann) [1091126]
- [ethernet] i40e: allow for more VSIs (Stefan Assmann) [1091126]
- [ethernet] i40e: add checks for AQ error status bits (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove deprecated device IDs (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: fix poll weight (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: fix TSO accounting (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove chatty reset messages (Stefan Assmann) [1091126]
- [ethernet] i40e: not all VSIs have rings (Stefan Assmann) [1091126]
- [ethernet] i40e: clear pxe after adminq is rebuilt (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix incorrect feature configuration status (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Clean up a few things (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Fix code to accommodate i40e_register.h changes (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: fix rx descriptor status (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091126]
- [ethernet] i40e: remove irqs only when they are set up (Stefan Assmann) [1091126]
- [ethernet] i40e: don't remove HMC that doesn't exist (Stefan Assmann) [1091126]
- [ethernet] i40e: print full link message (Stefan Assmann) [1091126]
- [ethernet] i40e: add xcast stats for port (Stefan Assmann) [1091126]
- [ethernet] i40e: add vsi x-cast stats (Stefan Assmann) [1091126]
- [ethernet] i40e: increase reset wait time (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add Tx pre queue disable function (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: check AQ register for valid data (Stefan Assmann) [1091126]
- [ethernet] i40e: print message for pre-production hardware (Stefan Assmann) [1091126]
- [ethernet] i40e: add VEB stats to ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e: set lan_veb index (Stefan Assmann) [1091126]
- [ethernet] i40e: add missing VSI statistics (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove rx_errors and rx_missed (Stefan Assmann) [1091126]
- [ethernet] i40e: refactor stats collection (Stefan Assmann) [1091126]
- [ethernet] i40e: refactor send version (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: VEB structure added, GTIME macro update (Stefan Assmann) [1091126]
- [ethernet] i40e: notify VF of all types of resets (Stefan Assmann) [1091126]
- [ethernet] i40e: clamp jumbo frame size (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove unused RX_LRO define (Stefan Assmann) [1091126]
- [ethernet] i40e: remove check for large buffer (Stefan Assmann) [1091126]
- [ethernet] i40e: Rework register diagnostic (Stefan Assmann) [1091126]
- [ethernet] i40e: don't use OR to check a value (Stefan Assmann) [1091126]
- [ethernet] i40e: relax the firmware API version check (Stefan Assmann) [1091126]
- [ethernet] i40e: disable FCoE for MFP modes (Stefan Assmann) [1091126]
- [ethernet] i40e: add clear_pxe AdminQ request (Stefan Assmann) [1091126]
- [ethernet] i40e: Clear recovery pending, if reset failed (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Change type to u32 to avoid sparse error (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: remove storm control (Stefan Assmann) [1091126]
- [ethernet] i40e: Use the new i40e_get_fd_cnt_all function in other places (Stefan Assmann) [1091126]
- [ethernet] i40e: Report cmd->data in ETHTOOL_GRXCLSRLCNT instead of ETHTOOL_GRXCLSRULE (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Remove reserved PCTYPE defines (Stefan Assmann) [1091126]
- [ethernet] i40e: Tx/Rx rings declaration (Stefan Assmann) [1091126]
- [ethernet] i40evf: tweak Tx rate params and de-magic-ify (Stefan Assmann) [1091126]
- [ethernet] i40evf: don't round Tx rate down to 0 (Stefan Assmann) [1091126]
- [ethernet] i40e: enable descriptor prefetch for VFs (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Update check for AQ aliveness (Stefan Assmann) [1091126]
- [ethernet] i40e: remove usless return statements (Stefan Assmann) [1091126]
- [ethernet] i40e: fix passing wrong error code to i40e_open() (Stefan Assmann) [1091126]
- [ethernet] i40e: Check PCI_IOV config to avoid compile error (Stefan Assmann) [1091126]
- [ethernet] i40e: remove Tx work for ptp (Stefan Assmann) [1091126]
- [ethernet] i40e: Don't disable SR-IOV when VFs are assigned (Stefan Assmann) [1091126]
- [ethernet] i40e: remove hardcode of stats struct size in ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: control auto ITR through ethtool (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: set proper default for ITR registers (Stefan Assmann) [1091126]
- [ethernet] i40e: add required include (Stefan Assmann) [1091126]
- [ethernet] i40e: get rid of SET_ETHTOOL_OPS (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build version (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Retrieve and store missing link config information (Stefan Assmann) [1091126]
- [ethernet] i40e: Update function formal parameters (Stefan Assmann) [1091126]
- [ethernet] i40e: Do not expose fd-sb commands from debugfs (Stefan Assmann) [1091126]
- [ethernet] i40e: Do not enable NTUPLE feature control in MFP mode (Stefan Assmann) [1091126]
- [ethernet] i40e: Change variable type to avoid typecheck failure (Stefan Assmann) [1091126]
- [ethernet] i40e: Don't stop driver probe when querying DCB config fails (Stefan Assmann) [1091126]
- [ethernet] i40e: Redistribute queue vectors after DCB reconfiguration (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add driver version string to driver version command (Stefan Assmann) [1091126]
- [ethernet] i40e: Use port VLAN in MAC/VLAN filter configuration (Stefan Assmann) [1091126]
- [ethernet] i40e: Retain MAC filters when changing port VLAN (Stefan Assmann) [1091126]
- [ethernet] i40e: remove ptp_tx_work timestamp work item (Stefan Assmann) [1091126]
- [ethernet] i40e: fix Timesync Tx interrupt handler code (Stefan Assmann) [1091126]
- [ethernet] i40e: report VF link state correctly (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091126]
- [ethernet] i40e: Tweak for-loop in i40e_ethtool.c (Stefan Assmann) [1091126]
- [ethernet] i40e: Cleanup if/else statements (Stefan Assmann) [1091126]
- [ethernet] i40e: rework fdir setup and teardown (Stefan Assmann) [1091126]
- [ethernet] i40e: use generic vsi_open to unquiesce vsi (Stefan Assmann) [1091126]
- [ethernet] i40e: abstract the close path for better netdev vsis (Stefan Assmann) [1091126]
- [ethernet] i40e: prep vsi_open logic for non-netdev cases (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: update AdminQ API (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: add tracking to NVM busy state (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix an issue with displaying IPv4 FD filters (Stefan Assmann) [1091126]
- [ethernet] i40e: Remove a FW workaround (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091126]
- [ethernet] i40e: Enable VF Tx bandwidth setting (Stefan Assmann) [1091126]
- [ethernet] i40e: Reset the VF upon conflicting VLAN configuration (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: unhide and enable to one prefena field (Stefan Assmann) [1091126]
- [ethernet] i40e: Add bridge FDB add/del/dump ops (Stefan Assmann) [1091126]
- [ethernet] i40e: fix message terminations (Stefan Assmann) [1091126]
- [ethernet] i40e: fix TCP flag replication for hardware offload (Stefan Assmann) [1091126]
- [ethernet] i40e: remove open-coded skb_cow_head (Stefan Assmann) [1091126]
- [ethernet] i40e: Mass conversion of smp_mb__*() (Stefan Assmann) [1091126]
- [powerpc] asm: Convert smp_mb__*() (Stefan Assmann) [1091126]
- [s390] asm: Convert smp_mb__*() (Stefan Assmann) [1091126]
- [x86] asm: Convert smp_mb__*() (Stefan Assmann) [1091126]
- [kernel] sched: Prepare for smp_mb__{before, after}_atomic() (Stefan Assmann) [1091126]
- [ethernet] i40e: Remove casts of pointer to same type (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Remove addressof casts to same type (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: fix error checking path (Stefan Assmann) [1091126]
- [ethernet] i40e: fix function kernel doc description (Stefan Assmann) [1091126]
- [ethernet] i40e: Use DEBUG_FD message level for an FD message (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add an FD message level (Stefan Assmann) [1091126]
- [ethernet] i40e: check for netdev before debugfs use (Stefan Assmann) [1091126]
- [ethernet] i40e: Add functionality for FD SB to drop packets (Stefan Assmann) [1091126]
- [ethernet] i40e: Cleanup in FDIR SB ethtool code (Stefan Assmann) [1091126]
- [ethernet] i40e: eeprom integrity check on load and empr (Stefan Assmann) [1091126]
- [ethernet] i40e: Make the alloc and free queue vector calls orthogonal (Stefan Assmann) [1091126]
- [ethernet] i40e: Delete ATR filter on RST (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix a message string (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Add EEE LPI stats (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump build versions (Stefan Assmann) [1091126]
- [ethernet] i40e: potential array underflow in i40e_vc_process_vf_msg() (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: reduce context descriptors (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: enable hardware feature head write back (Stefan Assmann) [1091126]
- [ethernet] i40e: Refactor and cleanup i40e_open(), adding i40e_vsi_open() (Stefan Assmann) [1091126]
- [ethernet] i40e: Patch to enable Ethtool/netdev feature flag for NTUPLE control (Stefan Assmann) [1091126]
- [ethernet] i40e: support VF link state ndo (Stefan Assmann) [1091126]
- [ethernet] i40e: Avoid double setting of NETIF_F_SG for the HW encapsulation feature mask (Stefan Assmann) [1091126]
- [ethernet] i40e: Don't receive packets when the napi budget == 0 (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Use dma_set_mask_and_coherent (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Use correct number of VF vectors (Stefan Assmann) [1091126]
- [ethernet] i40e: Let MDD events be handled by MDD handler (Stefan Assmann) [1091126]
- [ethernet] i40e: Bug fix for FDIR replay logic (Stefan Assmann) [1091126]
- [ethernet] i40e: Add code to handle FD table full condition (Stefan Assmann) [1091126]
- [ethernet] i40e: Define a new state variable to keep track of feature auto disable (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix function comments (Stefan Assmann) [1091126]
- [ethernet] i40e: simplified init string (Stefan Assmann) [1091126]
- [ethernet] i40e: cleanup strings (Stefan Assmann) [1091126]
- [ethernet] i40e: make string references to q be queue (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Some flow director HW definition fixes (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix a bug in the update logic for FDIR SB filter (Stefan Assmann) [1091126]
- [ethernet] i40e: delete netdev after deleting napi and vectors (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump pf&vf build versions (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: carefully fill tx ring (Stefan Assmann) [1091126]
- [ethernet] i40e: fix nvm version and remove firmware report (Stefan Assmann) [1091126]
- [ethernet] i40e: Fix static checker warning (Stefan Assmann) [1091126]
- [ethernet] i40e: Remove a redundant filter addition (Stefan Assmann) [1091126]
- [ethernet] i40e: count timeout events (Stefan Assmann) [1091126]
- [ethernet] i40e: Remove a FW workaround for Number of MSIX vectors (Stefan Assmann) [1091126]
- [ethernet] i40e: clean up comment style (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: i40e implementation for skb_set_hash (Stefan Assmann) [1091126]
- [ethernet] i40e: Prevent overflow due to kzalloc (Stefan Assmann) [1091126]
- [ethernet] i40e: Flow Director sideband accounting (Stefan Assmann) [1091126]
- [ethernet] i40e/i40evf: Bump driver versions (Stefan Assmann) [1091126]
- [ethernet] i40e: Change MSIX to MSI-X (Stefan Assmann) [1091126]
- [ethernet] i40e: tighten up ring enable/disable flow (Stefan Assmann) [1091126]
- [ethernet] i40e: remove unnecessary delay (Stefan Assmann) [1091126]
- [ethernet] i40e: Use pci_enable_msix_range() instead of pci_enable_msix() (Stefan Assmann) [1091126]
- [ethernet] i40e: don't handle VF reset on unload (Stefan Assmann) [1091126]
- [ethernet] i40e: enable extant VFs (Stefan Assmann) [1091126]
- [ethernet] i40e: reset VFs after PF reset (Stefan Assmann) [1091126]
- [ethernet] i40e: set VF state to active when reset is complete (Stefan Assmann) [1091126]
- [ethernet] i40e: remove dead code (Stefan Assmann) [1091126]
- [ethernet] i40e: Setting i40e_down bit for tx_timeout (Stefan Assmann) [1091126]
- [ethernet] i40evf: clean up memsets (Stefan Assmann) [1091126]
- [ethernet] i40e: bump driver version (Stefan Assmann) [1091126]
- [ethernet] i40e: spelling error (Stefan Assmann) [1091126]
- [ethernet] i40e: Add missing braces to i40e_dcb_need_reconfig() (Stefan Assmann) [1091126]
- [net] sunrpc: get rid of use_gssp_lock ("J. Bruce Fields") [1117914]
- [net] sunrpc: fix potential race between setting use_gss_proxy and the upcall rpc_clnt ("J. Bruce Fields") [1117914]
- [net] sunrpc: don't wait for write before allowing reads from use-gss-proxy file ("J. Bruce Fields") [1117914]
- [net] sunrpc: trim off EC bytes in GSSAPI v2 unwrap ("J. Bruce Fields") [1117914]
- [net] svcrpc: handle some gssproxy encoding errors ("J. Bruce Fields") [1117914]
- [net] svcrpc: fix error-handling on badd gssproxy downcall ("J. Bruce Fields") [1117914]

* Thu Sep 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-152.el7]
- [scsi] scsi_lib: remove the description string in scsi_io_completion() (Maurizio Lombardi) [1045998]
- [scsi] sd: fix a bug in deriving the FLUSH_TIMEOUT from the basic I/O timeout (Ewan Milne) [1123906]
- [scsi] scsi_debug: simple short transfer injection (Ewan Milne) [1132100]
- [scsi] scsi_debug: add ability to enable clustering (Ewan Milne) [1132100]
- [scsi] scsi_debug: protect device access with atomic_rw lock (Ewan Milne) [1132100]
- [scsi] scsi_debug: prepare to enable clustering (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix resp_xdwriteread() return value when running out of memory (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix duplicate dif_errors increment (Ewan Milne) [1132100]
- [scsi] scsi_debug: make pseudo_primary static (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix false positive logical block reference tag check fail (Ewan Milne) [1132100]
- [scsi] scsi_debug: simplify creation and destruction of driver attribute files (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix sparse warnings related to data integrity field (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix invalid value check for guard module parameter (Ewan Milne) [1132100]
- [scsi] scsi_debug: avoid partial copying PI from prot_sglist to dif_storep (Ewan Milne) [1132100]
- [scsi] scsi_debug: factor out copying PI from dif_storep to prot_sglist (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix buffer overrun when DIF/DIX is enabled and virtual_gb > 0 (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix logical block provisioning support when unmap_alignment != 0 (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix do_device_access() with wrap around range (Ewan Milne) [1132100]
- [scsi] lib/scatterlist: introduce sg_pcopy_from_buffer() and sg_pcopy_to_buffer() (Ewan Milne) [1132100]
- [scsi] lib/scatterlist: factor out sg_miter_get_next_page() from sg_miter_next() (Ewan Milne) [1132100]
- [scsi] scsi_debug: reduce duplication between prot_verify_read and prot_verify_write (Ewan Milne) [1132100]
- [scsi] scsi_debug: simplify offset calculation for dif_storep (Ewan Milne) [1132100]
- [scsi] scsi_debug: invalidate protection info for unmapped region (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix NULL pointer dereference with parameters dif=0 dix=1 (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix incorrectly nested kmap_atomic() (Ewan Milne) [1132100]
- [scsi] scsi_debug: fix invalid address passed to kunmap_atomic() (Ewan Milne) [1132100]
- [scsi] use dev_printk variants where possible (Ewan Milne) [998695]
- [scsi] use dev_printk() variants for ioctl (Ewan Milne) [998695]
- [scsi] Implement st_printk() (Ewan Milne) [998695]
- [scsi] Implement ch_printk() (Ewan Milne) [998695]
- [scsi] Implement sg_printk() (Ewan Milne) [998695]
- [scsi] Implement sr_printk() (Ewan Milne) [998695]
- [scsi] ses: Use vpd information from scsi_device (Ewan Milne) [1132092]
- [scsi] Add EVPD page 0x83 and 0x80 to sysfs (Ewan Milne) [1132092]
- [scsi] Return VPD page length in scsi_vpd_inquiry() (Ewan Milne) [1132092]
- [scsi] Workaround for disks that report bad optimal transfer length (Ewan Milne) [1132092]
- [scsi] sg: O_EXCL and other lock handling (Ewan Milne) [1132092]
- [scsi] sg: add SG_FLAG_Q_AT_TAIL flag (Ewan Milne) [1132092]
- [scsi] sg: relax 16 byte cdb restriction (Ewan Milne) [1132092]
- [scsi] scsi constants: command, sense key + additional sense strings (Ewan Milne) [1132092]
- [scsi] scsi_error: disable eh_deadline if no host_reset_handler is set (Ewan Milne) [1132092]
- [scsi] cleanup switch in scsi_adjust_queue_depth (Ewan Milne) [1132092]
- [scsi] set correct completion code in scsi_send_eh_cmnd() (Ewan Milne) [1132092]
- [scsi] Spelling hsot -> host (Ewan Milne) [1132092]
- [scsi] scsi_sysfs: Implement 'is_visible' callback (Ewan Milne) [1132092]
- [scsi] export device_busy for sdev (Ewan Milne) [1132092]
- [scsi] fc: ensure scan_work isn't active when freeing fc_rport (Ewan Milne) [1132092]
- [scsi] scsi_transport_fc: Add 32Gbps speed definition (Ewan Milne) [1132092]
- [scsi] sd: bad return code of init_sd (Ewan Milne) [1132092]
- [scsi] sd: notify block layer when using temporary change to cache_type (Ewan Milne) [1132092]
- [scsi] sd: medium access timeout counter fails to reset (Ewan Milne) [1101729]
- [scsi] sd: Quiesce mode sense error messages (Ewan Milne) [1132092]
- [scsi] sd: Do not call do_div() with a 64-bit divisor (Ewan Milne) [1132092]
- [scsi] sd: Reduce buffer size for vpd request (Ewan Milne) [1132092]
- [scsi] sd: avoid deadlocks when running under multipath (Ewan Milne) [1132092]
- [scsi] st: fix enlarge_buffer (Ewan Milne) [1132092]
- [scsi] use the scsi data buffer length to extract transfer size (Ewan Milne) [1132092]
- [scsi] scsi_cmnd: Introduce scsi_transfer_length helper (Ewan Milne) [1132092]
- [scsi] Add CDB definition for COMPARE_AND_WRITE (Ewan Milne) [1132092]

* Thu Sep 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-151.el7]
- [md] raid6: avoid data corruption during recovery of double-degraded RAID6 (Jes Sorensen) [1130905]
- [block] scsi_ioctl: verify return pointer from blk_get_request (Jeff Moyer) [1104324]
- [pnp] pnpacpi: Fix acpi_pnp_match() (Myron Stowe) [1128632]
- [pnp] pnpacpi: Do not return errors if _DIS or _SRS are not present (Myron Stowe) [1128632]
- [acpi] dock: Make 'docked' sysfs attribute work as documented (Myron Stowe) [1128632]
- [acpi] dock: Use acpi_device_enumerated() to check if dock is present (Myron Stowe) [1128632]
- [acpi] hotplug: Fix panic on eject to ejected device (Myron Stowe) [1128632]
- [acpi] scan: Clear match_driver flag in acpi_bus_trim() (Myron Stowe) [1128632]
- [acpi] scan: Use direct recurrence for device hierarchy walks (Myron Stowe) [1128632]
- [acpi] Introduce acpi_set_device_status() (Myron Stowe) [1128632]
- [acpi] hotplug: Drop unfinished global notification handling routines (Myron Stowe) [1128632]
- [acpi] hotplug: Rework generic code to handle suprise removals (Myron Stowe) [1128632]
- [acpi] hotplug: Move container-specific code out of the core (Myron Stowe) [1128632]
- [acpi] hotplug: Make ACPI PCI root hotplug use common hotplug code (Myron Stowe) [1128632]
- [acpi] hotplug: Introduce common hotplug function acpi_device_hotplug() (Myron Stowe) [1128632]
- [acpi] hotplug: Do not fail bus and device checks for disabled hotplug (Myron Stowe) [1128632]
- [acpi] scan: Add acpi_device objects for all device nodes in the namespace (Myron Stowe) [1128632]
- [acpi] scan: Define non-empty device removal handler (Myron Stowe) [1128632]
- [acpi] core: Store an ACPI device pointer in struct acpi_dev_node (Myron Stowe) [1128632]
- [acpi] pm: Drop two functions that are not used any more (Myron Stowe) [1128632]
- [acpi] power: Drop automaitc resume of power resource dependent devices (Myron Stowe) [1128632]
- [acpi] Use EXPORT_SYMBOL() for acpi_bus_get_device() (Myron Stowe) [1128632]
- [acpi] Print diagnostic messages if device links cannot be created (Myron Stowe) [1128632]
- [acpi] Drop unnecessary label from acpi_bind_one() (Myron Stowe) [1128632]
- [acpi] Clean up error code path in acpi_unbind_one() (Myron Stowe) [1128632]
- [acpi] Use list_for_each_entry() in acpi_unbind_one() (Myron Stowe) [1128632]
- [acpi] acpi_bind_one()/acpi_unbind_one() whitespace cleanups (Myron Stowe) [1128632]
- [acpi] Create symlinks in acpi_bind_one() under physical_node_lock (Myron Stowe) [1128632]
- [acpi] Reduce acpi_bind_one()/acpi_unbind_one() code duplication (Myron Stowe) [1128632]
- [acpi] Do not fail acpi_bind_one() if device is already bound correctly (Myron Stowe) [1128632]
- [acpi] Move acpi_bus_get_device() from bus.c to scan.c (Myron Stowe) [1128632]
- [acpi] pm: Use ACPI_STATE_D3_COLD instead of ACPI_STATE_D3 everywhere (Myron Stowe) [1128632]
- [usb] xhci: convert TRB_CYCLE to le32 before using it to set Link TRB's cycle bit (Steve Best) [1123119]
- [usb] xhci: fix incorrect type in assignment in handle_device_notification() (Steve Best) [1123119]
- [input] alps: Rushmore and v7 resolution support (Benjamin Tissoires) [1107819]
- [input] alps: add support for v7 devices (Benjamin Tissoires) [1107819]
- [input] alps: cache firmware version (Benjamin Tissoires) [1107819]
- [input] alps: change decode function prototype to return an int (Benjamin Tissoires) [1107819]
- [input] alps: report 2 touches when we've > 2 fingers (Benjamin Tissoires) [1107819]
- [input] alps: add an alps_report_semi_mt_data function (Benjamin Tissoires) [1107819]
- [input] alps: use single touch data when v3 mt data contains only one finger (Benjamin Tissoires) [1107819]
- [input] alps: use standard contact tracking instead of DIY (Benjamin Tissoires) [1107819]
- [input] alps: use struct input_mt_pos to track coordinates (Benjamin Tissoires) [1107819]
- [input] alps: process_bitmap, round down when spreading adjescent fingers over 2 points (Benjamin Tissoires) [1107819]
- [input] alps: process_bitmap, fix counting of high point bits (Benjamin Tissoires) [1107819]
- [input] alps: process_bitmap, add alps_get_bitmap_points() helper function (Benjamin Tissoires) [1107819]
- [input] alps: process_bitmap, don't invert the Y-axis on Rushmore (Benjamin Tissoires) [1107819]
- [input] alps: improve 2-finger reporting on v3 models (Benjamin Tissoires) [1107819]
- [input] alps: fix rushmore packet decoding (Benjamin Tissoires) [1107819]
- [input] alps: add support for "Dolphin" devices (Benjamin Tissoires) [1107819]
- [input] alps: add support for DualPoint device on Dell XT2 model (Benjamin Tissoires) [1107819]
- [input] alps: change secondary device's name (Benjamin Tissoires) [1107819]
- [tools] turbostat: tweak whitespace in output format (Prarit Bhargava) [1133893]
- [tools] cpupower: bench/parse.c, Fix several minor errors (Prarit Bhargava) [1133893]
- [tools] cpupower: Remove redundant error check (Prarit Bhargava) [1133893]
- [tools] cpupower: mperf monitor, Correct use of ! and & (Prarit Bhargava) [1133893]
- [tools] cpupower: drop negativity check on unsigned value (Prarit Bhargava) [1133893]
- [tools] cpupower: Remove mc and smt power aware scheduler info/settings (Prarit Bhargava) [1133893]
- [tools] cpupower: cpupower info -b should return 0 on success, not the perf bias value (Prarit Bhargava) [1133893]
- [tools] cpupower: Remove dead link to homepage, and update the targets built (Prarit Bhargava) [1133893]
- [tools] cpupower: Rename cpufrequtils -> cpupower, and libcpufreq -> libcpupower (Prarit Bhargava) [1133893]
- [tools] cpupower: If root, try to load msr driver on x86 if /dev/cpu/0/msr is not available (Prarit Bhargava) [1133893]
- [tools] cpupower: Install recently added cpupower-idle-{set, info} manpages (Prarit Bhargava) [1133893]
- [tools] cpupower: Remove all manpages on make uninstall (Prarit Bhargava) [1133893]
- [tools] cpupower: Introduce idle state disable-by-latency and enable-all (Prarit Bhargava) [1133893]
- [tools] turbostat: Drop temperature checks (Prarit Bhargava) [1133893]
- [tools] cpufreq: Make linux-pm@vger.kernel.org official mailing list (Prarit Bhargava) [1133893]
- [tools] turbostat: simplify output, add Avg_MHz (Prarit Bhargava) [1133893]
- [tools] turbostat: introduce -s to dump counters (Prarit Bhargava) [1133893]
- [tools] turbostat: remove unused command line option (Prarit Bhargava) [1133893]
- [tools] turbostat: Add option to report joules consumed per sample (Prarit Bhargava) [1133893]
- [tools] turbostat: Clean up error handling; disambiguate error messages; use err and errx (Prarit Bhargava) [1133893]
- [tools] turbostat: Add a .gitignore to ignore the compiled turbostat binary (Prarit Bhargava) [1133893]
- [tools] turbostat: Factor out common function to open file and exit on failure (Prarit Bhargava) [1133893]
- [tools] turbostat: Add a helper to parse a single int out of a file (Prarit Bhargava) [1133893]
- [tools] turbostat: Check return value of fscanf (Prarit Bhargava) [1133893]
- [tools] turbostat: Don't attempt to printf an off_t with zx (Prarit Bhargava) [1133893]
- [tools] turbostat: Use GCC's CPUID functions to support PIC (Prarit Bhargava) [1133893]
- [tools] turbostat: Don't put unprocessed uapi headers in the include path (Prarit Bhargava) [1133893]
- [tools] cpupower: Fix sscanf robustness in cpufreq-set (Prarit Bhargava) [1133893]
- [tools] cpupower: Fix segfault due to incorrect getopt_long arugments (Prarit Bhargava) [1133893]
- [tools] cpupower: fix wrong err msg not supported vs not available (Prarit Bhargava) [1133893]
- [tools] cpupower: Add cpupower-idle-set(1) manpage (Prarit Bhargava) [1133893]
- [virt] virtio-scsi: Skip setting affinity on uninitialized vq (Fam Zheng) [1083860]
- [mm] memcontrol: remove hierarchy restrictions for swappiness and oom_control (Johannes Weiner) [1124110]
- [mm] thp: fix copy_page_rep GPF by testing is_huge_zero_pmd once only (Rik van Riel) [1123040]
- [mm] numa: Remove BUG_ON() in __handle_mm_fault() (Rik van Riel) [1119439]
- [iommu] Add empty stub for iommu_group_get_by_id() (Steve Best) [1123122]
- [input] Revert: wacom: testing result shows get_report is unnecessary (Aristeu Rozanski) [1079541]
- [kernel] kexec: fix build error when hugetlbfs is disabled (Baoquan He) [1115240]
- [kernel] kexec: export free_huge_page to VMCOREINFO (Baoquan He) [1115240]
- [kernel] kexec: save PG_head_mask in VMCOREINFO (Baoquan He) [1115240]
- [block] nvme: Fix START_STOP_UNIT Scsi->NVMe translation (David Milburn) [1111259]
- [block] nvme: Use Log Page constants in SCSI emulation (David Milburn) [1111259]
- [block] nvme: Define Log Page constants (David Milburn) [1111259]
- [block] nvme: Fix hot cpu notification dead lock (David Milburn) [1111259]
- [block] nvme: Rename io_timeout to nvme_io_timeout (David Milburn) [1111259]
- [block] nvme: Use last bytes of f/w rev SCSI Inquiry (David Milburn) [1111259]
- [block] nvme: Adhere to request queue block accounting enable/disable (David Milburn) [1111259]
- [block] nvme: Fix nvme get/put queue semantics (David Milburn) [1111259]
- [block] nvme: Delete NVME_GET_FEAT_TEMP_THRESH (David Milburn) [1111259]
- [block] nvme: Make admin timeout a module parameter (David Milburn) [1111259]
- [block] nvme: Make iod bio timeout a parameter (David Milburn) [1111259]
- [block] nvme: Prevent possible NULL pointer dereference (David Milburn) [1111259]
- [block] nvme: Fix the buffer size passed in GetLogPage(CDW10.NUMD) (David Milburn) [1111259]
- [block] nvme: Update data structures for NVMe 1.2 (David Milburn) [1111259]
- [block] nvme: Enable BUILD_BUG_ON checks (David Milburn) [1111259]
- [block] nvme: Update namespace and controller identify structures to the 1.1a spec (David Milburn) [1111259]
- [block] nvme: Flush with data support (David Milburn) [1111259]
- [block] nvme: Configure support for block flush (David Milburn) [1111259]
- [block] nvme: Add tracepoints (David Milburn) [1111259]
- [block] nvme: Protect against badly formatted CQEs (David Milburn) [1111259]
- [block] nvme: Improve error messages (David Milburn) [1111259]
- [block] nvme: Update copyright headers (David Milburn) [1111259]
- [powerpc] 64bit sendfile is capped at 2GB (Gustavo Duarte) [1107774]
- [powerpc] sched: stop updating inside arch_update_cpu_topology() when nothing to be update (Gustavo Duarte) [1098372]
- [firewire] ohci: fix probe failure with Agere/LSI controllers (Neil Horman) [994878]
- [firewire] ohci: beautify some macro definitions (Neil Horman) [994878]
- [s390] airq: silence lockdep warning (Hendrik Brueckner) [1088554]
- [virt] virtio_scsi: don't call virtqueue_add_sgs(... GFP_NOIO) holding spinlock (Hendrik Brueckner) [1088554]
- [virt] virtio_ccw: introduce device_lost in virtio_ccw_device (Hendrik Brueckner) [1088554]
- [virt] virtio: virtio_break_device() to mark all virtqueues broken (Hendrik Brueckner) [1088554]
- [virt] s390/sclp_vt220: Fix kernel panic due to early terminal input (Hendrik Brueckner) [1088554]
- [virt] virtio: fail adding buffer on broken queues (Hendrik Brueckner) [1088554]
- [virt] virtio_net: don't crash if virtqueue is broken (Hendrik Brueckner) [1088554]
- [virt] s390/virtio_ccw: fix hang in set offline processing (Hendrik Brueckner) [1088554]
- [s390] irq: improve displayed interrupt order in /proc/interrupts (Hendrik Brueckner) [1088554]
- [virt] virtio-ccw: virtio-ccw adapter interrupt support (Hendrik Brueckner) [1088554]
- [virt] virtio_ccw: fix vcdev pointer handling issues (Hendrik Brueckner) [1088554]
- [virt] s390/airq: add support for irq ranges (Hendrik Brueckner) [1088554]
- [virt] kvm/s390/virtio-ccw: Handle command rejects (Hendrik Brueckner) [1088554]
- [virt] virtio_scsi: verify if queue is broken after virtqueue_get_buf() (Hendrik Brueckner) [1088554]
- [virt] virtio_ring: adapt to notify() returning bool (Hendrik Brueckner) [1088554]
- [virt] virtio_net: verify if queue is broken after virtqueue_get_buf() (Hendrik Brueckner) [1088554]
- [virt] virtio_blk: verify if queue is broken after virtqueue_get_buf() (Hendrik Brueckner) [1088554]
- [virt] virtio_ring: add new function virtqueue_is_broken() (Hendrik Brueckner) [1088554]
- [virt] virtio_ring: let virtqueue_{kick()/notify()} return a bool (Hendrik Brueckner) [1088554]
- [virt] tools/virtio: fix missing kmemleak_ignore symbol (Hendrik Brueckner) [1088554]
- [virt] virtio_ring: plug kmemleak false positive (Hendrik Brueckner) [1088554]
- [mm] page_alloc: do not cache reclaim distances (Larry Woodman) [1120342]
- [mm] disable zone_reclaim_mode by default (Larry Woodman) [1120342]

* Tue Sep 02 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-150.el7]
- [net] team: set IFF_TEAM_PORT priv_flag after rx_handler is registered (Jiri Pirko) [1132943]
- [net] ipv6: fix calculation of option len in ip6_append_data (Hannes Frederic Sowa) [1127218]
- [net] ipv6: pmtudisc setting not respected with UFO/CORK (Hannes Frederic Sowa) [1127218]
- [net] ipv4: fix DO and PROBE pmtu mode regarding local fragmentation with UFO/CORK (Hannes Frederic Sowa) [1127218]
- [net] clear local_df when passing skb between namespaces (Jiri Pirko) [1128223]
- [net] rtnetlink: fix VF info size (Jiri Benc) [1128267]
- [net] netfilter: connlimit: move lock array out of struct connlimit_data (Florian Westphal) [1052282]
- [net] netfilter: connlimit: use rbtree for per-host conntrack obj storage (Florian Westphal) [1052282]
- [net] netfilter: connlimit: make same_source_net signed (Florian Westphal) [1052282]
- [net] netfilter: connlimit: use keyed locks (Florian Westphal) [1052282]
- [net] netfilter: connlimit: use kmem_cache for conn objects (Florian Westphal) [1052282]
- [net] netfilter: connlimit: move insertion of new element out of count function (Florian Westphal) [1052282]
- [net] netfilter: connlimit: improve packet-to-closed-connection logic (Florian Westphal) [1052282]
- [net] netfilter: connlimit: factor hlist search into new function (Florian Westphal) [1052282]
- [net] ipv6: increase ip6_rt_max_size to 16384 (Hannes Frederic Sowa) [1119364]
- [net] ipv6: don't count addrconf generated routes against gc limit (Hannes Frederic Sowa) [1119364]
- [net] tcp: add tcp_syncookies mode to allow unconditionally generation of syncookies (Florian Westphal) [1084439]
- [net] tcp: syncookies: do not use getnstimeofday() (Florian Westphal) [1084439]
- [net] tcp: syncookies: reduce mss table to four values (Florian Westphal) [1084439]
- [net] tcp: syncookies: reduce cookie lifetime to 128 seconds (Florian Westphal) [1084439]
- [net] sctp: only warn in proc_sctp_do_alpha_beta if write (Daniel Borkmann) [1110290]
- [net] sctp: check proc_dointvec result in proc_sctp_do_auth (Daniel Borkmann) [1110290]
- [net] sctp: propagate sysctl errors from proc_do* properly (Daniel Borkmann) [1110290]
- [net] sctp: fix permissions for rto_alpha and rto_beta knobs (Daniel Borkmann) [1110290]
- [net] sctp: cache auth_enable per endpoint (Daniel Borkmann) [1110290]
- [net] sctp: fix a missed .data initialization (Daniel Borkmann) [1110290]
- [net] sctp: fix up a spacing (Daniel Borkmann) [1110290]
- [net] sctp: add check rto_min and rto_max in sysctl (Daniel Borkmann) [1110290]
- [net] Revert: introduce netif_skb_dev_features (Florian Westphal) [1109214]
- [net] ip: push gso skb forwarding handling down the stack (Florian Westphal) [1109214]
- [net] ipv6: send pkttoobig immediately if orig frag size > mtu (Florian Westphal) [1109214]
- [net] ipv4: ip_forward: fix inverted local_df test (Florian Westphal) [1109214]
- [net] netfilter: ipv4: defrag: set local_df flag on defragmented skb (Florian Westphal) [1109214]
- [net] don't account for udp header size when computing seglen (Florian Westphal) [1109214]

* Tue Sep 02 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-149.el7]
- [fs] ext4: fix type declaration of ext4_validate_block_bitmap (Lukas Czerner) [1091055]
- [fs] ext4: error out if verifying the block bitmap fails (Lukas Czerner) [1091055]
- [fs] cifs: Fix memory leaks in SMB2_open (Sachin Prabhu) [1082049]
- [fs] cifs: ensure that vol->username is not NULL before running strlen on it (Sachin Prabhu) [1082049]
- [fs] cifs: Clarify SMB2/SMB3 create context and add missing ones (Sachin Prabhu) [1082049]
- [fs] cifs: Do not send ClientGUID on SMB2.02 dialect (Sachin Prabhu) [1082049]
- [fs] cifs: Set client guid on per connection basis (Sachin Prabhu) [1082049]
- [fs] cifs/netmisc: convert printk to pr_foo() (Sachin Prabhu) [1082049]
- [fs] cifs: replace seq_printf by seq_puts (Sachin Prabhu) [1082049]
- [fs] cifs: Update cifs version number to 2.03 (Sachin Prabhu) [1082049]
- [fs] cifs: new helper file_inode(file) (Sachin Prabhu) [1082049]
- [fs] cifs: fix potential races in cifs_revalidate_mapping (Sachin Prabhu) [1082049]
- [fs] cifs: new helper function: cifs_revalidate_mapping (Sachin Prabhu) [1082049]
- [fs] cifs: convert booleans in cifsInodeInfo to a flags field (Sachin Prabhu) [1082049]
- [fs] cifs: fix cifs_uniqueid_to_ino_t not to ever return 0 (Sachin Prabhu) [1082049]
- [fs] cifs: fix actimeo=0 corner case when cifs_i->time == jiffies (Sachin Prabhu) [1082049]
- [fs] cifs: fix dead code (Sachin Prabhu) [1082049]
- [fs] cifs: fix error handling cifs_user_readv (Sachin Prabhu) [1082049]
- [fs] cifs: remove unused variable (Sachin Prabhu) [1082049]
- [fs] cifs: Return correct error on query of xattr on file with empty xattrs (Sachin Prabhu) [1082049]
- [fs] cifs: fix the race in cifs_writev() (Sachin Prabhu) [1082049]
- [fs] cifs: add __init to cifs_init_inodecache() (Sachin Prabhu) [1082049]
- [fs] cifs: ->rename() without ->lookup() makes no sense (Sachin Prabhu) [1082049]
- [fs] cifs: Fix too big maxBuf size for SMB3 mounts (Sachin Prabhu) [1082049]
- [fs] cifs: Fix cifsacl mounts over smb2 to not call cifs (Sachin Prabhu) [1082049]
- [fs] cifs: retrieving CIFS ACLs when mounted with SMB2 fails dropping session (Sachin Prabhu) [1082049]
- [fs] cifs: Add protocol specific operation for CIFS xattrs (Sachin Prabhu) [1082049]
- [fs] cifs: Fix SMB2 mounts so they don't try to set or get xattrs via cifs (Sachin Prabhu) [1082049]
- [fs] cifs: Cleanup cifs open codepath (Sachin Prabhu) [1082049]
- [fs] cifs: Remove extra indentation in cifs_sfu_type (Sachin Prabhu) [1082049]
- [fs] cifs: Cleanup cifs_mknod (Sachin Prabhu) [1082049]
- [fs] cifs: Cleanup CIFSSMBOpen (Sachin Prabhu) [1082049]
- [fs] cifs: Fix memory leak in cifs_hardlink() (Sachin Prabhu) [1082049]
- [fs] cifs: Add missing end of line termination to some cifs messages (Sachin Prabhu) [1082049]
- [fs] cifs: Do not use btrfs refcopy ioctl for SMB2 copy offload (Sachin Prabhu) [1082049]
- [fs] cifs: Check SMB3 dialects against downgrade attacks (Sachin Prabhu) [1082049]
- [fs] cifs: Removed duplicated (and unneeded) goto (Sachin Prabhu) [1082049]
- [fs] cifs: Fix SMB2/SMB3 Copy offload support (refcopy) for large files (Sachin Prabhu) [1082049]
- [fs] cifs: Warn if SMB3 encryption required by server (Sachin Prabhu) [1082049]
- [fs] cifs: Set copychunk defaults (Sachin Prabhu) [1082049]
- [fs] cifs: SMB2/SMB3 Copy offload support (refcopy) phase 1 (Sachin Prabhu) [1082049]
- [fs] cifs: Use data structures to compute NTLMv2 response offsets (Sachin Prabhu) [1082049]
- [fs] cifs: O_DIRECT opens should work on directio mounts (Sachin Prabhu) [1082049]
- [fs] cifs: don't spam the logs on unexpected lookup errors (Sachin Prabhu) [1082049]
- [fs] cifs: change ERRnomem error mapping from ENOMEM to EREMOTEIO (Sachin Prabhu) [1082049]
- [fs] cifs: Fix symbolic links usage (Sachin Prabhu) [1082049]
- [fs] cifs: Query network adapter info at mount time for debugging (Sachin Prabhu) [1082049]
- [fs] cifs: Fix unused variable warning when CIFS POSIX disabled (Sachin Prabhu) [1082049]
- [fs] cifs: Allow setting per-file compression via CIFS protocol (Sachin Prabhu) [1082049]
- [fs] cifs: Query File System Alignment (Sachin Prabhu) [1082049]
- [fs] cifs: Query device characteristics at mount time from server on SMB2/3 not just on cifs mounts (Sachin Prabhu) [1082049]
- [fs] cifs: Send a logoff request before removing a smb session (Sachin Prabhu) [1082049]
- [fs] cifs: Make big endian multiplex ID sequences monotonic on the wire (Sachin Prabhu) [1082049]
- [fs] cifs: Remove redundant multiplex identifier check from check_smb_hdr() (Sachin Prabhu) [1082049]
- [fs] cifs: Query file system attributes from server on SMB2, not just cifs, mounts (Sachin Prabhu) [1082049]
- [fs] cifs: Allow setting per-file compression via SMB2/3 (Sachin Prabhu) [1082049]
- [fs] cifs: Fix corrupt SMB2 ioctl requests (Sachin Prabhu) [1082049]
- [fs] cifs: rcu-delay unload_nls() and freeing sbi (Sachin Prabhu) [1082049]
- [fs] cifs: new helper kfree_put_link() (Sachin Prabhu) [1082049]
- [fs] cifs: ntstatus_to_dos_map[] is not terminated (Sachin Prabhu) [1082049]
- [fs] cifs: Allow LANMAN auth method for servers supporting unencapsulated authentication methods (Sachin Prabhu) [1082049]
- [fs] cifs: Fix inability to write files >2GB to SMB2/3 shares (Sachin Prabhu) [1082049]
- [fs] cifs: Avoid umount hangs with smb2 when server is unresponsive (Sachin Prabhu) [1082049]
- [fs] cifs: do not treat non-symlink reparse points as valid symlinks (Sachin Prabhu) [1082049]
- [fs] cifs: update cifs.ko version (Sachin Prabhu) [1082049]
- [fs] cifs: Provide sane values for nlink (Sachin Prabhu) [1082049]
- [fs] cifs: FS-Cache: Uncache unread pages in cifs_readpages() before freeing them (Sachin Prabhu) [1082049]
- [fs] cifs: Avoid calling unlock_page() twice in cifs_readpage() when using fscache (Sachin Prabhu) [1082049]
- [fs] cifs: Do not take a reference to the page in cifs_readpage_worker() (Sachin Prabhu) [1082049]
- [fs] cifs: Fix wrong pos argument of cifs_find_lock_conflict (Sachin Prabhu) [1082049]

* Sat Aug 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-148.el7]
- [ethernet] igbvf: Remove DEFINE_PCI_DEVICE_TABLE macro use (Stefan Assmann) [1091122]
- [ethernet] igbvf: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Stefan Assmann) [1091122]
- [ethernet] igbvf: remove usless return statements (Stefan Assmann) [1091122]
- [ethernet] igbvf: get rid of SET_ETHTOOL_OPS (Stefan Assmann) [1091122]
- [ethernet] igbvf: remove open-coded skb_cow_head (Stefan Assmann) [1091122]
- [ethernet] igbvf: Convert uses of __constant_<foo> to <foo> (Stefan Assmann) [1091122]
- [ethernet] igbvf: Use pci_enable_msix_range() instead of pci_enable_msix() (Stefan Assmann) [1091122]
- [ethernet] igbvf: slight optimization of addr compare (Stefan Assmann) [1091122]
- [ethernet] igbvf: add missing iounmap() on error in igbvf_probe() (Stefan Assmann) [1091122]
- [ethernet] igbvf: integer wrapping bug setting the mtu (Stefan Assmann) [1091122]
- [ethernet] igbvf: Miscellaneous conversions to ETH_ALEN (Stefan Assmann) [1091122]
- [ethernet] igbvf: Remove extern from function prototypes (Stefan Assmann) [1091122]
- [ethernet] igbvf: fix 32-bit DMA mask handling (Stefan Assmann) [1091122]
- [ethernet] igb: bump igb version to 5.2.13 (Stefan Assmann) [1091121]
- [ethernet] igb: Add message when malformed packets detected by hw (Stefan Assmann) [1091121]
- [ethernet] igb: remove unnecessary break after return (Stefan Assmann) [1091121]
- [ethernet] igb: remove unnecessary break after goto (Stefan Assmann) [1091121]
- [ethernet] igb: do a reset on SR-IOV re-init if device is down (Stefan Assmann) [1091121]
- [ethernet] igb: workaround for i210 errata 25, Slow System Clock (Stefan Assmann) [1091121]
- [ethernet] igb: bring link up when PHY is powered up (Stefan Assmann) [1091121]
- [ethernet] igb: separate hardware setting from the set_ts_config ioctl (Stefan Assmann) [1091121]
- [ethernet] igb: Replace 1/0 return values with true/false (Stefan Assmann) [1091121]
- [ethernet] igb: unhide invariant returns (Stefan Assmann) [1091121]
- [ethernet] igb: use ethtool_cmd_speed_set helper to set ethtool speed value (Stefan Assmann) [1091121]
- [ethernet] igb: use SPEED_UNKNOWN and DUPLEX_UNKNOWN when appropriate (Stefan Assmann) [1091121]
- [ethernet] igb: add defaults for i210 TX/RX PBSIZE (Stefan Assmann) [1091121]
- [ethernet] igb: use mac loopback for i354 backplane (Stefan Assmann) [1091121]
- [ethernet] igb: rename igb_ptp_enable to igb_ptp_feature_enable (Stefan Assmann) [1091121]
- [ethernet] igb: remove redundant PHY power down register write (Stefan Assmann) [1091121]
- [ethernet] igb: remove usless return statements (Stefan Assmann) [1091121]
- [ethernet] igb: remove return statements for void functions (Stefan Assmann) [1091121]
- [ethernet] igb: get rid of SET_ETHTOOL_OPS (Stefan Assmann) [1091121]
- [ethernet] igb: Change memcpy to struct assignment (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to remove unneeded extern declaration (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to replace deprecated DEFINE_PCI_DEVICE_TABLE (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix static initialization (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix msleep warnings (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix line length warnings (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to remove return parentheses (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix missing break in switch statements (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix assignment in if error (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to change comment style on license headers (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix for trailing statement (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix pointer location error (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix incorrect indentation (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups to fix braces location warnings (Stefan Assmann) [1091121]
- [ethernet] igb: Cleanups for messaging (Stefan Assmann) [1091121]
- [ethernet] igb: fix message terminations (Stefan Assmann) [1091121]
- [ethernet] igb: fix stats for i210 rx_fifo_errors (Stefan Assmann) [1091121]
- [ethernet] igb: fix last_rx_timestamp usage (Stefan Assmann) [1091121]
- [ethernet] igb: remove open-coded skb_cow_head (Stefan Assmann) [1091121]
- [ethernet] igb: Convert iounmap to pci_iounmap (Stefan Assmann) [1091121]
- [ethernet] igb: fix race conditions on queuing skb for HW time stamp (Stefan Assmann) [1091121]
- [ethernet] igb: never generate both software and hardware timestamps (Stefan Assmann) [1091121]
- [ethernet] igb: Unset IGB_FLAG_HAS_MSIX-flag when falling back to msi-only (Stefan Assmann) [1091121]
- [ethernet] igb: Fix Null-pointer dereference in igb_reset_q_vector (Stefan Assmann) [1091121]
- [ethernet] igb: specify phc_index of 82575 for get_ts_info (Stefan Assmann) [1091121]
- [ethernet] igb: Fix memory leak in igb_get_module_eeprom() (Stefan Assmann) [1091121]
- [ethernet] igb: add register rd/wr for surprise removal (Stefan Assmann) [1091121]
- [ethernet] igb: implement SIOCGHWTSTAMP ioctl (Stefan Assmann) [1091121]
- [ethernet] igb: Convert uses of __constant_<foo> to <foo> (Stefan Assmann) [1091121]
- [ethernet] igb: enable VLAN stripping for VMs with i350 (Stefan Assmann) [1091121]
- [ethernet] igb: Add register defines needed for time sync functions (Stefan Assmann) [1091121]
- [ethernet] igb: remove references to long gone command line parameters (Stefan Assmann) [1091121]
- [ethernet] igb: Don't receive packets when the napi budget == 0 (Stefan Assmann) [1091121]
- [ethernet] igb: Fix code comment (Stefan Assmann) [1091121]
- [ethernet] igb: Fix for devices using ethtool for EEE settings (Stefan Assmann) [1091121]
- [ethernet] igb: fix calls to skb_set_hash (Stefan Assmann) [1091121]
- [ethernet] igb: fix warning if !CONFIG_IGB_HWMON (Stefan Assmann) [1091121]
- [ethernet] igb: fix array size calculation (Stefan Assmann) [1091121]
- [ethernet] igb: Update license text to remove FSF address and update copyright (Stefan Assmann) [1091121]
- [ethernet] igb: make local functions static and remove dead code (Stefan Assmann) [1091121]
- [ethernet] igb: Use pci_enable_msix_range() instead of pci_enable_msix() (Stefan Assmann) [1091121]
- [ethernet] igb: Change to use statically allocated array for MSIx entries (Stefan Assmann) [1091121]
- [ethernet] igb: Fix queue allocation method to accommodate changing during runtime (Stefan Assmann) [1091121]
- [ethernet] igb: Fix for issue where values could be too high for udelay function (Stefan Assmann) [1091121]
- [ethernet] igb: Start temperature sensor attribute index with 1 (Stefan Assmann) [1091121]
- [ethernet] igb: Add new feature Media Auto Sense for 82580 devices only (Stefan Assmann) [1091121]
- [ethernet] igb: Support ports mapped in 64-bit PCI space (Stefan Assmann) [1091121]
- [ethernet] igb: Add media switching feature for i354 PHY's (Stefan Assmann) [1091121]
- [ethernet] igb: Fixed Wake On LAN support (Stefan Assmann) [1091121]
- [ethernet] igb: Update link modes display in ethtool (Stefan Assmann) [1091121]
- [ethernet] igb: Explicitly initialize u64_stats_sync structures for lockdep (Stefan Assmann) [1091121]
- [ethernet] igb: Don't let ethtool try to write to iNVM in i210/i211 (Stefan Assmann) [1091121]
- [ethernet] igb: Fix master/slave mode for all m88 i354 PHY's (Stefan Assmann) [1091121]
- [ethernet] igb: Miscellaneous conversions to ETH_ALEN (Stefan Assmann) [1091121]
- [ethernet] igb: Avoid uninitialized advertised variable in eee_set_cur (Stefan Assmann) [1091121]
- [ethernet] igb: Add ethtool support to configure number of channels (Stefan Assmann) [1091121]
- [ethernet] igb: Add ethtool offline tests for i354 (Stefan Assmann) [1091121]
- [ethernet] igb: Fix ethtool loopback test for 82580 copper (Stefan Assmann) [1091121]
- [ethernet] igb: Remove extern from function prototypes (Stefan Assmann) [1091121]
- [ethernet] igb: fix 32-bit DMA mask handling (Stefan Assmann) [1091121]
- [ethernet] igb: Read flow control for i350 from correct EEPROM section (Stefan Assmann) [1091121]
- [ethernet] igb: Add additional get_phy_id call for i354 devices (Stefan Assmann) [1091121]
- [kernel] workqueue: zero cpumask of wq_numa_possible_cpumask on init (Motohiro Kosaki) [1117184]
- [firmware] memmap: don't allocate firmware_map_entry of same memory range (Motohiro Kosaki) [1117186]
- [firmware] memmap: pass the correct argument to firmware_map_find_entry_bootmem() (Motohiro Kosaki) [1117186]
- [cpufreq] acpi-cpufreq: skip loading acpi_cpufreq after intel_pstate (Motohiro Kosaki) [1123250]
- [x86] mem-hotplug: modify PGD entry when removing memory (Motohiro Kosaki) [1116286]
- [x86] mem-hotplug: pass sync_global_pgds() a correct argument in remove_pagetable() (Motohiro Kosaki) [1116286]
- [virt] kvm: increase x86 VCPU limit to 240 (Radim Krcmar) [1061403]
- [kernel] sched/fair: Rework sched_fair time accounting (Rik van Riel) [1123731]
- [kernel] math64: Add mul_u64_u32_shr() (Rik van Riel) [1123731]

* Wed Aug 27 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-147.el7]
- [s390] fix restore of invalid floating-point-control (Hendrik Brueckner) [1121965]
- [s390] crypto: fix aes_s390 crypto module unload problem (Hendrik Brueckner) [1103114]
- [x86] avx-512: Enable AVX-512 States Context Switch (Rui Wang) [1085563]
- [x86] avx-512: AVX-512 Feature Detection (Rui Wang) [1085563]
- [ethernet] netxen: Remove DEFINE_PCI_DEVICE_TABLE macro use (Veaceslav Falico) [1089356]
- [ethernet] netxen: slight optimization of addr compare (Veaceslav Falico) [1089356]
- [ethernet] netxen: Update version to 4.0.82 (Veaceslav Falico) [1089356]
- [ethernet] netxen: Miscellaneous conversions to ETH_ALEN (Veaceslav Falico) [1089356]
- [ethernet] netxen: get rid of SET_ETHTOOL_OPS (Veaceslav Falico) [1089356]
- [ethernet] netxen: Correct off-by-one errors in bounds checks (Veaceslav Falico) [1089356]
- [ethernet] netxen: remove unnecessary pci_set_drvdata() (Veaceslav Falico) [1089356]
- [ethernet] netxen: Print ULA information (Veaceslav Falico) [1089356]
- [ethernet] netxen: lower NAPI weight (Veaceslav Falico) [1089356]
- [ethernet] netxen: Remove extern from function prototypes (Veaceslav Falico) [1089356]
- [x86] Mark Intel Broadwell processor as supported (Steve Best) [1089025]
- [mm] Fix NULL pointer dereference in madvise(MADV_WILLNEED) support (Jan Stancek) [1072385]
- [hid] logitech-dj: Fix USB 3.0 issue (Benjamin Tissoires) [1110523]
- [lib] percpu_counter: fix bad percpu counter state during suspend (Eric Sandeen) [1129839]
- [kernel] user_namespace: fix incorrect memory barriers (Mikulas Patocka) [1128950]
- [kernel] capabilities: remove undefined caps from all processes (Paul Moore) [1123063]
- [tty] hvc: don't free hvc_console_setup after init (Luiz Capitulino) [976490]
- [mfd] lpc_ich: Add Device IDs for Intel Wildcat Point-LP PCH (Steve Best) [1086359]
- [i2c] i801: Add Device IDs for Intel Wildcat Point-LP PCH (Steve Best) [1086359]
- [x86] perf: Add model number for Avoton Silvermont (Steve Best) [1086821]
- [x86] perf: Add Silvermont (22nm Atom) support (Steve Best) [1086821]
- [x86] perf: use INTEL_UEVENT_EXTRA_REG to define MSR_OFFCORE_RSP_X (Steve Best) [1086821]
- [virt] hyperv/storvsc: Correctly handle TEST_UNIT_READY failure (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Set srb_flags in all cases (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Implement a eh_timed_out handler (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Fix a bug in handling VMBUS protocol version (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Filter commands based on the storage protocol version (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Set cmd_per_lun to reflect value supported by the Host (Fam Zheng) [1122317]
- [virt] hyperv/storvsc: Change the limits to reflect the values on the host (Fam Zheng) [1122317]
- [powerpc] perf: Add BHRB constraint and IFM MMCRA handling for EBB (Gustavo Duarte) [1121408]
- [powerpc] perf: Reject EBB events which specify a sample_type (Gustavo Duarte) [1121408]
- [powerpc] perf: Enable BHRB access for EBB events (Gustavo Duarte) [1121408]
- [powerpc] perf: Avoid mutating event in power8_get_constraint() (Gustavo Duarte) [1121408]
- [powerpc] perf: Clean up the EBB hash defines a little (Gustavo Duarte) [1121408]
- [powerpc] mm: Check paca psize is up to date for huge mappings (Gustavo Duarte) [1107337]
- [powerpc] perf: Add lost exception workaround (Gustavo Duarte) [1121407]
- [powerpc] Add a cpu feature CPU_FTR_PMAO_BUG (Gustavo Duarte) [1121407]

* Tue Aug 26 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-146.el7]
- [edac] sb_edac: add support for Haswell based systems (Seth Jennings) [1127019]
- [edac] add DDR4 and RDDR4 (Seth Jennings) [1127019]
- [edac] sb_edac: update Kconfig description (Seth Jennings) [1127019]
- [edac] sb_edac: Fix mix tab/spaces alignments (Seth Jennings) [1127019]
- [edac] sb_edac: remove bogus assumption on mc ordering (Seth Jennings) [1127019]
- [edac] sb_edac: make minimal use of channel_mask (Seth Jennings) [1127019]
- [edac] sb_edac: fix socket detection on Ivy Bridge controllers (Seth Jennings) [1127019]
- [edac] sb_edac: search devices using product id (Seth Jennings) [1127019]
- [edac] sb_edac: Degrade log level for device registration (Seth Jennings) [1127019]
- [edac] sb_edac: make RIR limit retrieval per model (Seth Jennings) [1127019]
- [edac] sb_edac: make node id retrieval per model (Seth Jennings) [1127019]
- [edac] sb_edac: make memory type detection per memory controller (Seth Jennings) [1127019]
- [hwrng] virtio-rng: add derating factor for use by hwrng core (Amit Shah) [1129195]
- [hwrng] Pass entropy to add_hwgenerator_randomness() in bits, not bytes (Amit Shah) [1129195]
- [hwrng] hw_random: fix sparse warning (NULL vs 0 for pointer) (Amit Shah) [1129195]
- [hwrng] add per-device entropy derating (Amit Shah) [1129195]
- [hwrng] create filler thread (Amit Shah) [1129195]
- [hwrng] random: add_hwgenerator_randomness() for feeding entropy from devices (Amit Shah) [1129195]
- [char] Revert: hwrng: virtio - ensure reads happen after successful probe (Amit Shah) [1129195]
- [char] hwrng: virtio - delay hwrng_register() till driver is ready (Amit Shah) [1119299]
- [char] hwrng: virtio - re-arrange struct elements for better packing (Amit Shah) [1119299]
- [char] hwrng: virtio - remove unused struct element (Amit Shah) [1119299]
- [char] hwrng: virtio - ensure reads happen after successful probe (Amit Shah) [1119299]
- [char] hwrng: fetch randomness only after device init (Amit Shah) [1119299]
- [char] hwrng: add randomness to system from rng sources (Amit Shah) [1119299]
- [char] hwrng: cleanup in hwrng_register() (Amit Shah) [1119299]
- [virt] virtio/pm: use CONFIG_PM_SLEEP instead of CONFIG_PM (Amit Shah) [1119299]
- [virt] virtio-rng: fixes for device registration/unregistration (Amos Kong) [915335]
- [virt] virtio-rng: fix boot with virtio-rng device (Amos Kong) [915335]
- [virt] virtio-rng: support multiple virtio-rng devices (Amos Kong) [915335]
- [virt] virtio-rng: don't crash if virtqueue is broken (Amos Kong) [915335]
- [pci] Fix unaligned access in AF transaction pending test (Myron Stowe) [1110896]
- [pci] Wrong register used to check pending traffic (Myron Stowe) [1110896]
- [pci] shpchp: Check bridge's secondary (not primary) bus speed (Myron Stowe) [1110896]
- [pci] Update maintainer email address (Myron Stowe) [1110896]
- [powerpc] pci: Fix NULL dereference in sys_pciconfig_iobase() list traversal (Myron Stowe) [1110896]
- [pci] Log IDE resource quirk in dmesg (Myron Stowe) [1110896]
- [pci] Change pci_bus_alloc_resource() type_mask to unsigned long (Myron Stowe) [1110896]
- [pci] Check all IORESOURCE_TYPE_BITS in pci_bus_alloc_from_region() (Myron Stowe) [1110896]
- [kernel] resources: Set type in __request_region() (Myron Stowe) [1110896]
- [s390] pci: Use generic pci_enable_resources() (Myron Stowe) [1110896]
- [pci] Add "weak" generic pcibios_enable_device() implementation (Myron Stowe) [1110896]
- [pci] Don't enable decoding if BAR hasn't been assigned an address (Myron Stowe) [1110896]
- [pci] Mark 64-bit resource as IORESOURCE_UNSET if we only support 32-bit (Myron Stowe) [1110896]
- [pci] Don't try to claim IORESOURCE_UNSET resources (Myron Stowe) [1110896]
- [pci] Check IORESOURCE_UNSET before updating BAR (Myron Stowe) [1110896]
- [pci] Don't clear IORESOURCE_UNSET when updating BAR (Myron Stowe) [1110896]
- [pci] Mark resources as IORESOURCE_UNSET if we can't assign them (Myron Stowe) [1110896]
- [pci] Remove pci_find_parent_resource() use for allocation (Myron Stowe) [1110896]
- [lib] vsprintf: Add support for IORESOURCE_UNSET in pR (Myron Stowe) [1110896]
- [kernel] resource: Add resource_contains() (Myron Stowe) [1110896]
- [message] i2o: Use pci_bus_alloc_resource(), not allocate_resource() directly (Myron Stowe) [1110896]
- [message] i2o: Refactor i2o_iop_systab_set() PCI space allocation (Myron Stowe) [1110896]
- [message] i2o: Fix I/O space alignment requirement (Myron Stowe) [1110896]
- [message] i2o: Fix I/O space allocation copy/paste error (Myron Stowe) [1110896]
- [pci] pciehp: Cleanup whitespace (Myron Stowe) [1110896]
- [pci] pciehp: Remove a non-existent card, regardless of "surprise" capability (Myron Stowe) [1110896]
- [pci] Remove unused SR-IOV VF Migration support (Myron Stowe) [1110896]
- [iommu] amd: Add include of <linux/irqreturn.h> (Myron Stowe) [1110896]
- [misc] mei: Add include of <linux/irqreturn.h> (Myron Stowe) [1110896]
- [vfio] pci: Use pci_enable_msi_range() and pci_enable_msix_range() (Myron Stowe) [1110896]
- [ata] ahci: Use pci_enable_msi_range() instead of pci_enable_msi_block() (Myron Stowe) [1110896]
- [x86] pci: Set IORESOURCE_ROM_SHADOW only for the default VGA device (Myron Stowe) [1110896]
- [pci] Remove pci_bus_b() and use list_for_each_entry() directly (Myron Stowe) [1110896]
- [pcmcia] Use list_for_each_entry() for bus traversal (Myron Stowe) [1110896]
- [powerpc] pci: Use list_for_each_entry() for bus traversal (Myron Stowe) [1110896]
- [drm] Use list_for_each_entry() for bus traversal (Myron Stowe) [1110896]
- [pci] hotplug/apci: Use list_for_each_entry() for bus traversal (Myron Stowe) [1110896]
- [pci] pciehp: Don't turn slot off when hot-added device already exists (Myron Stowe) [1110896]
- [pci] Cleanup per-arch list of object files (Myron Stowe) [1110896]
- [pci] hotplug/cpqphp: Fix hex vs decimal typo in cpqhpc_probe() (Myron Stowe) [1110896]
- [x86] pci: Fix function definition whitespace (Myron Stowe) [1110896]
- [x86] pci: Reword comments (Myron Stowe) [1110896]
- [x86] pci: Remove unnecessary local variable initialization (Myron Stowe) [1110896]
- [pci] Don't scan random busses in pci_scan_bridge() (Myron Stowe) [1110896]
- [pci] Check for child busses which use more bus numbers than allocated (Myron Stowe) [1110896]
- [pci] Remove pci_fixup_parent_subordinate_busnr() (Myron Stowe) [1110896]
- [pci] Make sure bus number resources stay within their parents bounds (Myron Stowe) [1110896]
- [pci] Use request_resource_conflict() instead of insert_ for bus numbers (Myron Stowe) [1110896]
- [pci] Assign CardBus bus number only during the second pass (Myron Stowe) [1110896]
- [pci] Clarify the "scan anyway" comment in pci_scan_bridge() (Myron Stowe) [1110896]
- [pci] Increment max correctly in pci_scan_bridge() (Myron Stowe) [1110896]
- [pci] Remove unnecessary list_empty(&pci_pme_list) check (Myron Stowe) [1110896]
- [acpi] numa: Use __weak, not the gcc-specific version (Myron Stowe) [1110896]
- [acpi] numa: Make __acpi_map_pxm_to_node(), acpi_get_pxm() static (Myron Stowe) [1110896]
- [acpi] numa: Simplify acpi_get_node() style (Myron Stowe) [1110896]
- [acpi] numa: Fix acpi_get_node() prototype (Myron Stowe) [1110896]
- [x86] pci: Remove acpi_get_pxm() usage (Myron Stowe) [1110896]
- [x86] pci: Use NUMA_NO_NODE, not -1, for unknown node (Myron Stowe) [1110896]
- [x86] pci: Remove unnecessary list_empty(&pci_root_infos) check (Myron Stowe) [1110896]
- [x86] pci: Remove mp_bus_to_node[], set_mp_bus_to_node(), get_mp_bus_to_node() (Myron Stowe) [1110896]
- [x86] pci: Use x86_pci_root_bus_node() instead of get_mp_bus_to_node() (Myron Stowe) [1110896]
- [x86] pci: Add x86_pci_root_bus_node() to look up NUMA node from PCI bus (Myron Stowe) [1110896]
- [x86] pci: Drop return value of pcibios_scan_root() (Myron Stowe) [1110896]
- [x86] pci: Merge pci_scan_bus_on_node() into pcibios_scan_root() (Myron Stowe) [1110896]
- [x86] pci: Use pcibios_scan_root() instead of pci_scan_bus_on_node() (Myron Stowe) [1110896]
- [x86] pci: Use pcibios_scan_root() instead of pci_scan_bus_with_sysdata() (Myron Stowe) [1110896]
- [x86] pci: Drop pcibios_scan_root() check for bus already scanned (Myron Stowe) [1110896]
- [ata] ahci: convert ahci_init_interrupts to a static routine (Myron Stowe) [1110896]
- [acpi] mm: use NUMA_NO_NODE (Myron Stowe) [1110896]

* Tue Aug 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-145.el7]
- [fs] btrfs: test for valid bdev before kobj removal in btrfs_rm_device (Eric Sandeen) [1071179]
- [fs] btrfs: fix abnormal long waiting in fsync (Eric Sandeen) [1071179]
- [fs] btrfs: fix crash when starting transaction (Eric Sandeen) [1071179]
- [fs] btrfs: fix btrfs_print_leaf for skinny metadata (Eric Sandeen) [1071179]
- [fs] btrfs: fix race of using total_bytes_pinned (Eric Sandeen) [1071179]
- [fs] btrfs: use E2BIG instead of EIO if compression does not help (Eric Sandeen) [1071179]
- [fs] btrfs: remove stale comment from btrfs_flush_all_pending_stuffs (Eric Sandeen) [1071179]
- [fs] btrfs: fix use-after-free when cloning a trailing file hole (Eric Sandeen) [1071179]
- [fs] btrfs: fix null pointer dereference in btrfs_show_devname when name is null (Eric Sandeen) [1071179]
- [fs] btrfs: fix null pointer dereference in clone_fs_devices when name is null (Eric Sandeen) [1071179]
- [fs] btrfs: fix nossd and ssd_spread mount option regression (Eric Sandeen) [1071179]
- [fs] btrfs: fix race between balance recovery and root deletion (Eric Sandeen) [1071179]
- [fs] btrfs: only unlock block in verify_parent_transid if we locked it (Eric Sandeen) [1071179]
- [fs] btrfs: assert send doesn't attempt to start transactions (Eric Sandeen) [1071179]
- [fs] btrfs: compression - reuse recently used workspace (Eric Sandeen) [1071179]
- [fs] btrfs: fix crash when mounting raid5 btrfs with missing disks (Eric Sandeen) [1071179]
- [fs] btrfs: create sprout should rename fsid on the sysfs as well (Eric Sandeen) [1071179]
- [fs] btrfs: dev replace should replace the sysfs entry (Eric Sandeen) [1071179]
- [fs] btrfs: dev add should add its sysfs entry (Eric Sandeen) [1071179]
- [fs] btrfs: dev delete should remove sysfs entry (Eric Sandeen) [1071179]
- [fs] btrfs: rename add_device_membership to btrfs_kobj_add_device (Eric Sandeen) [1071179]
- [fs] btrfs: fix deadlock when mounting a degraded fs (Eric Sandeen) [1071179]
- [fs] btrfs: fix NULL pointer crash when running balance and scrub concurrently (Eric Sandeen) [1071179]
- [fs] btrfs: Skip scrubbing removed chunks to avoid -ENOENT (Eric Sandeen) [1071179]
- [fs] btrfs: fix broken free space cache after the system crashed (Eric Sandeen) [1071179]
- [fs] btrfs: make free space cache write out functions more readable (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused wait queue in struct extent_buffer (Eric Sandeen) [1071179]
- [fs] btrfs: fix deadlocks with trylock on tree nodes (Eric Sandeen) [1071179]
- [fs] btrfs: fix error handling in create_pending_snapshot (Eric Sandeen) [1071179]
- [fs] btrfs: fix use of uninit "ret" in end_extent_writepage() (Eric Sandeen) [1071179]
- [fs] btrfs: free ulist in qgroup_shared_accounting() error path (Eric Sandeen) [1071179]
- [fs] btrfs: fix qgroups sanity test crash or hang (Eric Sandeen) [1071179]
- [fs] btrfs: prevent RCU warning when dereferencing radix tree slot (Eric Sandeen) [1071179]
- [fs] btrfs: fix unfinished readahead thread for raid5/6 degraded mounting (Eric Sandeen) [1071179]
- [fs] btrfs: new ioctl TREE_SEARCH_V2 (Eric Sandeen) [1071179]
- [fs] btrfs: tree_search, search_ioctl: direct copy to userspace (Eric Sandeen) [1071179]
- [fs] btrfs: new function read_extent_buffer_to_user (Eric Sandeen) [1071179]
- [fs] btrfs: tree_search, copy_to_sk: return needed size on EOVERFLOW (Eric Sandeen) [1071179]
- [fs] btrfs: tree_search, copy_to_sk: return EOVERFLOW for too small buffer (Eric Sandeen) [1071179]
- [fs] btrfs: tree_search, search_ioctl: accept varying buffer (Eric Sandeen) [1071179]
- [fs] btrfs: tree_search: eliminate redundant nr_items check (Eric Sandeen) [1071179]
- [fs] btrfs: fix scrub_print_warning to handle skinny metadata extents (Eric Sandeen) [1071179]
- [fs] btrfs: make fsync work after cloning into a file (Eric Sandeen) [1071179]
- [fs] btrfs: use right type to get real comparison (Eric Sandeen) [1071179]
- [fs] btrfs: don't check nodes for extent items (Eric Sandeen) [1071179]
- [fs] btrfs: don't release invalid page in btrfs_page_exists_in_range() (Eric Sandeen) [1071179]
- [fs] btrfs: make sure we retry if page is a retriable exception (Eric Sandeen) [1071179]
- [fs] btrfs: make sure we retry if we couldn't get the page (Eric Sandeen) [1071179]
- [fs] btrfs: replace EINVAL with EOPNOTSUPP for dev_replace raid56 (Eric Sandeen) [1071179]
- [fs] btrfs: ioctl - fix typo s/substract/subtract/ (Eric Sandeen) [1071179]
- [fs] btrfs: fix leaf corruption after __btrfs_drop_extents (Eric Sandeen) [1071179]
- [fs] btrfs: ensure btrfs_prev_leaf doesn't miss 1 item (Eric Sandeen) [1071179]
- [fs] btrfs: fix clone to deal with holes when NO_HOLES feature is enabled (Eric Sandeen) [1071179]
- [fs] btrfs: free delayed node outside of root->inode_lock (Eric Sandeen) [1071179]
- [fs] btrfs: replace EINVAL with ERANGE for resize when ULLONG_MAX (Eric Sandeen) [1071179]
- [fs] btrfs: fix transaction leak during fsync call (Eric Sandeen) [1071179]
- [fs] btrfs: Avoid truncating page or punching hole in a already existed hole (Eric Sandeen) [1071179]
- [fs] btrfs: update commit root on snapshot creation after orphan cleanup (Eric Sandeen) [1071179]
- [fs] btrfs: ioctl, don't re-lock extent range when not necessary (Eric Sandeen) [1071179]
- [fs] btrfs: avoid visiting all extent items when cloning a range (Eric Sandeen) [1071179]
- [fs] btrfs: set dead flag on the right root when destroying snapshot (Eric Sandeen) [1071179]
- [fs] btrfs: ensure readers see new data after a clone operation (Eric Sandeen) [1071179]
- [fs] btrfs: volumes - Fix for possible null pointer dereference (Eric Sandeen) [1071179]
- [fs] btrfs: allocate raid type kobjects dynamically (Eric Sandeen) [1071179]
- [fs] btrfs: send, use the right limits for xattr names and values (Eric Sandeen) [1071179]
- [fs] btrfs: send, don't error in the presence of subvols/snapshots (Eric Sandeen) [1071179]
- [fs] btrfs: async delayed refs (Eric Sandeen) [1071179]
- [fs] btrfs: split up __extent_writepage to lower stack usage (Eric Sandeen) [1071179]
- [fs] btrfs: Drop EXTENT_UPTODATE check in hole punching and direct locking (Eric Sandeen) [1071179]
- [fs] btrfs: cut down stack usage in btree_write_cache_pages (Eric Sandeen) [1071179]
- [fs] btrfs: break up __btrfs_write_out_cache to cut down stack usage (Eric Sandeen) [1071179]
- [fs] btrfs: free tmp ulist for qgroup rescan (Eric Sandeen) [1071179]
- [fs] btrfs: usage error should not be logged into system log (Eric Sandeen) [1071179]
- [fs] btrfs: remove newline from inode cache kthread name (Eric Sandeen) [1071179]
- [fs] btrfs: remove stale newlines from log messages (Eric Sandeen) [1071179]
- [fs] btrfs: fix double free in find_lock_delalloc_range (Eric Sandeen) [1071179]
- [fs] btrfs: replace simple_strtoull() with kstrtoull() (Eric Sandeen) [1071179]
- [fs] btrfs: set right total device count for seeding support (Eric Sandeen) [1071179]
- [fs] btrfs: remove OPT_acl parse when acl disabled (Eric Sandeen) [1071179]
- [fs] btrfs: add sanity tests for new qgroup accounting code (Eric Sandeen) [1071179]
- [fs] btrfs: rework qgroup accounting (Eric Sandeen) [1071179]
- [fs] btrfs: mark mapping with error flag to report errors to userspace (Eric Sandeen) [1071179]
- [fs] btrfs: fix NULL pointer crash of deleting a seed device (Eric Sandeen) [1071179]
- [fs] btrfs: fix joining same transaction handle more than twice (Eric Sandeen) [1071179]
- [fs] btrfs: use helpers for last_trans_log_full_commit instead of opencode (Eric Sandeen) [1071179]
- [fs] btrfs: check if items are ordered when a leaf is marked dirty (Eric Sandeen) [1071179]
- [fs] btrfs: don't access non-existent key when csum tree is empty (Eric Sandeen) [1071179]
- [fs] btrfs: make sure there are not any read requests before stopping workers (Eric Sandeen) [1071179]
- [fs] btrfs: fix possible memory leak in btrfs_create_tree() (Eric Sandeen) [1071179]
- [fs] btrfs: remove useless ACL check (Eric Sandeen) [1071179]
- [fs] btrfs: btrfs_rm_device() should zero mirror SB as well (Eric Sandeen) [1071179]
- [fs] btrfs: use bitfield instead of integer data type for the some variants in btrfs_root (Eric Sandeen) [1071179]
- [fs] btrfs: send, fix more issues related to directory renames (Eric Sandeen) [1071179]
- [fs] btrfs: send, remove dead code from __get_cur_name_and_parent (Eric Sandeen) [1071179]
- [fs] btrfs: send, account for orphan directories when building path strings (Eric Sandeen) [1071179]
- [fs] btrfs: send, avoid unnecessary inode item lookup in the btree (Eric Sandeen) [1071179]
- [fs] btrfs: add dev maxs limit for __btrfs_alloc_chunk in kernel space (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong max system array size check in kernel space (Eric Sandeen) [1071179]
- [fs] btrfs: Add check to avoid cleanup roots already in fs_info->dead_roots (Eric Sandeen) [1071179]
- [fs] btrfs: reclaim the reserved metadata space at background (Eric Sandeen) [1071179]
- [fs] btrfs: output warning instead of error when loading free space cache failed (Eric Sandeen) [1071179]
- [fs] btrfs: Add ctime/mtime update for btrfs device add/remove (Eric Sandeen) [1071179]
- [fs] btrfs: assert that send is not in progres before root deletion (Eric Sandeen) [1071179]
- [fs] btrfs: protect snapshots from deleting during send (Eric Sandeen) [1071179]
- [fs] btrfs: remove redundant null check in btrfs_dentry_release() (Eric Sandeen) [1071179]
- [fs] btrfs: make FS_INFO ioctl available to anyone (Eric Sandeen) [1071179]
- [fs] btrfs: make DEV_INFO ioctl available to anyone (Eric Sandeen) [1071179]
- [fs] btrfs: export more from FS_INFO to sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: retrieve more info from FS_INFO ioctl (Eric Sandeen) [1071179]
- [fs] btrfs: balance filter: add limit of processed chunks (Eric Sandeen) [1071179]
- [fs] btrfs: fix leaf corruption caused by ENOSPC while hole punching (Eric Sandeen) [1071179]
- [fs] btrfs: do not increment on bio_index one by one (Eric Sandeen) [1071179]
- [fs] btrfs: read inode size after acquiring the mutex when punching a hole (Eric Sandeen) [1071179]
- [fs] btrfs: Remove unnecessary check for NULL (Eric Sandeen) [1071179]
- [fs] btrfs: fix inline compressed read err corruption (Eric Sandeen) [1071179]
- [fs] btrfs: return ptr error from compression workspace (Eric Sandeen) [1071179]
- [fs] btrfs: return errno instead of -1 from compression (Eric Sandeen) [1071179]
- [fs] btrfs: check_int: propagate out-of-memory error upwards (Eric Sandeen) [1071179]
- [fs] btrfs: fix hang on error (such as ENOSPC) when writing extent pages (Eric Sandeen) [1071179]
- [fs] btrfs: send, fix corrupted path strings for long paths (Eric Sandeen) [1071179]
- [fs] btrfs: send, fix incorrect ref access when using extrefs (Eric Sandeen) [1071179]
- [fs] btrfs: fix EIO on reading file after ioctl clone works on it (Eric Sandeen) [1071179]
- [fs] btrfs: limit the path size in send to PATH_MAX (Eric Sandeen) [1071179]
- [fs] btrfs: correctly set profile flags on seqlock retry (Eric Sandeen) [1071179]
- [fs] btrfs: use correct key when repeating search for extent item (Eric Sandeen) [1071179]
- [fs] btrfs: fix inode caching vs tree log (Eric Sandeen) [1071179]
- [fs] btrfs: fix possible memory leaks in open_ctree() (Eric Sandeen) [1071179]
- [fs] btrfs: avoid triggering bug_on() when we fail to start inode caching task (Eric Sandeen) [1071179]
- [fs] btrfs: move btrfs_{set, clear}_and_info() to ctree.h (Eric Sandeen) [1071179]
- [fs] btrfs: replace error code from btrfs_drop_extents (Eric Sandeen) [1071179]
- [fs] btrfs: Change the hole range to a more accurate value (Eric Sandeen) [1071179]
- [fs] btrfs: fix use-after-free in mount_subvol() (Eric Sandeen) [1071179]
- [fs] btrfs: fix compile warnings on on avr32 platform (Eric Sandeen) [1071179]
- [fs] btrfs: allow mounting btrfs subvolumes with different ro/rw options (Eric Sandeen) [1071179]
- [fs] btrfs: export global block reserve size as space_info (Eric Sandeen) [1071179]
- [fs] btrfs: fix crash in remount(thread_pool=) case (Eric Sandeen) [1071179]
- [fs] btrfs: abort the transaction when we don't find our extent ref (Eric Sandeen) [1071179]
- [fs] btrfs: fix EINVAL checks in btrfs_clone (Eric Sandeen) [1071179]
- [fs] btrfs: fix unlock in __start_delalloc_inodes() (Eric Sandeen) [1071179]
- [fs] btrfs: scrub raid56 stripes in the right way (Eric Sandeen) [1071179]
- [fs] btrfs: don't compress for a small write (Eric Sandeen) [1071179]
- [fs] btrfs: more efficient io tree navigation on wait_extent_bit (Eric Sandeen) [1071179]
- [fs] btrfs: send, build path string only once in send_hole (Eric Sandeen) [1071179]
- [fs] btrfs: filter invalid arg for btrfs resize (Eric Sandeen) [1071179]
- [fs] btrfs: send, fix data corruption due to incorrect hole detection (Eric Sandeen) [1071179]
- [fs] btrfs: kmalloc() doesn't return an ERR_PTR (Eric Sandeen) [1071179]
- [fs] btrfs: fix snapshot vs nocow writting (Eric Sandeen) [1071179]
- [fs] btrfs: Change the expanding write sequence to fix snapshot related bug (Eric Sandeen) [1071179]
- [fs] btrfs: make device scan less noisy (Eric Sandeen) [1071179]
- [fs] btrfs: fix lockdep warning with reclaim lock inversion (Eric Sandeen) [1071179]
- [fs] btrfs: hold the commit_root_sem when getting the commit root during send (Eric Sandeen) [1071179]
- [fs] btrfs: remove transaction from send (Eric Sandeen) [1071179]
- [fs] btrfs: don't clear uptodate if the eb is under IO (Eric Sandeen) [1071179]
- [fs] btrfs: check for an extent_op on the locked ref (Eric Sandeen) [1071179]
- [fs] btrfs: do not reset last_snapshot after relocation (Eric Sandeen) [1071179]
- [fs] btrfs: fix a crash of clone with inline extents's split (Eric Sandeen) [1071179]
- [fs] btrfs: fix uninit variable warning (Eric Sandeen) [1071179]
- [fs] btrfs: take into account total references when doing backref lookup (Eric Sandeen) [1071179]
- [fs] btrfs: part 2, fix incremental send's decision to delay a dir move/rename (Eric Sandeen) [1071179]
- [fs] btrfs: fix incremental send's decision to delay a dir move/rename (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary inode generation lookup in send (Eric Sandeen) [1071179]
- [fs] btrfs: fix race when updating existing ref head (Eric Sandeen) [1071179]
- [fs] btrfs: Add trace for btrfs_workqueue alloc/destroy (Eric Sandeen) [1071179]
- [fs] btrfs: less fs tree lock contention when using autodefrag (Eric Sandeen) [1071179]
- [fs] btrfs: return EPERM when deleting a default subvolume (Eric Sandeen) [1071179]
- [fs] btrfs: add missing kfree in btrfs_destroy_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: cache extent states in defrag code path (Eric Sandeen) [1071179]
- [fs] btrfs: fix deadlock with nested trans handles (Eric Sandeen) [1071179]
- [fs] btrfs: fix possible empty list access when flushing the delalloc inodes (Eric Sandeen) [1071179]
- [fs] btrfs: split the global ordered extents mutex (Eric Sandeen) [1071179]
- [fs] btrfs: don't flush all delalloc inodes when we doesn't get s_umount lock (Eric Sandeen) [1071179]
- [fs] btrfs: reclaim delalloc metadata more aggressively (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary lock in may_commit_transaction() (Eric Sandeen) [1071179]
- [fs] btrfs: remove the unnecessary flush when preparing the pages (Eric Sandeen) [1071179]
- [fs] btrfs: just do dirty page flush for the inode with compression before direct IO (Eric Sandeen) [1071179]
- [fs] btrfs: wake up the tasks that wait for the io earlier (Eric Sandeen) [1071179]
- [fs] btrfs: fix early enospc due to the race of the two ordered extent wait (Eric Sandeen) [1071179]
- [fs] btrfs: introduce btrfs_{start, end}_nocow_write() for each subvolume (Eric Sandeen) [1071179]
- [fs] btrfs: Add ftrace for btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Cleanup the btrfs_workqueue related function type (Eric Sandeen) [1071179]
- [fs] btrfs: add readahead for send_write (Eric Sandeen) [1071179]
- [fs] btrfs: share the same code for __record_{new, deleted}_ref (Eric Sandeen) [1071179]
- [fs] btrfs: avoid unnecessary utimes update in incremental send (Eric Sandeen) [1071179]
- [fs] btrfs: make defrag not fragment files when using prealloc extents (Eric Sandeen) [1071179]
- [fs] btrfs: correctly flush data on defrag when compression is enabled (Eric Sandeen) [1071179]
- [fs] btrfs: Cleanup the "_struct" suffix in btrfs_workequeue (Eric Sandeen) [1071179]
- [fs] btrfs: Cleanup the old btrfs_worker (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->scrub_* workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->qgroup_rescan_worker workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->delayed_workers workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->fixup_workers workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->readahead_workers workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->cache_workers workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->rmw_workers workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->endio_* workqueue with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->flush_workers with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->submit_workers with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->delalloc_workers with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Replace fs_info->workers with btrfs_workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Add threshold workqueue based on kernel workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Add high priority workqueue support for btrfs_workqueue_struct (Eric Sandeen) [1071179]
- [fs] btrfs: Added btrfs_workqueue_struct implemented ordered execution based on kernel workqueue (Eric Sandeen) [1071179]
- [fs] btrfs: Cleanup the unused struct async_sched (Eric Sandeen) [1071179]
- [fs] btrfs: skip search tree for REG files (Eric Sandeen) [1071179]
- [fs] btrfs: fix preallocate vs double nocow write (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong lock range and write size in check_can_nocow() (Eric Sandeen) [1071179]
- [fs] btrfs: send: simplify allocation code in fs_path_ensure_buf (Eric Sandeen) [1071179]
- [fs] btrfs: send: fix old buffer length in fs_path_ensure_buf (Eric Sandeen) [1071179]
- [fs] btrfs: more efficient btrfs_drop_extent_cache (Eric Sandeen) [1071179]
- [fs] btrfs: more efficient split extent state insertion (Eric Sandeen) [1071179]
- [fs] btrfs: remove unneeded field / smaller extent_map structure (Eric Sandeen) [1071179]
- [fs] btrfs: skip locking when searching commit root (Eric Sandeen) [1071179]
- [fs] btrfs: wake up @scrub_pause_wait as much as we can (Eric Sandeen) [1071179]
- [fs] btrfs: cancel scrub on transaction abortion (Eric Sandeen) [1071179]
- [fs] btrfs: device_replace: fix deadlock for nocow case (Eric Sandeen) [1071179]
- [fs] btrfs: fix a possible deadlock between scrub and transaction committing (Eric Sandeen) [1071179]
- [fs] btrfs: fix send issuing outdated paths for utimes, chown and chmod (Eric Sandeen) [1071179]
- [fs] btrfs: correctly determine if blocks are shared in btrfs_compare_trees (Eric Sandeen) [1071179]
- [fs] btrfs: fix send attempting to rmdir non-empty directories (Eric Sandeen) [1071179]
- [fs] btrfs: send, don't send rmdir for same target multiple times (Eric Sandeen) [1071179]
- [fs] btrfs: incremental send, fix invalid path after dir rename (Eric Sandeen) [1071179]
- [fs] btrfs: don't insert useless holes when punching beyond the inode's size (Eric Sandeen) [1071179]
- [fs] btrfs: cleanup delayed-ref.c:find_ref_head() (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary ref heads rb tree search (Eric Sandeen) [1071179]
- [fs] btrfs: wake up transaction thread upon remount (Eric Sandeen) [1071179]
- [fs] btrfs: stop joining the log transaction if sync log fails (Eric Sandeen) [1071179]
- [fs] btrfs: just wait or commit our own log sub-transaction (Eric Sandeen) [1071179]
- [fs] btrfs: fix skipped error handle when log sync failed (Eric Sandeen) [1071179]
- [fs] btrfs: use signed integer instead of unsigned long integer for log transid (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary memory barrier in btrfs_sync_log() (Eric Sandeen) [1071179]
- [fs] btrfs: don't start the log transaction if the log tree init fails (Eric Sandeen) [1071179]
- [fs] btrfs: fix the skipped transaction commit during the file sync (Eric Sandeen) [1071179]
- [fs] btrfs: use ACCESS_ONCE to prevent the optimize accesses to ->last_trans_log_full_commit (Eric Sandeen) [1071179]
- [fs] btrfs: avoid warning bomb of btrfs_invalidate_inodes (Eric Sandeen) [1071179]
- [fs] btrfs: fix possible deadlock in btrfs_cleanup_transaction (Eric Sandeen) [1071179]
- [fs] btrfs: faster/more efficient insertion of file extent items (Eric Sandeen) [1071179]
- [fs] btrfs: always choose work from prio_head first (Eric Sandeen) [1071179]
- [fs] Revert: btrfs: remove transaction from btrfs send (Eric Sandeen) [1071179]
- [fs] btrfs: skip readonly root for snapshot-aware defragment (Eric Sandeen) [1071179]
- [fs] btrfs: switch to btrfs_previous_extent_item() (Eric Sandeen) [1071179]
- [fs] btrfs: skip submitting barrier for missing device (Eric Sandeen) [1071179]
- [fs] btrfs: unlock extent and pages on error in cow_file_range (Eric Sandeen) [1071179]
- [fs] btrfs: balance delayed inode updates (Eric Sandeen) [1071179]
- [fs] btrfs: add simple debugfs interface (Eric Sandeen) [1071179]
- [fs] btrfs: send: lower memory requirements in common case (Eric Sandeen) [1071179]
- [fs] btrfs: make some tree searches in send.c more efficient (Eric Sandeen) [1071179]
- [fs] btrfs: use right extent item position in send when finding extent clones (Eric Sandeen) [1071179]
- [fs] btrfs: send: remove BUG_ON from name_cache_delete (Eric Sandeen) [1071179]
- [fs] btrfs: send: remove BUG from process_all_refs (Eric Sandeen) [1071179]
- [fs] btrfs: send: squeeze bitfilelds in fs_path (Eric Sandeen) [1071179]
- [fs] btrfs: send: remove virtual_mem member from fs_path (Eric Sandeen) [1071179]
- [fs] btrfs: send: remove prepared member from fs_path (Eric Sandeen) [1071179]
- [fs] btrfs: send: replace check with an assert in gen_unique_name (Eric Sandeen) [1071179]
- [fs] btrfs: more send support for parent/child dir relationship inversion (Eric Sandeen) [1071179]
- [fs] btrfs: fix send dealing with file renames and directory moves (Eric Sandeen) [1071179]
- [fs] btrfs: only add roots if necessary in find_parent_nodes() (Eric Sandeen) [1071179]
- [fs] btrfs: Fix 32/64-bit problem with BTRFS_SET_RECEIVED_SUBVOL ioctl (Eric Sandeen) [1071179]
- [fs] btrfs: add missing error check in incremental send (Eric Sandeen) [1071179]
- [fs] btrfs: fix use-after-free in the finishing procedure of the device replace (Eric Sandeen) [1071179]
- [fs] btrfs: fix unprotected alloc list insertion during the finishing procedure of replace (Eric Sandeen) [1071179]
- [fs] btrfs: Return EXDEV for cross file system snapshot (Eric Sandeen) [1071179]
- [fs] btrfs: don't mix the ordered extents of all files together during logging the inodes (Eric Sandeen) [1071179]
- [fs] btrfs: use right clone root offset for compressed extents (Eric Sandeen) [1071179]
- [fs] btrfs: fix null pointer deference at btrfs_sysfs_add_one+0x105 (Eric Sandeen) [1071179]
- [fs] btrfs: unset DCACHE_DISCONNECTED when mounting default subvol (Eric Sandeen) [1071179]
- [fs] btrfs: fix max_inline mount option (Eric Sandeen) [1071179]
- [fs] btrfs: fix a lockdep warning when cleaning up aborted transaction (Eric Sandeen) [1071179]
- [fs] Revert: btrfs: add ioctl to export size of global metadata reservation (Eric Sandeen) [1071179]
- [fs] btrfs: fix data corruption when reading/updating compressed extents (Eric Sandeen) [1071179]
- [fs] btrfs: don't loop forever if we can't run because of the tree mod log (Eric Sandeen) [1071179]
- [fs] btrfs: reserve no transaction units in btrfs_ioctl_set_features (Eric Sandeen) [1071179]
- [fs] btrfs: commit transaction after setting label and features (Eric Sandeen) [1071179]
- [fs] btrfs: fix assert screwup for the pending move stuff (Eric Sandeen) [1071179]
- [fs] btrfs: use late_initcall instead of module_init (Eric Sandeen) [1071179]
- [fs] btrfs: use btrfs_crc32c everywhere instead of libcrc32c (Eric Sandeen) [1071179]
- [fs] btrfs: disable snapshot aware defrag for now (Eric Sandeen) [1071179]
- [fs] btrfs: fix spin_unlock in check_ref_cleanup (Eric Sandeen) [1071179]
- [fs] btrfs: setup inode location during btrfs_init_inode_locked (Eric Sandeen) [1071179]
- [fs] btrfs: don't use ram_bytes for uncompressed inline items (Eric Sandeen) [1071179]
- [fs] btrfs: fix btrfs_search_slot_for_read backwards iteration (Eric Sandeen) [1071179]
- [fs] btrfs: do not export ulist functions (Eric Sandeen) [1071179]
- [fs] btrfs: rework ulist with list+rb_tree (Eric Sandeen) [1071179]
- [fs] btrfs: fix memory leaks on walking backrefs failure (Eric Sandeen) [1071179]
- [fs] btrfs: fix send file hole detection leading to data corruption (Eric Sandeen) [1071179]
- [fs] btrfs: add a reschedule point in btrfs_find_all_roots() (Eric Sandeen) [1071179]
- [fs] btrfs: make send's file extent item search more efficient (Eric Sandeen) [1071179]
- [fs] btrfs: fix to catch all errors when resolving indirect ref (Eric Sandeen) [1071179]
- [fs] btrfs: fix protection between walking backrefs and root deletion (Eric Sandeen) [1071179]
- [fs] btrfs: fix warning while merging two adjacent extents (Eric Sandeen) [1071179]
- [fs] btrfs: fix infinite path build loops in incremental send (Eric Sandeen) [1071179]
- [fs] btrfs: undo sysfs when open_ctree() fails (Eric Sandeen) [1071179]
- [fs] btrfs: fix snprintf usage by send's gen_unique_name (Eric Sandeen) [1071179]
- [fs] btrfs: fix defrag 32-bit integer overflow (Eric Sandeen) [1071179]
- [fs] btrfs: sysfs: list the NO_HOLES feature (Eric Sandeen) [1071179]
- [fs] btrfs: sysfs: don't show reserved incompat feature (Eric Sandeen) [1071179]
- [fs] btrfs: call permission checks earlier in ioctls and return EPERM (Eric Sandeen) [1071179]
- [fs] btrfs: restrict snapshotting to own subvolumes (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong block group in trace during the free space allocation (Eric Sandeen) [1071179]
- [fs] btrfs: cleanup the code of used_block_group in find_free_extent() (Eric Sandeen) [1071179]
- [fs] btrfs: cleanup the redundant code for the block group allocation and init (Eric Sandeen) [1071179]
- [fs] btrfs: change the members' order of btrfs_space_info structure to reduce the cache miss (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong search path initialization before searching tree root (Eric Sandeen) [1071179]
- [fs] btrfs: flush the dirty pages of the ordered extent aggressively during logging csum (Eric Sandeen) [1071179]
- [fs] btrfs: fix transaction abortion when remounting btrfs from RW to RO (Eric Sandeen) [1071179]
- [fs] btrfs: faster file extent item search in clone ioctl (Eric Sandeen) [1071179]
- [fs] btrfs: fix extent state leak on transaction abortion (Eric Sandeen) [1071179]
- [fs] btrfs: Cleanup the btrfs_parse_options for remount (Eric Sandeen) [1071179]
- [fs] btrfs: Add noinode_cache mount option (Eric Sandeen) [1071179]
- [fs] btrfs: fix to search previous metadata extent item since skinny metadata (Eric Sandeen) [1071179]
- [fs] btrfs: fix missing skinny metadata check in scrub_stripe() (Eric Sandeen) [1071179]
- [fs] btrfs: fix send to not send non-aligned clone operations (Eric Sandeen) [1071179]
- [fs] btrfs: fix btrfs boot when compiled as built-in (Eric Sandeen) [1071179]
- [fs] btrfs: unlock inodes in correct order in clone ioctl (Eric Sandeen) [1071179]
- [fs] btrfs: optimize to remove unnecessary removal with ulist reallocation (Eric Sandeen) [1071179]
- [fs] btrfs: release subvolume's block_rsv before transaction commit (Eric Sandeen) [1071179]
- [fs] btrfs: only process as many file extents as there are refs (Eric Sandeen) [1071179]
- [fs] btrfs: fix qgroup rescan to work with skinny metadata (Eric Sandeen) [1071179]
- [fs] btrfs: fix extent_from_logical to deal with skinny metadata (Eric Sandeen) [1071179]
- [fs] btrfs: throttle delayed refs better (Eric Sandeen) [1071179]
- [fs] btrfs: attach delayed ref updates to delayed ref heads (Eric Sandeen) [1071179]
- [fs] btrfs: make fsync latency less sucky (Eric Sandeen) [1071179]
- [fs] btrfs: add support for inode properties (Eric Sandeen) [1071179]
- [fs] btrfs: faster file extent item replace operations (Eric Sandeen) [1071179]
- [fs] btrfs: handle EAGAIN case properly in btrfs_drop_snapshot() (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary transaction commit before send (Eric Sandeen) [1071179]
- [fs] btrfs: fix protection between send and root deletion (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong send_in_progress accounting (Eric Sandeen) [1071179]
- [fs] btrfs: Add treelog mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add datasum mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add datacow mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add acl mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add noflushoncommit mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add noenospc_debug mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add nodiscard mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add noautodefrag mount option (Eric Sandeen) [1071179]
- [fs] btrfs: Add "barrier" option to support "-o remount, barrier" (Eric Sandeen) [1071179]
- [fs] btrfs: only fua the first superblock when writting supers (Eric Sandeen) [1071179]
- [fs] btrfs: return free space to global_rsv as much as possible (Eric Sandeen) [1071179]
- [fs] btrfs: fix an oops when we fail to relocate tree blocks (Eric Sandeen) [1071179]
- [fs] btrfs: fix an oops when we fail to merge reloc roots (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused argument from select_reloc_root() (Eric Sandeen) [1071179]
- [fs] btrfs: reduce btree node locking duration on item update (Eric Sandeen) [1071179]
- [fs] btrfs: Integer overflow in btrfs_ioctl_resize() (Eric Sandeen) [1071179]
- [fs] btrfs: stop caching thread if extent_commit_sem is contended (Eric Sandeen) [1071179]
- [fs] rwsem: add rwsem_is_contended (Eric Sandeen) [1071179]
- [fs] btrfs: introduce the delayed inode ref deletion for the single link inode (Eric Sandeen) [1071179]
- [fs] btrfs: use flags instead of the bool variants in delayed node (Eric Sandeen) [1071179]
- [fs] btrfs: remove btrfs_end_transaction_dmeta() (Eric Sandeen) [1071179]
- [fs] btrfs: cleanup code of btrfs_balance_delayed_items() (Eric Sandeen) [1071179]
- [fs] btrfs: don't run delayed nodes again after all nodes flush (Eric Sandeen) [1071179]
- [fs] btrfs: remove residual code in delayed inode async helper (Eric Sandeen) [1071179]
- [fs] btrfs: convert printk to btrfs_ and fix BTRFS prefix (Eric Sandeen) [1071179]
- [fs] btrfs: fix tree mod logging (Eric Sandeen) [1071179]
- [fs] btrfs: check balance of send_in_progress (Eric Sandeen) [1071179]
- [fs] btrfs: remove transaction from btrfs send (Eric Sandeen) [1071179]
- [fs] btrfs: fix double initialization of the raid kobject (Eric Sandeen) [1071179]
- [fs] btrfs: fix a warning when iput a file (Eric Sandeen) [1071179]
- [fs] btrfs: Check read-only status of roots during send (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused mnt from send_ctx (Eric Sandeen) [1071179]
- [fs] btrfs: send: clean up dead code (Eric Sandeen) [1071179]
- [fs] btrfs: fix deadlock when iterating inode refs and running delayed inodes (Eric Sandeen) [1071179]
- [fs] btrfs: remove dead comments for read_csums() (Eric Sandeen) [1071179]
- [fs] btrfs: remove field tree_mod_seq_elem from btrfs_fs_info struct (Eric Sandeen) [1071179]
- [fs] btrfs: fix use of uninitialized err variable (Eric Sandeen) [1071179]
- [fs] btrfs: remove unnecessary filemap writting and waiting after block group relocation (Eric Sandeen) [1071179]
- [fs] btrfs: fix error check of btrfs_lookup_dentry() (Eric Sandeen) [1071179]
- [fs] btrfs: return immediately if tree log mod is not necessary (Eric Sandeen) [1071179]
- [fs] btrfs: move the extent buffer radix tree into the fs_info (Eric Sandeen) [1071179]
- [fs] btrfs: use a bit to track if we're in the radix tree (Eric Sandeen) [1071179]
- [fs] btrfs: deal with io_tree->mapping being NULL (Eric Sandeen) [1071179]
- [fs] btrfs: more efficient push_leaf_right (Eric Sandeen) [1071179]
- [fs] btrfs: wrap repeated code into scrub_blocked_if_needed() (Eric Sandeen) [1071179]
- [fs] btrfs: fix wrong super generation mismatch when scrubbing supers (Eric Sandeen) [1071179]
- [fs] btrfs: fix pass of transid with wrong endianness in send.c (Eric Sandeen) [1071179]
- [fs] btrfs: fix extent_map block_len after merging (Eric Sandeen) [1071179]
- [fs] btrfs: remove dead code (Eric Sandeen) [1071179]
- [fs] btrfs: fix max dir item size calculation (Eric Sandeen) [1071179]
- [fs] btrfs: more efficient extent state insertions (Eric Sandeen) [1071179]
- [fs] btrfs: add missing extent state caching calls (Eric Sandeen) [1071179]
- [fs] btrfs: faster and more efficient extent map insertion (Eric Sandeen) [1071179]
- [fs] btrfs: fix extent boundary check in bio_readpage_error (Eric Sandeen) [1071179]
- [fs] btrfs: try harder to avoid btree node splits (Eric Sandeen) [1071179]
- [fs] btrfs: avoid unnecessary ordered extent cache resets (Eric Sandeen) [1071179]
- [fs] btrfs: fix leaks during sysfs teardown (Eric Sandeen) [1071179]
- [fs] btrfs: fix static checker warnings (Eric Sandeen) [1071179]
- [fs] btrfs: fix very slow inode eviction and fs unmount (Eric Sandeen) [1071179]
- [fs] btrfs: improve forever loop when doing balance relocation (Eric Sandeen) [1071179]
- [fs] btrfs: fix ordered extent check in btrfs_punch_hole (Eric Sandeen) [1071179]
- [fs] btrfs: replace BUG in can_modify_feature (Eric Sandeen) [1071179]
- [fs] btrfs: reserve no transaction units in btrfs_feature_attr_store (Eric Sandeen) [1071179]
- [fs] btrfs: make btrfs_debug match pr_debug handling related to DEBUG (Eric Sandeen) [1071179]
- [fs] btrfs: cleanup: removed unused 'btrfs_get_inode_ref_index' (Eric Sandeen) [1071179]
- [fs] btrfs: expand btrfs_find_item() to include find_orphan_item functionality (Eric Sandeen) [1071179]
- [fs] btrfs: expand btrfs_find_item() to include find_root_ref functionality (Eric Sandeen) [1071179]
- [fs] btrfs: bootstrap generic btrfs_find_item interface (Eric Sandeen) [1071179]
- [fs] btrfs: fix unused variables in qgroup.c (Eric Sandeen) [1071179]
- [fs] btrfs: replace path->slots[0] with otherwise unused variable 'slot' (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variable from scrub_fixup_nodatasum (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variable from setup_cluster_no_bitmap (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variables from extent_io.c (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variable from find_free_extent (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variables from disk-io.c (Eric Sandeen) [1071179]
- [fs] btrfs: remove unused variable from btrfs_new_inode (Eric Sandeen) [1071179]
- [fs] btrfs: publish fs label in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: publish device membership in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: publish allocation data in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: add ioctl to export size of global metadata reservation (Eric Sandeen) [1071179]
- [fs] btrfs: use feature attribute names to print better error messages (Eric Sandeen) [1071179]
- [fs] btrfs: add ability to change features via sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: publish unknown feature bits in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: publish per-super features in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: publish per-super attributes in sysfs (Eric Sandeen) [1071179]
- [fs] kobject: export kobj_sysfs_ops (Eric Sandeen) [1071179]
- [fs] btrfs: publish supported featured in sysfs (Eric Sandeen) [1071179]
- [fs] btrfs: add ioctls to query/change feature bits online (Eric Sandeen) [1071179]
- [fs] btrfs: skip merge part for delayed data refs (Eric Sandeen) [1071179]
- [fs] btrfs: introduce a head ref rbtree (Eric Sandeen) [1071179]
- [fs] btrfs: fix check-integrity to look at the referenced data properly (Eric Sandeen) [1071179]
- [fs] btrfs: incompatible format change to remove hole extents (Eric Sandeen) [1071179]
- [fs] btrfs: sanitize BTRFS_IOC_FILE_EXTENT_SAME (Eric Sandeen) [1071179]
- [fs] btrfs: fix comments and printk msgs (Eric Sandeen) [1071179]
- [fs] btrfs: Fix typos in printk (Eric Sandeen) [1071179]

* Tue Aug 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-144.el7]
- [net] ipv6: Fix MLD Query message check (Jiri Pirko) [1114650]
- [net] sctp: inherit auth_capable on INIT collisions (Daniel Borkmann) [1123763] {CVE-2014-5077}
- [net] ipv6: ipv6_find_hdr restore prev functionality (Jesper Brouer) [1074516]
- [net] ipvs: fix AF assignment in ip_vs_conn_new() (Jesper Brouer) [1074516]
- [virt] kvm: always exit on EOIs for interrupts listed in the IOAPIC redir table (Alex Williamson) [1126997]
- [iommu] amd: Fix interrupt remapping for aliased devices (Alex Williamson) [1090139]
- [pci] Add Patsburg (X79) to Intel PCH root port ACS quirk (Alex Williamson) [1081428]
- [kernel] time/alarmtimer: Fix bug where relative alarm timers were treated as absolute (Prarit Bhargava) [1124941]
- [acpi] processor: Fix STARTING/DYING action in acpi_cpu_soft_notify() (Prarit Bhargava) [1099594]
- [x86] mce_intel: Add raw_lock conversion again (Prarit Bhargava) [1127257]
- [sound] alsa/control: Don't access controls outside of protected regions (Radomir Vrbovsky) [1117331] {CVE-2014-4653}
- [kernel] tick: Clear broadcast pending bit when switching to oneshot (Alex Williamson) [1109996]
- [x86] efi: Do not export efi runtime map in case old map (Dave Young) [1080109]
- [x86] efi: Quirk out SGI UV (Dave Young) [1080109]
- [x86] efi: Split efi_enter_virtual_mode (Dave Young) [1080109]
- [x86] efi: Make efi virtual runtime map passing more robust (Dave Young) [1080109]
- [x86] mm/pageattr: Export page unmapping interface (Dave Young) [1080109]
- [x86] efi: Dump the EFI page table (Dave Young) [1080109]
- [x86] mm/ptdump: Add the functionality to dump an arbitrary pagetable (Dave Young) [1080109]
- [x86] efi: Style neatening (Dave Young) [1080109]
- [x86] efi: parse_efi_setup() build fix (Dave Young) [1080109]
- [x86] ksysfs.c build fix (Dave Young) [1080109]
- [x86] efi: Delete superfluous global variables (Dave Young) [1080109]
- [x86] setup: Reserve setup_data ranges late after parsing memmap cmdline (Dave Young) [1080109]
- [x86] Export x86 boot_params to sysfs (Dave Young) [1080109]
- [x86] boot: Add xloadflags bit for EFI runtime support on kexec (Dave Young) [1080109]
- [firmware] efi: Pass necessary EFI data for kexec via setup_data (Dave Young) [1080109]
- [firmware] efi: Export EFI runtime memory mapping to sysfs (Dave Young) [1080109]
- [firmware] efi: Export more EFI table variables to sysfs (Dave Young) [1080109]
- [firmware] efi: Cleanup efi_enter_virtual_mode() function (Dave Young) [1080109]
- [firmware] efi: Fix off-by-one bug in EFI Boot Services reservation (Dave Young) [1080109]
- [firmware] efi: Add a wrapper function efi_map_region_fixed() (Dave Young) [1080109]
- [firmware] efi: Remove unused variables in __map_region() (Dave Young) [1080109]
- [firmware] efi: Check krealloc return value (Dave Young) [1080109]
- [firmware] efi: Runtime services virtual mapping (Dave Young) [1080109]
- [x86] mm/pageattr: Map in an arbitrary pgd (Dave Young) [1080109]
- [x86] mm/pageattr: Add last levels of error path (Dave Young) [1080109]
- [x86] mm/pageattr: Add a PUD error unwinding path (Dave Young) [1080109]
- [x86] mm/pageattr: Add a PTE pagetable populating function (Dave Young) [1080109]
- [x86] mm/pageattr: Add a PMD pagetable populating function (Dave Young) [1080109]
- [x86] mm/pageattr: Add a PUD pagetable populating function (Dave Young) [1080109]
- [x86] mm/pageattr: Add a PGD pagetable populating function (Dave Young) [1080109]
- [x86] mm/pageattr: Lookup address in an arbitrary PGD (Dave Young) [1080109]
- [firmware] efi: Convert runtime services function ptrs (Dave Young) [1080109]
- [firmware] efi: Simplify EFI_DEBUG (Dave Young) [1080109]
- [firmware] efi: Fix config_table_type array termination (Dave Young) [1080109]
- [firmware] efi: make efi_lookup_mapped_addr() a common function (Dave Young) [1080109]
- [firmware] efi: provide a generic efi_config_init() (Dave Young) [1080109]
- [iommu] vt-d: Use list_for_each_entry_safe() for dmar_domain->devices traversa (Myron Stowe) [1127467]
- [iommu] vt-d: Use for_each_drhd_unit() instead of list_for_each_entry() (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call io_page_fault trace event (Myron Stowe) [1127467]
- [iommu] Add iommu_error class event to iommu trace (Myron Stowe) [1127467]
- [iommu] No need to pass '0x' when 'pa' is used (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call unmap trace event (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call map trace event (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call detach_device_to_domain trace event (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call attach_device_to_domain trace event (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call remove_device_to_group trace event (Myron Stowe) [1127467]
- [iommu] Change iommu driver to call add_device_to_group trace event (Myron Stowe) [1127467]
- [iommu] Add event tracing feature to iommu (Myron Stowe) [1127467]
- [iommu] intel: correct ICS register offset (Myron Stowe) [1127467]
- [Documentation] MAINTAINERS: add overall IOMMU section (Myron Stowe) [1127467]
- [iommu] amd: Fix resource leak in iommu_init_device() (Myron Stowe) [1127467]
- [iommu] amd: Clean up unnecessary MSI/MSI-X capability find (Myron Stowe) [1127467]
- [powerpc] Add iommu domain pointer to device archdata (Myron Stowe) [1127467]
- [iommu] vt-d: DMAR reporting table needs at least one DRHD (Myron Stowe) [1127467]
- [iommu] vt-d: Downgrade the warning if enabling irq remapping fails (Myron Stowe) [1127467]
- [net] l2tp: don't fall back on UDP [get|set]sockopt (Petr  Matousek) [1119466] {CVE-2014-4943}
- [x86] ptrace: force IRET path after a ptrace_stop() (Oleg Nesterov) [1115935] {CVE-2014-4699}
- [s390] ptrace: correct insufficient sanitization when setting psw mask (Hendrik Brueckner) [1113673] {CVE-2014-3534}

* Wed Aug 06 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-143.el7]
- [virt] kvm/async_pf: kill the unnecessary use_mm/unuse_mm async_pf_execute() (Paolo Bonzini) [1116936]
- [virt] kvm/async_pf: change async_pf_execute() to use get_user_pages(tsk => NULL) (Paolo Bonzini) [1116936]
- [virt] kvm: support any-length wildcard ioeventfd (Paolo Bonzini) [1116936]
- [virt] kvm: return an error code in kvm_vm_ioctl_register_coalesced_mmio() (Paolo Bonzini) [1116936]
- [virt] kvm/x86: preserve the high 32-bits of the PAT register (Paolo Bonzini) [1116936]
- [virt] kvm: fix wrong address when writing Hyper-V tsc page (Paolo Bonzini) [1116936]
- [kernel] sched: Fix signedness bug in yield_to() (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Check for nested events if there is an injectable interrupt (Paolo Bonzini) [1116936]
- [virt] kvm/svm: Fix CPL export via SS.DPL (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: disable APIC virtualization in nested guests (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Check for host supported fields in shadow vmcs (Paolo Bonzini) [1116936]
- [virt] kvm/x86: MOV CR/DR emulation should ignore mod (Paolo Bonzini) [1116936]
- [virt] kvm/lapic: sync highest ISR to hardware apic on EOI (Paolo Bonzini) [1116936]
- [virt] kvm/x86: get CPL from SS.DPL (Paolo Bonzini) [1078775 1088784 1116936]
- [virt] kvm/x86: check CS.DPL against RPL during task switch (Paolo Bonzini) [1078775 1088784 1116936]
- [virt] kvm/x86: drop set_rflags callback (Paolo Bonzini) [1078775 1088784 1116936]
- [virt] kvm/x86: use new CS.RPL as CPL during task switch (Paolo Bonzini) [1078775 1088784 1116936]
- [virt] kvm/x86: fix page fault tracing when KVM guest support enabled (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: DR7 masking on task switch emulation is wrong (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix CR3 reserved bits check in long mode (Paolo Bonzini) [1116936]
- [virt] kvm/x86: emulate monitor and mwait instructions as nop (Paolo Bonzini) [1116936]
- [virt] kvm/x86: implement hv EOI assist (Paolo Bonzini) [1086663 1116936]
- [virt] kvm/x86: Mark bit 7 in long-mode PDPTE according to 1GB pages support (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: handle_dr does not handle RSP correctly (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: move vmclear and vmptrld pre-checks to nested_vmx_check_vmptr (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: fail on invalid vmclear/vmptrld pointer (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: additional checks on vmxon region (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: rearrange get_vmx_mem_address (Paolo Bonzini) [1116936]
- [virt] kvm/x86: improve the usability of the 'kvm_pio' tracepoint (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Processor mode may be determined incorrectly (Paolo Bonzini) [1116936]
- [virt] kvm/x86: IN instruction emulation should ignore REP-prefix (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix CR3 reserved bits (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix wrong/stuck PMU when guest does not use PMI (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Advertise support for interrupt acknowledgement (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Ack and write vector info to intr_info if L1 asks us to (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Don't advertise single context invalidation for invept (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Advance rip to after an ICEBP instruction (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix CR3 and LDT sel should not be saved in TSS (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: speed up wildcard MMIO EVENTFD (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix page-tables reserved bits (Paolo Bonzini) [1116936]
- [virt] kvm/x86: remove WARN_ON from get_kernel_ns() (Paolo Bonzini) [1116936]
- [virt] kvm: Rename variable smep to cr4_smep (Paolo Bonzini) [1084616 1116936]
- [virt] kvm: expose SMAP feature to guest (Paolo Bonzini) [1084616 1116936]
- [virt] kvm: Disable SMAP for guests in EPT realmode and EPT unpaging mode (Paolo Bonzini) [1074747 1084616 1116936]
- [virt] kvm: Add SMAP support when setting CR4 (Paolo Bonzini) [1084616 1116936]
- [virt] kvm: Remove SMAP bit from CR4_RESERVED_BITS (Paolo Bonzini) [1084616 1116936]
- [x86] processor-flags: Fix the datatypes and add bit number defines (Paolo Bonzini) [1116936]
- [kernel] const: Add _BITUL() and _BITULL() (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: fix MPX detection (Paolo Bonzini) [1116936]
- [virt] kvm/x86: handle missing MPX in nested virtualization (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Add nested virtualization support for MPX (Paolo Bonzini) [1116936]
- [virt] kvm/svm: Allow the guest to run with dirty debug registers (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/svm: set/clear all DR intercepts in one swoop (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/nvmx: Allow nested guests to run with dirty debug registers (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/vmx: Allow the guest to run with dirty debug registers (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/x86: Allow the guest to run with dirty debug registers (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/x86: change vcpu->arch.switch_db_regs to a bit mask (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/vmx: we do rely on loading DR7 on entry (Paolo Bonzini) [1068627 1116936]
- [virt] kvm/x86: Remove return code from enable_irq/nmi_window (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Do not inject NMI vmexits when L2 has a pending interrupt (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Fully emulate preemption timer (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Rework interception of IRQs and NMIs (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Break kvm_for_each_vcpu loop after finding the VP_INDEX (Paolo Bonzini) [1116936]
- [x86] cpufeature: Rename X86_FEATURE_CLFLSH to X86_FEATURE_CLFLUSH (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: drop read-only large sptes when creating lower level sptes (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Enable Intel MPX for guest (Paolo Bonzini) [1076194 1116936]
- [virt] kvm/x86: add MSR_IA32_BNDCFGS to msrs_to_save (Paolo Bonzini) [1076194 1116936]
- [virt] kvm/x86: Intel MPX vmx and msr handle (Paolo Bonzini) [1076194 1116936]
- [virt] kvm/x86: introduce kvm_supported_xcr0() (Paolo Bonzini) [1076194 1116936]
- [virt] kvm: kABI fixup for MPX patches (Paolo Bonzini) [1116936]
- [x86] xsave: Support eager-only xsave features, add MPX support (Paolo Bonzini) [1076194 1116936]
- [x86] cpufeature: Define the Intel MPX feature flag (Paolo Bonzini) [1076194 1116936]
- [virt] kvm/x86: Fix xsave cpuid exposing bug (Paolo Bonzini) [1076194 1116936]
- [virt] kvm/x86: expose ADX feature to guest (Paolo Bonzini) [1084614 1116936]
- [virt] kvm/x86: expose new instruction RDSEED to guest (Paolo Bonzini) [1084614 1116936]
- [virt] kvm: remove redundant registration of BSP's hv_clock area (Paolo Bonzini) [1116936]
- [virt] kvm/x86: remove unused last_kernel_ns variable (Paolo Bonzini) [1116936]
- [virt] kvm/x86: correctly access the KVM_CPUID_FEATURES leaf at 0x40000101 (Paolo Bonzini) [1116936]
- [virt] kvm/x86: cache the base of the KVM cpuid leaves (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Validate guest writes to MSR_IA32_APICBASE (Paolo Bonzini) [1110125 1116936]
- [virt] kvm/x86: mark hyper-v vapic assist page as dirty (Paolo Bonzini) [1116936]
- [virt] kvm/x86: mark hyper-v hypercall page as dirty (Paolo Bonzini) [1116936]
- [virt] kvm: make KVM_MMU_AUDIT help text more readable (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Update guest activity state field on L2 exits (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Fix nested_run_pending on activity state HLT (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Clean up handling of VMX-related MSRs (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Add tracepoints for nested_vmexit and nested_vmexit_inject (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Pass vmexit parameters to nested_vmx_vmexit (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Leave VMX mode on clearing of feature control MSR (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Fix DR6 update on #DB exception (Paolo Bonzini) [1079841 1116936]
- [virt] kvm/svm: Fix reading of DR6 (Paolo Bonzini) [1079841 1116936]
- [virt] kvm/x86: Sync DR7 on KVM_SET_DEBUGREGS (Paolo Bonzini) [1079841 1116936]
- [virt] kvm: remove useless write to vcpu->hv_clock.tsc_timestamp (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Fix debug typo error in lapic (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: check use I/O bitmap first before unconditional I/O exit (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Unconditionally uninit the MMU on nested vmexit (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Do not skip the instruction if handle_dr injects a fault (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Support direct APIC access from L2 (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Add comment on vcpu_enter_guest()'s return value (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Add support for activity state HLT (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: shadow VM_(ENTRY (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: delay mmu audit activation (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Really fix lazy FPU on nested guest (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Fix lazy FPU on nested guest (Paolo Bonzini) [1116936]
- [virt] kvm/cpuid: Fix sparse warning (Paolo Bonzini) [1116936]
- [virt] kvm: Delete prototype for non-existent function kvm_check_iopl (Paolo Bonzini) [1116936]
- [virt] kvm: Delete prototype for non-existent function complete_pio (Paolo Bonzini) [1116936]
- [virt] kvm/x86: trace cpuid emulation when called from emulator (Paolo Bonzini) [1116936]
- [virt] kvm/emulator: cleanup decode_register_operand() a bit (Paolo Bonzini) [1116936]
- [virt] kvm/emulator: check rex prefix inside decode_register() (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: error message typo fix (Paolo Bonzini) [1116936]
- [virt] kvm: Emulate MOVBE (Paolo Bonzini) [1116936]
- [virt] kvm/emulator: Add initial three-byte insns support (Paolo Bonzini) [1116936]
- [virt] kvm/emulator: Rename VendorSpecific flag (Paolo Bonzini) [1116936]
- [virt] kvm/emulator: Use opcode length (Paolo Bonzini) [1116936]
- [virt] kvm: Add KVM_GET_EMULATED_CPUID (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Report CPU_BASED_VIRTUAL_NMI_PENDING as supported (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Report 2MB EPT pages as supported (Paolo Bonzini) [1116936]
- [virt] kvm: Move gfn_to_index to x86 specific code (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Fully support nested VMX preemption timer (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: change useless int return types to void (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: unify destroy_kvm_mmu with kvm_mmu_unload (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: remove uninteresting MMU "new_cr3" callbacks (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: remove uninteresting MMU "free" callbacks (Paolo Bonzini) [1116936]
- [virt] kvm: Convert kvm_lock back to non-raw spinlock (Paolo Bonzini) [1116936]
- [virt] kvm: protect kvm_usage_count with its own spinlock (Paolo Bonzini) [1116936]
- [virt] kvm: cleanup (physical) CPU hotplug (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Do not generate #DF if #PF happens during exception delivery into L2 (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Check all exceptions for intercept during delivery to L2 (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Do not put exception that caused vmexit to IDT_VECTORING_INFO (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Amend nested_run_pending logic (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Enable unrestricted guest mode support (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Implement support for EFER saving on VM-exit (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Do not set identity page map for L2 (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Replace kvm_set_cr0 with vmx_set_cr0 in load_vmcs12_host_state (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: fix shadow on EPT (Paolo Bonzini) [1116936]
- [virt] kvm/nept: reset PDPTR register cache on nested vmentry emulation (Paolo Bonzini) [1116936]
- [virt] kvm: Fix NULL dereference in gfn_to_hva_prot() (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: allow page tables to be in read-only slots (Paolo Bonzini) [1116936]
- [virt] kvm/x86: emulate RETF imm (Paolo Bonzini) [1116936]
- [virt] kvm/mmu: remove unused parameter (Paolo Bonzini) [1116936]
- [virt] kvm/x86: add comments where MMIO does not return to the emulator (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: count exits to userspace during invalid guest emulation (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Advertise IA32_PAT in VM exit control (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Fix up VM_ENTRY_IA32E_MODE control feature reporting (Paolo Bonzini) [1116936]
- [virt] kvm/nept: Advertise WB type EPTP (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nvmx: Keep arch.pat in sync on L1-L2 switches (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Miscelleneous cleanups (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Some additional comments (Paolo Bonzini) [1048496 1116936]
- [virt] kvm: Advertise the support of EPT to the L1 guest, through the appropriate MSR (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Nested INVEPT (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: MMU context for nested EPT (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Add nept violation/misconfigration support (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: correctly check if remote tlb flush is needed for shadowed EPT tables (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Redefine EPT-specific link_shadow_page() (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Add EPT tables support to paging_tmpl.h (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Support shadow paging for guest paging without A/D bits (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: make guest's A/D bits depends on guest's paging mode (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Move common code to paging_tmpl.h (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Fix wrong test in kvm_set_cr3 (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Fix cr3 handling in nested exit and entry (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/nept: Support LOAD_IA32_EFER entry/exit controls for L1 (Paolo Bonzini) [1048496 1116936]
- [virt] kvm/mmu: fix check the reserved bits on the gpte of L2 (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: correctly set tr base on nested vmexit emulation (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: reset rflags register cache during nested vmentry (Paolo Bonzini) [1116936]
- [virt] kvm/x86: handle singlestep during emulation (Paolo Bonzini) [1116936]
- [virt] kvm/x86: handle hardware breakpoints during emulation (Paolo Bonzini) [1116936]
- [virt] kvm/x86: rename EMULATE_DO_MMIO (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Drop some unused functions from lapic (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Simplify __apic_accept_irq (Paolo Bonzini) [1116936]
- [virt] kvm/perf: Support the in_tx/in_tx_cp modifiers in KVM arch perfmon emulation v5 (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Set segment infomation of L1 when L2 exits (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Fix read/write to MSR_IA32_FEATURE_CONTROL (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Drop useless cast (Paolo Bonzini) [1116936]
- [virt] kvm/vmx: Use proper types to access const arrays (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Set success rflags when emulate VMXON/VMXOFF in nested virt (Paolo Bonzini) [1116936]
- [virt] kvm/nvmx: Change location of 3 functions in vmx.c (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Avoid zapping mmio sptes twice for generation wraparound (Paolo Bonzini) [1116936]
- [virt] kvm: add missing cleanup_srcu_struct (Paolo Bonzini) [1116936]
- [virt] kvm/irqchip: Speed up KVM_SET_GSI_ROUTING (Paolo Bonzini) [1116936]
- [virt] kvm/async_pf: mm->mm_users can not pin apf->mm (Paolo Bonzini) [1116936]
- [virt] kvm: Specify byte order for KVM_EXIT_MMIO (Paolo Bonzini) [1116936]
- [virt] kvm/eventfd: Fix lock order inversion (Paolo Bonzini) [1116936]
- [virt] kvm: add kvm_arch_vcpu_runnable() test to kvm_vcpu_on_spin() loop (Paolo Bonzini) [1116936]
- [virt] kvm/asmlinkage: Make kvm_rebooting visible (Paolo Bonzini) [1116936]
- [virt] kvm: Provide kvm_vcpu_eligible_for_directed_yield() stub (Paolo Bonzini) [1116936]
- [virt] kvm/vfio: silence GCC warning (Paolo Bonzini) [1116936]
- [virt] kvm: remove dead code (Paolo Bonzini) [1116936]
- [virt] kvm: make local functions static (Paolo Bonzini) [1116936]
- [virt] kvm/doc: Fix typo in doc/virtual/kvm (Paolo Bonzini) [1116936]
- [virt] kvm: Use cond_resched() directly and remove useless kvm_resched() (Paolo Bonzini) [1116936]
- [virt] kvm: kvm_clear_guest_page(), fix empty_zero_page usage (Paolo Bonzini) [1116936]
- [virt] kvm: remove vm mmap method (Paolo Bonzini) [1116936]
- [virt] kvm/iommu: hva align mapping page size (Paolo Bonzini) [1116936]
- [virt] kvm_host: typo fix (Paolo Bonzini) [1116936]
- [Documentation] kvm: add a 00-INDEX file (Paolo Bonzini) [1116936]
- [virt] kvm: use a more sensible error number when debugfs directory creation fails (Paolo Bonzini) [1116936]
- [virt] kvm: Fix modprobe failure for kvm_intel/kvm_amd (Paolo Bonzini) [1116936]
- [virt] kvm: Enable pvspinlock after jump_label_init() to avoid VM hang (Paolo Bonzini) [1116936]
- [virt] kvm: Drop FOLL_GET in GUP when doing async page fault (Paolo Bonzini) [1116936]
- [virt] kvm/iommu: Add leading zeros to device's BDF notation in debug messages (Paolo Bonzini) [1116936]
- [Documentation] kvm: Update cpuid documentation for steal time and pv eoi (Paolo Bonzini) [1116936]
- [virt] kvm: remove .done from struct kvm_async_pf (Paolo Bonzini) [1116936]
- [virt] kvm: Add documentation for kvm->srcu lock (Paolo Bonzini) [1116936]
- [virt] kvm: free resources after canceling async_pf (Paolo Bonzini) [1116936]
- [virt] kvm/eventfd: switch to fdget (Paolo Bonzini) [1116936]
- [virt] kvm: Introduce kvm_arch_memslots_updated() (Paolo Bonzini) [1116936]
- [virt] kvm/x86: Rename X86_CR4_RDWRGSFS to X86_CR4_FSGSBASE (Paolo Bonzini) [1116936]
- [virt] kvm: rename __kvm_io_bus_sort_cmp to kvm_io_bus_cmp (Paolo Bonzini) [1116936]
- [virt] kvm: optimize away THP checks in kvm_is_mmio_pfn() (Paolo Bonzini) [1116936]
- [virt] kvm: use anon_inode_getfd() with O_CLOEXEC flag (Paolo Bonzini) [1116936]
- [virt] kvm: introduce __kvm_io_bus_sort_cmp (Paolo Bonzini) [1116936]
- [Documentation] virtual/kvm/api.txt fix a typo (Paolo Bonzini) [1116936]
- [virt] kvm/ppc: reserve a capability number for multitce support (Paolo Bonzini) [1116936]
- [virt] virtio_ring: change host notification API (Paolo Bonzini) [1116936]
- [x86] quirks: Mark Cave Creek chipset device id as supported (Steve Best) [1087659]
- [mm] memcg, vmscan: Fix forced scan of anonymous pages (Jerome Marchand) [1125240]
- [drm] qxl: return IRQ_NONE if it was not our irq (Jason Wang) [1095099]
- [kernel] sched/autogroup: Fix race with task_groups list (Gustavo Duarte) [1081406]
- [lib] percpu_counter: unbreak __percpu_counter_add() (Eric Sandeen) [1123968]
- [lib] percpu_counter: fix __percpu_counter_add() (Eric Sandeen) [1123968]

* Fri Aug 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-142.el7]
- [x86] Revert: Insert GART region into resource map (Myron Stowe) [1110895]
- [pci] Don't check resource_size() in pci_bus_alloc_resource() (Myron Stowe) [1110895]
- [pci] Enable INTx in pci_reenable_device() only when MSI/MSI-X not enabled (Myron Stowe) [1110895]
- [ahci] Fix broken fallback to single MSI mode (Myron Stowe) [1110895]
- [pci] Enable INTx if BIOS left them disabled (Myron Stowe) [1110895]
- [pci] msi: Add pci_enable_msi_exact() and pci_enable_msix_exact() (Myron Stowe) [1110895]
- [pci] msi: Fix cut-and-paste errors in documentation (Myron Stowe) [1110895]
- [pci] msi: Add pci_enable_msi() documentation back (Myron Stowe) [1110895]
- [pci] msi: Fix pci_msix_vec_count() htmldocs failure (Myron Stowe) [1110895]
- [pci] msi: Fix leak of msi_attrs (Myron Stowe) [1110895]
- [pci] msi: Check kmalloc() return value, fix leak of name (Myron Stowe) [1110895]
- [eisa] Revert: Initialize device before its resources (Myron Stowe) [1110895]
- [eisa] Revert: Log device resources in dmesg (Myron Stowe) [1110895]
- [pci] Check parent kobject in pci_destroy_dev() (Myron Stowe) [1110895]
- [powerpc] eeh: Use global PCI rescan-remove locking (Myron Stowe) [1110895]
- [pci] Fix pci_check_and_unmask_intx() comment typos (Myron Stowe) [1110895]
- [scsi] mpt: Use pci_stop_and_remove_bus_device_locked() (Myron Stowe) [1110895]
- [platform] x86: Use global PCI rescan-remove locking (Myron Stowe) [1110895]
- [pci] hotplug: Use global PCI rescan-remove locking (Myron Stowe) [1110895]
- [pcmcia] Use global PCI rescan-remove locking (Myron Stowe) [1110895]
- [pci] hotplug: Use global PCI rescan-remove locking (Myron Stowe) [1110895]
- [acpi] pci: Use global PCI rescan-remove locking in PCI root hotplug (Myron Stowe) [1110895]
- [pci] Add global pci_lock_rescan_remove() (Myron Stowe) [1110895]
- [pci] Cleanup pci.h whitespace (Myron Stowe) [1110895]
- [pci] Reorder so actual code comes before stubs (Myron Stowe) [1110895]
- [pci] aer: Support ACPI HEST AER error sources for PCI domains other than 0 (Myron Stowe) [1110895]
- [acpi] acpica: Add helper macros to extract bus/segment numbers from HEST table (Myron Stowe) [1110895]
- [pci] Make local functions static (Myron Stowe) [1110895]
- [pci] Remove unused alloc_pci_dev() (Myron Stowe) [1110895]
- [pci] Remove unused pci_renumber_slot() (Myron Stowe) [1110895]
- [pci] Remove unused pcie_aspm_enabled() (Myron Stowe) [1110895]
- [pci] Remove unused pci_vpd_truncate() (Myron Stowe) [1110895]
- [pci] Remove unused ID-Based Ordering support (Myron Stowe) [1110895]
- [pci] Remove unused Optimized Buffer Flush/Fill support (Myron Stowe) [1110895]
- [pci] Remove unused Latency Tolerance Reporting support (Myron Stowe) [1110895]
- [pci] Removed unused parts of Page Request Interface support (Myron Stowe) [1110895]
- [pci] Update documentation 00-INDEX file (Myron Stowe) [1110895]
- [pci] Allocate 64-bit BARs above 4G when possible (Myron Stowe) [1110895]
- [pci] Enforce bus address limits in resource allocation (Myron Stowe) [1110895]
- [pci] Split out bridge window override of minimum allocation address (Myron Stowe) [1110895]
- [agp] ati: Use PCI_COMMAND instead of hard-coded 4 (Myron Stowe) [1110895]
- [agp] intel: Use CPU physical address, not bus address, for ioremap() (Myron Stowe) [1110895]
- [agp] intel: Use pci_bus_address() to get GTTADR bus address (Myron Stowe) [1110895]
- [agp] intel: Use pci_bus_address() to get MMADR bus address (Myron Stowe) [1110895]
- [agp] intel: Support 64-bit GMADR (Myron Stowe) [1110895]
- [agp] intel: Rename gtt_bus_addr to gtt_phys_addr (Myron Stowe) [1110895]
- [drm] i915: Rename gtt_bus_addr to gtt_phys_addr (Myron Stowe) [1110895]
- [agp] Use pci_resource_start() to get CPU physical address for BAR (Myron Stowe) [1110895]
- [agp] Support 64-bit APBASE (Myron Stowe) [1110895]
- [pci] msi: Add pci_enable_msi_range() and pci_enable_msix_range() (Myron Stowe) [1110895]
- [pci] msi: Add pci_msix_vec_count() (Myron Stowe) [1110895]
- [pci] msi: Remove pci_enable_msi_block_auto() (Myron Stowe) [1110895]
- [pci] msi: Add pci_msi_vec_count() (Myron Stowe) [1110895]
- [pci] Convert ioapic to be builtin only, not modular (Myron Stowe) [1110895]
- [pci] Add pci_bus_address() to get bus address of a BAR (Myron Stowe) [1110895]
- [pci] Convert pcibios_resource_to_bus() to take a pci_bus, not a pci_dev (Myron Stowe) [1110895]
- [pci] Change pci_bus_region addresses to dma_addr_t (Myron Stowe) [1110895]
- [pci] msi: Return -ENOSYS for unimplemented interfaces, not -1 (Myron Stowe) [1110895]
- [pci] msi: Return msix_capability_init() failure if populate_msi_sysfs() fails (Myron Stowe) [1110895]
- [s390] pci: Remove superfluous check of MSI type (Myron Stowe) [1110895]
- [s390] pci: Fix single MSI only check (Myron Stowe) [1110895]
- [pci] msi: Export MSI mode using attributes, not kobjects (Myron Stowe) [1110895]
- [pci] portdrv: Remove extra get_device()/put_device() for pcie_device (Myron Stowe) [1110895]
- [pci] portdrv: Add put_device() after device_register() failure (Myron Stowe) [1110895]
- [pci] portdrv: Cleanup error paths (Myron Stowe) [1110895]
- [pci] Remove from bus_list and release resources in pci_release_dev() (Myron Stowe) [1110895]
- [pci] Move pci_proc_attach_device() to pci_bus_add_device() (Myron Stowe) [1110895]
- [pci] Use device_release_driver() in pci_stop_root_bus() (Myron Stowe) [1110895]
- [pci] aer: Consolidate HEST error source parsers (Myron Stowe) [1110895]
- [pci] aer: Ignore non-PCIe AER error sources in aer_hest_parse() (Myron Stowe) [1110895]
- [pci] aer: Clean up error printing code a bit (Myron Stowe) [1110895]
- [pci] aer: Add a TLP header print helper (Myron Stowe) [1110895]
- [eisa] Call put_device() if device_register() fails (Myron Stowe) [1110895]
- [pci] checkpatch: Deprecate DEFINE_PCI_DEVICE_TABLE (Myron Stowe) [1110895]
- [pci] Stop clearing bridge Secondary Status when setting up I/O aperture (Myron Stowe) [1110895]
- [pci] Prevent bus conflicts while checking for bridge apertures (Myron Stowe) [1110895]
- [pci] Drop "irq" param from *_restore_msi_irqs() (Myron Stowe) [1110895]
- [pci] portdrv: Remove superfluous name cast (Myron Stowe) [1110895]
- [x86] pci: Use dev_is_pci() to identify PCI devices (Myron Stowe) [1110895]
- [pci] Use dev_is_pci() to identify PCI devices (Myron Stowe) [1110895]
- [pci] Clear NumVFs when disabling SR-IOV in sriov_init() (Myron Stowe) [1110895]
- [s390] watchdog: add support for LPAR operation (diag288) (Hendrik Brueckner) [1088540]
- [s390] watchdog: use watchdog API (Hendrik Brueckner) [1088540]
- [scripts] headers_check: special case seqbuf_dump() (Prarit Bhargava) [1090078]
- [Documentation] mei-amt-version: remove unneeded call of mei_deinit() (Prarit Bhargava) [1090078]
- [drm] tegra: Include header drm/drm.h (Prarit Bhargava) [1090078]
- [mfd] lpc_ich: iTCO_wdt patch for Intel Coleto Creek DeviceIDs (Neil Horman) [1053912]
- [i2c] i801: SMBus patch for Intel Coleto Creek DeviceIDs (Neil Horman) [1053912]
- [x86] efi: earlyprintk-efi, keep fix (Rui Wang) [1085558]
- [x86] efi: Fix earlyprintk off-by-one bug (Rui Wang) [1085558]
- [x86] efi: Add EFI framebuffer earlyprintk support (Rui Wang) [1085558]
- [s390] zcrypt: remove zcrypt kmsg documentation again (Hendrik Brueckner) [1088511]
- [s390] zcrypt: add support for EP11 coprocessor cards (Hendrik Brueckner) [1088511]
- [s390] sclp_vt220: Enable ASCII console per default (Hendrik Brueckner) [1112739]
- [block] blkcg: fix use-after-free in __blkg_release_rcu() by making blkcg_gq refcnt an atomic_t (Vivek Goyal) [1118436]
- [ethernet] bnx2x: fix crash during TSO tunneling (Michal Schmidt) [1119133]
- [ethernet] cxgb4: allow large buffer size to have page size (Gustavo Duarte) [1078977]
- [fs] vfs: Don't copy mount bind mounts of /proc/<pid>/ns/mnt between namespaces (Aristeu Rozanski) [1098632]
- [cpufreq] intel_pstate: Add CPU IDs for Broadwell processors (Steve Best) [1086874]
- [pci] pciehp: Clear Data Link Layer State Changed during init (Myron Stowe) [1101097]
- [acpi] Fix bug when ACPI reset register is implemented in system memory (Nigel Croxon) [1109971]
- [ipc] shm: increase the defaults for SHMALL, SHMMAX (Larry Woodman) [1101821]
- [tools] power/turbostat: Run on Broadwell (Steve Best) [1086455]
- [drm] i915: make i915 less chatty on resume (Rob Clark) [1086777]
- [tools] cpupower: add option to display values without round offs (Prarit Bhargava) [1090540]
- [scripts] kbuild: fix make headers_install when path is too long (Frank Ramsay) [1099575]
- [kernel] audit: fix AUDIT_FEATURE_CHANGE record number (Richard Guy Briggs) [1085928]
- [usb] xhci: Link TRB must not occur within a USB payload burst (Don Zickus) [1049077]
- [virt] xen-netfront: fix resource leak in netfront (Vitaly Kuznetsov) [1070868]
- [virt] xen-blkfront: handle backend CLOSED without CLOSING (Vitaly Kuznetsov) [1070868]

* Fri Aug 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-141.el7]
- [misc] no animals were harmed in the making of this kernel (Jarod Wilson)

* Fri Jul 25 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-140.el7]
- [net] ipv6: addrconf: implement address generation modes (Jiri Pirko) [1107369]
- [net] gre: add link local route when local addr is any (Jiri Pirko) [1107369]
- [net] gre6: don't try to add the same route two times (Jiri Pirko) [1107369]
- [netdrv] bonding: remove no longer relevant vlan warnings (Jiri Pirko) [1048814]
- [netdrv] bonding: allow to add vlans on top of empty bond (Jiri Pirko) [1048814]
- [net] netfilter: nf_ct_timestamp: Fix BUG_ON after netns deletion (Jiri Pirko) [1085667]
- [net] netfilter: nf_nat: fix oops on netns removal (Florian Westphal) [1089581]
- [net] unix socket code abuses csum_partial (Hannes Frederic Sowa) [1106402]
- [net] ip_tunnel: Set network header properly for IP_ECN_decapsulate() (Jiri Pirko) [1094419]

* Fri Jul 25 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-139.el7]
- [fs] GFS2: fix potential NULL pointer dereference (Robert S Peterson) [1095835]
- [input] synaptics: fix resolution for manually provided min/max (Benjamin Tissoires) [1093449]
- [input] synaptics: change min/max quirk table to pnp-id matching (Benjamin Tissoires) [1093449]
- [input] synaptics: add a matches_pnp_id helper function (Benjamin Tissoires) [1093449]
- [input] synaptics: T540p - unify with other LEN0034 models (Benjamin Tissoires) [1093449]
- [input] synaptics: add min/max quirk for the ThinkPad W540 (Benjamin Tissoires) [1093449]
- [input] synaptics: add min/max quirk for ThinkPad Edge E431 (Benjamin Tissoires) [1093449]
- [input] synaptics: add min/max quirk for ThinkPad T431s, L440, L540, S1 Yoga and X1 (Benjamin Tissoires) [1093449]
- [input] synaptics: report INPUT_PROP_TOPBUTTONPAD property (Benjamin Tissoires) [1093449]
- [input] Add INPUT_PROP_TOPBUTTONPAD device property (Benjamin Tissoires) [1093449]
- [input] i8042: add firmware_id support (Benjamin Tissoires) [1093449]
- [input] serio: add firmware_id sysfs attribute (Benjamin Tissoires) [1093449]
- [input] synaptics: add manual min/max quirk for ThinkPad X240 (Benjamin Tissoires) [1093449]
- [input] synaptics: add manual min/max quirk (Benjamin Tissoires) [1093449]
- [input] synaptics: fix incorrect placement of __initconst (Benjamin Tissoires) [1093449]
- [s390] sclp_early: Return correct HSA block count also for zero (Hendrik Brueckner) [1107730]
- [s390] sclp_early: Add function to detect sclp console capabilities (Hendrik Brueckner) [1107730]
- [s390] sclp_early: Pass sccb pointer to every *_detect() function (Hendrik Brueckner) [1107730]
- [s390] sclp_early: Replace early_read_info_sccb with sccb_early (Hendrik Brueckner) [1107730]
- [s390] sclp_early: Get rid of sclp_early_read_info_sccb_valid (Hendrik Brueckner) [1107730]
- [s390] sclp: replace uninitialized early_event_mask_sccb variable with sccb_early (Hendrik Brueckner) [1107730]
- [s390] sclp: Consolidate early sclp init calls to sclp_early_detect() (Hendrik Brueckner) [1107730]
- [s390] sclp: Move declarations for sclp_sdias into separate header file (Hendrik Brueckner) [1107730]
- [s390] sclp: Move early code from sclp_cmd.c to sclp_early.c (Hendrik Brueckner) [1107730]
- [s390] sclp: Determine HSA size dynamically for zfcpdump (Hendrik Brueckner) [1107730]
- [s390] sclp: properly detect line mode console (Hendrik Brueckner) [1107730]
- [s390] sclp: add parameter to specify number of buffer pages (Hendrik Brueckner) [1103744]
- [md] dm-cache: set minimum_io_size to cache's data block size (Mike Snitzer) [1117872]
- [md] dm-thin: set minimum_io_size to pool's data block size (Mike Snitzer) [1117872]
- [md] dm-crypt: use per-bio data (Mike Snitzer) [1117872]
- [block] use kmalloc alignment for bio slab (Mike Snitzer) [1117872]
- [md] dm-crypt: fix cpu hotplug crash by removing per-cpu structure (Mike Snitzer) [1117872]
- [md] dm-mpath: print more useful warnings in multipath_message() (Mike Snitzer) [1117872]
- [md] dm-mpath: do not activate failed paths (Mike Snitzer) [1117872]
- [md] dm-mpath: eliminate pg_ready() wrapper (Mike Snitzer) [1117872]
- [md] dm-mpath: remove extra nesting in map function (Mike Snitzer) [1117872]
- [md] dm-mpath: remove map_io() (Mike Snitzer) [1117872]
- [md] dm-mpath: reduce memory pressure when requeuing (Mike Snitzer) [1117872]
- [md] dm-mpath: really fix lockdep warning (Mike Snitzer) [1117872]
- [md] dm-mpath: fix lock order inconsistency in multipath_ioctl (Mike Snitzer) [1117872]
- [md] dm-mpath: remove process_queued_ios() (Mike Snitzer) [1117872]
- [md] dm-mpath: fix IO hang due to logic bug in multipath_busy (Mike Snitzer) [1117872]
- [md] dm-mpath: push back requests instead of queueing (Mike Snitzer) [1117872]
- [md] dm-table: add dm_table_run_md_queue_async (Mike Snitzer) [1117872]
- [md] dm-mpath: do not call pg_init when it is already running (Mike Snitzer) [1117872]
- [md] dm-cache: fail migrations in the do_worker error path (Mike Snitzer) [1117872]
- [md] dm-cache: simplify deferred set reference count increments (Mike Snitzer) [1117872]
- [md] dm-cache-metadata: use dm-space-map-metadata.h defined size limits (Mike Snitzer) [1117872]
- [md] dm-cache-metadata: do not allow the data block size to change (Mike Snitzer) [1117872]
- [md] dm-thin-metadata: do not allow the data block size to change (Mike Snitzer) [1117872]
- [md] dm-thin: relax external origin size constraints (Mike Snitzer) [1065474]
- [md] dm-thin: switch to an atomic_t for tracking pending new block preparations (Mike Snitzer) [1065474]
- [md] dm-thin: cleanup noflush_work to use a proper completion (Mike Snitzer) [1117872]
- [md] dm-era: check for a non-NULL metadata object before closing it (Mike Snitzer) [1117872]
- [md] dm-io: simplify dec_count and sync_io (Mike Snitzer) [1117872]
- [md] dm-io: fix a race condition in the wake up code for sync_io (Mike Snitzer) [1117872]
- [md] dm-crypt, dm-zero: update author name following legal name change (Mike Snitzer) [1117872]
- [md] dm: allocate a special workqueue for deferred device removal (Mike Snitzer) [1117872]
- [md] dm-snapshot: do not split read bios sent to snapshot-origin target (Mike Snitzer) [1117872]
- [md] dm-snapshot: allocate a per-target structure for snapshot-origin target (Mike Snitzer) [1117872]
- [md] dm: introduce dm_accept_partial_bio (Mike Snitzer) [1117872]
- [md] dm: change sector_count member in clone_info from sector_t to unsigned (Mike Snitzer) [1117872]
- [md] dm: remove symbol export for dm_set_device_limits (Mike Snitzer) [1117872]
- [md] dm: disable WRITE SAME if it fails (Mike Snitzer) [1117872]
- [md] dm: use RCU_INIT_POINTER instead of rcu_assign_pointer in __unbind (Mike Snitzer) [1117872]
- [md] dm: stop using bi_private (Mike Snitzer) [1117872]
- [md] dm: remove dm_get_mapinfo (Mike Snitzer) [1117872]
- [md] dm-table: make dm_table_supports_discards static (Mike Snitzer) [1117872]
- [md] dm: make dm_table_alloc_md_mempools static (Mike Snitzer) [1117872]
- [mm] Revert: vmscan: do not swap anon pages just because free+file is low (Johannes Weiner) [1102991]
- [crypto] fips: only panic on bad/missing crypto mod signatures (Jarod Wilson) [903562]
- [x86] hugetlb: Add missing TLB page invalidation for hugetlb_cow() (Larry Woodman) [1097919]

* Fri Jul 18 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-138.el7]
- [mm] hugetlb: ensure hugepage access is denied if hugepages are not supported (David Gibson) [1081671]
- [x86] Delete non-required instances of include <linux/init.h> (Prarit Bhargava) [1119074]
- [mmc] sdhci-pci-o2micro: Add SeaBird SeaEagle SD3 support (David Milburn) [968020]
- [mmc] sdhci-pci: add support of O2Micro/BayHubTech SD hosts (David Milburn) [968020]
- [mmc] sdhci-pci: break out definitions to header file (David Milburn) [968020]
- [ethernet] cnic: Don't take cnic_dev_lock in cnic_alloc_uio_rings() (Maurizio Lombardi) [1079384 1094613]
- [ethernet] cnic: Don't take rcu_read_lock in cnic_rcv_netevent() (Maurizio Lombardi) [1079384 1094613]
- [idle] intel_idle: fix IVT idle state table setting (Prarit Bhargava) [1119374]
- [idle] intel_idle: fine-tune IVT residency targets (Prarit Bhargava) [1119374]
- [idle] intel_idle: do C1E promotion disable quirk for hotplugged CPUs (Prarit Bhargava) [1119374]
- [idle] intel_idle: remove superfluous dev->state_count initialization (Prarit Bhargava) [1119374]
- [x86] acpi, idle: Restructure the mwait idle routines (Prarit Bhargava) [1119374]
- [idle] intel_idle: use CPU_TASKS_FROZEN instead of a numeric constant (Prarit Bhargava) [1119374]
- [idle] intel_idle: shrink states tables (Prarit Bhargava) [1119374]
- [md] dm-thin: update discard_granularity to reflect the thin-pool blocksize (Mike Snitzer) [1099936]
- [md] dm-bio-prison: implement per bucket locking in the dm_bio_prison hash table (Mike Snitzer) [1099936]
- [md] dm-thin: return ENOSPC instead of EIO when error_if_no_space enabled (Mike Snitzer) [1099936]
- [md] dm-cache: always split discards on cache block boundaries (Mike Snitzer) [1103836]
- [md] dm-cache: fix writethrough mode quiescing in cache_map (Mike Snitzer) [1103836]
- [md] dm-cache: fix a lock-inversion (Mike Snitzer) [1103836]
- [md] dm-thin: add 'no_space_timeout' dm-thin-pool module param (Mike Snitzer) [1095639]
- [md] dm-thin: add timeout to stop out-of-data-space mode holding IO forever (Mike Snitzer) [1095639]
- [md] dm-thin: allow metadata commit if pool is in PM_OUT_OF_DATA_SPACE mode (Mike Snitzer) [1091852]
- [md] dm-thin: use INIT_WORK_ONSTACK in noflush_work to avoid ODEBUG warning (Mike Snitzer) [1098643]
- [md] dm-thin: fix rcu_read_lock being held in code that can sleep (Mike Snitzer) [1098643]
- [md] dm-thin: irqsave must always be used with the pool->lock spinlock (Mike Snitzer) [1098643]
- [md] dm-thin: sort the per thin deferred bios using an rb_tree (Mike Snitzer) [1098643]
- [md] dm-thin: use per thin device deferred bio lists (Mike Snitzer) [1098643]
- [md] dm-thin: simplify pool_is_congested (Mike Snitzer) [1098643]

* Thu Jul 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-137.el7]
- [powercap] Add to drivers Kconfig and Makefile (Steve Best) [1085575]
- [powercap] add Documentation (Steve Best) [1085575]
- [powercap] Fix build error with option -Werror=format-security (Steve Best) [1085575]
- [powercap] Introduce Intel RAPL power capping driver (Steve Best) [1085575]
- [powercap] Add class driver (Steve Best) [1085575]
- [x86] msr: add 64bit _on_cpu access functions (Steve Best) [1085575]
- [misc] bitops: Introduce BIT_ULL (Steve Best) [1085575]
- [virt] xen/spinlock: Don't use __initdate for xen_pv_spin (Vitaly Kuznetsov) [1006977]
- [virt] Revert: xen/spinlock: Disable IRQ spinlock (PV) allocation on PVHVM (Vitaly Kuznetsov) [1006977]
- [virt] xen/spinlock: Don't setup xen spinlock IPI kicker if disabled (Vitaly Kuznetsov) [1006977]
- [virt] xen/smp: Update pv_lock_ops functions before alternative code starts under PVHVM (Vitaly Kuznetsov) [1006977]
- [virt] xen/spinlock: We don't need the old structure anymore (Vitaly Kuznetsov) [1006977]
- [virt] xen/spinlock: Fix locking path engaging too soon under PVHVM (Vitaly Kuznetsov) [1006977]
- [ata] ahci: Do not receive interrupts sent by dummy ports (David Milburn) [1067838]
- [ata] ahci: do not request irq for dummy port (David Milburn) [1067838]
- [ata] ahci: fix Null pointer dereference in achi_host_active() (David Milburn) [1067838]
- [ata] ahci: Make distinct names for ports in /proc/interrupts (David Milburn) [1067838]
- [s390] 3270: fix crash with multiple reset device requests (Hendrik Brueckner) [1088320]
- [ata] ahci: accommodate tag ordered controller (David Milburn) [1083746]
- [scsi] libsas: introduce scmd_dbg() to quiet false positive "timeout" messages (David Milburn) [1074987]
- [ethernet] be2net: enable interrupts in EEH resume (Ivan Vecera) [1076682]
- [ethernet] bnx2: Fix shutdown sequence (Neil Horman) [1074656]
- [ethernet] be2net: Fix invocation of be_close() after be_clear() (Ivan Vecera) [1066644]
- [virt] hv/balloon: Ensure pressure reports are posted regularly (Luiz Capitulino) [1102888]
- [virt] kvm/x86: expose invariant tsc cpuid bit (Marcelo Tosatti) [1095990]
- [virt] kvm/x86: disable master clock if TSC is reset during suspend (Marcelo Tosatti) [1098604]
- [virt] xen/pvhvm: Initialize xen panic handler for PVHVM guests (Vitaly Kuznetsov) [839966]
- [fs] cifs: Wait for writebacks to complete before attempting write (Sachin Prabhu) [1040329]
- [fs] xfs: xfs_readsb needs to check for magic numbers (Eric Sandeen) [1102940]
- [net] svcrdma: fix offset calculation for non-page aligned sge entries (Jeff Layton) [1088954]
- [fs] lockd: ensure we tear down any live sockets when socket creation fails during lockd_up (Jeff Layton) [1085774]
- [net] svcrpc: fix gss-proxy NULL dereference in some error cases (Jeff Layton) [1085616]
- [mm] use paravirt friendly ops for NUMA hinting ptes (Vitaly Kuznetsov) [1101274]
- [mm] swap: discard while swapping only if SWAP_FLAG_DISCARD_PAGES (Rafael Aquini) [1053189]
- [x86] hwpoison: remove unused global variable in do_machine_check() (Prarit Bhargava) [1119306]
- [x86] mce: Panic when a core has reached a timeout (Prarit Bhargava) [1119306]
- [x86] mce: Improve mcheck_init_device() error handling (Prarit Bhargava) [1119306]
- [x86] mce: Fix CMCI preemption bugs (Prarit Bhargava) [1119306]
- [x86] cmci: Add proper detection of end of CMCI storms (Prarit Bhargava) [1119306]
- [x86] acpi, apei, ghes: Do not report only correctable errors with SCI (Prarit Bhargava) [1119306]
- [x86] mce: Call put_device on device_register failure (Prarit Bhargava) [1119306]
- [acpi] apei, cper: Add UEFI 2.4 support for memory error (Prarit Bhargava) [1119306]
- [x86] mce: Fix mce regression from recent cleanup (Prarit Bhargava) [1119306]
- [x86] mce: Update MCE severity condition check (Prarit Bhargava) [1119306]
- [x86] mce: Add comments to clarify usage of the various bitfields in the MCA subsystem (Prarit Bhargava) [1119306]
- [x86] mcheck, therm_throt: Process package thresholds (Prarit Bhargava) [1119306]
- [x86] mce: Fix "braodcast" typo (Prarit Bhargava) [1119306]
- [mm] vmstat: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [mm] vmstat: set N_CPU to node_states during boot (Prarit Bhargava) [1119078]
- [kernel] trace, ring-buffer: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [kernel] profile: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [mm] zswap: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [hwmon] via-cputemp: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [hwmon] coretemp: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [oprofile] nmi-timer: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [idle] intel-idle: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [base] topology: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [scsi] fcoe: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [cpufreq] acpi-cpufreq: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [scsi] bnx2i: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [scsi] bnx2fc: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [virt] x86, kvm: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] amd, uncore: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] pci, amd-bus: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] hpet: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] intel, cacheinfo: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] therm_throt: Remove unused therm_cpu_lock (Prarit Bhargava) [1119078]
- [x86] oprofile, nmi: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] amd, ibs: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] msr: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [powerpc] sysfs: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] mce: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] therm_throt: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] cpuid: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] vsyscall: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [x86] intel, uncore: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [s390] smp: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [s390] cacheinfo: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [kernel] cpu_hotplug, perf: Fix CPU hotplug callback registration (Prarit Bhargava) [1119078]
- [kernel] cpu/hotplug: Add lockdep annotations to get/put_online_cpus() (Prarit Bhargava) [1119078]
- [kernel] cpu/hotplug: Provide lockless versions of callback registration functions (Prarit Bhargava) [1119078]
- [Documentation] cpu-hotplug: Specify race-free way to register CPU hotplug callbacks (Prarit Bhargava) [1119078]
- [pci] Fail new_id for vendor/device values already built into driver (Bandan Das) [1055867]
- [init] main: add initcall_blacklist kernel parameter (Prarit Bhargava) [1080995]
- [kernel] pid_namespace: pidns_get() should check task_active_pid_ns() != NULL (Jan Stancek) [1106368]
- [i2c] i2c-ismt: support I2C_SMBUS_I2C_BLOCK_DATA transaction type (Neil Horman) [1094516]
- [misc] mei: fix lockdep warning when registering mei watchdog (Prarit Bhargava) [971855]

* Wed Jul 16 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-136.el7]
- [block] mtip32xx: minor performance enhancements (Mike Snitzer) [1105703]
- [block] mtip32xx: let blk_mq_tag_to_rq() take blk_mq_tags as the main parameter (Mike Snitzer) [1105703]
- [block] mtip32xx: move error handling to service thread (Mike Snitzer) [1105703]
- [block] mtip32xx: stop block hardware queues before quiescing IO (Mike Snitzer) [1105703]
- [block] mtip32xx: blk_mq_init_queue() returns an ERR_PTR (Mike Snitzer) [1105703]
- [block] mtip32xx: convert to use blk-mq (Mike Snitzer) [1105703]
- [block] mtip32xx: Fix ERO and NoSnoop values in PCIe upstream on AMD systems (Mike Snitzer) [1105703]
- [block] mtip32xx: Remove dfs_parent after pci unregister (Mike Snitzer) [1105703]
- [block] mtip32xx: Increase timeout for STANDBY IMMEDIATE command (Mike Snitzer) [1105703]
- [block] mtip32xx: Set queue bounce limit (Mike Snitzer) [1105703]
- [block] mtip32xx: Use pci_enable_msi() instead of pci_enable_msi_range() (Mike Snitzer) [1105703]
- [block] mtip32xx: fix bad use of smp_processor_id() (Mike Snitzer) [1105703]
- [block] mtip32xx: Use pci_enable_msix_range() instead of pci_enable_msix() (Mike Snitzer) [1105703]
- [block] mtip32xx: Remove superfluous call to pci_disable_msi() (Mike Snitzer) [1105703]
- [block] mtip32xx: Reduce the number of unaligned writes to 2 (Mike Snitzer) [1105703]
- [block] mtip32xx: Correctly handle security locked condition (Mike Snitzer) [1105703]
- [block] mtip32xx: Make SGL container per-command to eliminate high order dma allocation (Mike Snitzer) [1105703]
- [block] mtip32xx: dynamically allocate buffer in debugfs functions (Mike Snitzer) [1105703]
- [block] blk-mq: fix RHEL kABI breakage (Mike Snitzer) [1105204]
- [block] blk-mq: blk_mq_start_hw_queue() should use blk_mq_run_hw_queue() (Mike Snitzer) [1105204]
- [block] add support for limiting gaps in SG lists (Mike Snitzer) [1105204]
- [block] blk-mq: bitmap tag, fix races in bt_get() function (Mike Snitzer) [1105204]
- [block] blk-mq: bitmap tag, fix race on blk_mq_bitmap_tags::wake_cnt (Mike Snitzer) [1105204]
- [block] blk-mq: bitmap tag, fix races on shared ::wake_index fields (Mike Snitzer) [1105204]
- [block] blk_max_size_offset() should check ->max_sectors (Mike Snitzer) [1105204]
- [block] null_blk: fix softirq completions for queue_mode == 1 (Mike Snitzer) [1105204]
- [block] blk-mq: merge blk_mq_drain_queue and __blk_mq_drain_queue (Mike Snitzer) [1105204]
- [block] blk-mq: properly drain stopped queues (Mike Snitzer) [1105204]
- [block] blk-mq: for_each_* macro correctness (Mike Snitzer) [1105204]
- [scsi] reintroduce scsi_driver.init_command (Mike Snitzer) [1105204]
- [scsi] remove scsi_end_request (Mike Snitzer) [1105204]
- [scsi] explicitly release bidi buffers (Mike Snitzer) [1105204]
- [scsi] don't reference freed command in scsi_prep_return (Mike Snitzer) [1105204]
- [scsi] don't reference freed command in scsi_init_sgtable (Mike Snitzer) [1105204]
- [scsi] add support for per-host cmd pools (Mike Snitzer) [1105204]
- [scsi] simplify command allocation and freeing a bit (Mike Snitzer) [1105204]
- [scsi] megaraid: simplify internal command handling (Mike Snitzer) [1105204]
- [scsi] remove a useless get_put_device pair in scsi_requeue_command (Mike Snitzer) [1105204]
- [scsi] remove a useless get_put_device pair in scsi_next_command (Mike Snitzer) [1105204]
- [scsi] remove a useless get_put_device pair in scsi_request_fn (Mike Snitzer) [1105204]
- [scsi] do not manipulate device reference counts in scsi_get_put_command (Mike Snitzer) [1105204]
- [scsi] avoid taking host_lock in scsi_run_queue unless nessecary (Mike Snitzer) [1105204]
- [scsi] avoid useless free_list lock roundtrips (Mike Snitzer) [1105204]
- [scsi] enable destruction of blocked devices which fail LUN scanning (Mike Snitzer) [1105204]
- [scsi] Revert: reintroduce scsi_driver.init_command (Mike Snitzer) [1105204]
- [block] implement an unprep function corresponding directly to prep (Mike Snitzer) [1105204]
- [scsi] handle command allocation failure in scsi_reset_provider (Mike Snitzer) [1105204]
- [block] properly stack underlying max_segment_size to DM device (Mike Snitzer) [1105204]
- [block] remove elv_abort_queue and blk_abort_flushes (Mike Snitzer) [1105204]
- [block] __elv_next_request() shouldn't call into the elevator if bypassing (Mike Snitzer) [1105204]
- [block] trace all devices plug operation (Mike Snitzer) [1105204]
- [block] Reserve only one queue tag for sync IO if only 3 tags are available (Mike Snitzer) [1105204]
- [block] blk-exec: Cleaning up local variable address returned (Mike Snitzer) [1105204]
- [block] use __blk_end_request_all to free bios and also call rq->end_io (Mike Snitzer) [1105204]
- [block] fix RHEL kABI breakage (Mike Snitzer) [1105204]
- [block] null_blk: fix name and description of 'queue_mode' module parameter (Mike Snitzer) [1105204]
- [block] all blk-mq requests are tagged (Mike Snitzer) [1105204]
- [block] bsg: update check for rq based driver for blk-mq (Mike Snitzer) [1105204]
- [block] blk-mq: add timer in blk_mq_start_request (Mike Snitzer) [1105204]
- [block] blk-mq: always initialize request->start_time (Mike Snitzer) [1105204]
- [block] blk-mq: ->timeout should be cleared in blk_mq_rq_ctx_init() (Mike Snitzer) [1105204]
- [block] blk-mq: don't allow queue entering for a dying queue (Mike Snitzer) [1105204]
- [block] blk-mq: bump max tag depth to 10K tags (Mike Snitzer) [1105204]
- [block] add blk_rq_set_block_pc() (Mike Snitzer) [1105204]
- [block] ensure that bio_add_page() always accepts a page for an empty bio (Mike Snitzer) [1105204]
- [block] add notion of a chunk size for request merging (Mike Snitzer) [1105204]
- [block] blk-flush: clear flush_rq's tag in flush_end_io() (Mike Snitzer) [1105204]
- [block] blk-mq: let blk_mq_tag_to_rq() take blk_mq_tags as the main parameter (Mike Snitzer) [1105204]
- [block] blk-mq: fix regression from commit 624dbe475416 (Mike Snitzer) [1105204]
- [block] blk-mq: handle NULL req return from blk_map_request in single queue mode (Mike Snitzer) [1105204]
- [block] blk-mq: fix sparse warning on missed __percpu annotation (Mike Snitzer) [1105204]
- [block] blk-mq: fix schedule from atomic context (Mike Snitzer) [1105204]
- [block] blk-mq: move blk_mq_get_ctx_blk_mq_put_ctx to mq private header (Mike Snitzer) [1105204]
- [block] blk-mq: push IPI or local end_io decision to __blk_mq_complete_request() (Mike Snitzer) [1105204]
- [block] blk-mq: remember to start timeout handler for direct queue (Mike Snitzer) [1105204]
- [block] blk-mq: blk_mq_unregister_hctx() can be static (Mike Snitzer) [1105204]
- [block] blk-mq: make the sysfs mq/ layout reflect current mappings (Mike Snitzer) [1105204]
- [block] blk-mq: blk_mq_tag_to_rq should handle flush request (Mike Snitzer) [1105204]
- [block] blk-mq: request initialization optimizations (Mike Snitzer) [1105204]
- [block] add queue flag for disabling SG merging (Mike Snitzer) [1105204]
- [block] blk-mq: remove alloc_hctx and free_hctx methods (Mike Snitzer) [1105204]
- [block] blk-mq: add file comments and update copyright notices (Mike Snitzer) [1105204]
- [block] blk-mq: remove blk_mq_alloc_request_pinned (Mike Snitzer) [1105204]
- [block] blk-mq: do not use blk_mq_alloc_request_pinned in blk_mq_map_request (Mike Snitzer) [1105204]
- [block] blk-mq: remove blk_mq_wait_for_tags (Mike Snitzer) [1105204]
- [block] blk-mq: initialize request in __blk_mq_alloc_request (Mike Snitzer) [1105204]
- [block] blk-mq: merge blk_mq_alloc_reserved_request into blk_mq_alloc_request (Mike Snitzer) [1105204]
- [block] blk-mq: add helper to insert requests from irq context (Mike Snitzer) [1105204]
- [block] blk-mq: remove stale comment for blk_mq_complete_request() (Mike Snitzer) [1105204]
- [block] blk-mq: allow non-softirq completions (Mike Snitzer) [1105204]
- [block] blk-mq: pass in suggested NUMA node to ->alloc_hctx() (Mike Snitzer) [1105204]
- [block] only allocate/free mq_usage_counter in blk-mq (Mike Snitzer) [1105204]
- [block] blk-mq: avoid code duplication (Mike Snitzer) [1105204]
- [block] blk-mq: fix leak of hctx->ctx_map (Mike Snitzer) [1105204]
- [block] blk-mq: idle all hardware contexts before freeing a queue (Mike Snitzer) [1105204]
- [block] blk-mq: allow setting of per-request timeouts (Mike Snitzer) [1105204]
- [block] blk-mq: export blk_mq_tag_busy_iter (Mike Snitzer) [1105204]
- [block] blk-mq: split make request handler for multi and single queue (Mike Snitzer) [1105204]
- [block] blk-mq: save memory by freeing requests on unused hardware queues (Mike Snitzer) [1105204]
- [block] blk-mq: allow the hctx cpu hotplug notifier to return errors (Mike Snitzer) [1105204]
- [block] blk-mq: Micro-optimize blk_queue_nomerges() check (Mike Snitzer) [1105204]
- [block] Enable sysfs nomerge control for I/O requests in the plug list (Mike Snitzer) [1105204]
- [block] blk-mq: initialize q->nr_requests after calling blk_queue_make_request() (Mike Snitzer) [1105204]
- [block] blk-mq: allow changing of queue depth through sysfs (Mike Snitzer) [1105204]
- [block] blk-mq: switch ctx pending map to the sparser blk_align_bitmap (Mike Snitzer) [1105204]
- [block] blk-mq: move the cache friendly bitmap type of out blk-mq-tag (Mike Snitzer) [1105204]
- [block] blk-mq: improve support for shared tags maps (Mike Snitzer) [1105204]
- [block] blk-mq: cleanup blk_mq_init_tags (Mike Snitzer) [1105204]
- [block] blk-mq: select random tag betweet 0 and (depth - 1) (Mike Snitzer) [1105204]
- [block] blk-mq: remove barrier in bt_clear_tag() (Mike Snitzer) [1105204]
- [block] blk-mq: use clear_bit_unlock in bt_clear_tag() (Mike Snitzer) [1105204]
- [block] blk-mq: fix race in IO start accounting (Mike Snitzer) [1105204]
- [block] blk-mq: use sparser tag layout for lower queue depth (Mike Snitzer) [1105204]
- [block] blk-mq: implement new and more efficient tagging scheme (Mike Snitzer) [1105204]
- [block] blk-mq: initialize struct request fields individually (Mike Snitzer) [1105204]
- [block] blk-mq: update a hotplug comment for grammar (Mike Snitzer) [1105204]
- [block] blk-mq: add basic round-robin of what CPU to queue workqueue work on (Mike Snitzer) [1105204]
- [block] blk-mq: remove extra requeue trace (Mike Snitzer) [1105204]
- [block] null_blk: fix use after free (Mike Snitzer) [1105204]
- [block] blk-mq: refactor request insertion_merging (Mike Snitzer) [1105204]
- [block] blk-mq: remove debug BUG_ON() when draining software queues (Mike Snitzer) [1105204]
- [block] blk-mq: fix waiting for reserved tags (Mike Snitzer) [1105204]
- [block] ensure that the timer is always added (Mike Snitzer) [1105204]
- [block] fold __blk_add_timer into blk_add_timer (Mike Snitzer) [1105204]
- [block] blk-mq: respect rq_affinity (Mike Snitzer) [1105204]
- [block] blk-mq: fix race with timeouts and requeue events (Mike Snitzer) [1105204]
- [block] Revert: blk-mq: initialize req->q in allocation (Mike Snitzer) [1105204]
- [block] blk-mq: fix leak of set->tags (Mike Snitzer) [1105204]
- [block] blk-mq: initialize req->q in allocation (Mike Snitzer) [1105204]
- [block] blk-mq: user (1 << order) to implement order_to_size() (Mike Snitzer) [1105204]
- [block] blk-mq: fix allocation of set->tags (Mike Snitzer) [1105204]
- [block] blk-mq: free hctx->ctx_map when init failed (Mike Snitzer) [1105204]
- [block] export blk_finish_request (Mike Snitzer) [1105204]
- [block] blk-mq: rename mq_flush_work struct request member (Mike Snitzer) [1105204]
- [block] blk-mq: add blk_mq_requeue_request (Mike Snitzer) [1105204]
- [block] blk-mq: add blk_mq_start_hw_queues (Mike Snitzer) [1105204]
- [block] blk-mq: add blk_mq_delay_queue (Mike Snitzer) [1105204]
- [block] blk-mq: add async parameter to blk_mq_start_stopped_hw_queues (Mike Snitzer) [1105204]
- [block] blk-mq: bidi support (Mike Snitzer) [1105204]
- [block] blk-mq: allow drivers to hook into I_O completion (Mike Snitzer) [1105204]
- [block] blk-mq: kill preempt disable_enable in blk_mq_work_fn() (Mike Snitzer) [1105204]
- [block] blk-mq: don't use preempt_count() to check for right CPU (Mike Snitzer) [1105204]
- [block] blk-mq: split out tag initialization, support shared tags (Mike Snitzer) [1105204]
- [block] blk-mq: initialize request on allocation (Mike Snitzer) [1105204]
- [block] blk-mq: add ->init_request and ->exit_request methods (Mike Snitzer) [1105204]
- [block] blk-mq: make ->flush_rq fully transparent to drivers (Mike Snitzer) [1105204]
- [block] blk-mq: do not initialize req->special (Mike Snitzer) [1105204]
- [block] blk-mq: initialize resid_len (Mike Snitzer) [1105204]
- [block] blk-mq: simplify blk_mq_hw_sysfs_cpus_show() (Mike Snitzer) [1105204]
- [block] blk-mq: ensure that hardware queues are always run on the mapped CPUs (Mike Snitzer) [1105204]
- [block] add kblockd_schedule_delayed_work_on() (Mike Snitzer) [1105204]
- [block] remove 'q' parameter from kblockd_schedule_*_work() (Mike Snitzer) [1105204]
- [block] blk-mq: fix potential stall during CPU unplug with IO pending (Mike Snitzer) [1105204]
- [block] remove dead code in scsi_ioctl:blk_verify_command (Mike Snitzer) [1105204]
- [block] only calculate part_in_flight() once (Mike Snitzer) [1105204]
- [block] relax when to modify the timeout timer (Mike Snitzer) [1105204]
- [char] random: export add_disk_randomness (Mike Snitzer) [1105204]
- [block] blk-mq: add REQ_SYNC early (Mike Snitzer) [1105204]
- [block] blk-mq: Make blk_mq_cpu_notify_lock a raw spinlock (Mike Snitzer) [1105204]
- [block] blk-mq: don't dump CPU -> hw queue map on driver load (Mike Snitzer) [1105204]
- [block] blk-mq: fix wrong usage of hctx->state vs hctx->flags (Mike Snitzer) [1105204]
- [block] blk-mq: allow blk_mq_init_commands() to return failure (Mike Snitzer) [1105204]
- [block] fix regression with block enabled tagging (Mike Snitzer) [1105204]
- [block] Stop abusing rq->csd.list in blk-softirq (Mike Snitzer) [1105204]
- [scsi] Make sure cmd_flags are 64-bit (Mike Snitzer) [1109271]
- [block] Replace __get_cpu_var uses (Mike Snitzer) [1105204]
- [block] Remove useless IPI struct initialization (Mike Snitzer) [1105204]
- [block] Stop abusing csd.list for fifo_time (Mike Snitzer) [1105204]
- [block] blktrace: fix accounting of partially completed requests (Mike Snitzer) [1105204]
- [fs] bio: don't write "bio: create slab" messages to syslog (Mike Snitzer) [1105204]
- [block] make __blkdev_issue_zeroout static (Mike Snitzer) [1105204]
- [block] Do not call sector_div() with a 64-bit divisor (Mike Snitzer) [1105204]
- [block] add cond_resched() to potentially long running ioctl discard loop (Mike Snitzer) [1105204]
- [kernel] smp: Rename __smp_call_function_single() to smp_call_function_single_async() (Prarit Bhargava) [1105192]
- [kernel] smp: Remove wait argument from __smp_call_function_single() (Prarit Bhargava) [1105192]
- [kernel] smp: Move __smp_call_function_single() below its safe version (Prarit Bhargava) [1105192]
- [kernel] smp: Consolidate the various smp_call_function_single() declensions (Prarit Bhargava) [1105192]
- [kernel] smp: Teach __smp_call_function_single() to check for offline cpus (Prarit Bhargava) [1105192]
- [kernel] smp: Iterate functions through llist_for_each_entry_safe() (Prarit Bhargava) [1105192]
- [kernel] llist: lock-less list, Add llist_for_each_entry_safe() (Prarit Bhargava) [1105192]
- [kernel] smp: remove cpumask_ipi (Prarit Bhargava) [1105192]
- [kernel] smp: use lockless list for smp_call_function_single (Prarit Bhargava) [1105192]
- [kernel] smp: fix generic_exec_single indentation (Prarit Bhargava) [1105192]
- [kernel] smp: quit unconditionally enabling irqs in on_each_cpu_mask() (Prarit Bhargava) [1105192]
- [kernel] smp: free related resources when failure occurs in hotplug_cfd() (Prarit Bhargava) [1105192]
- [kernel] smp/generic-ipi/locking: Fix misleading smp_call_function_any() description (Prarit Bhargava) [1105192]
- [kernel] smp/generic-ipi: Kill unnecessary variable - csd_flags (Prarit Bhargava) [1105192]
- [kernel] init: remove __cpuinit sections from the kernel (Prarit Bhargava) [1105893]
- [block] blk-mq: remove newly added instances of __cpuinit (Prarit Bhargava) [1105893]
- [misc] delete __cpuinit usage from all remaining drivers files (Prarit Bhargava) [1105893]
- [kernel] delete __cpuinit usage from all core kernel files (Prarit Bhargava) [1105893]
- [block] delete __cpuinit usage from all block files (Prarit Bhargava) [1105893]
- [acpi] delete __cpuinit usage from all acpi files (Prarit Bhargava) [1105893]
- [kernel] rcu: delete __cpuinit usage from all rcu files (Prarit Bhargava) [1105893]
- [net] delete __cpuinit usage from all net files (Prarit Bhargava) [1105893]
- [hwmon] delete __cpuinit usage from all hwmon files (Prarit Bhargava) [1105893]
- [clocksource] delete __cpuinit usage from all related files (Prarit Bhargava) [1105893]
- [x86] delete __cpuinit usage from all x86 files (Prarit Bhargava) [1105893]
- [s390] delete __cpuinit usage from all s390 files (Prarit Bhargava) [1105893]
- [powerpc] Delete __cpuinit usage from all users (Prarit Bhargava) [1105893]

* Wed Jul 16 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-135.el7]
- [pci] hotplug: Avoid warning when _ADR not present (Myron Stowe) [1114228]
- [pci] hotplug/acpi: Drop unused acpiphp_debug declaration (Myron Stowe) [1114228]
- [acpi] scan: Set flags.match_driver in acpi_bus_scan_fixed() (Myron Stowe) [1114228]
- [acpi] pci_root: Clear driver_data before failing enumeration (Myron Stowe) [1114228]
- [acpi] hotplug: Fix PCI host bridge hot removal (Myron Stowe) [1114228]
- [acpi] hotplug: Fix acpi_bus_get_device() return value check (Myron Stowe) [1114228]
- [acpi] hotplug: Consolidate deferred execution of ACPI hotplug routines (Myron Stowe) [1114228]
- [acpi] hotplug: Do not execute "insert in progress" _OST (Myron Stowe) [1114228]
- [acpi] hotplug: Carry out PCI root eject directly (Myron Stowe) [1114228]
- [acpi] hotplug: Merge device hot-removal routines (Myron Stowe) [1114228]
- [acpi] hotplug: Make acpi_bus_hot_remove_device() internal (Myron Stowe) [1114228]
- [acpi] hotplug: Simplify device ejection routines (Myron Stowe) [1114228]
- [acpi] hotplug: Fix handle_root_bridge_removal() (Myron Stowe) [1114228]
- [acpi] hotplug: Refuse to hot-remove all objects with disabled hotplug (Myron Stowe) [1114228]
- [acpi] scan: Start matching drivers after trying scan handlers (Myron Stowe) [1114228]
- [acpi] Remove acpi_pci_slot_init() headers from internal.h (Myron Stowe) [1114228]
- [pci] Revert: acpi / hotplug / pci: Avoid doing too much for spurious notifies (Myron Stowe) [1114228]
- [base] Release device_hotplug_lock when store_mem_state returns EINVAL (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop WARN_ON() from acpiphp_enumerate_slots() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Fix error code path in acpiphp_enumerate_slots() (Myron Stowe) [1114228]
- [acpi] memhotplug: Use defined marco METHOD_NAME__STA (Myron Stowe) [1114228]
- [acpi] hotplug: Use kobject_init_and_add() instead of _init() and _add() (Myron Stowe) [1114228]
- [acpi] hotplug: Don't set kobject parent pointer explicitly (Myron Stowe) [1114228]
- [acpi] hotplug: Set kobject name via kobject_add(), not kobject_set_name() (Myron Stowe) [1114228]
- [base] hotplug: Remove cpu_hotplug_driver_lock() (Myron Stowe) [1114228]
- [x86] hotplug: Disable ARCH_CPU_PROBE_RELEASE on x86 (Myron Stowe) [1114228]
- [x86] hotplug: Add hotplug lock to missing places (Myron Stowe) [1114228]
- [x86] hotplug: Fix online state in cpu0 debug interface (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Avoid parent bus rescans on spurious device checks (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Use _OST to notify firmware about notify status (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Avoid doing too much for spurious notifies (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Don't trim devices before scanning the namespace (Myron Stowe) [1114228]
- [kernel] power/hibernate/memory_hotplug: Rework mutual exclusion (Myron Stowe) [1114228]
- [kernel] power/hibernate: Create memory bitmaps after freezing user space (Myron Stowe) [1114228]
- [acpi] scan: Change ordering of locks for device hotplug (Myron Stowe) [1114228]
- [acpi] hotplug: Remove containers synchronously (Myron Stowe) [1114228]
- [base] core/acpi: Avoid device hot remove locking issues (Myron Stowe) [1114228]
- [base] introduce help macro to_memory_block (Myron Stowe) [1114228]
- [base] use standard device online/offline for state change (Myron Stowe) [1114228]
- [base] refactor add_memory_section() to add_memory_block() (Myron Stowe) [1114228]
- [base] remove improper get/put in add_memory_section() (Myron Stowe) [1114228]
- [base] reduce add_memory_section() for boot-time only (Myron Stowe) [1114228]
- [base] unshare add_memory_section() from hotplug (Myron Stowe) [1114228]
- [base] use device get/put functions (Myron Stowe) [1114228]
- [base] remove unneeded variable (Myron Stowe) [1114228]
- [base] move mutex lock out of add_memory_section() (Myron Stowe) [1114228]
- [acpi] sleep: Hold acpi_scan_lock over system PM transitions (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Fix NULL pointer dereference in cleanup_bridge() (Myron Stowe) [1114228]
- [base] cpu: Check if NUMA node is valid before bringing CPU up (Myron Stowe) [1114228]
- [pci] acpi: Use dev_dbg() instead of dev_info() in acpi_pci_set_power_state() (Myron Stowe) [1114228]
- [acpi] sleep: Introduce acpi_os_prepare_extended_sleep() for extended sleep (Myron Stowe) [1114228]
- [base] core: replace strict_strto*() with kstrto*() (Myron Stowe) [1114228]
- [acpi] dock: fix error return code in dock_add() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Get rid of check_sub_bridges() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Clean up bridge_mutex usage (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Redefine enable_device() and disable_device() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Sanitize acpiphp_get_(latch) (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Get rid of unused constants in acpiphp.h (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Check for new devices on enabled slots (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Allow slots without new devices to be rescanned (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Do not check SLOT_ENABLED in enable_device() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Do not exectute _PS0 and _PS3 directly (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Do not queue up event handling work items in vain (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Consolidate slot disabling and ejecting (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop redundant checks from check_hotplug_bridge() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Rework namespace scanning and trimming routines (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Store parent in functions and bus in slots (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop handle field from struct acpiphp_bridge (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop handle field from struct acpiphp_func (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Embed function struct into struct acpiphp_context (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop flags field from struct acpiphp_bridge (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop sun field from struct acpiphp_slot (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Register all devices under the given bridge (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Refactor slot allocation code in register_slot() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Drop func field from struct acpiphp_bridge (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Merge hotplug event handling functions (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Pass hotplug context objects to event handlers (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Rework acpiphp_handle_to_bridge() (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Unified notify handler for hotplug events (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Hotplug context objects for bridges and functions (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Always return success after adding a function (Myron Stowe) [1114228]
- [acpi] hotplug/pci: Consolidate acpiphp_enumerate_slots() (Myron Stowe) [1114228]
- [acpi] pci: Make bus registration and unregistration symmetric (Myron Stowe) [1114228]
- [x86] pci: prevent re-allocation of already existing bridge and ROM resource (Myron Stowe) [1114228]
- [acpi] dock: Drop unnecessary local variable from dock_add() (Myron Stowe) [1114228]
- [acpi] dock/pci: Drop ACPI dock notifier chain (Myron Stowe) [1114228]
- [acpi] dock: Do not check CONFIG_ACPI_DOCK_MODULE (Myron Stowe) [1114228]
- [acpi] dock: Do not leak memory on falilures to add a dock station (Myron Stowe) [1114228]
- [acpi] Drop ACPI bus notifier call chain (Myron Stowe) [1114228]
- [acpi] dock: Rework the handling of notifications (Myron Stowe) [1114228]
- [acpi] dock: Simplify dock_init_hotplug() and dock_release_hotplug() (Myron Stowe) [1114228]
- [acpi] dock: Walk list in reverse order during removal of devices (Myron Stowe) [1114228]
- [acpi] dock: Rework and simplify find_dock_devices() (Myron Stowe) [1114228]
- [acpi] dock: Drop the hp_lock mutex from struct dock_station (Myron Stowe) [1114228]
- [acpi] simplify acpiphp driver with new helper functions (Myron Stowe) [1114228]
- [acpi] simplify dock driver with new helper functions (Myron Stowe) [1114228]
- [acpi] Export acpi_(bay) (Myron Stowe) [1114228]
- [acpi] introduce two helper functions for _EJ0 and _LCK (Myron Stowe) [1114228]
- [acpi] introduce helper function acpi_execute_simple_method() (Myron Stowe) [1114228]
- [acpi] introduce helper function acpi_has_method() (Myron Stowe) [1114228]
- [acpi] dock: simplify dock_create_acpi_device() (Myron Stowe) [1114228]
- [acpi] dock: mark initialization functions with __init (Myron Stowe) [1114228]
- [acpi] dock: drop redundant spin lock in dock station object (Myron Stowe) [1114228]
- [acpi] dock: avoid initializing acpi_dock_notifier_list multiple times (Myron Stowe) [1114228]
- [base] Use attribute groups to create sysfs memory files (Myron Stowe) [1114228]
- [mm] hugetlb: add support for gigantic page allocation at runtime (Luiz Capitulino) [996763]
- [mm] hugetlb: move helpers up in the file (Luiz Capitulino) [996763]
- [mm] hugetlb: update_and_free_page(), don't clear PG_reserved bit (Luiz Capitulino) [996763]
- [mm] hugetlb: add hstate_is_gigantic() (Luiz Capitulino) [996763]
- [mm] hugetlb: fix and clean-up node iteration code to alloc or free (Luiz Capitulino) [996763]
- [mm] dma-contiguous: clean source code and prepare for device tree (Luiz Capitulino) [996763]
- [mm] cma: Move dma contiguous changes into a seperate config (Luiz Capitulino) [996763]
- [thermal] intel_powerclamp: Fix cstate counter detection (Steve Best) [1103376]
- [thermal] Tidy up error handling in powerclamp_init (Steve Best) [1103376]
- [thermal] intel_powerclamp: Add newer CPU models (Steve Best) [1103376]
- [security] selinux: Increase ebitmap_node size for 64-bit configuration (Paul Moore) [922752]
- [security] selinux: Reduce overhead of mls_level_isvalid() function call (Paul Moore) [922752]
- [powerpc] mm: fix ".__node_distance" undefined (David Milburn) [1081734]
- [block] nvme: Retry failed commands with non-fatal error (David Milburn) [1081734]
- [block] nvme: Fix divide-by-zero in nvme_trans_io_get_num_cmds (David Milburn) [1081734]
- [block] nvme: Add getgeo to block ops (David Milburn) [1081734]
- [block] nvme: Start-stop nvme_thread during device add-remove (David Milburn) [1081734]
- [block] nvme: Make I/O timeout a module parameter (David Milburn) [1081734]
- [block] nvme: CPU hot plug notification (David Milburn) [1081734]
- [block] nvme: per-cpu io queues (David Milburn) [1081734]
- [block] nvme: Replace DEFINE_PCI_DEVICE_TABLE (David Milburn) [1081734]
- [block] nvme: IOCTL path RCU protect queue access (David Milburn) [1081734]
- [block] nvme: RCU protected access to io queues (David Milburn) [1081734]
- [block] nvme: Initialize device reference count earlier (David Milburn) [1081734]
- [scsi] fnic: fix broken FIP discovery by initializing multicast address (Chris Leech) [1100078]
- [scsi] libfcoe: Make fcoe_sysfs optional / fix fnic NULL exception (Chris Leech) [1100078]

* Mon Jul 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-134.el7]
- [fs] nfs: populate ->net in mount data when remounting (Steve Dickson) [1113248]
- [fs] nfs: fix lockup caused by pnfs_generic_pg_test (Steve Dickson) [1113248]
- [fs] nfs: Fix typo in dprintk (Steve Dickson) [1113248]
- [fs] nfs: Comment is now wrong and redundant to code (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Disconnect on registration failure (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Remove BUG_ON() call sites (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Avoid deadlock when credit window is reset (Steve Dickson) [1113248]
- [net] sunrpc: Move congestion window constants to header file (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Reset connection timeout after successful reconnect (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Use macros for reconnection timeout constants (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Allocate missing pagelist (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Remove Tavor MTU setting (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Ensure ia->ri_id->qp is not NULL when reconnecting (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Reduce the number of hardway buffer allocations (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Limit work done by completion handler (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Reduce calls to ib_poll_cq() in completion handlers (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Reduce lock contention in completion handlers (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Split the completion queue (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Make rpcrdma_ep_destroy() return void (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Simplify rpcrdma_deregister_external() synopsis (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: mount reports "Invalid mount option" if memreg mode not supported (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Fall back to MTHCAFMR when FRMR is not supported (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Remove REGISTER memory registration mode (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Remove MEMWINDOWS registration modes (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Remove BOUNCEBUFFERS memory registration mode (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: RPC/RDMA must invoke xprt_wake_pending_tasks() in process context (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: Fix for FMR leaks (Steve Dickson) [1113248]
- [net] sunrpc/xprtrdma: mind the device's max fast register page list depth (Steve Dickson) [1113248]
- [fs] nfs: Push the file layout driver into a subdirectory (Steve Dickson) [1113248]
- [fs] nfs: Handle allocation errors correctly in objlayout_alloc_layout_hdr() (Steve Dickson) [1113248]
- [fs] nfs: Handle allocation errors correctly in filelayout_alloc_layout_hdr() (Steve Dickson) [1113248]
- [fs] nfs: Use error handler on failed GETATTR with successful OPEN (Steve Dickson) [1113248]
- [fs] nfs: Fix a potential busy wait in nfs_page_group_lock (Steve Dickson) [1113248]
- [fs] nfs: Fix error handling in __nfs_pageio_add_request (Steve Dickson) [1113248]
- [net] sunrpc: suppress allocation warning in rpc_malloc() (Steve Dickson) [1113248]
- [fs] nfs: support page groups in nfs_read_completion (Steve Dickson) [1113248]
- [fs] nfs: support non page aligned layouts (Steve Dickson) [1113248]
- [fs] nfs: allow non page aligned pnfs layout segments (Steve Dickson) [1113248]
- [fs] nfs: support multiple verfs per direct req (Steve Dickson) [1113248]
- [fs] nfs: remove data list from pgio header (Steve Dickson) [1113248]
- [fs] nfs: use > 1 request to handle bsize < PAGE_SIZE (Steve Dickson) [1113248]
- [fs] nfs: chain calls to pg_test (Steve Dickson) [1113248]
- [fs] nfs: allow coalescing of subpage requests (Steve Dickson) [1113248]
- [fs] nfs: clean up filelayout_alloc_commit_info (Steve Dickson) [1113248]
- [fs] nfs: page group support in nfs_mark_uptodate (Steve Dickson) [1113248]
- [fs] nfs: page group syncing in write path (Steve Dickson) [1113248]
- [fs] nfs: page group syncing in read path (Steve Dickson) [1113248]
- [fs] nfs: add support for multiple nfs reqs per page (Steve Dickson) [1113248]
- [fs] nfs: call nfs_can_coalesce_requests for every req (Steve Dickson) [1113248]
- [fs] nfs: modify pg_test interface to return size_t (Steve Dickson) [1113248]
- [fs] nfs: remove unused arg from nfs_create_request (Steve Dickson) [1113248]
- [fs] nfs: clean up PG_* flags (Steve Dickson) [1113248]
- [fs] nfs: fix race in filelayout commit path (Steve Dickson) [1113248]
- [fs] nfs: Create a common nfs_pageio_ops struct (Steve Dickson) [1113248]
- [fs] nfs: Create a common generic_pg_pgios() (Steve Dickson) [1113248]
- [fs] nfs: Create a common multiple_pgios() function (Steve Dickson) [1113248]
- [fs] nfs: Create a common initiate_pgio() function (Steve Dickson) [1113248]
- [fs] nfs: Create a generic_pgio function (Steve Dickson) [1113248]
- [fs] nfs: Create a common pgio_error function (Steve Dickson) [1113248]
- [fs] nfs: Create a common rpcsetup function for reads and writes (Steve Dickson) [1113248]
- [fs] nfs: Create a common rpc_call_ops struct (Steve Dickson) [1113248]
- [fs] nfs: Create a common nfs_pgio_result_common function (Steve Dickson) [1113248]
- [fs] nfs: Create a common pgio_rpc_prepare function (Steve Dickson) [1113248]
- [fs] nfs: Create a common rw_header_alloc and rw_header_free function (Steve Dickson) [1113248]
- [fs] nfs: Create a common pgio_alloc and pgio_release function (Steve Dickson) [1113248]
- [fs] nfs: Move the write verifier into the nfs_pgio_header (Steve Dickson) [1113248]
- [fs] nfs: Create a common read and write header struct (Steve Dickson) [1113248]
- [fs] nfs: Create a common read and write data struct (Steve Dickson) [1113248]
- [fs] nfs: Create a common results structure for reads and writes (Steve Dickson) [1113248]
- [fs] nfs: Create a common argument structure for reads and writes (Steve Dickson) [1113248]
- [fs] nfs: remove ->read_pageio_init from rpc ops (Steve Dickson) [1113248]
- [fs] nfs: remove ->write_pageio_init from rpc ops (Steve Dickson) [1113248]
- [fs] nfs: commit layouts in fdatasync (Steve Dickson) [1113248]
- [net] sunrpc: Fix a module reference issue in rpcsec_gss (Steve Dickson) [1113248]
- [fs] nfs: Don't ignore suid/sgid bit changes after a successful write (Steve Dickson) [1113248]
- [fs] nfs: Don't declare inode uptodate unless all attributes were checked (Steve Dickson) [1113248]
- [fs] nfs: Fix memroy leak for double mounts (Steve Dickson) [1113248]
- [fs] nfs: pass string length to pr_notice message about readdir loops (Steve Dickson) [1111170]
- [net] sunrpc: rpc_restart_call/rpc_restart_call_prepare should clear task->tk_status (Steve Dickson) [1111170]
- [net] sunrpc: Don't let rpc_delay() clobber non-timeout errors (Steve Dickson) [1111170]
- [net] sunrpc: Ensure call_status() deals correctly with SOFTCONN tasks (Steve Dickson) [1111170]
- [fs] nfs: Clear the open state flags if the new stateid does not match (Steve Dickson) [1111170]
- [fs] nfs: Use correct locking when updating nfs4_state in nfs4_close_done (Steve Dickson) [1111170]
- [fs] nfs: Ensure that we free existing layout segments if we get a new layout (Steve Dickson) [1111170]
- [fs] nfs: Minor optimisation in get_layout_by_fh_locked() (Steve Dickson) [1111170]
- [fs] nfs: Ensure that the layout recall callback matches layout stateids (Steve Dickson) [1111170]
- [fs] nfs: Don't update the open stateid unless it is newer than the old one (Steve Dickson) [1111170]
- [fs] nfs: Fix wraparound issues in pnfs_seqid_is_newer() (Steve Dickson) [1111170]
- [fs] nfs: Be more aggressive in using readdirplus for 'ls -l' situations (Steve Dickson) [1111170]
- [net] sunrpc: RPC callbacks may be split across several TCP segments (Steve Dickson) [1111170]
- [net] sunrpc: Fix oops when trace sunrpc_task events in nfs client (Steve Dickson) [1111170]
- [fs] nfs: Fail the truncate() if the lock/open stateid is invalid (Steve Dickson) [1111170]
- [fs] nfs: Fail data server I/O if stateid represents a lost lock (Steve Dickson) [1111170]
- [fs] nfs: Fix the return value of nfs4_select_rw_stateid (Steve Dickson) [1111170]
- [fs] nfs: nfs4_stateid_is_current should return 'true' for an invalid stateid (Steve Dickson) [1111170]
- [fs] nfs: Fix a delegation callback race (Steve Dickson) [1111170]
- [fs] nfs: Fix another nfs4_sequence corruptor (Steve Dickson) [1111170]
- [fs] nfsd: fix bug for readdir of pseudofs ("J. Bruce Fields") [1109733 1111719]
- [fs] nfsd: Don't hand out delegations for 30 seconds after recalling them ("J. Bruce Fields") [1111227 1111719]
- [fs] nfsd: fix FREE_STATEID lockowner leak ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't halt scanning the DRC LRU list when there's an RC_INPROG entry ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill READ64 ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill READ32 ("J. Bruce Fields") [1111719]
- [fs] nfsd: simplify server xdr->next_page use ("J. Bruce Fields") [1111719]
- [fs] nfsd: hash deleg stateid only on successful nfs4_set_delegation ("J. Bruce Fields") [1111719]
- [fs] nfsd: rename recall_lock to state_lock ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove unneeded zeroing of fields in nfsd4_proc_compound ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix setting of NFS4_OO_CONFIRMED in nfsd4_open ("J. Bruce Fields") [1111719]
- [fs] nfsd: use recall_lock for delegation hashing ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix laundromat next-run-time calculation ("J. Bruce Fields") [1111719]
- [fs] nfsd: make nfsd4_encode_fattr static ("J. Bruce Fields") [1111719]
- [net] sunrpc: Remove using of dprintk with KERN_WARNING ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove unused function nfsd_read_file ("J. Bruce Fields") [1111719]
- [fs] nfsd: getattr for FATTR4_WORD0_FILES_AVAIL needs the statfs buffer ("J. Bruce Fields") [1111719]
- [fs] nfsd: Error out when getting more than one fsloc/secinfo/uuid ("J. Bruce Fields") [1111719]
- [fs] nfsd: Using type of uint32_t for ex_nflavors instead of int ("J. Bruce Fields") [1111719]
- [fs] nfsd: Add missing comment of "expiry" in expkey_parse() ("J. Bruce Fields") [1111719]
- [fs] nfsd: Remove typedef of svc_client and svc_export in export.c ("J. Bruce Fields") [1111719]
- [fs] nfsd: Cleanup unneeded including net/ipv6.h ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove unneeded linux/user_namespace.h include ("J. Bruce Fields") [1111719]
- [fs] nfsd: Adds macro EX_UUID_LEN for exports uuid's length ("J. Bruce Fields") [1111719]
- [fs] nfsd: Helper function for parsing uuid ("J. Bruce Fields") [1111719]
- [fs] nfsd:Avoid NULL reference or double free in nfsd4_fslocs_free() ("J. Bruce Fields") [1109733 1111719]
- [fs] nfsd: better reservation of head space for krb5 ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill write32, write64 ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill WRITEMEM ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill WRITE64 ("J. Bruce Fields") [1111719]
- [fs] nfsd: kill WRITE32 ("J. Bruce Fields") [1111719]
- [fs] nfsd: really fix nfs4err_resource in 4.1 case ("J. Bruce Fields") [1111719]
- [fs] nfsd: allow exotic read compounds ("J. Bruce Fields") [1111719]
- [fs] nfsd: more read encoding cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: read encoding cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: separate splice and readv cases ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd_vfs_read doesn't use file handle parameter ("J. Bruce Fields") [1111719]
- [fs] nfsd: turn off zero-copy-read in exotic cases ("J. Bruce Fields") [1111719]
- [fs] nfsd: estimate sequence response size ("J. Bruce Fields") [1111719]
- [fs] nfsd: better estimate of getattr response size ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't treat readlink like a zero-copy operation ("J. Bruce Fields") [1111719]
- [fs] nfsd: enforce rd_dircount ("J. Bruce Fields") [1111719]
- [fs] nfsd: allow large readdirs ("J. Bruce Fields") [1111719]
- [fs] nfsd: use session limits to release send buffer reservation ("J. Bruce Fields") [1111719]
- [fs] nfsd: adjust buflen to session channel limit ("J. Bruce Fields") [1111719]
- [net] sunrpc: define xdr_restrict_buflen ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix buflen calculation after read encoding ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd4_check_resp_size should check against whole buffer ("J. Bruce Fields") [1111719]
- [fs] nfsd: minor encode_read cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: more precise nfsd4_max_reply ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't try to encode conflicting owner if low on space ("J. Bruce Fields") [1111719]
- [fs] nfsd: convert 4.1 replay encoding ("J. Bruce Fields") [1111719]
- [fs] nfsd: allow encoding across page boundaries ("J. Bruce Fields") [1023319 1111719]
- [fs] nfsd: size-checking cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove redundant encode buffer size checking ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd4_check_resp_size needn't recalculate length ("J. Bruce Fields") [1111719]
- [fs] nfsd: reserve space before inlining 0-copy pages ("J. Bruce Fields") [1111719]
- [fs] nfsd: teach encoders to handle reserve_space failures ("J. Bruce Fields") [1111719]
- [fs] nfsd: "backfill" using write_bytes_to_xdr_buf ("J. Bruce Fields") [1111719]
- [fs] nfsd: use xdr_truncate_encode ("J. Bruce Fields") [1111719]
- [net] sunrpc: xdr_truncate_encode ("J. Bruce Fields") [1111719]
- [fs] nfsd: keep xdr buf length updated ("J. Bruce Fields") [1111719]
- [fs] nfsd: no need for encode_compoundres to adjust lengths ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove ADJUST_ARGS ("J. Bruce Fields") [1111719]
- [fs] nfsd: use xdr_stream throughout compound encoding ("J. Bruce Fields") [1111719]
- [fs] nfsd: use xdr_reserve_space in attribute encoding ("J. Bruce Fields") [1111719]
- [fs] nfsd: allow space for final error return ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix encoding of out-of-space replies ("J. Bruce Fields") [1111719]
- [fs] nfsd: reserve head space for krb5 integ/priv info ("J. Bruce Fields") [1111719]
- [fs] nfsd: move proc_compound xdr encode init to helper ("J. Bruce Fields") [1111719]
- [fs] nfsd: tweak nfsd4_encode_getattr to take xdr_stream ("J. Bruce Fields") [1111719]
- [fs] nfsd: embed xdr_stream in nfsd4_compoundres ("J. Bruce Fields") [1111719]
- [fs] nfsd: decoding errors can still be cached and require space ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix write reply size estimate ("J. Bruce Fields") [1111719]
- [fs] nfsd: read size estimate should include padding ("J. Bruce Fields") [1111719]
- [fs] nfsd: allow larger 4.1 session drc slots ("J. Bruce Fields") [1111719]
- [fs] nfsd: READ, READDIR, etc., are idempotent ("J. Bruce Fields") [1111719]
- [fs] nfsd: Only set PF_LESS_THROTTLE when really needed ("J. Bruce Fields") [1111719]
- [net] sunrpc: track whether a request is coming from a loop-back interface ("J. Bruce Fields") [1111719]
- [net] sunrpc: Fix a module reference leak in svc_handle_xprt ("J. Bruce Fields") [1111719]
- [fs] nfsd: Ignore client's source port on RDMA transports ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove nfsd4_free_slab ("J. Bruce Fields") [1111719]
- [fs] nfsd: Remove assignments inside conditions ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix delegation cleanup on error ("J. Bruce Fields") [1111719]
- [fs] nfsd: Don't clear SUID/SGID after root writing data ("J. Bruce Fields") [1111719]
- [fs] nfsd: warn on finding lockowner without stateid's ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove lockowner when removing lock stateid ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix corruption on setting an ACL ("J. Bruce Fields") [1111719]
- [fs] nfsd: Get rid of empty function nfs4_state_init ("J. Bruce Fields") [1111719]
- [fs] nfsd: Use simple_read_from_buffer for coping data to userspace ("J. Bruce Fields") [1111719]
- [fs] nfsd: clean up fh_auth usage ("J. Bruce Fields") [1111719]
- [fs] nfsd: cleanup unneeded including linux/export.h ("J. Bruce Fields") [1111719]
- [fs] nfsd: Clean up nfs4_preprocess_stateid_op ("J. Bruce Fields") [1111719]
- [fs] nfsd: Mark nfs4_free_lockowner and nfs4_free_openowner as static functions ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove <linux/nfsd/debug.h> ("J. Bruce Fields") [1111719]
- [fs] nfsd: move <linux/nfsd/stats.h> to fs/nfsd ("J. Bruce Fields") [1111719]
- [fs] nfsd: move <linux/nfsd/export.h> to fs/nfsd ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove <linux/nfsd/nfsfh.h> ("J. Bruce Fields") [1111719]
- [fs] nfsd: Remove 'inline' designation for free_client() ("J. Bruce Fields") [1111719]
- [fs] nfsd: call rpc_destroy_wait_queue() from free_client() ("J. Bruce Fields") [1111719]
- [fs] nfsd: Move default initialisers from create_client() to alloc_client() ("J. Bruce Fields") [1111719]
- [fs] nfsd: set timeparms.to_maxval in setup_callback_client ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't create unnecessary mask acl ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't return high mode bits" ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix memory leak in nfsd4_encode_fattr() ("J. Bruce Fields") [1111719]
- [fs] nfsd: check passed socket's net matches NFSd superblock's one ("J. Bruce Fields") [1111719]
- [fs] nfsd: Check rpc_xprt out of xs_setup_bc_tcp ("J. Bruce Fields") [1111719]
- [net] sunrpc: New helper for creating client with rpc_xprt ("J. Bruce Fields") [1111719]
- [fs] nfsd: Free backchannel xprt in bc_destroy ("J. Bruce Fields") [1111719]
- [net] sunrpc: fix memory leak of peer addresses in XPRT ("J. Bruce Fields") [1111719]
- [fs] nfsd: Clear wcc data between compound ops ("J. Bruce Fields") [1111719]
- [fs] nfsd: Don't return NFS4ERR_STALE_STATEID for NFSv4.1+ ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix setclientid encode size ("J. Bruce Fields") [1111719]
- [fs] nfsd: remove redundant check from nfsd4_check_resp_size ("J. Bruce Fields") [1111719]
- [fs] nfsd: use more generous NFS4_ACL_MAX ("J. Bruce Fields") [1111719]
- [fs] nfsd: minor nfsd4_replay_cache_entry cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd4_replay_cache_entry should be static ("J. Bruce Fields") [1111719]
- [fs] nfsd: update comments with obsolete function name ("J. Bruce Fields") [1111719]
- [fs] nfsd: Using free_conn free connection ("J. Bruce Fields") [1111719]
- [fs] nfsd: typo in nfsd_rename comment ("J. Bruce Fields") [1111719]
- [fs] nfsd: simplify saved/current fh uses in nfsd4_proc_compound ("J. Bruce Fields") [1111719]
- [fs] nfsd: Traverse unconfirmed client through hash-table ("J. Bruce Fields") [1111719]
- [net] svcrpc: explicitly reject compounds that are not padded out to 4-byte multiple ("J. Bruce Fields") [1111719]
- [fs] nfsd: notify_change needs elevated write count ("J. Bruce Fields") [1111719 1115034]
- [fs] nfsd: fix test_stateid error reply encoding ("J. Bruce Fields") [1111719]
- [fs] nfsd: leave reply buffer space for failed setattr ("J. Bruce Fields") [1111719]
- [fs] nfsd: make set of large acl return efbig, not resource ("J. Bruce Fields") [1111719]
- [fs] nfsd: session needs room for following op to error out ("J. Bruce Fields") [1111719]
- [fs] nfsd: buffer-length check for SUPPATTR_EXCLCREAT ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix lost nfserrno() call in nfsd_setattr() ("J. Bruce Fields") [1111719]
- [net] sunrpc: Mark functions as static in net/sunrpc/svc_xprt.c ("J. Bruce Fields") [1111719]
- [fs] nfsd: decrease nfsd4_encode_fattr stack usage ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix encode_entryplus_baggage stack usage ("J. Bruce Fields") [1111719]
- [fs] nfsd: simplify xdr encoding of nfsv4 names ("J. Bruce Fields") [1111719]
- [fs] nfsd: encode_rdattr_error cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd4_encode_fattr cleanup ("J. Bruce Fields") [1111719]
- [fs] nfsd: better VERIFY comment ("J. Bruce Fields") [1111719]
- [fs] nfsd: Fix a memory leak in nfsd4_create_session ("J. Bruce Fields") [1111719]
- [fs] nfsd: get rid of unused function definition ("J. Bruce Fields") [1111719]
- [fs] nfsd:Define op_iattr for nfsd4_open instead using macro ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix compile warning without CONFIG_NFSD_V3 ("J. Bruce Fields") [1111719]
- [fs] nfsd: Don't start lockd when only NFSv4 is running ("J. Bruce Fields") [1111719]
- [net] sunrpc: Support a new option for ignoring the result of svc_register ("J. Bruce Fields") [1103348 1111719]
- [fs] nfsd: fix bad length checking for backchannel ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix a leak which can cause CREATE_SESSION failures ("J. Bruce Fields") [1111719]
- [fs] nfsd:Add missing recording of back channel attrs in nfsd4_session ("J. Bruce Fields") [1111719]
- [fs] nfsd: get rid of unused macro definition ("J. Bruce Fields") [1111719]
- [fs] nfsd: clean up unnecessary temporary variable in nfsd4_decode_fattr ("J. Bruce Fields") [1111719]
- [fs] nfsd: using nfsd4_encode_noop for encoding destroy_session/free_stateid ("J. Bruce Fields") [1111719]
- [fs] nfsd: clean up an xdr reserved space calculation ("J. Bruce Fields") [1111719]
- [fs] nfsd: get rid of unused function definition ("J. Bruce Fields") [1111719]
- [fs] nfsd: calculate the missing length of bitmap in EXCHANGE_ID ("J. Bruce Fields") [1111719]
- [fs] nfsd: revoking of suid/sgid bits after chown() in a consistent way ("J. Bruce Fields") [1111719]
- [net] sunrpc: fix some typos ("J. Bruce Fields") [1111719]
- [fs] nfsd: start documenting some XDR handling functions ("J. Bruce Fields") [1111719]
- [fs] nfsd: don't return high mode bits ("J. Bruce Fields") [1111719]
- [fs] nfsd: export proper maximum file size to the client ("J. Bruce Fields") [1111719]
- [fs] nfsd: improve write performance with better sendspace reservations ("J. Bruce Fields") [1111719]
- [net] svcrpc: remove an unnecessary assignment ("J. Bruce Fields") [1111719]
- [fs] nfsd: Add support for NFS v4.2 operation checking ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd_shutdown_net needs state lock ("J. Bruce Fields") [1111719]
- [fs] nfsd: Combine decode operations for v4 and v4.1 ("J. Bruce Fields") [1111719]
- [fs] nfsd: -EINVAL on invalid anonuid/gid instead of silent failure ("J. Bruce Fields") [1111719]
- [fs] nfsd: return better errors to exportfs ("J. Bruce Fields") [1111719]
- [fs] nfsd: fh_update should error out in unexpected cases ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix Kconfig syntax ("J. Bruce Fields") [1111719]
- [fs] nfsd: switch to p(dD) ("J. Bruce Fields") [1111719]
- [fs] nfsd: racy access to ->d_name in nsfd4_encode_path() ("J. Bruce Fields") [1111719]
- [net] svcrpc: remove unused rq_resused ("J. Bruce Fields") [1111719]
- [fs] nfsd: nfsd4_create_clid_dir prints uninitialized data ("J. Bruce Fields") [1111719]
- [fs] nfsd: Fix MACH_CRED NULL dereference ("J. Bruce Fields") [1111719]
- [fs] nfsd: fix xdr decoding of large non-write compounds ("J. Bruce Fields") [1095061 1111719]
- [fs] gfs2: When using flock() a GFS2 filesystem hangs (Robert S Peterson) [1111624]
- [fs] nfs: emit a fsnotify_nameremove call in sillyrename codepath (Jeff Layton) [919347]
- [fs] nfs: remove synchronous rename code (Jeff Layton) [919347]
- [fs] nfs: convert nfs_rename to use async_rename infrastructure (Jeff Layton) [919347]
- [fs] nfs: make nfs_async_rename non-static (Jeff Layton) [919347]
- [fs] nfs: abstract out code needed to complete a sillyrename (Jeff Layton) [919347]
- [fs] gfs2: Fix race in glock lru glock disposal (Robert S Peterson) [1095835]
- [fs] gfs2: Use lockref for glocks (Robert S Peterson) [1095835]
- [fs] cifs: Fix check for regular file in couldbe_mf_symlink() (Sachin Prabhu) [1077230]
- [fs] cifs: Re-order M-F Symlink code (Sachin Prabhu) [1077230]
- [fs] cifs: Add create MFSymlinks to protocol ops struct (Sachin Prabhu) [1077230]
- [fs] cifs: use protocol specific call for query_mf_symlink() (Sachin Prabhu) [1077230]
- [fs] cifs: Rename MF symlink function names (Sachin Prabhu) [1077230]
- [fs] cifs: Rename and cleanup open_query_close_cifs_symlink() (Sachin Prabhu) [1077230]
- [fs] cifs: We do not drop reference to tlink in CIFSCheckMFSymlink() (Sachin Prabhu) [1077230]

* Tue Jul 08 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-133.el7]
- [s390] af_iucv: recvmsg problem for SOCK_STREAM sockets (Hendrik Brueckner) [1109703]
- [s390] af_iucv: correct cleanup if listen backlog is full (Hendrik Brueckner) [1109033]
- [kernel] auditsc: audit_krule mask accesses need bounds checking (Denys Vlasenko) [1102710] {CVE-2014-3917}
- [fs] nfs: Don't mark the data cache as invalid if it has been flushed (Scott Mayhew) [1114054]
- [fs] nfs: Clear NFS_INO_REVAL_PAGECACHE when we update the file size (Scott Mayhew) [1114054]
- [fs] nfs: Fix cache_validity check in nfs_write_pageuptodate() (Scott Mayhew) [1114054]
- [mm] avoid kABI breakage (Jerome Marchand) [1097419]
- [mm] swap: change swap_list_head to plist, add swap_avail_head (Jerome Marchand) [1097419]
- [lib] plist: add plist_requeue (Jerome Marchand) [1097419]
- [lib] plist: add helper functions (Jerome Marchand) [1097419]
- [mm] swap: change swap_info singly-linked list to list_head (Jerome Marchand) [1097419]
- [block] mtip32xx: mtip_async_complete() bug fixes (Jeff Moyer) [1102281]
- [block] mtip32xx: Unmap the DMA segments before completing the IO request (Jeff Moyer) [1102281]
- [ethernet] tg3: Change nvram command timeout value to 50ms (Ivan Vecera) [1086397]
- [ethernet] tg3: Override clock, link aware and link idle mode during NVRAM dump (Ivan Vecera) [1086397]
- [edac] sb_edac: mark MCE messages as KERN_DEBUG (Aristeu Rozanski) [1056785]
- [edac] sb_edac: use "event" instead of "exception" when MC wasnt signaled (Aristeu Rozanski) [1056785]
- [Documentation] MAINTAINERS: Add DesignWare, i.MX6, Armada, R-Car PCI host maintainers (Myron Stowe) [1110890]
- [pci] Disable Bus Master only on kexec reboot (Myron Stowe) [1110890]
- [pci] Omit PCI ID macro strings to shorten quirk names (Myron Stowe) [1110890]
- [pci] Move device_del() from pci_stop_dev() to pci_destroy_dev() (Myron Stowe) [1110890]
- [pci] Avoid unnecessary CPU switch when calling driver .probe() method (Myron Stowe) [1110890]
- [Documentation] MAINTAINERS: Add Jingoo Han as Samsung Exynos PCIe driver maintainer (Myron Stowe) [1110890]
- [Documentation] MAINTAINERS: Add Tegra PCIe maintainer (Myron Stowe) [1110890]
- [ethernet] ixgbe: set driver_max_VFs should be done before enabling SRIOV (Alex Williamson) [1090154]
- [ethernet] ixgbe: define IXGBE_MAX_VFS_DRV_LIMIT macro and cleanup const 63 (Alex Williamson) [1090154]
- [fs] nfs: advertise only supported callback netids (Jeff Layton) [1048477]
- [fs] nfs: clean up, revert increase in READDIR RPC buffer max size (Jeff Layton) [1048477]
- [net] sunrpc: Fix large reads on NFS/RDMA (Jeff Layton) [1048477]
- [net] sunrpc: remove KERN_INFO from dprintk() call sites (Jeff Layton) [1048477]
- [kernel] ftrace: Hardcode ftrace_module_init() call into load_module() (Takahiro MUNEDA) [1061553]
- [kernel] trace: Make register/unregister_ftrace_command __init (Takahiro MUNEDA) [1061553]
- [tools] turbostat: run on HSX (Prarit Bhargava) [1081657]
- [tools] Revert: turbostat: servers do not support uncore power register (Prarit Bhargava) [1081657]

* Thu Jul 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-132.el7]
- [net] neigh: set nud_state to NUD_INCOMPLETE when probing router reachability (Hannes Frederic Sowa) [1110193]
- [net] bridge: Set vlan_features to allow offloads on vlans (Florian Westphal) [1058544]
- [net] team: fix mtu setting (Jiri Pirko) [1103083]
- [net] ptp: validate the requested frequency adjustment (Jiri Benc) [1092969]
- [net] netfilter: ctnetlink: don't add null bindings if no nat requested (Florian Westphal) [1089929]
- [net] netfilter: ctnetlink: force null nat binding on insert (Florian Westphal) [1089929]
- [net] netfilter: nf_conntrack: don't release a conntrack with non-zero refcnt (Florian Westphal) [1089929]
- [net] netfilter: nf_conntrack: fix RCU race in nf_conntrack_find_get (Florian Westphal) [1089929]
- [net] rtnetlink: Only supply IFLA_VF_PORTS information when RTEXT_FILTER_VF is set (Jiri Pirko) [1092400]
- [net] rtnetlink: Warn when interface's information won't fit in our packet (Jiri Pirko) [1092400]
- [net] fib_frontend: fix possible NULL pointer dereference (Jiri Benc) [1091142]
- [net] team: forbid incorrect fall-through in notifier (Jiri Pirko) [1090495]
- [net] gre: don't allow to add the same tunnel twice (Florian Westphal) [1086498]
- [net] sctp: confirm route during forward progress (Daniel Borkmann) [1089629]
- [net] nf_conntrack: decrement global counter after object release (Jiri Pirko) [1089191]
- [net] add busy_poll device feature (Jiri Pirko) [1080093]
- [net] ipv6: reallocate addrconf router for ipv6 address when lo device up (Jiri Benc) [1077053]
- [net] macvlan: Add support for 'always_on' offload features (Florian Westphal) [928644]
- [net] macvlan: fix netdev feature propagation from lower device (Florian Westphal) [928644]

* Wed Jul 02 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-131.el7]
- [scsi] pm80xx: Spinlock fix (Rich Bono) [1044636]
- [scsi] aacraid: Update unsupported card list (Rich Bono) [1080712]
- [scsi] vmw_pvscsi: Some improvements in pvscsi driver (Ewan Milne) [1075090]
- [scsi] vmw_pvscsi: Add support for I/O requests coalescing (Ewan Milne) [1075090]
- [scsi] vmw_pvscsi: Fix pvscsi_abort() function (Ewan Milne) [1075090]
- [net] sctp: Fix sk_ack_backlog wrap-around problem (Daniel Borkmann) [1112726] {CVE-2014-4667}
- [net] ipv4/tunnels: fix an oops when using ipip/sit with IPsec (Jiri Pirko) [1108857]
- [net] filter: let bpf_tell_extensions return SKF_AD_MAX (Jiri Benc) [1079524]
- [net] filter: introduce SO_BPF_EXTENSIONS (Jiri Benc) [1079524]

* Tue Jul 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-130.el7]
- [scsi] qla2xxx: Update version number to 8.06.00.08.07.0-k3 (Chad Dupuis) [1090378]
- [scsi] qla2xxx: Reduce the time we wait for a command to complete during SCSI error handling (Chad Dupuis) [1090378]
- [scsi] qla2xxx: Clear loop_id for ports that are marked lost during fabric scanning (Chad Dupuis) [1090378]
- [scsi] qla2xxx: Avoid escalating the SCSI error handler if the command is not found in firmware (Chad Dupuis) [1090378]
- [scsi] qla2xxx: Don't check for firmware hung during the reset context for ISP82XX (Chad Dupuis) [1090378]
- [scsi] qla2xxx: Issue abort command for outstanding commands during cleanup when only firmware is alive (Chad Dupuis) [1090378]
- [scsi] set DID_TIME_OUT correctly (Ewan Milne) [1103881]
- [scsi] fix invalid setting of host byte (Ewan Milne) [1103881]
- [scsi] More USB deadlock fixes (Ewan Milne) [1103881]
- [scsi] Fix USB deadlock caused by SCSI error handling (Ewan Milne) [1103881]
- [scsi] Fix command result state propagation (Ewan Milne) [1103881]
- [scsi] Fix spurious request sense in error handling (Ewan Milne) [1103881]
- [scsi] Add timeout to avoid infinite command retry (Ewan Milne) [1061871]
- [scsi] lpfc: Update version for 10.2.8021.0 driver release (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8001.0: Fix ExpressLane priority setup (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8001.0: Removed obsolete PCI IDs from the driver (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8001.0: Fix for initializing RRQ bitmap (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8001.0: Fix for cleaning up stale ring flag and sp_queue_event entries (Rob Evers) [1088574]
- [scsi] lpfc: Add iotag memory barrier (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Update Copyright on changed files from 8.3.45 patches (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fixed locking for scsi task management commands (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Convert runtime references to old xlane cfg param to fof cfg param (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fix FW dump using sysfs (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fix SLI4 s abort loop to process all FCP rings and under ring_lock (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fixed kernel panic in lpfc_abort_handler (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fix locking for postbufq when freeing (Rob Evers) [1088574]
- [scsi] lpfc: remove self-assignments (Rob Evers) [1088574]
- [scsi] lpfc: Using plain integer as NULL pointer (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fix locking for lpfc_hba_down_post (Rob Evers) [1088574]
- [scsi] lpfc 10.2.8000.0: Fix dynamic transitions of FirstBurst from on to off (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Fixed crash during driver unload (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Fixed driver error messages after firmware download (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Fixed missing initialization for task management IOCBs (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Fix sysfs buffer overrun in read of lpfc_fcp_cpu_map for 128 CPUs (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Incorporate changes to use reason in change_queue_depth function (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Incorporated support of a low-latency io path (Rob Evers) [1088574]
- [scsi] lpfc 8.3.45: Added dport mailbox pass through support (Rob Evers) [1088574]
- [scsi] be2iscsi: Bump the driver version (Rob Evers) [1088576]
- [scsi] be2iscsi: fix bad if expression (Rob Evers) [1088576]
- [scsi] be2iscsi: fix memory leak in error path (Rob Evers) [1088576]
- [scsi] be2iscsi: Jump to 'free_memory' is apparently missing (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix destroy MCC-CQ before MCC-EQ is destroyed (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix memory corruption in MBX path (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix TCP parameters while connection offloading (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix interrupt Coalescing mechanism (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix exposing Host in sysfs after adapter initialization is complete (Rob Evers) [1088576]
- [scsi] be2iscsi: Fix retreving MCCQ_WRB in non-embedded Mbox path (Rob Evers) [1088576]

* Tue Jul 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-129.el7]
- [drm] nouveau/bios: fix a bit shift error introduced by recent commit (Ulrich Obergfell) [1089936]
- [ethernet] sfc: PIO:Restrict to 64bit arch and use 64-bit writes (Nikolay Aleksandrov) [1089024]
- [fs] nfs: Apply NFS_MOUNT_CMP_FLAGMASK to nfs_compare_remount_data() (Scott Mayhew) [1103805]
- [fs] gfs2: Prevent recovery before the local journal is set (Robert S Peterson) [1079433]
- [fs] gfs2: Increase the max number of ACLs (Robert S Peterson) [1078231]
- [fs] gfs2: check NULL return value in gfs2_ok_to_move (Abhijith Das) [1097042]
- [fs] gfs2: Refresh quota after setting through quotactl (Abhijith Das) [1088740]
- [kernel] hrtimer: Prevent all reprogramming if hang detected (Prarit Bhargava) [1094732]
- [tty] Set correct tty name in 'active' sysfs attribute (Denys Vlasenko) [1066403]
- [ethernet] bnx2x: Fix kernel crash and data miscompare after EEH recovery (Michal Schmidt) [1101808]
- [ethernet] bnx2x: Adapter not recovery from EEH error injection (Michal Schmidt) [1067154]
- [powerpc] tm: Disable IRQ in tm_recheckpoint (Larry Woodman) [1088224]
- [x86] thinkpad: save and restore adaptive keyboard mode for suspend and, resume (Don Zickus) [1094476]
- [x86] thinkpad: support Thinkpad X1 Carbon 2nd generation's adaptive keyboard (Don Zickus) [1094476]

* Thu Jun 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-128.el7]
- [lib] random32: minor cleanups and kdoc fix (Hannes Frederic Sowa) [1100299]
- [lib] random32: avoid attempt to late reseed if in the middle of seeding (Hannes Frederic Sowa) [1100299]
- [lib] random32: use msecs_to_jiffies for reseed timer (Hannes Frederic Sowa) [1100299]
- [lib] random32: add __init prefix to prandom_start_seed_timer (Hannes Frederic Sowa) [1100299]
- [lib] random32: add test cases for taus113 implementation (Hannes Frederic Sowa) [1100299]
- [lib] random32: upgrade taus88 generator to taus113 from errata paper (Hannes Frederic Sowa) [1100299]
- [lib] random32: move rnd_state to linux/random.h (Hannes Frederic Sowa) [1100299]
- [lib] random32: add prandom_reseed_late() and call when nonblocking pool becomes initialized (Hannes Frederic Sowa) [1100299]
- [lib] random32: add periodic reseeding (Hannes Frederic Sowa) [1100299]
- [lib] random: allow architectures to optionally define random_get_entropy() (Hannes Frederic Sowa) [1100299]
- [net] packet: use percpu mmap tx frame pending refcount (Daniel Borkmann) [1052366]
- [net] packet: use reciprocal_divide in fanout_demux_hash (Daniel Borkmann) [1052366]
- [net] packet: add randomized fanout scheduler (Daniel Borkmann) [1052366]
- [net] packet: don't unconditionally schedule() in case of MSG_DONTWAIT (Daniel Borkmann) [1052366]
- [net] packet: improve socket create/bind latency in some cases (Daniel Borkmann) [1052366]
- [net] vxlan: convert to act as a pernet subsystem (Daniel Borkmann) [1039587]
- [net] vxlan: do not use vxlan_net before checking event type (Daniel Borkmann) [1039587]
- [net] vxlan: properly cleanup devs on module unload (Daniel Borkmann) [1039587]
- [net] vxlan: when lower dev unregisters remove vxlan dev as well (Daniel Borkmann) [1039587]
- [net] netfilter: x_tables: lightweight process control group matching (Daniel Borkmann) [1005839]
- [net] sctp: fix and consolidate SCTP checksumming code (Daniel Borkmann) [1054215]
- [net] checksum: fix warning in skb_checksum (Daniel Borkmann) [1054215]
- [net] skb_checksum: allow custom update/combine for walking skb (Daniel Borkmann) [1054215]
- [lib] crc32: reduce number of cases for crc32{, c}_combine (Daniel Borkmann) [1054215]
- [lib] crc32: conditionally resched when running testcases (Daniel Borkmann) [1054215]
- [lib] crc32: add test cases for crc32{, c}_combine routines (Daniel Borkmann) [1054215]
- [lib] crc32: add functionality to combine two crc32{, c}s in GF(2) (Daniel Borkmann) [1054215]
- [lib] crc32: clean up spacing in test cases (Daniel Borkmann) [1054215]
- [lib] crc32: update the comments of crc32_{be, le}_generic() (Daniel Borkmann) [1054215]
- [net] ipvs: sctp: do not recalc sctp csum when ports didn't change (Daniel Borkmann) [1054215]
- [net] ipvs: sctp: add missing verdict assignments in sctp_conn_schedule (Daniel Borkmann) [1054215]
- [tools] bpf_exp: free duplicated labels at exit time (Daniel Borkmann) [958035]
- [tools] bpf_dbg: always close socket in bpf_runnable (Daniel Borkmann) [958035]
- [net] filter: doc: improve BPF documentation (Daniel Borkmann) [958035]
- [tools] filter: bpf_asm: add minimal bpf asm tool (Daniel Borkmann) [958035]
- [tools] filter: bpf_dbg: add minimal bpf debugger (Daniel Borkmann) [958035]
- [net] sched: cls_bpf: add BPF-based classifier (Daniel Borkmann) [958035]
- [net] Use netlink_ns_capable to verify the permisions of netlink messages (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] netlink: Add variants of capable for use on netlink messages (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] diag: Move the permission check in sock_diag_put_filterinfo to packet_diag_dump (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] netlink: Rename netlink_capable netlink_allowed (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] diag: Fix ns_capable check in sock_diag_put_filterinfo (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] netlink: Fix permission check in netlink_connect() (Jiri Benc) [1094272] {CVE-2014-0181}
- [net] filter: prevent nla extensions to peek beyond the end of the message (Jiri Benc) [1096781] {CVE-2014-3144 CVE-2014-3145}

* Fri Jun 06 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-127.el7]
- [net] mac80211: fix crash due to AP powersave TX vs. wakeup race (Jacob Tanenbaum) [1083534] {CVE-2014-2706}
- [ethernet] qlcnic: Fix ethtool statistics length calculation (Michal Schmidt) [1099634]
- [kernel] futex: Make lookup_pi_state more robust (Larry Woodman) [1104520] {CVE-2014-3153}
- [kernel] futex: Always cleanup owner tid in unlock_pi (Larry Woodman) [1104520] {CVE-2014-3153}
- [kernel] futex: Validate atomic acquisition in futex_lock_pi_atomic() (Larry Woodman) [1104520] {CVE-2014-3153}
- [kernel] futex: prevent requeue pi on same futex (Larry Woodman) [1104520] {CVE-2014-3153}
- [net] gro: restore frag0 optimization (and fix crash) (Michal Schmidt) [1069741]
- [net] ipv4: current group_info should be put after using (Jiri Benc) [1087416] {CVE-2014-2851}
- [net] core, nfqueue, openvswitch: Orphan frags in skb_zerocopy and handle errors (Jiri Pirko) [1079014] {CVE-2014-2568}
- [fs] aio: fix plug memory disclosure and fix reqs_active accounting backport (Jeff Moyer) [1094605] {CVE-2014-0206}

* Tue Jun 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-126.el7]
- [fs] aio: plug memory disclosure and fix reqs_active accounting (Mateusz Guzik) [1094605] {CVE-2014-0206}
- [kernel] mutexes: Give more informative mutex warning in the !lock->owner case (Larry Woodman) [1087655 1087919 1087922]
- [kernel] mutex: replace CONFIG_HAVE_ARCH_MUTEX_CPU_RELAX with simple ifdef (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutexes: Introduce cancelable MCS lock for adaptive spinning (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutexes: Modify the way optimistic spinners are queued (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutexes: Return false if task need_resched() in mutex_can_spin_on_owner() (Larry Woodman) [1087655 1087919 1087922]
- [kernel] Restructure the MCS lock defines and locking & Move mcs_spinlock.h into kernel/locking/ (Larry Woodman) [1087655 1087919 1087922]
- [misc] arch: Introduce smp_load_acquire(), smp_store_release() (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutex: Fix debug_mutexes (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutex: Fix debug checks (Larry Woodman) [1087655 1087919 1087922]
- [kernel] locking/mutexes: Unlock the mutex without the wait_lock (Larry Woodman) [1087655 1087919 1087922]

* Tue Jun 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-125.el7]
- [scsi] st: fix corruption of the st_modedef structures in st_set_options() (Maurizio Lombardi) [1084968]
- [net] openvswitch: fix a possible deadlock and lockdep warning (Flavio Leitner) [1094867]
- [fs] dcache: make prepend_name() work correctly when called with negative *buflen (Mikulas Patocka) [1092746]
- [fs] dcache: __dentry_path() fixes (Mikulas Patocka) [1092746]
- [fs] dcache: prepend_path() needs to reinitialize dentry/vfsmount/mnt on restarts (Mikulas Patocka) [1092746]
- [net] ip: generate unique IP identificator if local fragmentation is allowed (Jiri Pirko) [1076106]
- [target] tcm_fc: Fix use-after-free of ft_tpg (Andy Grover) [1071340]
- [wireless] ath9k: tid->sched race in ath_tx_aggr_sleep() (Jacob Tanenbaum) [1083252] {CVE-2014-2672}
- [kernel] futex: Fix pthread_cond_broadcast() to wake up all threads (Larry Woodman) [1084757]
- [watchdog] hpwdt: display informative string (Nigel Croxon) [1074038]
- [mm] page-writeback: fix divide by zero in pos_ratio_polynom (Rik van Riel) [1091784]
- [mm] page-writeback: add strictlimit feature (Rik van Riel) [1091784]
- [powerpc] tm: Fix crash when forking inside a transaction (Radomir Vrbovsky) [1083215] {CVE-2014-2673}
- [block] floppy: don't write kernel-only members to FDRAWCMD ioctl output (Denys Vlasenko) [1094318] {CVE-2014-1737 CVE-2014-1738}
- [block] floppy: ignore kernel-only members in FDRAWCMD ioctl input (Denys Vlasenko) [1094318] {CVE-2014-1737 CVE-2014-1738}
- [s390] kernel: avoid page table walk on user space access (Hendrik Brueckner) [1097687]
- [s390] af_iucv: wrong mapping of sent and confirmed skbs (Hendrik Brueckner) [1098513]
- [s390] crypto: fix aes, des ctr mode concurrency finding (Hendrik Brueckner) [1097686]
- [mm] filemap: update find_get_pages_tag() to deal with shadow entries (Johannes Weiner) [1091795]
- [fs] xfs: log vector rounding leaks log space (Brian Foster) [1091136]
- [fs] xfs: truncate_setsize should be outside transactions (Brian Foster) [1091136]

* Tue May 20 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-124.el7]
- [tty] n_tty: Fix n_tty_write crash when echoing in raw mode (Aristeu Rozanski) [1094242] {CVE-2014-0196}
- [fs] gfs2: Fix uninitialized VFS inode in gfs2_create_inode (Abhijith Das) [1087995]
- [kernel] cputime: Fix jiffies based cputime assumption on steal accounting (Frederic Weisbecker) [1047732]
- [kernel] cputime: Bring cputime -> nsecs conversion (Frederic Weisbecker) [1047732]
- [kernel] cputime: Default implementation of nsecs -> cputime conversion (Frederic Weisbecker) [1047732]
- [x86] irq, pic: Probe for legacy PIC and set legacy_pic appropriately (Vivek Goyal) [1037957]
- [virt] hyperv/vmbus: Negotiate version 3.0 when running on ws2012r2 hosts (Vivek Goyal) [1037957]

* Mon May 05 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-123.el7]
- [mm] rmap: try_to_unmap_cluster() should lock_page() before mlocking (Larry Woodman) [1078349] {CVE-2014-3122}
- [mm] huge_memory: Fix cpuset cgroups so all pages for a task remain on correct node (Larry Woodman) [1076613]
- [mm] mprotect: fix oops in change_pmd_range called from task_numa_work (Rik van Riel) [1085050]

* Thu May 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-122.el7]
- [security] device_cgroup: check if exception removal is allowed (Aristeu Rozanski) [1086057]
- [security] device_cgroup: rework device access check and rule checking (Aristeu Rozanski) [1086057]
- [fs] autofs: fix lockref lookup (Ian Kent) [1083815]
- [mei] me: do not load the driver if the FW doesn't support MEI interface (Prarit Bhargava) [1082789]

* Tue Apr 08 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-121.el7]
- [virt] vhost/net: fix total length when packets are too short ("Michael S. Tsirkin") [1064446] {CVE-2014-0077}
- [virt] vhost/net: validate vhost_get_vq_desc return value ("Michael S. Tsirkin") [1070940] {CVE-2014-0055}

* Mon Apr 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-120.el7]
- [net] netfilter: fix panic when oom during rule replacement (Florian Westphal) [985657]
- [net] netfilter: x_tables: fix ordering of jumpstack allocation and table update (Florian Westphal) [985657]
- [virt] kvm/ioapic: try to recover if pending_eoi goes out of range (Paolo Bonzini) [1036478]
- [virt] kvm/ioapic: fix assignment of ioapic->rtc_status.pending_eoi (Paolo Bonzini) [1036478 1081590] {CVE-2014-0155}
- [virt] kvm/ioapic: reinject pending interrupts on KVM_SET_IRQCHIP (Paolo Bonzini) [1036478]
- [virt] kvm/ioapic: extract body of kvm_ioapic_set_irq (Paolo Bonzini) [1036478]
- [virt] kvm/ioapic: clear IRR for edge-triggered interrupts at delivery (Paolo Bonzini) [1036478]
- [virt] kvm/ioapic: merge ioapic_deliver into ioapic_service (Paolo Bonzini) [1036478]
- [virt] kvm: ignore ioapic polarity (Paolo Bonzini) [1036478]
- [core] device: Create 'device_driver_rh' KABI shadowing structure (Myron Stowe) [1083692]
- [core] device: Create 'device_rh' KABI shadowing structure (Myron Stowe) [1083692]
- [scsi] Reserve space in structures for future XCOPY support (Ewan Milne) [1080430]
- [fs] xfs: fix bad hash ordering (Brian Foster) [1083206]
- [fs] xfs: always do log forces via the workqueue (Brian Foster) [1052004]

* Thu Apr 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-119.el7]
- [net] bonding: remove bond_resend_igmp_join_requests read_unlock leftover (Veaceslav Falico) [1080924]
- [ethernet] mlx4: Support shutdown() interface (Amir Vadai) [1046216]
- [zram] fix invalid memory access (Jerome Marchand) [1081936]
- [zram] protect zram_reset_device() call (Jerome Marchand) [1081936]
- [zram] remove zram_sysfs file (Jerome Marchand) [1081936]
- [zram] use atomic64_xxx() to replace zram_stat64_xxx() (Jerome Marchand) [1081936]
- [zram] optimize memory operations with clear_page()/copy_page() (Jerome Marchand) [1081936]
- [zram] kill unused zram_get_num_devices() (Jerome Marchand) [1081936]
- [zram] simplify and optimize dev_to_zram() (Jerome Marchand) [1081936]
- [kernel] futex: revert back to the explicit waiter counting code (Larry Woodman) [1081100]
- [kernel] audit: Allow login in non-init namespaces (Richard Guy Briggs) [1082597]

* Tue Apr 01 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-118.el7]
- [wireless] ath9k: Fix LNA gpio for AR9485 (John Green) [1082017]
- [infiniband] core: Don't resolve passive side RoCE L2 address in cma req handler (Amir Vadai) [1075852]
- [fs] xfs: fix buffer use after free on IO error (Eric Sandeen) [924301]
- [scsi] be2iscsi: Bump the driver version (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix DMA Out of SW-IOMMU space error (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix scsi_cmnd leakage in driver (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix the session cleanup when reboot/shutdown happens (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix doorbell format for EQ/CQ/RQ s per SLI spec (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix port speed typo in driver (Rob Evers) [1052416]
- [scsi] be2iscsi: Fix handling timed out MBX completion from FW (Rob Evers) [1052416]
- [fs] nfs: Fix a use-after-free problem in open() (Steve Dickson) [1062809]

* Mon Mar 31 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-117.el7]
- [md] dm-thin: fix dangling bio in process_deferred_bios error path (Mike Snitzer) [1081781]
- [md] dm: take care to copy the space map roots before locking the superblock (Mike Snitzer) [1081781]
- [md] dm-transaction-manager: fix corruption due to non-atomic transaction commit (Mike Snitzer) [1081781]
- [md] dm-era: fixes for issues identified upstream (Mike Snitzer) [1081781]
- [md] dm-cache: remove remainder of distinct discard block size (Mike Snitzer) [1062679]
- [md] dm-cache: prevent corruption caused by discard_block_size > cache_block_size (Mike Snitzer) [1062679]
- [ipc] change kern_ipc_perm.deleted type to bool (Phillip Lougher) [1043807] {CVE-2013-7026}
- [ipc] introduce ipc_valid_object() helper to sort out IPC_RMID races (Phillip Lougher) [1043807] {CVE-2013-7026}
- [ipc] shm: fix shm_file deletion races (Phillip Lougher) [1043807] {CVE-2013-7026}
- [drm] udl: take reference to device struct for dma-bufs (Dave Airlie) [1077774]
- [security] keys: Allow special keys (eg. DNS results) to be invalidated by CAP_SYS_ADMIN (David Howells) [1074240]

* Fri Mar 28 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-116.el7]
- [s390] qeth: postpone freeing of qdio memory (Hendrik Brueckner) [1077650]
- [kernel] rh_taint: Remove taint and update unsupported hardware message (Prarit Bhargava) [1076974]
- [fs] proc/vmcore: continue vmcore initialization if PT_NOTE is found empty (Chao WANG) [1077535]
- [net] ipv6: ip6_append_data_mtu do not handle the mtu of the second fragment properly (Jiri Pirko) [1079873]

* Tue Mar 25 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-115.el7]
- [block] free q->flush_rq in blk_init_allocated_queue error paths (Mike Snitzer) [1078522]
- [x86] fpu: Clear exceptions in AMD FXSAVE workaround (Phillip Lougher) [1053596] {CVE-2014-1438}
- [mm] page_alloc: spill to remote nodes before waking kswapd (Johannes Weiner) [1076546]
- [mm] vmscan: do not swap anon pages just because free+file is low (Johannes Weiner) [1076546]
- [fs] sunrpc: Ensure call_connect_status() deals correctly with SOFTCONN tasks (Steve Dickson) [1071532]
- [fs] nfs: Ensure we respect soft mount timeouts during trunking discovery (Steve Dickson) [1071532]
- [fs] nfs: Schedule recovery if nfs40_walk_client_list() is interrupted (Steve Dickson) [1071532]
- [fs] sunrpc: Ensure that call_bind times out correctly (Steve Dickson) [1071532]
- [fs] sunrpc: Ensure that call_connect times out correctly (Steve Dickson) [1071532]

* Fri Mar 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-114.el7]
- [net] netfilter: nf_conntrack_dccp: fix skb_header_pointer API usages (Jiri Pirko) [1077351] {CVE-2014-2523}
- [net] ipv6: don't set DST_NOCOUNT for remotely added routes (Jiri Pirko) [1075060] {CVE-2014-2309}
- [net] skbuff: skb_segment: orphan frags before copying ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] skbuff: skb_segment: s/fskb/list_skb/ ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] skbuff: skb_segment: s/skb/head_skb/ ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] skbuff: skb_segment: s/skb_frag/frag/ ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] skbuff: skb_segment: s/frag/nskb_frag/ ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] use kfree_skb_list() helper ("Michael S. Tsirkin") [1056934] {CVE-2014-0131}
- [net] veth: fix veth vlan features (Flavio Leitner) [1076077]
- [net] sunrpc/xprtrdma: add separate Kconfig options for NFSoRDMA client and server support (Jeff Layton) [1077957]
- [virt] kvm/x86: emulate MOVAPD (Igor Mammedov) [1052090]
- [virt] kvm/x86: emulate MOVAPS (Igor Mammedov) [1052090]
- [mm] x86: Wrong page freed on preallocate_pmds() failure exit (Larry Woodman) [1073641]
- [mm] x86: do not leak page->ptl for pmd page tables (Larry Woodman) [1073641]
- [virt] kvm/x86: fix emulator buffer overflow (Andrew Jones) [1071836] {CVE-2014-0049}
- [virt] hyperv: Change the receive buffer size for legacy hosts (Jason Wang) [1075279]
- [x86] quirks: Update DH8900CC Unsupported Device ID (Prarit Bhargava) [1076137]

* Tue Mar 18 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-113.el7]
- [security] selinux: fix broken peer recv check (Paul Moore) [1043165]
- [md] dm-raid: Fix possibility of skipping device recovery (Jonathan E Brassow) [1069927]
- [fs] xfs: avoid AGI/AGF deadlock scenario for inode chunk allocation (Brian Foster) [1052789]
- [md] dm-cache: fix access beyond end of origin device (Mike Snitzer) [1074606]
- [md] dm-cache: fix truncation bug when copying a block to/from >2TB fast device (Mike Snitzer) [1075709]
- [ethernet] bna: don't disable VLAN tag stripping in promisc mode (Ivan Vecera) [1057842]
- [kernel] posix-timers: Spare workqueue if there is no full dynticks CPU to kick (Frederic Weisbecker) [1074168]

* Mon Mar 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-112.el7]
- [net] bridge: multicast: enable snooping on general queries only (Florian Westphal) [1074491]
- [net] bridge: multicast: add sanity check for general query destination (Florian Westphal) [1074491]
- [net] bridge: multicast: add sanity check for query source addresses (Florian Westphal) [1074491]
- [net] inet: frag: fix oops when unloading inetfrag modules (Florian Westphal) [1073962]
- [virt] vhost/net: fix ref cnt checking deadlock ("Michael S. Tsirkin") [1065878]
- [virt] vhost_net: correctly limit the max pending buffers ("Michael S. Tsirkin") [1065878]
- [virt] vhost/net: fix a theoretical race in device cleanup ("Michael S. Tsirkin") [1065878]
- [powerpc] pseries: Expose in kernel device tree update to drmgr (Steve Best) [1064745]
- [powerpc] pseries: Update dynamic cache nodes for suspend/resume operation (Steve Best) [1064745]
- [powerpc] pseries: Device tree should only be updated once after suspend/migrate (Steve Best) [1064745]
- [powerpc] pseries: Child nodes are not detached by dlpar_detach_node (Steve Best) [1064745]
- [powerpc] pseries: Add mising of_node_put in delete_dt_node (Steve Best) [1064745]
- [powerpc] pseries: Make dlpar_configure_connector parent node aware (Steve Best) [1064745]
- [powerpc] pseries: Do all node initialization in dlpar_parse_cc_node (Steve Best) [1064745]
- [powerpc] pseries: Fix parsing of initial node path in update_dt_node (Steve Best) [1064745]
- [powerpc] pseries: Pack update_props_workarea to map correctly to rtas buffer header (Steve Best) [1064745]
- [powerpc] pseries: Fix over writing of rtas return code in update_dt_node (Steve Best) [1064745]
- [powerpc] pseries: Fix creation of loop in device node property list (Steve Best) [1064745]
- [infiniband] mlx4: Don't allocate range of steerable UD QPs for Ethernet-only device (Doug Ledford) [1061795]
- [ethernet] e1000: fix lockdep warning in e1000_reset_task (John Green) [1056355]
- [ethernet] mlx4: mlx4_init_slave() shouldn't access comm channel before PF is ready (Amir Vadai) [1058413]
- [ethernet] mlx4: Fix memory access error in mlx4_QUERY_DEV_CAP_wrapper() (Amir Vadai) [1058413]
- [mm] numa: recheck for transhuge pages under lock during protection changes (Rik van Riel) [1073674]

* Fri Mar 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-111.el7]
- [net] inet: fix for a race condition in the inet frag code (Nikolay Aleksandrov) [1070711] {CVE-2014-0100}
- [scsi] aacraid: Print warning message if unsupported card is being used (Rich Bono) [1019091]
- [drm] ttm: don't oops if no invalidate_caches() (Rob Clark) [1073470 1075068]
- [security] selinux: bigendian problems with filename trans rules (Paul Moore) [1029837]
- [security] selinux: Fix memory leak upon loading policy (Paul Moore) [1051042]
- [x86] apic: Plug racy xAPIC access of CPU hotplug code (Igor Mammedov) [1073568]
- [kernel] sched: Remove redundant update_runtime notifier (Igor Mammedov) [1074476]
- [virt] kvm/svm: fix cr8 intercept window (Radim Krcmar) [1056982]
- [video] fb: reorder the lock sequence to fix potential dead lock (Jason Wang) [1040781]
- [virt] hv/vmbus: Don't timeout during the initial connection with host (Jason Wang) [1037957]
- [virt] hv/vmbus: Specify the target CPU that should receive notification (Jason Wang) [1037957]
- [mm] percpu scalability fixes (Alexander Viro) [1072446]
- [x86] fix compile error due to X86_TRAP_NMI use in asm files (Don Zickus) [1051428]
- [x86] Ignore NMIs that come in during early boot (Don Zickus) [1051428]
- [fs] cifs: Add support for follow_link on dfs shares under posix extensions (Sachin Prabhu) [1020715]
- [fs] cifs: move unix extension call to cifs_query_symlink() (Sachin Prabhu) [1020715]
- [kernel] audit: include subject in login records (Richard Guy Briggs) [1075155]
- [kernel] audit: remove superfluous new- prefix in AUDIT_LOGIN messages (Richard Guy Briggs) [1075155]
- [ethernet] tg3: Don't check undefined error bits in RXBD (Ivan Vecera) [1071483]
- [fs] gfs2: Move recovery variables to journal structure in memory (Robert S Peterson) [1059439]
- [security] keys: Make the keyring cycle detector ignore other keyrings of the same name (David Howells) [1071346] {CVE-2014-0102}
- [x86] fix x86 fixup_irqs() error handling (Prarit Bhargava) [1074644]
- [fs] gfs2: Re-add a call to log_flush_wait when flushing the journal (Robert S Peterson) [1074556]
- [fs] gfs2: Ensure workqueue is scheduled after noexp request (Robert S Peterson) [1074556]

* Wed Mar 12 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-110.el7]
- [mm] Revert: percpu scalability fixes (Jarod Wilson) [1072446]

* Tue Mar 11 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-109.el7]
- [block] change flush sequence list addition back to front add (Mike Snitzer) [1072577]
- [block] fix q->flush_rq NULL pointer crash on dm-mpath flush (Mike Snitzer) [1072577]
- [md] dm-era: mark as tech preview for RHEL7.0 (Mike Snitzer) [995644]
- [md] dm-bitset: only flush the current word if it has been dirtied (Mike Snitzer) [995644]
- [md] dm-era: support non power-of-2 blocksize (Mike Snitzer) [995644]
- [md] dm: add era target (Mike Snitzer) [995644]
- [md] dm-cache-mq: fix memory allocation failure for large cache devices (Mike Snitzer) [995644]
- [md] dm-cache: fix truncation bug when mapping I/O to >2TB fast device (Mike Snitzer) [995644]
- [md] dm-space-map-metadata: fix refcount decrement below 0 which caused corruption (Mike Snitzer) [1065051]
- [Documentation] dm-thin: fix Documentation for held metadata root feature (Mike Snitzer) [1065051]
- [md] dm-thin: fix noflush suspend IO queueing (Mike Snitzer) [1065051]
- [md] dm-thin: fix deadlock in __requeue_bio_list (Mike Snitzer) [1065051]
- [md] dm-thin: fix out of data space handling (Mike Snitzer) [1065051]
- [md] dm-thin: ensure user takes action to validate data and metadata consistency (Mike Snitzer) [1065051]
- [md] dm-thin: synchronize the pool mode during suspend (Mike Snitzer) [1065051]
- [md] dm: fix Kconfig indentation (Mike Snitzer) [1065051]
- [md] dm-thin: allow metadata space larger than supported to go unused (Mike Snitzer) [1065051]
- [md] dm-thin: fix the error path for the thin device constructor (Mike Snitzer) [1065051]
- [md] dm-thin: avoid metadata commit if a pool's thin devices haven't changed (Mike Snitzer) [1065051]
- [virt] hyperv: Add support for physically discontinuous receive buffer (Jason Wang) [988689]
- [virt] virtio-scsi: Fix hotcpu_notifier use-after-free with virtscsi_freeze (Jason Wang) [1024220]
- [fs] pnode: smarter propagate_mnt() (Alexander Viro) [1072457]
- [kernel] perf: Allow mmap2 interface (Jiri Olsa) [1071945]
- [crypto] ansi_cprng: Fix off by one error in non-block size request (Radomir Vrbovsky) [1009139]
- [fs] xfs: don't leak EFSBADCRC to userspace (Brian Foster) [1071925]
- [fs] xfs: modify verifiers to differentiate CRC from other errors (Brian Foster) [1071925]
- [fs] xfs: print useful caller information in xfs_error_report (Brian Foster) [1071925]
- [fs] xfs: add xfs_verifier_error() (Brian Foster) [1071925]
- [fs] xfs: add helper for updating checksums on xfs_bufs (Brian Foster) [1071925]
- [fs] xfs: add helper for verifying checksums on xfs_bufs (Brian Foster) [1071925]
- [fs] xfs: Use defines for CRC offsets in all cases (Brian Foster) [1071925]
- [fs] xfs: skip pointless CRC updates after verifier failures (Brian Foster) [1071925]
- [fs] xfs: limit superblock corruption errors to actual corruption (Brian Foster) [1071925]
- [fs] xfs: skip verification on initial "guess" superblock read (Brian Foster) [1071925]
- [fs] xfs: xfs_sb_read_verify() doesn't flag bad crcs on primary sb (Brian Foster) [1071925]
- [md] dm-snapshot: fix data corruption (Mikulas Patocka) [1070291]
- [ethernet] e1000e: Fix SHRA register access for 82579 (John Green) [1040315]
- [ethernet] be2net: do external loopback test only when it is requested (Ivan Vecera) [1065833]
- [drm] i915: fix potential oops in early irqs (Rob Clark) [1073136]
- [security] selinux: correctly label /proc inodes in use before the policy is loaded (Paul Moore) [1071858]
- [fs] vfs: unexport the getname() symbol (Jeff Layton) [1060739]
- [mm] percpu scalability fixes (Alexander Viro) [1072446]
- [kernel] uprobes: Fix the memory out of bound overwrite in copy_insn() (Oleg Nesterov) [984056]
- [kernel] uprobes: Fix the wrong usage of current->utask in uprobe_copy_process() (Oleg Nesterov) [984056]
- [kernel] uprobes: Teach uprobe_copy_process() to handle CLONE_VFORK (Oleg Nesterov) [984056]
- [kernel] uprobes: Change uprobe_copy_process() to dup xol_area (Oleg Nesterov) [984056]
- [kernel] uprobes: Change uprobe_copy_process() to dup return_instances (Oleg Nesterov) [984056]
- [kernel] uprobes: Teach __create_xol_area() to accept the predefined vaddr (Oleg Nesterov) [984056]
- [kernel] uprobes: Introduce __create_xol_area() (Oleg Nesterov) [984056]
- [kernel] uprobes: Change the callsite of uprobe_copy_process() (Oleg Nesterov) [984056]

* Mon Mar 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-108.el7]
- [scsi] megaraid_sas: fix a small problem when reading state value from hw (Tomas Henzl) [1070563]
- [scsi] megaraid_sas: driver bug fix (Tomas Henzl) [1064509]
- [scsi] qla2xxx: Update driver version to 8.06.00.08.07.0-k2 (Chad Dupuis) [1066003]
- [scsi] qla2xxx: Fixup looking for a space in the outstanding_cmds array in qla2x00_alloc_iocbs() (Chad Dupuis) [1066003]
- [scsi] qla2xxx: Set host can_queue value based on available resources (Chad Dupuis) [1066003]
- [scsi] qla2xxx: Fix request queue null dereference (Chad Dupuis) [1058624]
- [mm] add overcommit_kbytes sysctl variable (Jerome Marchand) [1058788]
- [mm] factor commit limit calculation (Jerome Marchand) [1058788]
- [drm] radeon/uvd: add kernel parameter to make uvd optional on evergreen (Jerome Glisse) [1056702]
- [drm] radeon: free uvd ring on unload (Jerome Glisse) [1056702]
- [s390] pci: obtain function handle in hotplug notifier (Hendrik Brueckner) [1059247]
- [s390] pci/dma: fix accounting of allocated_pages (Hendrik Brueckner) [1059247]
- [s390] pci: set error state for unavailable functions (Hendrik Brueckner) [1059247]
- [s390] pci: fix removal of nonexistent pci bus (Hendrik Brueckner) [1059247]
- [s390] pci: prevent inadvertently triggered bus scans (Hendrik Brueckner) [1059247]
- [pci] msi: Make pci_enable_msi/msix() 'nvec' argument type as int (Myron Stowe) [1070909]
- [pci] msi: Export MSI mode using attributes, not kobjects (Myron Stowe) [1070909]
- [drm] nouveau: attempt to disarm all interrupts before request_irq() (Ben Skeggs) [986654]
- [drm] nouveau: disable runtime pm by default (Ben Skeggs) [1072481]
- [s390] appldata_os: fix cpu array size calculation (Hendrik Brueckner) [1071354]
- [s390] cio: Fix missing subchannels after CHPID configure on (Hendrik Brueckner) [1071248]
- [s390] pci/dma: use correct segment boundary size (Hendrik Brueckner) [1071239]
- [scsi] isci: fix reset timeout handling (David Milburn) [1040402]
- [wireless] ath9k: Add custom parameters for CUS198 (John Green) [1044005]
- [ethernet] bnx2x: utilize FW 7.8.19 (Michal Schmidt) [1058008]
- [fs] fix the performance of reading /proc/mounts and friends (Alexander Viro) [1072461]
- [fs] namespace: mount hash table is too small (Alexander Viro) [1072451]
- [fs] xfs: inode log reservations are still too small (Brian Foster) [1071068]
- [fs] aio, memory-hotplug: Fix confliction when migrating and accessing ring pages (Motohiro Kosaki) [1060974]
- [x86] only add -Werror when using RHEL7 gcc (Stefan Assmann) [1073055]
- [mm] filemap: fix truncation crash due to exceptional entries (Johannes Weiner) [1069295 1071162]
- [mm] Add kernel and mm data structure padding before kABI freeze (Larry Woodman) [1071438]
- [pci] add pci_hw_vendor_status() (Prarit Bhargava) [1073062]
- [cpufreq] pcc: Enable autoload of pcc-cpufreq for all ACPI processors (Lenny Szubowicz) [928152]
- [idle] intel_idle: Repair large-server 50-watt idle-power regression (Lenny Szubowicz) [1054325]
- [fs] clean up page array when uncached write send fails (Sachin Prabhu) [1063780]
- [fs] cifs: use a flexarray in cifs_writedata (Sachin Prabhu) [1063780]
- [mm] oom_kill: add rcu_read_lock() into find_lock_task_mm() (Oleg Nesterov) [1000335]
- [mm] oom_kill: has_intersects_mems_allowed() needs rcu_read_lock() (Oleg Nesterov) [1000335]
- [mm] oom_kill: change oom_kill.c to use for_each_thread() (Oleg Nesterov) [1000335]
- [kernel] fork: introduce for_each_thread() to replace the buggy while_each_thread() (Oleg Nesterov) [1000335]
- [kernel] fork: copy_process(), consolidate the lockless CLONE_THREAD checks (Oleg Nesterov) [1000335]
- [kernel] fork: copy_process(), don't add the uninitialized child to thread/task/pid lists (Oleg Nesterov) [1000335]
- [kernel] fork: copy_process(), unify CLONE_THREAD-or-thread_group_leader code (Oleg Nesterov) [1000335]
- [fs] exec: de_thread(), use change_pid() rather than detach_pid/attach_pid (Oleg Nesterov) [1000335]
- [powerpc] xmon: Don't signal we've entered until we're finished printing (Steve Best) [1072790]
- [powerpc] xmon: Fix timeout loop in get_output_lock() (Steve Best) [1072790]
- [powerpc] xmon: Don't loop forever in get_output_lock() (Steve Best) [1072790]

* Fri Mar 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-107.el7]
- [net] make neigh_priv_len in struct net_device 16bit instead of 8bit (Jiri Benc) [1062308]
- [net] sctp: fix sctp_sf_do_5_1D_ce to verify if we/peer is AUTH capable (Daniel Borkmann) [1070716] {CVE-2014-0101}
- [net] sctp: fix sctp_connectx abi for ia32 emulation/compat mode (Daniel Borkmann) [1058284]
- [net] ip_tunnel: return more precise errno value when adding tunnel fails (Florian Westphal) [1070135]
- [net] ip_tunnel: Add fallback tunnels to the hash lists (Florian Westphal) [1070135]
- [net] openvswitch: Fix ovs_dp_cmd_msg_size() (Francesco Fusco) [1069577]
- [net] team: Don't allow team devices to change network namespaces (Jiri Pirko) [1069527]
- [net] team: add support for sending multicast rejoins (Jiri Pirko) [1069520]
- [net] convert resend IGMP to notifier event (Jiri Pirko) [1069520]
- [net] team: add peer notification (Jiri Pirko) [1069490]
- [net] team: remove synchronize_rcu() called during port disable (Jiri Pirko) [1069498]
- [net] team: use kfree_rcu instead of synchronize_rcu in team_port_dev (Jiri Pirko) [1069498]
- [net] team: remove synchronize_rcu() called during queue override change (Jiri Pirko) [1069498]
- [net] remove last caller of skb_tail_offset() and itself (Jiri Pirko) [1068666]
- [net] netpoll: fix position of network header (Jiri Pirko) [1068666]
- [net] neigh: fix setting of default gc_* values (Jiri Pirko) [1067274]

* Thu Mar 06 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-106.el7]
- [drm] nouveau/devinit: lock/unlock crtc regs for all devices, not just pre-nv50 (Ben Skeggs) [928744]
- [drm] nouveau: use correct register to determine DP display bpp (Ben Skeggs) [928744]
- [pci] Enable quirks for PCIe ACS on Intel PCH root ports (Alex Williamson) [1037684]
- [pci] Add pci_dev_flag for ACS enable quirks (Alex Williamson) [1037684]
- [pci] Add device-specific PCI ACS enable (Alex Williamson) [1037684]
- [virt] hyperv-fb: kick off efifb early (Gerd Hoffmann) [1038900]
- [virt] hyperv-fb: add support for generation 2 virtual machines (Gerd Hoffmann) [1038900]
- [virt] hv/vmbus: use resource for hyperv mmio region (Gerd Hoffmann) [1038900]
- [virt] hv/vmbus: add missing breaks (Gerd Hoffmann) [1038900]
- [virt] hv/vmbus: Extract the mmio information from DSDT (Gerd Hoffmann) [1038900]
- [s390] cio/blacklist: Perform subchannel scan only when needed (Hendrik Brueckner) [1071244]
- [s390] css: Prevent unnecessary allocation in subchannel loop (Hendrik Brueckner) [1071244]
- [s390] cio: Delay scan for newly available I/O devices (Hendrik Brueckner) [1071244]
- [s390] cio: Relax subchannel scan loop (Hendrik Brueckner) [1071244]
- [s390] cio: More efficient handling of CHPID availability events (Hendrik Brueckner) [1071244]
- [ethernet] cxgb4: Add API to correctly calculate tuple fields (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Account for stid entries properly in case of IPv6 (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Assign filter server TIDs properly (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Include TCP as protocol when creating server filters (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Reserve stid 0 for T4/T5 adapters (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Add new scheme to update T4/T5 firmware (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Much cleaner implementation of is_t4()/is_t5() (Jay Fenlason) [1060264]
- [ethernet] cgxb4: remove duplicate include in cxgb4.h (Jay Fenlason) [1060264]
- [ethernet] cxgb4: remove unnecessary pci_set_drvdata() (Jay Fenlason) [1060264]
- [ethernet] cxgb4: remove workqueue when driver registration fails (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Add CLIP support to store compressed IPv6 address (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Add routines to create and remove listening IPv6 servers (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Do not set net_device::dev_id to VI index (Jay Fenlason) [1060264]
- [ethernet] cxgb4: Force uninitialized state if FW_ON_ADAPTER is < FW_VERSION and we're the MASTER_PF (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Use cxgb4_select_ntuple to correctly calculate ntuple fields (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Server filters are supported only for IPv4 (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Calculate the filter server TID properly (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Make _c4iw_write_mem_dma() static (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Fix formatting of physical address (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Issue RI.FINI before closing when entering TERM (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Advertise ~0ULL as max MR size (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Always do GTS write if cidx_inc == CIDXINC_MASK (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Set arp error handler for PASS_ACCEPT_RPL messages (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Fix accounting for unsignaled SQ WRs to deal with wrap (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Fix QP flush logic (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Handle newer firmware changes (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Use correct bit shift macros for vlan filter tuples (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Add support for active and passive open connection with IPv6 address (Jay Fenlason) [1060264]
- [infiniband] cxgb4: Fix stack info leak in c4iw_create_qp() (Jay Fenlason) [1060264]
- [scsi] cxgb4i: add support for T5 adapter (Jay Fenlason) [1060264]
- [ethernet] cxgb4vf: added much cleaner implementation of is_t4() (Jay Fenlason) [1060264]
- [ethernet] cxgb4vf: use DEFINE_PCI_DEVICE_TABLE (Jay Fenlason) [1060264]
- [ethernet] cxgb4vf: remove unnecessary pci_set_drvdata() (Jay Fenlason) [1060264]
- [ethernet] cxgb4vf: Staticize local symbols (Jay Fenlason) [1060264]
- [infiniband] mlx5: Remove dependency on X86 (Doug Ledford) [1058614]
- [infiniband] mlx5: Add include of <linux/slab.h> because of kzalloc()/kfree() use (Doug Ledford) [1058614]
- [infiniband] mlx5: Don't set "block multicast loopback" capability (Doug Ledford) [1058614]
- [infiniband] mlx5: Fix binary compatibility with libmlx5 (Doug Ledford) [1058614]
- [infiniband] mlx5: Fix RC transport send queue overhead computation (Doug Ledford) [1058614]
- [infiniband] mlx5: Verify reserved fields are cleared (Doug Ledford) [1058614]
- [infiniband] mlx5: Remove old field for create mkey mailbox (Doug Ledford) [1058614]
- [infiniband] mlx5: Abort driver cleanup if teardown hca fails (Doug Ledford) [1058614]
- [infiniband] mlx5: Allow creation of QPs with zero-length work queues (Doug Ledford) [1058614]
- [ethernet] mlx5: Fix PowerPC support (Doug Ledford) [1058614]
- [ethernet] mlx5: Improve debugfs readability (Doug Ledford) [1058614]
- [infiniband] mlx5: Add support for resize CQ (Doug Ledford) [1058614]
- [infiniband] mlx5: Implement modify CQ (Doug Ledford) [1058614]
- [infiniband] mlx5: Make sure doorbell record is visible before doorbell (Doug Ledford) [1058614]
- [ethernet] mlx5: Use mlx5 core style warning (Doug Ledford) [1058614]
- [ethernet] mlx5: Clear out struct before create QP command (Doug Ledford) [1058614]
- [ethernet] mlx5: Fix out arg size in access_register command (Doug Ledford) [1058614]
- [infiniband] mlx5: Fix micro UAR allocator (Doug Ledford) [1058614]
- [ethernet] mlx5: Remove dead code (Doug Ledford) [1058614]
- [infiniband] mlx5: Remove unused code in mr.c (Doug Ledford) [1058614]
- [virt] kvm/x86: introduce periodic global clock updates (Andrew Jones) [1036457]
- [virt] kvm/x86: rate-limit global clock updates (Andrew Jones) [1036457]
- [mm] slub: fix page->_count corruption (again) (Rik van Riel) [1070918]
- [kernel] stop_machine: Fix^2 race between stop_two_cpus() and stop_cpus() (Rik van Riel) [1061778 1071454]
- [fs] proc/vmcore: prevent PT_NOTE p_memsz overflow during header update (Nigel Croxon) [1061368]
- [ioat] dma: check DMA mapping error in ioat_dma_self_test() (Kyle McMartin) [922694]
- [drm] nouveau/bios: add more checks to PRAMIN image fetching (Ben Skeggs) [1033345]
- [fs] block: Fix nr_vecs for inline integrity vectors (David Milburn) [1040893]

* Wed Mar 05 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-105.el7]
- [redhat] kabi: actually add symbols to the whitelists this time (Jarod Wilson) [726863]

* Tue Mar 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-104.el7]
- [redhat] kabi: add initial whitelist checksums (Jiri Olsa) [726863]

* Tue Mar 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-103.el7]
- [fs] epoll: do not take the nested ep->mtx on EPOLL_CTL_DEL (Rik van Riel) [1069371]
- [fs] epoll: do not take global 'epmutex' for simple topologies (Rik van Riel) [1069371]
- [fs] epoll: optimize EPOLL_CTL_DEL using rcu (Rik van Riel) [1069371]
- [fs] epoll: add a reschedule point in ep_free() (Rik van Riel) [1069371]
- [fs] eventpoll: switch epoll_ctl() to fdget (Rik van Riel) [1069371]
- [fs] eventpoll: do not use sigprocmask() (Rik van Riel) [1069371]
- [target] iscsi-target: Add demo-mode TPG authentication context support (Andy Grover) [1066726]
- [target] Add se_portal_group->tpg_auth_group (Andy Grover) [1066726]
- [mm] page-writeback: do not count anon pages as dirtyable memory (Johannes Weiner) [832482]
- [mm] page-writeback: fix dirty_balance_reserve subtraction from dirtyable memory (Johannes Weiner) [832482]
- [misc] stackprotector: Introduce CONFIG_CC_STACKPROTECTOR_STRONG (Jarod Wilson) [1069367]
- [misc] stackprotector: Unify the HAVE_CC_STACKPROTECTOR logic between architectures (Jarod Wilson) [1069367]
- [kernel] futexes: Fix futex_hashsize initialization (Larry Woodman) [1069800]
- [kernel] futexes: Avoid taking the hb->lock if there's nothing to wake up (Larry Woodman) [1069800]
- [kernel] futexes: Document multiprocessor ordering guarantees (Larry Woodman) [1069800]
- [kernel] futexes: Increase hash table size for better performance (Larry Woodman) [1069800]
- [kernel] futexes: Clean up various details (Larry Woodman) [1069800]
- [kernel] futex: move user address verification up to common code (Larry Woodman) [1069800]
- [kernel] futex: fix handling of read-only-mapped hugepages (Larry Woodman) [1069800]
- [powerpc] Support crashkernel auto memory reservation on a system with 2GB or more (Steve Best) [1051974]
- [powerpc] Set crashkernel 'auto' memory reservation threshold to 2GB (Steve Best) [1051974]
- [s390] cio: improve cio_commit_config (Hendrik Brueckner) [1064781]
- [s390] zfcpdump: Fix mount order for XFS and ext4 (Hendrik Brueckner) [1058307]
- [scsi] iSCSI connection errors on logout (Chris Leech) [1000356]
- [block] add padding to queue_limits structure (Mike Snitzer) [973669]
- [virt] kvm/nvmx: Fix pick-up of uninjected NMIs (Marcelo Tosatti) [1069089]
- [virt] kvm/svm: fix NMI window after iret (Radim Krcmar) [1049862]
- [mm] exclude memoryless nodes from zone_reclaim (Steve Best) [1070491]
- [x86] mm/srat: Skip NUMA_NO_NODE while parsing SLIT (Prarit Bhargava) [1063539]

* Tue Mar 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-102.el7]
- [ethernet] cxgb3: remove duplicate defines (Jay Fenlason) [1060263]
- [ethernet] cxgb3: remove unnecessary pci_set_drvdata() (Jay Fenlason) [1060263]
- [ethernet] cxgb3: Add __GFP_NOWARN to k.alloc calls with v.alloc fallbacks (Jay Fenlason) [1060263]
- [ethernet] cxgb3: Missing rtnl lock in error recovery (Jay Fenlason) [1060263]
- [infiniband] cxgb3: Fix stack info leak in iwch_create_cq() (Jay Fenlason) [1060263]
- [infiniband] cxgb3: Timeout condition is never true (Jay Fenlason) [1060263]
- [ethernet] qlcnic: Update version to 5.3.48.2 (Chad Dupuis) [1063848]
- [ethernet] qlcnic: Fix tx timeout (Chad Dupuis) [1063848]
- [ethernet] qlcnic: Fix diagnostic test for all adapters (Chad Dupuis) [1063848]
- [ethernet] qlcnic: Fix VF reset recovery (Chad Dupuis) [1063848]
- [ethernet] qlcnic: underflow in qlcnic_validate_max_tx_rings() (Chad Dupuis) [1063848]
- [ethernet] qlcnic: Fix backporting BUG while doing inbox submission upto 5.3.48 (Chad Dupuis) [1063848]
- [pci] pciehp: Add hotplug_lock to serialize hotplug events (Myron Stowe) [1061514]
- [pci] pciehp: Ensure very fast hotplug events are also processed (Myron Stowe) [1061514]
- [pci] pciehp: Disable link notification across slot reset (Myron Stowe) [1061514]
- [pci] pciehp: Don't check adapter or latch status while disabling (Myron Stowe) [1061514]
- [pci] pciehp: Don't disable the link permanently during removal (Myron Stowe) [1061514]
- [pci] pciehp: Enable link state change notifications (Myron Stowe) [1061514]
- [pci] pciehp: Use link change notifications for hot-plug and removal (Myron Stowe) [1061514]
- [pci] pciehp: Make check_link_active() non-static (Myron Stowe) [1061514]
- [pci] pciehp: Move Attention & Power Indicator support tests to accessors (Myron Stowe) [1061514]
- [pci] pciehp: Use symbolic constants for Slot Control fields (Myron Stowe) [1061514]
- [pci] pciehp: Use symbolic constants, not hard-coded bitmask (Myron Stowe) [1061514]
- [pci] pciehp: Simplify "Power Fault Detected" checking/clearing (Myron Stowe) [1061514]
- [pci] pciehp: Announce slot capabilities (slot #, button, LEDs, etc) (Myron Stowe) [1061514]
- [pci] pciehp: Make various functions void since they can't fail (Myron Stowe) [1061514]
- [pci] pciehp: Remove error checks when accessing PCIe Capability (Myron Stowe) [1061514]
- [pci] pciehp: Drop pciehp_readw()/pciehp_writew() wrappers (Myron Stowe) [1061514]
- [drm] mgag200: on cards with < 2MB VRAM default to 16-bit (Dave Airlie) [1056356]
- [drm] cirrus: correct register values for 16bpp (Dave Airlie) [1056352]
- [infiniband] mlx4: Build the port IBoE GID table properly under bonding (Doug Ledford) [1061729]
- [infiniband] mlx4: Do IBoE GID table resets in port based manner (Doug Ledford) [1061729]
- [infiniband] mlx4: Do IBoE locking earlier when initializing the GID table (Doug Ledford) [1061729]
- [infiniband] mlx4: Move rtnl locking to the right location (Doug Ledford) [1061729]
- [infiniband] mlx4: Make sure GID index 0 is always occupied (Doug Ledford) [1061729]
- [infiniband] mlx4: Report using RoCE IP based gids in port caps (Doug Ledford) [1061729]
- [mm] thp: fix infinite loop on memcg OOM (Motohiro Kosaki) [1054655]
- [mm] thp: count thp_fault_fallback anytime thp fault fails (Motohiro Kosaki) [1054655]
- [mm] thp: consolidate code between handle_mm_fault() and, do_huge_pmd_anonymous_page() (Motohiro Kosaki) [1054655]
- [mm] thp: do_huge_pmd_anonymous_page() cleanup (Motohiro Kosaki) [1054655]
- [fs] nfs: fix error return in nfs4_select_rw_stateid (Steve Dickson) [1071041]
- [fs] nfs: Use the correct net namespace in nfs4_update_server (Steve Dickson) [1071041]
- [net] sunrpc: Fix a pipe_version reference leak (Steve Dickson) [1071041]
- [net] sunrpc: Fix races in xs_nospace() (Steve Dickson) [1071041]
- [fs] nfs: Do not set NFS_INO_INVALID_LABEL unless server supports labeled NFS (Steve Dickson) [1071041]
- [target] iscsi: Fix network portal creation race (Andy Grover) [1055064]
- [ethernet] bnx2x: Add missing bit in default Tx switching (Michal Schmidt) [1070726]
- [pci] dev_num_vf needs to return an int, not a bool (Alex Williamson) [1066825]
- [kernel] cgroup: update cgroup_enable_task_cg_lists() to grab siglock (Rik van Riel) [1070919]
- [powerpc] mm: Fix mmap errno when MAP_FIXED is set and mapping exceeds the allowed address space (Jerome Marchand) [1053681]

* Mon Mar 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-101.el7]
- [fs] btrfs: fix the race between write back and nocow buffered write (Zach Brown) [1051406]
- [fs] btrfs: fix the wrong nocow range check (Zach Brown) [1051406]
- [fs] btrfs: fix the reserved space leak caused by the race between nonlock dio and buffered io (Zach Brown) [1051406]
- [fs] btrfs: cleanup unnecessary parameter and variant of prepare_pages() (Zach Brown) [1051406]
- [fs] btrfs: fix access_ok() check in btrfs_ioctl_send() (Zach Brown) [1051282]
- [fs] btrfs: make sure we cleanup all reloc roots if error happens (Zach Brown) [1051282]
- [fs] btrfs: skip building backref tree for uuid and quota tree when doing balance relocation (Zach Brown) [1051282]
- [fs] btrfs: fix an oops when doing balance relocation (Zach Brown) [1051282]
- [fs] btrfs: don't miss skinny extent items on delayed ref head contention (Zach Brown) [1051282]
- [fs] btrfs: call mnt_drop_write after interrupted subvol deletion (Zach Brown) [1051282]
- [fs] btrfs: don't clear the default compression type (Zach Brown) [1051282]
- [fs] btrfs: backport of btrfs part of "block: submit_bio_wait() conversions" (Zach Brown) [1051282]
- [Documentation] filesystems: update btrfs tools section (Zach Brown) [1051282]
- [Documentation] filesystems: add new btrfs mount options (Zach Brown) [1051282]
- [fs] btrfs: update kconfig help text (Zach Brown) [1051282]
- [fs] btrfs: fix bio_size_ok() for max_sectors > 0xffff (Zach Brown) [1051282]
- [fs] btrfs: Use trace condition for get_extent tracepoint (Zach Brown) [1051282]
- [fs] btrfs: fix typo in the log message (Zach Brown) [1051282]
- [fs] btrfs: fix list delete warning when removing ordered root from the list (Zach Brown) [1051282]
- [fs] btrfs: print bytenr instead of page pointer in check-int (Zach Brown) [1051282]
- [fs] btrfs: remove dead codes from ctree.h (Zach Brown) [1051282]
- [fs] btrfs: don't wait for ordered data outside desired range (Zach Brown) [1051282]
- [fs] btrfs: fix lockdep error in async commit (Zach Brown) [1051282]
- [fs] btrfs: avoid heavy operations in btrfs_commit_super (Zach Brown) [1051282]
- [fs] btrfs: fix __btrfs_start_workers retval (Zach Brown) [1051282]
- [fs] btrfs: disable online raid-repair on ro mounts (Zach Brown) [1051282]
- [fs] btrfs: do not inc uncorrectable_errors counter on ro scrubs (Zach Brown) [1051282]
- [fs] btrfs: only drop modified extents if we logged the whole inode (Zach Brown) [1051282]
- [fs] btrfs: make sure to copy everything if we rename (Zach Brown) [1051282]
- [fs] btrfs: don't BUG_ON() if we get an error walking backrefs (Zach Brown) [1051282]
- [fs] btrfs: get rid of fdentry() (Zach Brown) [1051282]
- [fs] btrfs: fix empty_zero_page misusage (Zach Brown) [1051282]
- [fs] btrfs: rename btrfs_start_all_delalloc_inodes (Zach Brown) [1051282]
- [fs] btrfs: don't wait for the completion of all the ordered extents (Zach Brown) [1051282]
- [fs] btrfs: don't wait for all the async delalloc when shrinking delalloc (Zach Brown) [1051282]
- [fs] btrfs: fix the confusion between delalloc bytes and metadata bytes (Zach Brown) [1051282]
- [fs] btrfs: pick up the code for the item number calculation in flush_space() (Zach Brown) [1051282]
- [fs] btrfs: wait for the ordered extent only when we want (Zach Brown) [1051282]
- [fs] btrfs: remove unnecessary initialization and memory barrier in shrink_delalloc() (Zach Brown) [1051282]
- [fs] btrfs: avoid unnecessary scrub workers allocation (Zach Brown) [1051282]
- [fs] btrfs: check file extent type before anything else (Zach Brown) [1051282]
- [fs] btrfs: Remove useless variable in write_ctree_super() (Zach Brown) [1051282]
- [fs] btrfs: Fix checkpatch.pl warning of spacing issues (Zach Brown) [1051282]
- [fs] btrfs: Replace kmalloc with kmalloc_array (Zach Brown) [1051282]
- [fs] btrfs: Enclose macros with complex values within parenthesis (Zach Brown) [1051282]
- [fs] btrfs: Use WARN_ON()'s return value in place of WARN_ON(1) (Zach Brown) [1051282]
- [fs] btrfs: Remove redundant local zero structure (Zach Brown) [1051282]
- [fs] btrfs: Pack struct btrfs_device (Zach Brown) [1051282]
- [fs] btrfs: Replace multiple atomic_inc() with atomic_add() (Zach Brown) [1051282]
- [fs] btrfs: Add helper function for free_root_pointers() (Zach Brown) [1051282]
- [fs] btrfs: fix a crash when running balance and defrag concurrently (Zach Brown) [1051282]
- [fs] btrfs: do not run snapshot-aware defragment on error (Zach Brown) [1051282]
- [fs] btrfs: log recovery, don't unlink inode always on error (Zach Brown) [1051282]
- [fs] btrfs: fix csum search offset/length calculation in log tree (Zach Brown) [1051282]
- [fs] btrfs: fix verification of dir_item (Zach Brown) [1051282]
- [fs] btrfs: remove scrub_super_lock holding in btrfs_sync_log() (Zach Brown) [1051282]
- [fs] btrfs: use 'u64' rather than 'int' to get extent's generation (Zach Brown) [1051282]
- [fs] btrfs: fix the free space write out failure when there is no data space (Zach Brown) [1051282]
- [fs] btrfs: stop committing the transaction so much during relocate (Zach Brown) [1051282]
- [fs] btrfs: make sure the delalloc workers actually flush compressed writes (Zach Brown) [1051282]
- [fs] btrfs: take ordered root lock when removing ordered operations inode (Zach Brown) [1051282]
- [fs] btrfs: don't abort transaction in run_delalloc_nocow (Zach Brown) [1051282]
- [fs] btrfs: do not bug_on if we try to cow a free space cache inode (Zach Brown) [1051282]
- [fs] btrfs: return an error from btrfs_wait_ordered_range (Zach Brown) [1051282]
- [fs] btrfs: stop using vfs_read in send (Zach Brown) [1051282]
- [fs] btrfs: check_int, remove warning for mixed-mode (Zach Brown) [1051282]
- [fs] btrfs: fix check_int 'leaf item out of bounce' regression (Zach Brown) [1051282]
- [fs] btrfs: optimize extent item search in run_delayed_extent_op (Zach Brown) [1051282]
- [fs] btrfs: add tracing for failed reservations (Zach Brown) [1051282]
- [fs] btrfs: remove fs/btrfs/compat.h (Zach Brown) [1051282]
- [fs] btrfs: remove move_pages() (Zach Brown) [1051282]
- [fs] btrfs: use get_seconds() instead of btrfs wrapper (Zach Brown) [1051282]
- [fs] btrfs: fix incorrect inode acl reset (Zach Brown) [1051282]
- [fs] btrfs: Don't allocate inode that is already in use (Zach Brown) [1051282]
- [fs] btrfs: fix btrfs_prev_leaf() previous key computation (Zach Brown) [1051282]
- [fs] btrfs: optimize tree-log.c:count_inode_refs() (Zach Brown) [1051282]
- [fs] btrfs: simplify kmalloc+copy_from_user to memdup_user (Zach Brown) [1051282]
- [fs] btrfs: btrfs_add_ordered_operation, Fix last modified transaction comparison (Zach Brown) [1051282]
- [fs] btrfs: don't leak delayed node on path allocation failure (Zach Brown) [1051282]
- [fs] btrfs: Wait for uuid-tree rebuild task on remount read-only (Zach Brown) [1051282]
- [fs] btrfs: init device stats for new devices (Zach Brown) [1051282]
- [fs] btrfs: fixup error path in __btrfs_inc_extent_ref (Zach Brown) [1051282]
- [fs] btrfs: disallow 'btrfs (balance, replace) cancel' on ro mounts (Zach Brown) [1051282]
- [fs] btrfs: don't leak ioctl args in btrfs_ioctl_dev_replace (Zach Brown) [1051282]
- [fs] btrfs: nuke a bogus rw_devices decrement in __btrfs_close_devices (Zach Brown) [1051282]
- [fs] btrfs: Fix memory leakage in the tree-log.c (Zach Brown) [1051282]
- [fs] btrfs: kill unused code in btrfs_search_forward (Zach Brown) [1051282]
- [fs] btrfs: cleanup dead code of defragment (Zach Brown) [1051282]
- [fs] btrfs: remove unnecessary key copy when logging inode (Zach Brown) [1051282]
- [fs] btrfs: Simplify the logic in alloc_extent_buffer() for existing extent buffer case (Zach Brown) [1051282]
- [fs] btrfs: fix up seek_hole/seek_data handling (Zach Brown) [1051282]
- [fs] btrfs: add an assert to btrfs_lookup_csums_range for alignment (Zach Brown) [1051282]
- [fs] btrfs: fix hole check in log_one_extent (Zach Brown) [1051282]
- [fs] btrfs: add a sanity test for a vacant extent at the front of a file (Zach Brown) [1051282]
- [fs] btrfs: handle a missing extent for the first file extent (Zach Brown) [1051282]
- [fs] btrfs: stop all workers after we free block groups (Zach Brown) [1051282]
- [fs] btrfs: add tests for btrfs_get_extent (Zach Brown) [1051282]
- [fs] btrfs: add tests for find_lock_delalloc_range (Zach Brown) [1051282]
- [fs] btrfs: free reserved space on error in a few places (Zach Brown) [1051282]
- [fs] btrfs: fixup reserved trace points (Zach Brown) [1051282]
- [fs] btrfs: free up block groups after everything (Zach Brown) [1051282]
- [fs] btrfs: cleanup reserved space when freeing tree log on error (Zach Brown) [1051282]
- [fs] btrfs: do not free the dirty bytes from the trans block rsv on cleanup (Zach Brown) [1051282]
- [fs] btrfs: fix memory leaks on transaction commit failure (Zach Brown) [1051282]
- [fs] btrfs: fix the dev-replace suspend sequence (Zach Brown) [1051282]
- [fs] btrfs: improve inode hash function/inode lookup (Zach Brown) [1051282]
- [fs] btrfs: remove unnecessary tree search when logging inode (Zach Brown) [1051282]
- [fs] btrfs: remove unused max_key arg from btrfs_search_forward (Zach Brown) [1051282]
- [fs] btrfs: fix memory leak of chunks' extent map (Zach Brown) [1051282]
- [fs] btrfs: improve jitter performance of the sequential buffered write (Zach Brown) [1051282]
- [fs] btrfs: fix BUG_ON() casued by the reserved space migration (Zach Brown) [1051282]
- [fs] btrfs: remove unused parameter from btrfs_header_fsid (Zach Brown) [1051282]
- [fs] btrfs: fix two use-after-free bugs with transaction cleanup (Zach Brown) [1051282]
- [fs] btrfs: remove all BUG_ON()'s from commit_cowonly_roots (Zach Brown) [1051282]
- [fs] btrfs: don't delete ordered roots from list during cleanup (Zach Brown) [1051282]
- [fs] btrfs: cleanup transaction on abort (Zach Brown) [1051282]
- [fs] btrfs: do not release metadata for space cache inodes (Zach Brown) [1051282]
- [fs] btrfs: reset intwrite on transaction abort (Zach Brown) [1051282]
- [fs] btrfs: don't leak block group on error (Zach Brown) [1051282]
- [fs] btrfs: fix sync fs to actually wait for all data to be persisted (Zach Brown) [1051282]
- [fs] btrfs: fix tracking of orphan inode count (Zach Brown) [1051282]
- [fs] btrfs: export btrfs space shared info to userspace (Zach Brown) [1051282]
- [fs] btrfs: remove path arg from btrfs_truncate_free_space_cache (Zach Brown) [1051282]
- [fs] btrfs: remove duplicated ino cache's inode lookup (Zach Brown) [1051282]
- [fs] btrfs: do a full search everytime in btrfs_search_old_slot (Zach Brown) [1051282]
- [fs] btrfs: add a sanity test for btrfs_split_item (Zach Brown) [1051282]
- [fs] btrfs: drop unused parameter from btrfs_item_nr (Zach Brown) [1051282]
- [fs] btrfs: don't store NULL byte in symlink extents (Zach Brown) [1051282]
- [fs] btrfs: eliminate the exceptional root_tree refs=0 (Zach Brown) [1051282]

* Mon Mar 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-100.el7]
- [scsi] report sense even for TEST UNIT READY commands (Ewan Milne) [1070982]
- [bfa] Fix for crash during sfpshow command (Chad Dupuis) [1065950]
- [mm] fix GFP_THISNODE callers and clarify (Johannes Weiner) [1069551 1069639]
- [mm] page_alloc: exempt GFP_THISNODE allocations from zone fairness (Johannes Weiner) [1069551 1069639]
- [scsi] reserve space in structures for future scsi-mq changes (Mike Snitzer) [1071014]
- [block] remove unprep_rq_fn (Mike Snitzer) [1071014]
- [scsi] reintroduce scsi_driver.init_command (Mike Snitzer) [1071014]
- [block] blk-mq: support partial I/O completions (Mike Snitzer) [1071014]
- [block] blk-mq: merge blk_mq_insert_request and blk_mq_run_request (Mike Snitzer) [1071014]
- [block] blk-mq: remove blk_mq_alloc_rq (Mike Snitzer) [1071014]
- [block] blk-mq: pair blk_mq_start_request / blk_mq_requeue_request (Mike Snitzer) [1071014]
- [block] blk-mq: dont assume rq->errors is set when returning an error from ->queue_rq (Mike Snitzer) [1071014]
- [block] Fix type mismatch in ssize_t_blk_mq_tag_sysfs_show (Mike Snitzer) [1071014]
- [block] blk-mq: rework flush sequencing logic (Mike Snitzer) [1071014]
- [block] null_blk: use blk_complete_request and blk_mq_complete_request (Mike Snitzer) [1071014]
- [block] blk-mq: rework I/O completions (Mike Snitzer) [1071014]
- [block] null_blk: Fix completion processing from LIFO to FIFO (Mike Snitzer) [1071014]
- [lib] llist: move llist_reverse_order from raid5 to llist.c (Mike Snitzer) [1071014]
- [lib] llist: llist_add() can use llist_add_batch() (Mike Snitzer) [1071014]
- [lib] llist: fix_simplify llist_add() and llist_add_batch() (Mike Snitzer) [1071014]
- [block] blk-mq: Add bio_integrity setup to blk_mq_make_request (Mike Snitzer) [1071014]
- [block] blk-mq: initialize sg_reserved_size (Mike Snitzer) [1071014]
- [block] blk-mq: handle dma_drain_size (Mike Snitzer) [1071014]
- [block] blk-mq: divert __blk_put_request for MQ ops (Mike Snitzer) [1071014]
- [block] blk-mq: support at_head inserations for blk_execute_rq (Mike Snitzer) [1071014]
- [block] null_blk: Null pointer deference problem in alloc_page_buffers (Mike Snitzer) [1071014]
- [block] null_blk: fix queue leak inside removing device (Mike Snitzer) [1071014]
- [block] null_blk: support submit_queues on use_per_node_hctx (Mike Snitzer) [1071014]
- [block] null_blk: set use_per_node_hctx param to false (Mike Snitzer) [1071014]
- [block] null_blk: warning on ignored submit_queues param (Mike Snitzer) [1071014]
- [block] null_blk: refactor init and init errors code paths (Mike Snitzer) [1071014]
- [block] null_blk: mem garbage on NUMA systems during init (Mike Snitzer) [1071014]
- [block] null_blk: corrections to documentation (Mike Snitzer) [1071014]
- [block] null_blk: documentation (Mike Snitzer) [1071014]
- [block] null_blk: fix differences between RHEL7 and upstream (Mike Snitzer) [1071014]
- [target] iscsi-target: Fix connection reset hang with percpu_ida_alloc (Mike Snitzer) [1071014]
- [lib] percpu_ida: Make percpu_ida_alloc + callers accept task state bitmask (Mike Snitzer) [1071014]
- [lib] percpu_ida: Removing unused arguement from alloc_local_tag (Mike Snitzer) [1071014]
- [block] blk-mq: use hotcpu_notifier() (Mike Snitzer) [1071014]
- [block] blk-mq: uses page->list incorrectly (Mike Snitzer) [1071014]
- [block] blk-mq: use __smp_call_function_single directly (Mike Snitzer) [1071014]
- [kernel] provide a __smp_call_function_single stub for !CONFIG_SMP (Mike Snitzer) [1071014]
- [block] blk-mq: fix initializing request's start time (Mike Snitzer) [1071014]
- [block] blk-mq: don't export blk_mq_free_queue() (Mike Snitzer) [1071014]
- [block] blk-mq: make blk_sync_queue support mq (Mike Snitzer) [1071014]
- [block] blk-mq: support draining mq queue (Mike Snitzer) [1071014]
- [virt] kvm/x86: emulator_cmpxchg_emulated should mark_page_dirty (Marcelo Tosatti) [994431]
- [x86] irq: Fix kbuild warning in smp_irq_move_cleanup_interrupt() (Prarit Bhargava) [1065735]
- [security] selinux: put the mmap() DAC controls before the MAC controls (Paul Moore) [1070827]
- [infiniband] iser: Avoid dereferncing iscsi_iser conn object when not bound to iser connection (Doug Ledford) [1061129]
- [mm] Use ptep/pmdp_set_numa() for updating _PAGE_NUMA bit (Steve Best) [1049012]
- [mm] Dirty accountable change only apply to non prot numa case (Steve Best) [1049012]
- [powerpc] mm: Add new "set" flag argument to pte/pmd update function (Steve Best) [1049012]
- [powerpc] mm: Enable _PAGE_NUMA for book3s (Steve Best) [1049012]
- [powerpc] mm: Only check for _PAGE_PRESENT in set_pte/pmd functions (Steve Best) [1049012]
- [powerpc] mm: Free up _PAGE_COHERENCE for numa fault use later (Steve Best) [1049012]
- [powerpc] mm: Use HPTE constants when updating hpte bits (Steve Best) [1049012]
- [mm] Move change_prot_numa outside CONFIG_ARCH_USES_NUMA_PROT_NONE (Steve Best) [1049012]

* Fri Feb 28 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-99.el7]
- [target] Pass through I/O topology for block backstores (Andy Grover) [873474]
- [target] iscsi-target: ST response on IN6ADDR_ANY socket (Andy Grover) [913033]
- [security] keys: Fix searching of nested keyrings (David Howells) [1033467]
- [security] keys: Fix multiple key add into associative array (David Howells) [1033467]
- [security] keys: Fix the keyring hash function (David Howells) [1033467]
- [ethernet] bnx2x: Fix generic option settings (Michal Schmidt) [1066076]
- [tools] perf/kvm: Fix kvm report without guestmount (Jiri Olsa) [1051298]
- [mm] readahead: fix readahead failure for memoryless NUMA nodes and limit readahead pages (Steve Best) [1062288]
- [ethernet] Mark Intel DH8900CC Series Gigabit Network Device Unsupported (Prarit Bhargava) [727275]
- [drm] nouveau/mxm: fix null deref on load (Ben Skeggs) [1067807]
- [ethernet] i40e: Fix device ID define names to align to standard (Stefan Assmann) [1057192]
- [ethernet] i40e: add DCB option to Kconfig (Stefan Assmann) [1057192]
- [ethernet] i40e: add DCB and DCBNL support (Stefan Assmann) [1057192]
- [ethernet] i40e: implement DCB support infastructure (Stefan Assmann) [1057192]
- [ethernet] i40e: refactor flow director (Stefan Assmann) [1057192]
- [ethernet] i40e: rename defines (Stefan Assmann) [1057192]
- [ethernet] i40e: whitespace fixes (Stefan Assmann) [1057192]
- [ethernet] i40e: Change firmware workaround (Stefan Assmann) [1057192]
- [ethernet] i40e: fix compile warning on checksum_local (Stefan Assmann) [1057192]
- [ethernet] i40e: updates to AdminQ interface (Stefan Assmann) [1057192]
- [ethernet] i40e: check desc pointer before printing (Stefan Assmann) [1057192]
- [ethernet] i40e: delete non-required instances of include <linux/init.h> (Stefan Assmann) [1057192]
- [ethernet] i40e: Retain MAC filters on port VLAN deletion (Stefan Assmann) [1057192]
- [ethernet] i40e: Warn admin to reload VF driver on port VLAN configuration (Stefan Assmann) [1057192]
- [ethernet] i40e: Bump version number (Stefan Assmann) [1057192]
- [ethernet] i40e: trivial cleanup (Stefan Assmann) [1057192]
- [ethernet] i40e: whitespace fixes (Stefan Assmann) [1057192]
- [ethernet] i40e: make message meaningful (Stefan Assmann) [1057192]
- [ethernet] i40e: associate VMDq queue with VM type (Stefan Assmann) [1057192]
- [ethernet] i40e: remove extra register write (Stefan Assmann) [1057192]
- [ethernet] i40e: Bump version (Stefan Assmann) [1057192]
- [ethernet] i40e: fix log message wording (Stefan Assmann) [1057192]
- [ethernet] i40e: enable PTP (Stefan Assmann) [1057192]
- [ethernet] i40e: call clear_pxe after adminq is initialized (Stefan Assmann) [1057192]
- [ethernet] i40e: clear qtx_head before enabling Tx queue (Stefan Assmann) [1057192]
- [ethernet] i40e: adjust ITR max and min values (Stefan Assmann) [1057192]
- [ethernet] i40e: check for possible incorrect ipv6 checksum (Stefan Assmann) [1057192]
- [ethernet] i40e: allow VF to remove any MAC filter (Stefan Assmann) [1057192]
- [ethernet] i40e: do not bail when disabling if Tx queue disable fails (Stefan Assmann) [1057192]
- [ethernet] i40e: Setting queue count to 1 using ethtool is valid (Stefan Assmann) [1057192]
- [ethernet] i40e: Cleanup Doxygen warnings (Stefan Assmann) [1057192]
- [ethernet] i40e: fix long lines (Stefan Assmann) [1057192]
- [ethernet] i40e: Bump version (Stefan Assmann) [1057192]
- [ethernet] i40e: Update the Current NVM version Low value (Stefan Assmann) [1057192]
- [ethernet] i40e: drop unused macros (Stefan Assmann) [1057192]
- [ethernet] i40e: use assignment instead of memcpy (Stefan Assmann) [1057192]
- [ethernet] i40e: Turn flow director off in MFP mode (Stefan Assmann) [1057192]
- [ethernet] i40e: Add a dummy packet template (Stefan Assmann) [1057192]
- [ethernet] i40e: fix spelling errors (Stefan Assmann) [1057192]
- [ethernet] i40e: formatting and checkpatch fixes (Stefan Assmann) [1057192]
- [ethernet] i40e: shorten wordy fields (Stefan Assmann) [1057192]
- [ethernet] i40e: accept pf to pf adminq messages (Stefan Assmann) [1057192]
- [ethernet] i40e: remove interrupt on AQ error (Stefan Assmann) [1057192]
- [ethernet] i40e: release NVM resource reservation on startup (Stefan Assmann) [1057192]
- [ethernet] i40e: Cleanup reconfig rss path (Stefan Assmann) [1057192]
- [ethernet] i40e: disable packet split (Stefan Assmann) [1057192]
- [ethernet] i40e: add a comment on barrier and fix panic on reset (Stefan Assmann) [1057192]
- [ethernet] i40e: Fix MAC format in Write MAC address AQ cmd (Stefan Assmann) [1057192]
- [ethernet] i40e: Fix GPL header (Stefan Assmann) [1057192]
- [ethernet] i40e: use kernel specific defines (Stefan Assmann) [1057192]
- [ethernet] i40e: Re-enable interrupt on ICR0 (Stefan Assmann) [1057192]

* Thu Feb 27 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-98.el7]
- [scsi] qla4xxx: v5.04.00.04.07.00-k0 (Chad Dupuis) [1063205]
- [scsi] qla4xxx: Initialize hardware queue for ISP40XX (Chad Dupuis) [1063205]
- [fs] cifs: mask off top byte in get_rfc1002_length() (Sachin Prabhu) [1062588] {CVE-2014-0069}
- [infiniband] mlx4: Add support for steerable IB UD QPs (Doug Ledford) [1058518]
- [infiniband] mlx4: Add mechanism to support flow steering over IB links (Doug Ledford) [1058518]
- [infiniband] mlx4: Enable device-managed steering support for IB ports too (Doug Ledford) [1058518]
- [ethernet] mlx4: Add support for steerable IB UD QPs (Doug Ledford) [1058518]
- [infiniband] core: Add support for IB L2 device-managed steering (Doug Ledford) [1058518]
- [infiniband] core: Add flow steering support for IPoIB UD traffic (Doug Ledford) [1058518]
- [scsi] isci: correct erroneous for_each_isci_host macro (David Milburn) [1054302]
- [virt] vhost/net: disable zero copy by default (Jason Wang) [1069045]
- [x86] cpu-hotplug: Fix stack frame warning in check_irq_vectors_for_cpu_disable() (Prarit Bhargava) [1061317]
- [drm] radeon/kms: add crtc_disable function for legacy crtc (Jerome Glisse) [1029570]
- [drm] radeon/kms: unpin fb in atombios crtc disable (Jerome Glisse) [1029570]
- [powerpc] Fix 32-bit frames for signals delivered when transactional (Steve Best) [1059703]
- [edac] Correct workqueue setup path (Aristeu Rozanski) [1055892]
- [edac] Poll timeout cannot be zero, p2 (Aristeu Rozanski) [1055892]
- [edac] edac_mc_sysfs: poll timeout cannot be zero (Aristeu Rozanski) [1055892]

* Tue Feb 25 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-97.el7]
- [fs] cifs: sanity check length of data to send before sending (Sachin Prabhu) [1062588] {CVE-2014-0069}
- [fs] cifs: ensure that uncached writes handle unmapped areas correctly (Sachin Prabhu) [1062588] {CVE-2014-0069}
- [fs] cifs: set FILE_CREATED (Sachin Prabhu) [1065982]
- [fs] ext4: Disable punch hole on non-extent mapped files (Lukas Czerner) [1033438]
- [fs] Fix mountpoint reference leakage in linkat (Jeff Layton) [1063287]
- [fs] NFSD/sunrpc: avoid deadlock on TCP connection due to memory pressure ("J. Bruce Fields") [994257]
- [fs] nfsd: consider CLAIM_FH when handing out delegation ("J. Bruce Fields") [1031097]
- [fs] nfsd4: minor nfs4_setlease cleanup ("J. Bruce Fields") [1031097]
- [fs] nfsd4: need to destroy revoked delegations in destroy_client ("J. Bruce Fields") [1031097]
- [fs] nfsd: no need to unhash_stid before free ("J. Bruce Fields") [1031097]
- [fs] nfsd: nfs4_open_delegation needs to remove_stid rather than unhash_stid ("J. Bruce Fields") [1031097]
- [fs] nfsd: nfs4_free_stid ("J. Bruce Fields") [1031097]
- [fs] nfsd4: fix leak of inode reference on delegation failure ("J. Bruce Fields") [1031097]
- [fs] nfsd4: fix setlease error return ("J. Bruce Fields") [1031097]
- [fs] nfsd4: fix delegation-unlink/rename race ("J. Bruce Fields") [1031097]
- [fs] nfsd4: delay setting current_fh in open ("J. Bruce Fields") [1031097]
- [fs] nfsd4: break only delegations when appropriate ("J. Bruce Fields") [1031097]
- [fs] nfsd: make sure to balance get/put_write_access ("J. Bruce Fields") [1031097]
- [fs] nfsd: split up nfsd_setattr ("J. Bruce Fields") [1031097]
- [fs] locks: break delegations on any attribute modification ("J. Bruce Fields") [1031097]
- [fs] locks: break delegations on link ("J. Bruce Fields") [1031097]
- [fs] locks: break delegations on rename ("J. Bruce Fields") [1031097]
- [fs] locks: helper functions for delegation breaking ("J. Bruce Fields") [1031097]
- [fs] locks: break delegations on unlink ("J. Bruce Fields") [1031097]
- [fs] namei: minor vfs_unlink cleanup ("J. Bruce Fields") [1031097]
- [fs] locks: implement delegations ("J. Bruce Fields") [1031097]
- [fs] locks: introduce new FL_DELEG lock flag ("J. Bruce Fields") [1031097]
- [fs] vfs: take i_mutex on renamed file ("J. Bruce Fields") [1031097]
- [fs] vfs: rename I_MUTEX_QUOTA now that it's not used for quotas ("J. Bruce Fields") [1031097]
- [fs] vfs: don't use PARENT/CHILD lock classes for non-directories ("J. Bruce Fields") [1031097]
- [fs] vfs: pull ext4's double-i_mutex-locking into common code ("J. Bruce Fields") [1031097]
- [fs] ext4: fix FITRIM in no journal mode (Lukas Czerner) [1044519]
- [fs] ext4: add ratelimiting to ext4 messages (Lukas Czerner) [1044513]
- [fs] ext4: rate limit printk in buffer_io_error() (Lukas Czerner) [1044513]
- [fs] ext4: translate flag bits to strings in tracepoints (Lukas Czerner) [1044505]
- [fs] ext4: Fix fsync error handling after filesystem abort (Lukas Czerner) [1044501]

* Tue Feb 25 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-96.el7]
- [x86] Makefile: add -Werror to compile (Prarit Bhargava) [1006333]
- [edac] sb_edac: Shut up compiler warning when EDAC_DEBUG is enabled (Prarit Bhargava) [1006333]
- [kernel] mutex: Avoid label warning when !CONFIG_MUTEX_SPIN_ON_OWNER (Prarit Bhargava) [1006333]
- [infiniband] ocrdma: Fix compiler warning (Prarit Bhargava) [1006333]
- [isdn] hfcpci_softirq: get func return to suppress compiler warning (Prarit Bhargava) [1006333]
- [x86] Fix return value in generic_processor_info() (Prarit Bhargava) [1006333]
- [wireless] rtlwifi: initialize local array and set value (Prarit Bhargava) [1006333]
- [ethernet] mlx4: clean up srq_res_start_move_to() (Prarit Bhargava) [1006333]
- [ethernet] mlx4: clean up cq_res_start_move_to() (Prarit Bhargava) [1006333]
- [powerpc] Link VDSOs at 0x0 (Steve Best) [1066468]
- [powerpc] Use unstripped VDSO image for more accurate profiling data (Steve Best) [1066468]
- [scsi] fnic: Incremented driver version (Chris Leech) [831836]
- [scsi] fnic: Fnic Statistics Collection (Chris Leech) [831836]
- [scsi] fnic: host reset returns nonzero value(errno) on (Chris Leech) [831836]
- [scsi] fnic: Convert uses of compare_ether_addr to ether_addr_equal (Chris Leech) [831836]
- [scsi] fnic: remove unnecessary pci_set_drvdata() (Chris Leech) [831836]
- [scsi] fnic: fnic Driver Tuneables Exposed through CLI (Chris Leech) [831836]
- [scsi] fnic: Kernel panic while running sh/nosh with max lun (Chris Leech) [831836]
- [scsi] fnic: Hitting BUG_ON(io_req->abts_done) in (Chris Leech) [831836]
- [scsi] fnic: Remove QUEUE_FULL handling code (Chris Leech) [831836]
- [scsi] fnic: On system with >1.1TB RAM, VIC fails multipath (Chris Leech) [831836]
- [scsi] fnic: FC stat param seconds_since_last_reset not (Chris Leech) [831836]
- [scsi] fnic: BUG, sleeping function called from invalid (Chris Leech) [831836]
- [scsi] fnic: switch to fixed_size_llseek() (Chris Leech) [831836]
- [scsi] fnic: potential dead lock in fnic_is_abts_pending() (Chris Leech) [831836]
- [powerpc] mm: Fix compile error of pgtable-ppc64.h (Steve Best) [1047636]
- [powerpc] thp: Fix crash on mremap (Steve Best) [1047636]
- [ethernet] bnx2x: Allow VF rss on higher PFs (Michal Schmidt) [1062634]
- [ethernet] bnx2x: Fix VF flr flow (Michal Schmidt) [1062634]
- [ethernet] bnx2x: Correct default Tx switching behaviour (Michal Schmidt) [1058592]
- [block] sg_io: allow WRITE SAME without CAP_SYS_RAWIO (Paolo Bonzini) [966883]
- [block] sg_io: introduce unpriv_sgio queue flag (Paolo Bonzini) [966883]
- [block] sg_io: pass request_queue to blk_verify_command (Paolo Bonzini) [966883]
- [scsi] aacraid: prevent invalid pointer dereference (Frantisek Hrbata) [1034301] {CVE-2013-6380}
- [ethernet] be2net: Fix be_vlan_add/rem_vid() routines (Ivan Vecera) [1065829]
- [wireless] libertas: potential oops in debugfs (Denys Vlasenko) [1034178] {CVE-2013-6378}
- [mm] remove bogus warning in copy_huge_pmd() (Rik van Riel) [1067326]
- [wireless] ath9k: properly set MAC address and BSSID mask (Denys Vlasenko) [1033071] {CVE-2013-4579}
- [video] matroxfb: Default to 1024x768 @ 60 (Adam Jackson) [1055533]
- [powerpc] pseries: Add Gen3 definitions for PCIE link speed (Jerome Glisse) [1056701]
- [powerpc] pseries: Fix regression on PCI link speed (Jerome Glisse) [1056701]

* Sat Feb 22 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-95.el7]
- [fs] nfs: nfs4_destroy_session must call rpc_destroy_waitqueue (Steve Dickson) [1061707]
- [fs] nfs: Fix memory corruption in nfs4_proc_open_confirm (Steve Dickson) [1061707]
- [fs] nfs: initialize the ACL support bits to zero (Steve Dickson) [1059241 919382]
- [fs] nfs: Cleanup (Steve Dickson) [1059241 919382]
- [fs] nfs: Clean up nfs41_sequence_done (Steve Dickson) [1059241 919382]
- [fs] nfs: Fix a slot leak in nfs40_sequence_done (Steve Dickson) [1059241 919382]
- [fs] nfs: free slot before resending I/O to MDS (Steve Dickson) [1059241 919382]
- [fs] nfs: add memory barriers around NFS_INO_INVALID_DATA and NFS_INO_INVALIDATING (Steve Dickson) [1059241 919382]
- [fs] nfs: Fix races in nfs_revalidate_mapping (Steve Dickson) [1059241 919382]
- [net] sunrpc: turn warn_gssd() log message into a dprintk() (Steve Dickson) [1059241 919382]
- [fs] nfs: fix the handling of NFS_INO_INVALID_DATA flag in nfs_revalidate_mapping (Steve Dickson) [1059241 919382]
- [fs] nfs: handle servers that support only ALLOW ACE type (Steve Dickson) [1059241 919382]
- [fs] nfs: Proper delay for NFS4ERR_RECALLCONFLICT in layout_get_done (Steve Dickson) [1059622]
- [fs] nfs: fix BUG in filelayout_recover_commit_reqs (Steve Dickson) [1059622]
- [fs] nfs: fix discover_server_trunking use after free (Steve Dickson) [1059622]
- [fs] nfs: Handle errors correctly in nfs41_walk_client_list (Steve Dickson) [1059622]
- [fs] nfs: always make sure page is up-to-date before extending a write to cover the entire page (Steve Dickson) [1059622]
- [fs] nfs: page cache invalidation for dio (Steve Dickson) [1059622]
- [fs] nfs: take i_mutex during direct I/O reads (Steve Dickson) [1059622]
- [fs] nfs: merge nfs_direct_write into nfs_file_direct_write (Steve Dickson) [1059622]
- [fs] nfs: merge nfs_direct_read into nfs_file_direct_read (Steve Dickson) [1059622]
- [fs] nfs: increment i_dio_count for reads, too (Steve Dickson) [1059622]
- [fs] nfs: defer inode_dio_done call until size update is done (Steve Dickson) [1059622]
- [fs] nfs: fix size updates for aio writes (Steve Dickson) [1059622]
- [fs] nfs: properly handle ENOTSUP in SECINFO_NO_NAME (Steve Dickson) [1059622]
- [fs] nfs: Fix a race in nfs4_write_inode (Steve Dickson) [1059622]
- [fs] nfs: Don't trust attributes if a pNFS LAYOUTCOMMIT is outstanding (Steve Dickson) [1059622]
- [fs] nfs: use p(dD) point to the right include file in a comment (left over from a9004abc3) (Steve Dickson) [1059622]
- [fs] nfs: dprintk() should not print negative fileids and inode numbers (Steve Dickson) [1059622]
- [fs] nfs: use (dD) instead of open-coded (and often racy) equivalents (Steve Dickson) [1059622]
- [lib] vsprintf: document formats for dentry and struct file (Steve Dickson) [1059622]
- [lib] vsprintf: add formats for dentry/file pathnames (Steve Dickson) [1059622]
- [fs] nfs: fix dead code of ipv6_addr_scope (Steve Dickson) [1059622]
- [net] sunrpc: Fix infinite loop in RPC state machine (Steve Dickson) [1059622]
- [net] sunrpc: Add tracepoint for socket errors (Steve Dickson) [1059622]
- [net] sunrpc: Report connection error values to rpc_tasks on the pending queue (Steve Dickson) [1059622]
- [net] sunrpc: Handle connect errors ECONNABORTED and EHOSTUNREACH (Steve Dickson) [1059622]
- [net] sunrpc: Ensure xprt_connect_status handles all potential connection errors (Steve Dickson) [1059622]
- [fs] nfs: OPEN must handle the NFS4ERR_IO return code correctly (Steve Dickson) [1059622]

* Sat Feb 22 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-94.el7]
- [powerpc] finish off merge to put FP/VSX and VR state into structures (Steve Best) [1051192]
- [powerpc] pseries: Fix endian issues in pseries EEH code (Steve Best) [1051192]
- [powerpc] pseries: Fix endian issues in nvram code (Steve Best) [1051192]
- [powerpc] Fix endian issues in crash dump code (Steve Best) [1051192]
- [powerpc] pseries: Fix endian issues in MSI code (Steve Best) [1051192]
- [powerpc] pseries: Fix PCIE link speed endian issue (Steve Best) [1051192]
- [powerpc] Fix topology core_id endian issue on LE builds (Steve Best) [1051192]
- [powerpc] Fix endian issue in setup-common.c (Steve Best) [1051192]
- [powerpc] allyesconfig should not select CONFIG_CPU_LITTLE_ENDIAN (Steve Best) [1051192]
- [powerpc] Fix error when cross building TAGS & cscope (Steve Best) [1051192]
- [powerpc] kvm: allow guest control "E" attribute in mas2 (Steve Best) [1051192]
- [powerpc] Wrong DWARF CFI in the kernel vdso for little-endian / ELFv2 (Steve Best) [1051192]
- [powerpc] Add CONFIG_CPU_LITTLE_ENDIAN kernel config option (Steve Best) [1051192]
- [powerpc] Don't use ELFv2 ABI to build the kernel (Steve Best) [1051192]
- [powerpc] ELF2 binaries signal handling (Steve Best) [1051192]
- [powerpc] ELF2 binaries launched directly (Steve Best) [1051192]
- [powerpc] Set eflags correctly for ELF ABIv2 core dumps (Steve Best) [1051192]
- [powerpc] Add TIF_ELF2ABI flag (Steve Best) [1051192]
- [powerpc] Remove big endianness assumption in of_find_next_cache_node (Steve Best) [1051192]
- [powerpc] word-at-a-time optimization for 64-bit Little Endian (Steve Best) [1051192]
- [powerpc] bpf: BPF JIT compiler for 64-bit Little Endian (Steve Best) [1051192]
- [powerpc] nvram: Fix endian issue when using the partition length (Steve Best) [1051192]
- [powerpc] nvram: Fix endian issue when reading the NVRAM size (Steve Best) [1051192]
- [powerpc] Use -mcpu=power7 on ppc64 little endian builds (Steve Best) [1051192]
- [powerpc] booke64: Use appropriate -mcpu (Steve Best) [1051192]
- [powerpc] Fix Unaligned LE Floating Point Loads and Stores (Steve Best) [1051192]
- [powerpc] Fix Unaligned Loads and Stores (Steve Best) [1051192]
- [powerpc] Enable Little Endian Alignment Handler for Float Pair Instructions (Steve Best) [1051192]
- [powerpc] Fix Handler of Unaligned Load/Store Strings (Steve Best) [1051192]
- [powerpc] pseries: Fix endian issues in pseries iommu code (Steve Best) [1051192]
- [powerpc] Fix little endian issue in OF PCI scan (Steve Best) [1051192]
- [powerpc] Make kernel module helper endian-safe (Steve Best) [1051192]
- [powerpc] prom_init exception when updating core value (Steve Best) [1051192]
- [powerpc] kernel: Fix endian issue in rtas_pci (Steve Best) [1051192]
- [powerpc] Work around little endian gcc bug (Steve Best) [1051192]
- [powerpc] Don't set HAVE_EFFICIENT_UNALIGNED_ACCESS on little endian builds (Steve Best) [1051192]
- [powerpc] Add ability to build little endian kernels (Steve Best) [1051192]
- [powerpc] kvm: Disable KVM on little endian builds (Steve Best) [1051192]
- [powerpc] hvsi: Fix endian issues in HVSI driver (Steve Best) [1051192]
- [powerpc] powernv: More little endian issues in OPAL RTC driver (Steve Best) [1051192]
- [powerpc] powernv: Don't register exception handlers in little endian mode (Steve Best) [1051192]
- [powerpc] powernv: Fix OPAL entry and exit in little endian mode (Steve Best) [1051192]
- [powerpc] powernv: Fix endian issues in OPAL console and udbg backend (Steve Best) [1051192]
- [powerpc] powernv: Fix endian issues in powernv PCI code (Steve Best) [1051192]
- [powerpc] powernv: Make OPAL NVRAM device tree accesses endian safe (Steve Best) [1051192]
- [powerpc] powernv: Fix endian issues in OPAL ICS backend (Steve Best) [1051192]
- [powerpc] powernv: Fix endian issues in OPAL RTC driver (Steve Best) [1051192]
- [powerpc] Little endian sparse clean up for arch/powerpc/platforms/powernv/pci-ioda.c (Steve Best) [1051192]
- [powerpc] Little endian fix for arch/powerpc/platforms/powernv/pci-p5ioc2.c (Steve Best) [1051192]
- [powerpc] Little endian fix for arch/powerpc/platforms/powernv/pci.c (Steve Best) [1051192]
- [powerpc] Little endian fixes for platforms/powernv/opal.c (Steve Best) [1051192]
- [powerpc] uname should return ppc64le/ppcle on little endian builds (Steve Best) [1051192]
- [powerpc] Use generic memcpy code in little endian (Steve Best) [1051192]
- [powerpc] Use generic checksum code in little endian (Steve Best) [1051192]
- [powerpc] Handle VSX alignment faults in little endian mode (Steve Best) [1051192]
- [powerpc] Add little endian support to alignment handler (Steve Best) [1051192]
- [powerpc] Alignment handler shouldn't access VSX registers with TS_FPR (Steve Best) [1051192]
- [powerpc] Remove hard coded FP offsets in alignment handler (Steve Best) [1051192]
- [powerpc] Remove open coded byte swap macro in alignment handler (Steve Best) [1051192]
- [powerpc] Endian safe trampoline (Steve Best) [1051192]
- [powerpc] Include the appropriate endianness header (Steve Best) [1051192]
- [powerpc] Set MSR_LE bit on little endian builds (Steve Best) [1051192]
- [powerpc] Add little endian support for word-at-a-time functions (Steve Best) [1051192]
- [powerpc] Support endian agnostic MMIO (Steve Best) [1051192]
- [powerpc] Little endian builds double word swap VSX state during context save/restore (Steve Best) [1051192]
- [powerpc] PTRACE_PEEKUSR/PTRACE_POKEUSER of FPR registers in little endian builds (Steve Best) [1051192]
- [powerpc] Fix offset of FPRs in VSX registers in little endian builds (Steve Best) [1051192]
- [powerpc] Book 3S MMU little endian support (Steve Best) [1051192]
- [powerpc] Fix endian issues in VMX copy loops (Steve Best) [1051192]
- [powerpc] Make rwlocks endian safe (Steve Best) [1051192]
- [powerpc] Fix little endian coredumps (Steve Best) [1051192]
- [powerpc] Simplify logic in include/uapi/asm/elf.h (Steve Best) [1051192]
- [powerpc] pseries: Fix endian issues in H_GET_TERM_CHAR/H_PUT_TERM_CHAR (Steve Best) [1051192]
- [powerpc] pseries: Simplify H_GET_TERM_CHAR (Steve Best) [1051192]
- [powerpc] Little endian SMP IPI demux (Steve Best) [1051192]
- [powerpc] Emulate instructions in little endian mode (Steve Best) [1051192]
- [powerpc] Fix little endian lppaca, slb_shadow and dtl_entry (Steve Best) [1051192]
- [powerpc] Add endian annotations to lppaca, slb_shadow and dtl_entry (Steve Best) [1051192]
- [powerpc] Stop using non-architected shared_proc field in lppaca (Steve Best) [1051192]
- [powerpc] Make NUMA device node code endian safe (Steve Best) [1051192]
- [powerpc] Little endian fixes for legacy_serial.c (Steve Best) [1051192]
- [powerpc] Make PCI device node device tree accesses endian safe (Steve Best) [1051192]
- [powerpc] Make OF PCI device tree accesses endian safe (Steve Best) [1051192]
- [powerpc] Make device tree accesses in VIO subsystem endian safe (Steve Best) [1051192]
- [powerpc] Make device tree accesses in cache info code endian safe (Steve Best) [1051192]
- [powerpc] of_parse_dma_window should take a __be32 *dma_window (Steve Best) [1051192]
- [powerpc] Fix some endian issues in xics code (Steve Best) [1051192]
- [powerpc] Add some endian annotations to time and xics code (Steve Best) [1051192]
- [powerpc] More little endian fixes for setup-common.c (Steve Best) [1051192]
- [powerpc] Make logical to real cpu mapping code endian safe (Steve Best) [1051192]
- [powerpc] Make RTAS calls endian safe (Steve Best) [1051192]
- [powerpc] Make cache info device tree accesses endian safe (Steve Best) [1051192]
- [powerpc] Make RTAS device tree accesses endian safe (Steve Best) [1051192]
- [powerpc] More little endian fixes for prom.c (Steve Best) [1051192]
- [powerpc] Make prom.c device tree accesses endian safe (Steve Best) [1051192]

* Fri Feb 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-93.el7]
- [net] netfilter: xt_nfqueue: fix --queue-bypass regression (Florian Westphal) [1067042]
- [net] netfilter: nft_reject_inet: fix unintended fall-through in switch-statatement (Jiri Benc) [1066156]
- [net] netfilter: nf_tables: fix log/queue expressions for NFPROTO_INET (Jiri Benc) [1066156]
- [net] netfilter: nf_tables: add reject module for NFPROTO_INET (Jiri Benc) [1066156]
- [net] netfilter: nft_reject: split up reject module into IPv4 and IPv6 specifc parts (Jiri Benc) [1066156]
- [net] netfilter: nf_tables: add hook ops to struct nft_pktinfo (Jiri Benc) [1066156]
- [net] netfilter: nft_reject: fix compilation warning if NF_TABLES_IPV6 is disabled (Jiri Benc) [1066156]
- [net] netfilter: add help information to new nf_tables Kconfig options (Jiri Benc) [1066156]
- [net] netfilter: nft_reject: support for IPv6 and TCP reset (Jiri Benc) [1066156]
- [net] netfilter: reject: separate reusable code (Jiri Benc) [1066156]
- [net] netfilter: nft: add queue module (Jiri Benc) [1066156]
- [net] netfilter: xt_nfqueue: separate reusable code (Jiri Benc) [1066156]
- [net] netfilter: ip6t_reject: skip checksum verification for outgoing ipv6 packets (Jiri Benc) [1066156]
- [net] netfilter: nf_tables: check if payload length is a power of 2 (Jiri Benc) [1034791]
- [net] netfilter: nft_meta: fix typo "CONFIG_NET_CLS_ROUTE" (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: unininline nft_trace_packet() (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix loop checking with end interval elements (Jiri Benc) [1034791]
- [net] netfilter: nft_rbtree: fix data handling of end interval elements (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: do not allow NFT_SET_ELEM_INTERVAL_END flag and data (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix racy rule deletion (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix log/queue expressions for NFPROTO_INET (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add AF specific expression support (Jiri Benc) [1034791]
- [net] netfilter: nft_ct: fix missing NFT_CT_L3PROTOCOL key in validity checks (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix potential oops when dumping sets (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix overrun in nf_tables_set_alloc_name() (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix oops when deleting a chain with references (Jiri Benc) [1034791]
- [net] netfilter: nft_ct: fix unconditional dump of 'dir' attr (Jiri Benc) [1034791]
- [net] netfilter: nft_ct: fix compilation warning if NF_CONNTRACK_MARK is not set (Jiri Benc) [1034791]
- [net] netfilter: Add dependency on IPV6 for NF_TABLES_INET (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix missing byteorder conversion in policy (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix error path in the init functions (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: rename nft_do_chain_pktinfo() to nft_do_chain() (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: prohibit deletion of a table with existing sets (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: take AF module reference when creating a table (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: perform flags validation before table allocation (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: minor nf_chain_type cleanups (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: constify chain type definitions and pointers (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: replay request after dropping locks to load chain type (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add missing module references to chain types (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix chain type module reference handling (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix check for table overflow (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: restore chain change atomicity (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: split chain policy validation from actually setting it (Jiri Benc) [1034791]
- [net] netfilter: nft_meta: fix lack of validation of the input register (Jiri Benc) [1034791]
- [net] netfilter: nft_ct: Add support to set the connmark (Jiri Benc) [1034791]
- [net] netfilter: nft_ct: load both IPv4 and IPv6 conntrack modules for NFPROTO_INET (Jiri Benc) [1034791]
- [net] netfilter: nft_meta: add l4proto support (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add nfproto support to meta expression (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add "inet" table for IPv4/IPv6 (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add support for multi family tables (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: add hook ops to struct nft_pktinfo (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: make chain types override the default AF functions (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: dump sets in all existing families (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: remove unused variable in nf_tables_dump_set() (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix type in parsing in nf_tables_set_alloc_name() (Jiri Benc) [1034791]
- [net] netfilter: add help information to new nf_tables Kconfig options (Jiri Benc) [1034791]
- [net] netfilter: select NFNETLINK when enabling NF_TABLES (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: remove nft_meta_target (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: nft_meta module get/set ops (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: Expose the table usage counter via netlink (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix issue with verdict support (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix wrong datatype in nft_validate_data_load() (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix oops when updating table with user chains (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix dumping with large number of sets (Jiri Benc) [1034791]
- [net] netfilter: nft_exthdr: call ipv6_find_hdr() with explicitly initialized offset (Jiri Benc) [1034791]
- [net] netfilter: nft_reject: fix endianness in dump function (Jiri Benc) [1034791]
- [net] nf_tables*.h: Remove extern from function prototypes (Jiri Benc) [1034791]
- [net] netfilter: nf_tables: fix missing rules flushing per table (Jiri Benc) [1034791]
- [net] netfilter: nft_compat: fix error path in nft_parse_compat() (Jiri Benc) [1034791]
- [net] pktgen: Fix position of ip and udp header (Jiri Pirko) [1067485]
- [net] nf: remove automatic helper assignment removal warning (Jiri Pirko) [1066453]
- [net] inet_diag: fix inet_diag_dump_icsk() to use correct state for timewait sockets (Jesper Brouer) [1059721]
- [net] netfilter: xt_socket: use sock_gen_put() (Jesper Brouer) [1059721]
- [net] inet_diag: use sock_gen_put() (Jesper Brouer) [1059721]
- [net] inet: rename ir_loc_port to ir_num (Jesper Brouer) [1059721]
- [net] inet: includes a sock_common in request_sock (Jesper Brouer) [1059721]
- [net] inet: inet_timewait_sock.h missing semi-colon when KMEMCHECK is enabled (Jesper Brouer) [1059721]
- [net] fix build errors if ipv6 is disabled (Jesper Brouer) [1059721]
- [net] sctp: fix initialization of local source address on accepted ipv6 sockets (Jesper Brouer) [1059721]
- [net] ipv6: make lookups simpler and faster (Jesper Brouer) [1059721]
- [net] tcp/dccp: remove twchain (Jesper Brouer) [1059721]
- [net] tcp: shrink tcp6_timewait_sock by one cache line (Jesper Brouer) [1059721]
- [net] inet: consolidate INET_TW_MATCH (Jesper Brouer) [1059721]
- [net] inet*.h: Remove extern from function prototypes (Jesper Brouer) [1059721]
- [net] openvswitch: datapath: fix dp check in ovs_dp_reset_user_features (Francesco Fusco) [1057099]
- [net] openvswitch: Suppress error messages on megaflow updates (Francesco Fusco) [1057099]
- [net] openvswitch: Fix ovs_flow_free() ovs-lock assert (Francesco Fusco) [1057099]
- [net] openvswitch: Fix kernel panic on ovs_flow_free (Francesco Fusco) [1057099]
- [net] openvswitch: Pad OVS_PACKET_ATTR_PACKET if linear copy was performed (Francesco Fusco) [1057099]
- [tools] perf: Fix include for non x86 architectures (Francesco Fusco) [1057099]
- [net] openvswitch: Use kmem_cache_free() instead of kfree() (Francesco Fusco) [1057099]
- [net] openvswitch: Compute checksum in skb_gso_segment() if needed (Francesco Fusco) [1057099]
- [net] openvswitch: Use skb_zerocopy() for upcall (Francesco Fusco) [1057099]
- [net] openvswitch: Pass datapath into userspace queue functions (Francesco Fusco) [1057099]
- [net] openvswitch: Drop user features if old user space attempted to create datapath (Francesco Fusco) [1057099]
- [net] openvswitch: Allow user space to announce ability to accept unaligned Netlink messages (Francesco Fusco) [1057099]
- [net] Export skb_zerocopy() to zerocopy from one skb to another (Francesco Fusco) [1057099]
- [net] nf_queue: add NFQA_SKB_CSUM_NOTVERIFIED info flag (Francesco Fusco) [1057099]
- [net] openvswitch: remove duplicated include from flow_table.c (Francesco Fusco) [1057099]
- [net] openvswitch: use kfree_rcu instead of rcu_free_{sw_flow_mask_cb, acts_callback} (Francesco Fusco) [1057099]
- [net] openvswitch: Per cpu flow stats (Francesco Fusco) [1057099]
- [net] openvswitch: Enable memory mapped Netlink i/o (Francesco Fusco) [1057099]
- [net] netlink: Avoid netlink mmap alloc if msg size exceeds frame size (Francesco Fusco) [1057099]
- [net] genl: Add genlmsg_new_unicast() for unicast message allocation (Francesco Fusco) [1057099]
- [net] openvswitch: Silence RCU lockdep checks from flow lookup (Francesco Fusco) [1057099]
- [net] openvswitch: Change ovs_flow_tbl_lookup_xx() APIs (Francesco Fusco) [1057099]
- [net] openvswitch: Shrink sw_flow_mask by 8 bytes (64-bit) or 4 bytes (32-bit) (Francesco Fusco) [1057099]
- [net] openvswitch: Correct comment (Francesco Fusco) [1057099]
- [net] Add utility functions to clear rxhash (Francesco Fusco) [1057099]
- [net] openvswitch: use CRC32 accelerated flow hash if available (Francesco Fusco) [1057099]
- [lib] hash: follow-up fixups for arch hash (Francesco Fusco) [1057099]
- [lib] hash: Add missing arch generic-y entries for asm-generic/hash.h (Francesco Fusco) [1057099]
- [lib] hash: introduce arch optimized hash library (Francesco Fusco) [1057099]
- [net] rtnl: make ifla_policy static (Jiri Pirko) [1066614]
- [net] ip, ipv6: handle gso skbs in forwarding path (Florian Westphal) [1065299]
- [net] introduce netif_skb_dev_features (Florian Westphal) [1065299]
- [net] add and use skb_gso_transport_seglen() (Florian Westphal) [1065299]
- [net] bridge: separate querier and query timer into IGMP/IPv4 and MLD/IPv6 ones (Florian Westphal) [1065257]
- [net] bridge: send query as soon as leave is received (Florian Westphal) [1065257]
- [net] gro: remove a sparse error (Thomas Graf) [1051111]
- [net] ipv4: Use proper RCU APIs for writer-side in udp_offload.c (Thomas Graf) [1051111]
- [net] vxlan: Go over all candidate streams for GRO matching (Thomas Graf) [1051111]
- [net] ipv4: Use non-atomic allocation of udp offloads structure instance (Thomas Graf) [1051111]
- [net] ipv4: udp_offload: Handle static checker complaints (Thomas Graf) [1051111]
- [net] vxlan: Share RX skb de-marking and checksum checks with ovs (Thomas Graf) [1051111]
- [net] vxlan: Add GRO support for vxlan traffic (Thomas Graf) [1051111]
- [net] vxlan: use __dev_get_by_index instead of dev_get_by_index to find interface (Thomas Graf) [1051111]
- [net] vxlan: keep original skb ownership (Thomas Graf) [1051111]
- [net] vxlan: remove vxlan_group_used in vxlan_open (Thomas Graf) [1051111]
- [net] vxlan: release rt when found circular route (Thomas Graf) [1051111]
- [net] vxlan: Use ERR_CAST inlined function instead of ERR_PTR(PTR_ERR(...)) (Thomas Graf) [1051111]
- [net] vxlan: Have the NIC drivers do less work for offloads (Thomas Graf) [1051111]
- [net] vxlan: silence one build warning (Thomas Graf) [1051111]
- [net] vxlan: Use RCU apis to access sk_user_data (Thomas Graf) [1051111]
- [net] vxlan: Avoid creating fdb entry with NULL destination (Thomas Graf) [1051111]
- [net] vxlan: Fix sparse warnings (Thomas Graf) [1051111]
- [net] vxlan: Notify drivers for listening UDP port changes (Thomas Graf) [1051111]
- [net] vxlan: Optimize vxlan rcv (Thomas Graf) [1051111]
- [net] Export gro_find_by_type helpers (Thomas Graf) [1051111]
- [net] Add GRO support for UDP encapsulating protocols (Thomas Graf) [1051111]
- [net] gro: change GRO overflow strategy (Thomas Graf) [1051111]
- [net] gre_offload: fix sparse non static symbol warning (Thomas Graf) [1051111]
- [net] gre: gro: Add GRE support to the GRO stack (Thomas Graf) [1051111]
- [net] ipv4: don't use module_init in non-modular gre_offload (Thomas Graf) [1051111]
- [net] gre_offload: statically build GRE offloading support (Thomas Graf) [1051111]
- [net] ipv6: Fix alleged compiler warning in ipv6_exthdrs_len() (Thomas Graf) [1051111]
- [net] ipv6: fix compiler warning in ipv6_exthdrs_len (Thomas Graf) [1051111]
- [net] gro: Prepare GRO stack for the upcoming tunneling support (Thomas Graf) [1051111]
- [net] gro: small napi_get_frags() optim (Thomas Graf) [1051111]
- [net] tcp: do not export tcp_gso_segment() and tcp_gro_receive() (Thomas Graf) [1051111]
- [net] gro: Clean up tcpX_gro_receive checksum verification (Thomas Graf) [1051111]
- [net] gro: Only verify TCP checksums for candidates (Thomas Graf) [1051111]
- [net] gso: handle new frag_list of frags GRO packets (Thomas Graf) [1051111]
- [net] gro: allow to build full sized skb (Thomas Graf) [1051111]
- [net] tcp: gso: fix truesize tracking (Thomas Graf) [1051111]
- [net] tcp: rename tcp_tso_segment() (Thomas Graf) [1051111]
- [net] gro: should aggregate frames without DF (Thomas Graf) [1051111]
- [net] sit: fix use after free of fb_tunnel_dev (Jiri Pirko) [1060210]
- [net] sit: allow to use rtnl ops on fb tunnel (Jiri Pirko) [1060210]
- [net] ip6tnl: fix use after free of fb_tnl_dev (Jiri Pirko) [1012835]
- [net] ip6tnl: allow to use rtnl ops on fb tunnel (Jiri Pirko) [1012835]
- [net] ip6tnl: add x-netns support (Jiri Pirko) [1012835]
- [net] Correctly sync addresses from multiple sources to single device (Vlad Yasevich) [1059394]

* Fri Feb 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-92.el7]
- [fs] xfs: ensure correct log item buffer alignment (Brian Foster) [1059843]
- [fs] xfs: ensure correct timestamp updates from truncate (Brian Foster) [1059843]
- [fs] xfs: remove XFS_TRANS_DEBUG dead code (Brian Foster) [1059843]
- [fs] xfs: return -E2BIG if hit the maximum size limits of ACLs (Brian Foster) [1059843]
- [fs] xfs: sanitize sb_inopblock in xfs_mount_validate_sb (Brian Foster) [1059843]
- [fs] xfs: convert xfs_log_commit_cil() to void (Brian Foster) [1059843]
- [fs] xfs: use tr_qm_dqalloc log reservation for dquot alloc (Brian Foster) [1059843]
- [fs] xfs: remove unused tr_swrite (Brian Foster) [1059843]
- [fs] xfs: use tr_growrtalloc for growing rt files (Brian Foster) [1059843]
- [fs] xfs: Calling destroy_work_on_stack() to pair with INIT_WORK_ONSTACK() (Brian Foster) [1059843]
- [fs] xfs: fix off-by-one error in xfs_attr3_rmt_verify (Brian Foster) [1059843]
- [fs] xfs: assert that we hold the ilock for extent map access (Brian Foster) [1059843]
- [fs] xfs: use xfs_ilock_attr_map_shared in xfs_attr_list_int (Brian Foster) [1059843]
- [fs] xfs: use xfs_ilock_attr_map_shared in xfs_attr_get (Brian Foster) [1059843]
- [fs] xfs: use xfs_ilock_data_map_shared in xfs_qm_dqiterate (Brian Foster) [1059843]
- [fs] xfs: use xfs_ilock_data_map_shared in xfs_qm_dqtobp (Brian Foster) [1059843]
- [fs] xfs: take the ilock around xfs_bmapi_read in xfs_zero_remaining_bytes (Brian Foster) [1059843]
- [fs] xfs: reinstate the ilock in xfs_readdir (Brian Foster) [1059843]
- [fs] xfs: add xfs_ilock_attr_map_shared (Brian Foster) [1059843]
- [fs] xfs: rename xfs_ilock_map_shared (Brian Foster) [1059843]
- [fs] xfs: remove xfs_iunlock_map_shared (Brian Foster) [1059843]
- [fs] xfs: no need to lock the inode in xfs_find_handle (Brian Foster) [1059843]
- [fs] xfs: abort metadata writeback on permanent errors (Brian Foster) [1059843]
- [fs] xfs: swalloc doesn't align allocations properly (Brian Foster) [1059843]
- [fs] xfs: remove xfsbdstrat error (Brian Foster) [1059843]
- [fs] xfs: use xfs_icluster_size_fsb in xfs_imap (Brian Foster) [1059843]
- [fs] xfs: use xfs_icluster_size_fsb in xfs_ifree_cluster (Brian Foster) [1059843]
- [fs] xfs: use xfs_icluster_size_fsb in xfs_ialloc_inode_init (Brian Foster) [1059843]
- [fs] xfs: use xfs_icluster_size_fsb in xfs_bulkstat (Brian Foster) [1059843]
- [fs] xfs: introduce a common helper xfs_icluster_size_fsb (Brian Foster) [1059843]
- [fs] xfs: get rid of XFS_IALLOC_BLOCKS macros (Brian Foster) [1059843]
- [fs] xfs: get rid of XFS_INODE_CLUSTER_SIZE macros (Brian Foster) [1059843]
- [fs] xfs: get rid of XFS_IALLOC_INODES macros (Brian Foster) [1059843]
- [fs] xfs: remove the quotaoff log format from the quotaoff log item (Brian Foster) [1059843]
- [fs] xfs: remove the dquot log format from the dquot log item (Brian Foster) [1059843]
- [fs] xfs: remove the inode log format from the inode log item (Brian Foster) [1059843]
- [fs] xfs: format logged extents directly into the CIL (Brian Foster) [1059843]
- [fs] xfs: format log items write directly into the linear CIL buffer (Brian Foster) [1059843]
- [fs] xfs: introduce xlog_copy_iovec (Brian Foster) [1059843]
- [fs] xfs: refactor xfs_inode_item_format (Brian Foster) [1059843]
- [fs] xfs: refactor xfs_inode_item_size (Brian Foster) [1059843]
- [fs] xfs: refactor xfs_buf_item_format_segment (Brian Foster) [1059843]
- [fs] xfs: remove duplicate code in xlog_cil_insert_format_items (Brian Foster) [1059843]
- [fs] xfs: align initial file allocations correctly (Brian Foster) [1059843]
- [fs] xfs: fix calculation of freed inode cluster blocks (Brian Foster) [1059843]
- [fs] xfs: xfs_dir2_block_to_sf temp buffer allocation fails (Brian Foster) [1059843]
- [fs] xfs: fix infinite loop by detaching the group/project hints from user dquot (Brian Foster) [1059843]
- [fs] xfs: fix assertion failure at xfs_setattr_nonsize (Brian Foster) [1059843]
- [fs] xfs: add xfs_setattr_time (Brian Foster) [1059843]
- [fs] xfs: tiny xfs_setattr_mode cleanup (Brian Foster) [1059843]
- [fs] xfs: fix false assertion at xfs_qm_vop_create_dqattach (Brian Foster) [1059843]
- [fs] xfs: integrate xfs_quota_priv header file to xfs_qm (Brian Foster) [1059843]
- [fs] xfs: make quota metadata truncation behavior consistent to user space (Brian Foster) [1059843]
- [fs] xfs: fix memory leak in xfs_dir2_node_removename (Brian Foster) [1059843]
- [fs] xfs: free the list of recovery items on error (Brian Foster) [1059843]
- [fs] xfs: growfs overruns AGFL buffer on V4 filesystems (Brian Foster) [1059843]
- [fs] xfs: don't perform discard if the given range length is less than block size (Brian Foster) [1059843]
- [fs] xfs: fix the comment explaining xfs_trans_dqlockedjoin (Brian Foster) [1059843]
- [fs] xfs: underflow bug in xfs_attrlist_by_handle() (Brian Foster) [1059843 1034667] {CVE-2013-6382}
- [fs] xfs: remove unused FI_ flags (Brian Foster) [1059843]
- [fs] xfs: open code inc_inode_iversion when logging an inode (Brian Foster) [1059843]
- [fs] xfs: increase inode cluster size for v5 filesystems (Brian Foster) [1059843]
- [fs] xfs: fix unlock in xfs_bmap_add_attrfork (Brian Foster) [1059843]
- [fs] xfs: simplify kmem_(zone_)zalloc (Brian Foster) [1059843]
- [fs] xfs: add tracepoints to AGF/AGI read operations (Brian Foster) [1059843]
- [fs] xfs: trace AIL manipulations (Brian Foster) [1059843]
- [fs] xfs: xfs_remove deadlocks due to inverted AGF vs AGI lock ordering (Brian Foster) [1059843]
- [fs] xfs: fix the extent count when allocating an new indirection array entry (Brian Foster) [1059843]
- [fs] xfs: be more forgiving of a v4 secondary sb w/ junk in v5 fields (Brian Foster) [1059843]
- [fs] xfs: fix possible NULL dereference in xlog_verify_iclog (Brian Foster) [1059843]
- [fs] xfs:xfs_dir2_node.c: pointer use before check for null (Brian Foster) [1059843]
- [fs] xfs: prevent stack overflows from page cache allocation (Brian Foster) [1059843]
- [fs] xfs: fix static and extern sparse warnings (Brian Foster) [1059843]
- [fs] xfs: validity check the directory block leaf entry count (Brian Foster) [1059843]
- [fs] xfs: make dir2 ftype offset pointers explicit (Brian Foster) [1059843]
- [fs] xfs: convert directory vector functions to constants (Brian Foster) [1059843]
- [fs] xfs: convert directory vector functions to constants (Brian Foster) [1059843]
- [fs] xfs: vectorise encoding/decoding directory headers (Brian Foster) [1059843]
- [fs] xfs: vectorise DA btree operations (Brian Foster) [1059843]
- [fs] xfs: vectorise directory leaf operations (Brian Foster) [1059843]
- [fs] xfs: vectorise directory data operations part 2 (Brian Foster) [1059843]
- [fs] xfs: vectorise directory data operations (Brian Foster) [1059843]
- [fs] xfs: vectorise remaining shortform dir2 ops (Brian Foster) [1059843]
- [fs] xfs: abstract the differences in dir2/dir3 via an ops vector (Brian Foster) [1059843]
- [fs] xfs: split xfs_rtalloc.c for userspace sanity (Brian Foster) [1059843]
- [fs] xfs: decouple inode and bmap btree header files (Brian Foster) [1059843]
- [fs] xfs: decouple log and transaction headers (Brian Foster) [1059843]
- [fs] xfs: remove unused transaction callback variables (Brian Foster) [1059843]
- [fs] xfs: split dquot buffer operations out (Brian Foster) [1059843]
- [fs] xfs: unify directory/attribute format definitions (Brian Foster) [1059843]
- [fs] xfs: create a shared header file for format-related information (Brian Foster) [1059843]
- [fs] xfs: fold xfs_change_file_space into xfs_ioc_space (Brian Foster) [1059843]
- [fs] xfs: simplify the fallocate path (Brian Foster) [1059843]
- [fs] xfs: always hold the iolock when calling xfs_change_file_space (Brian Foster) [1059843]
- [fs] xfs: remove the unused XFS_ATTR_NONBLOCK flag (Brian Foster) [1059843]
- [fs] xfs: always take the iolock around xfs_setattr_size (Brian Foster) [1059843]
- [fs] xfs: don't break from growfs ag update loop on error (Brian Foster) [1059843]
- [fs] xfs: don't emit corruption noise on fs probes (Brian Foster) [1059843]
- [fs] xfs: remove newlines from strings passed to __xfs_printk (Brian Foster) [1059843]
- [fs] xfs: prevent deadlock trying to cover an active log (Brian Foster) [1059843]
- [fs] xfs: clean up xfs_inactive() error handling, kill VN_INACTIVE_(NO)CACHE (Brian Foster) [1059843]
- [fs] xfs: push down inactive transaction mgmt for ifree (Brian Foster) [1059843]
- [fs] xfs: push down inactive transaction mgmt for truncate (Brian Foster) [1059843]
- [fs] xfs: push down inactive transaction mgmt for remote symlinks (Brian Foster) [1059843]
- [fs] xfs: add the inode directory type support to XFS_IOC_FSGEOM (Brian Foster) [1059843]
- [fs] xfs: remove usage of is_bad_inode (Brian Foster) [1059843]
- [fs] xfs: fix the wrong new_size/rnew_size at xfs_iext_realloc_direct() (Brian Foster) [1059843]
- [fs] xfs: get rid of count from xfs_iomap_write_allocate() (Brian Foster) [1059843]
- [fs] xfs: Use kmem_free() instead of free() (Brian Foster) [1059843]
- [fs] xfs: fix memory leak in xlog_recover_add_to_trans (Brian Foster) [1059843]
- [fs] xfs: dirent dtype presence is dependent on directory magic numbers (Brian Foster) [1059843]
- [fs] xfs: lockdep needs to know about 3 dquot-deep nesting (Brian Foster) [1059843]
- [fs] xfs: log recovery lsn ordering needs uuid check (Brian Foster) [1059843]
- [fs] xfs: fix XFS_IOC_FREE_EOFBLOCKS definition (Brian Foster) [1059843]
- [fs] xfs: asserting lock not held during freeing not valid (Brian Foster) [1059843]
- [fs] xfs: lock the AIL before removing the buffer item (Brian Foster) [1059843]
- [fs] ext4: yield during large unlinks (Lukas Czerner) [1044544]
- [fs] ext4: implement error handling of ext4_mb_new_preallocation() (Lukas Czerner) [1044544]
- [fs] ext4: return FIEMAP_EXTENT_UNKNOWN for delalloc extents (Lukas Czerner) [1044544]
- [fs] jbd2: fix duplicate debug label for phase 2 (Lukas Czerner) [1044544]
- [fs] jbd2: drop checkpoint mutex when waiting in __jbd2_log_wait_for_space() (Lukas Czerner) [1044544]
- [fs] jbd2: remove unused waitqueues (Lukas Czerner) [1044544]
- [fs] jbd2: fix race in t_outstanding_credits update in jbd2_journal_extend() (Lukas Czerner) [1044544]
- [fs] ext4: fix use of potentially uninitialized variables in debugging code (Lukas Czerner) [1044544]
- [fs] ext4: check error return from ext4_write_inline_data_end() (Lukas Czerner) [1044544]
- [fs] jbd2: relocate assert after state lock in journal_commit_transaction() (Lukas Czerner) [1044544]
- [fs] ext4: add cond_resched() to ext4_free_blocks() & ext4_mb_regular_allocator() (Lukas Czerner) [1044544]
- [fs] ext4: optimize test_root() (Lukas Czerner) [1044544]
- [fs] ext4: add sanity check to ext4_get_group_info() (Lukas Czerner) [1044544]
- [fs] ext4: verify group number in verify_group_input() before using it (Lukas Czerner) [1044544]
- [fs] ext4: add check to io_submit_init_bio (Lukas Czerner) [1044544]
- [fs] Fix race when checking i_size on direct i/o read (Robert S Peterson) [1052927]
- [fs] gfs2: No need to invalidate pages for a dio read (Robert S Peterson) [1052927]
- [fs] gfs2: Wait for async DIO in glock state changes (Robert S Peterson) [1052927]
- [fs] gfs2: Fix incorrect invalidation for DIO/buffered I/O (Robert S Peterson) [1052927]
- [fs] xfs: allow logical-sector sized O_DIRECT (Eric Sandeen) [999239]
- [fs] xfs: rename xfs_buftarg structure members (Eric Sandeen) [999239]
- [fs] xfs: clean up xfs_buftarg (Eric Sandeen) [999239]
- [fs] xfs: simplify xfs_setsize_buftarg callchain; remove unused arg (Eric Sandeen) [999239]
- [fs] sunrpc: Don't create a gss auth cache unless rpc.gssd is running (Steve Dickson) [1063752]
- [fs] gfs2: journal data writepages update (Robert S Peterson) [1010452]
- [fs] nfs: Fix SP4_MACH_CRED negotiation in EXCHANGE_ID (Steve Dickson) [1063509]
- [fs] gfs2: Add hints to directory leaf blocks (Robert S Peterson) [1062143]
- [fs] gfs2: Lock i_mutex and use a local gfs2_holder for fallocate (Robert S Peterson) [1062305]
- [fs] compat: fix lookup_dcookie() parameter handling (Hendrik Brueckner) [1060203]
- [fs] compat: fix parameter handling for compat readv/writev syscalls (Hendrik Brueckner) [1049599]

* Fri Feb 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-91.el7]
- [kernel] sched: Fix endless sync_sched/rcu() loop inside _cpu_down() (Rik van Riel) [1062647]
- [kernel] sched: Remove extra put_online_cpus() inside sched_setaffinity() (Rik van Riel) [1062647]
- [kernel] sched: Remove get_online_cpus() usage (Rik van Riel) [1062647]
- [mm] move mmu notifier call from change_protection to change_pmd_range (Rik van Riel) [1066655]
- [mm] numa: reorganize change_pmd_range (Rik van Riel) [1066655]
- [kernel] sched/numa: add cond_resched to task_numa_work (Rik van Riel) [1066655]
- [cpufreq] intel_pstate: Fail initialization if P-state information is missing (Marcelo Tosatti) [1061481]
- [cpufreq] intel_pstate: Add X86_FEATURE_APERFMPERF to cpu match (Marcelo Tosatti) [1061481]
- [ethernet] bnx2x: More Shutdown revisions (Michal Schmidt) [1046885]
- [ethernet] bnx2x: Don't release PCI bars on shutdown (Michal Schmidt) [1046885]
- [security] keys, shmem: implement kernel private shmem inodes (Paul Moore) [1031154 1034833]

* Wed Feb 19 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-90.el7]
- [drm] nouveau/devinit: prevent use of engines marked as disabled by hw/vbios (Rob Clark) [1054409]
- [drm] nouveau/device: provide a way for devinit to mark engines as disabled (Rob Clark) [1054409]
- [drm] nouveau/devinit: tidy up the subdev class definition (Rob Clark) [1054409]
- [drm] nouveau: populate master subdev pointer only when fully constructed (Rob Clark) [1054409]
- [drm] nouveau/i2c: use a custom bitbanging delay for the adt7473 (Rob Clark) [1054409]
- [drm] nouveau/bios: fix offset calculation for BMPv1 bioses (Rob Clark) [1054409]
- [drm] nouveau: return offset of allocated notifier (Rob Clark) [1054409]
- [drm] nouveau/bios: make jump conditional (Rob Clark) [1054409]
- [drm] nouveau: fix mthd data submission (Rob Clark) [1054409]
- [drm] nouveau/disp: min/max are reversed in nv50_crtc_gamma_set() (Rob Clark) [1054409]
- [drm] nouveau/sw: fix oops if gpu has its display block disabled (Rob Clark) [1054409]
- [drm] nouveau/kms: send timestamp data for correct head in flip completion events (Rob Clark) [1054409]
- [drm] nouveau: do not map evicted vram buffers in nouveau_bo_vma_add (Rob Clark) [1054409]
- [drm] nouveau: shift wrapping bug in nvc0_grctx_generate_r406800 (Rob Clark) [1054409]
- [drm] nouveau: allow nouveau_fence_ref() to be a noop (Rob Clark) [1054409]
- [drm] nouveau: consider CLASS_DISPLAY_3D devices while detecting dsm/optimus (Rob Clark) [1054409]
- [drm] nouveau: only runtime suspend by default in optimus configuration (Rob Clark) [1054409]
- [drm] radeon: set correct pipe config for Hawaii in DCE (Rob Clark) [1054409]
- [drm] radeon: 0x9649 is SUMO2 not SUMO (Rob Clark) [1054409]
- [drm] radeon: expose render backend mask to the userspace (Rob Clark) [1054409]
- [drm] radeon: fix render backend setup for SI and CIK (Rob Clark) [1054409]
- [drm] radeon: fix UVD 256MB check (Rob Clark) [1054409]
- [drm] i915: Use the correct GMCH_CTRL register for Sandybridge+ (Rob Clark) [1054409]
- [drm] i915: change CRTC assertion on LCPLL disable (Rob Clark) [1054409]
- [drm] i915: Fix erroneous dereference of batch_obj inside reset_status (Rob Clark) [1054409]
- [drm] radeon: fix asic gfx values for scrapper asics (Rob Clark) [1054409]
- [drm] radeon: check for 0 count in speaker allocation and SAD code (Rob Clark) [1054409]
- [drm] radeon/dpm: disable ss on Cayman (Rob Clark) [1054409]
- [drm] i915: don't update the dri1 breadcrumb with modesetting (Rob Clark) [1054409]
- [drm] i915: Fix use-after-free in do_switch (Rob Clark) [1054409]
- [drm] i915: Hold mutex across i915_gem_release (Rob Clark) [1054409]
- [drm] i915: Take modeset locks around intel_modeset_setup_hw_state() (Rob Clark) [1054409]
- [drm] radeon: add missing display tiling setup for oland (Rob Clark) [1054409]
- [drm] radeon: fix typo in cik_copy_dma (Rob Clark) [1054409]
- [drm] radeon: Fix sideport problems on certain RS690 boards (Rob Clark) [1054409]
- [drm] ttm: Fix accesses through vmas with only partial coverage (Rob Clark) [1054409]
- [drm] edid: add quirk for BPC in Samsung NP700G7A-S01PL notebook (Rob Clark) [1054409]
- [drm] i915/vlv: fix up broken precision in vlv_crtc_clock_get (Rob Clark) [1054409]
- [drm] i915/vlv: add VLV specific clock_get function v3 (Rob Clark) [1054409]
- [drm] i915/vlv: untangle integrated clock source handling v4 (Rob Clark) [1054409]
- [drm] radeon/atom: fix bus probes when hw_i2c is set (Rob Clark) [1054409]
- [drm] radeon: fixup bad vram size on SI (Rob Clark) [1054409]
- [drm] radeon: program DCE2 audio dto just like DCE3 (Rob Clark) [1054409]
- [drm] radeon: fix typo in fetching mpll params (Rob Clark) [1054409]
- [drm] i915: use the correct force_wake function at the PC8 code (Rob Clark) [1054409]
- [drm] i915: Fix pipe CSC post offset calculation (Rob Clark) [1054409]
- [drm] udl: fix issue with imported prime buffers (Rob Clark) [1054409]
- [drm] radeon: adjust TN dpm parameters for stability (Rob Clark) [1054409]
- [drm] radeon: hook up backlight functions for CI and KV family (Rob Clark) [1054409]
- [drm] radeon/i2c: do not count reg index in number of i2c byte we are writing (Rob Clark) [1054409]
- [drm] radeon: fix UVD destroy IB size (Rob Clark) [1054409]
- [drm] i915: Replicate BIOS eDP bpp clamping hack for hsw (Rob Clark) [1054409]
- [drm] i915: restore the early forcewake cleanup (Rob Clark) [1054409]
- [drm] i915/dvo: call ->mode_set callback only when the port is running (Rob Clark) [1054409]
- [drm] vmwgfx: Resource evict fixes (Rob Clark) [1054409]
- [drm] i915: fix compiler warning (Rob Clark) [1054409]
- [drm] allow DRM_IOCTL_VERSION on render-nodes (Rob Clark) [1054409]
- [drm] i915: Fix the PPT fdi lane bifurcate state handling on ivb (Rob Clark) [1054409]
- [drm] i915: No LVDS hardware on Intel D410PT and D425KT (Rob Clark) [1054409]
- [drm] i915/dp: workaround BIOS eDP bpp clamping issue (Rob Clark) [1054409]
- [drm] i915: Add HSW CRT output readout support (Rob Clark) [1054409]
- [drm] i915: Add support for pipe_bpp readout (Rob Clark) [1054409]
- [drm] radeon/dpm: fix incompatible casting on big endian (Rob Clark) [1054409]
- [drm] radeon: disable bapm on KB (Rob Clark) [1054409]
- [drm] radeon: use sw CTS/N values for audio on DCE4+ (Rob Clark) [1054409]
- [s390] crypto: Fix aes-cbc IV corruption (Hendrik Brueckner) [1063810]
- [s390] appldata: restore missing init_virt_timer() (Hendrik Brueckner) [1064246]
- [s390] mm: Fix dump memory detection (Hendrik Brueckner) [1064244]
- [s390] fix kernel crash due to linkage stack instructions (Hendrik Brueckner) [1059732]
- [s390] crypto: fix des and des3_ede ctr concurrency issue (Hendrik Brueckner) [1062269]
- [s390] crypto: fix des and des3_ede cbc concurrency issue (Hendrik Brueckner) [1062266]
- [s390] crypto: fix concurrency issue in aes-ctr mode (Hendrik Brueckner) [1062260]
- [ethernet] cxgb4: Fix referencing freed adapter (Steve Best) [1063483]
- [mm] oom: base root bonus on current usage (Johannes Weiner) [822790]
- [kernel] lockdep: increase MAX_LOCKDEP_ENTRIES (Kyle McMartin) [989385]
- [scripts] tags.sh: ignore redhat/rpm (Prarit Bhargava) [1065511]
- [security] selinux: Fix kernel BUG on empty security contexts (Paul Moore) [1064548]
- [security] selinux: add SOCK_DIAG_BY_FAMILY to the list of netlink message types (Paul Moore) [1022394]
- [powerpc] eeh: Drop taken reference to driver on eeh_rmv_device (Steve Best) [1059851]
- [scripts] tags.sh: Ignore *.mod.c (Mark Langsdorf) [1062383]
- [mm] keep page cache radix tree nodes in check (Johannes Weiner) [1062372]
- [lib] radix_tree: tree node interface (Johannes Weiner) [1062372]
- [mm] thrash detection-based file cache sizing (Johannes Weiner) [1062372]
- [mm] store shadow entries in page cache (Johannes Weiner) [1062372]
- [lib] radix-tree: radix_tree_delete_item() (Johannes Weiner) [1062372]
- [mm] shmem: save one radix tree lookup when truncating swapped pages (Johannes Weiner) [1062372]
- [mm] prepare for non-page entries in page cache radix trees (Johannes Weiner) [1062372]
- [mm] vmstat: fix UP zone state accounting (Johannes Weiner) [1062372]
- [mm] filemap: move radix tree hole searching here (Johannes Weiner) [1062372]
- [fs] cachefiles: use add_to_page_cache_lru() (Johannes Weiner) [1062372]
- [mm] page_alloc: revert NUMA aspect of fair allocation policy (Johannes Weiner) [1062372]
- [mm] page_alloc: fair zone allocator policy (Johannes Weiner) [1062372]
- [mm] memory-failure: shift page lock from head page to tail page after thp split (Naoya Horiguchi) [1051704]
- [fs] proc/page: add PageAnon check to surely detect thp (Naoya Horiguchi) [1051704]
- [mm] memory-failure: transfer page count from head page to tail page after split thp (Naoya Horiguchi) [1051704]
- [mm] memory-failure: recheck PageHuge() after hugetlb page migrate successfully (Naoya Horiguchi) [1051704]
- [mm] memory-failure: move set_migratetype_isolate() outside get_any_page() (Naoya Horiguchi) [1051704]
- [mm] hwpoison: fix false report on 2nd attempt at page recovery (Naoya Horiguchi) [1051704]
- [mm] hwpoison: fix test for a transparent huge page (Naoya Horiguchi) [1051704]
- [mm] memory-failure: fix bug triggered by unpoisoning empty zero page (Naoya Horiguchi) [1051704]
- [mm] hwpoison: don't set migration type twice to avoid holding heavily contend zone->lock (Naoya Horiguchi) [1051704]
- [mm] hwpoison: replace atomic_long_sub() with atomic_long_dec() (Naoya Horiguchi) [1051704]
- [mm] hwpoison: fix race against poison thp (Naoya Horiguchi) [1051704]
- [mm] hwpoison: don't need to hold compound lock for hugetlbfs page (Naoya Horiguchi) [1051704]
- [mm] hwpoison: fix loss of PG_dirty for errors on mlocked pages (Naoya Horiguchi) [1051704]
- [mm] hwpoison: always unset MIGRATE_ISOLATE before returning from soft_offline_page() (Naoya Horiguchi) [1051704]
- [mm] memory-failure: fix memory leak in successful soft offlining (Naoya Horiguchi) [1051704]
- [virt] kvm: move KVM_CAP_HYPERV_TIME outside #ifdef (Vadim Rozenfeld) [1057170]
- [virt] kvm: add support for Hyper-V reference time counter (Vadim Rozenfeld) [1057170]
- [input] wacom: not all multi-interface devices support touch (Aristeu Rozanski) [1022595]
- [input] wacom: add support for three new Intuos Pro devices (Aristeu Rozanski) [1022595]
- [input] wacom: LED is only supported through digitizer interface (Aristeu Rozanski) [1022595]
- [input] wacom: testing result shows get_report is unnecessary (Aristeu Rozanski) [1022595]
- [input] wacom: send proper tablet state info when pen leaves proximity (Aristeu Rozanski) [1022595]
- [input] wacom: fix error return code in wacom_probe() (Aristeu Rozanski) [1022595]
- [input] wacom: integrate resolution calculation (Aristeu Rozanski) [1022595]
- [fs] buffer: __set_page_dirty uses spin_lock_irqsave instead of spin_lock_irq (Motohiro Kosaki) [1057270]
- [mm] __set_page_dirty_nobuffers uses spin_lock_irqseve instead of spin_lock_irq (Motohiro Kosaki) [1057270]
- [virt] hv/ballon: Make pressure posting thread sleep interruptibly (Luiz Capitulino) [1065107]
- [input] hyperv-keyboard: pass through 0xE1 prefix (Jason Wang) [1044874]
- [mm] drop_caches: add some documentation and info message (Johannes Weiner) [838935]
- [scsi] megaraid_sas: Performance boost fixes (Tomas Henzl) [1064509]
- [scsi] megaraid_sas: Set 32-bit DMA mask (Tomas Henzl) [1064509]
- [scsi] megaraid_sas: Big endian code related fixes (Tomas Henzl) [1064509]
- [scsi] megaraid_sas: Don't wait forever for non-IOCTL DCMDs (Tomas Henzl) [1064509]

* Fri Feb 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-89.el7]
- [powerpc] Fix kdump hang issue on p8 with relocation on exception enabled (Steve Best) [1056321]
- [powerpc] pseries: Disable relocation on exception while going down during crash (Steve Best) [1056321]
- [kernel] sched/debug: Fix formatting of /proc/<PID>/sched (Rik van Riel) [1064583]
- [kernel] sched/fair: Remove unused variable from expire_cfs_rq_runtime() (Rik van Riel) [1064583]
- [mm] vmscan: do not scale writeback pages when deciding whether to set ZONE_WRITEBACK (Rafael Aquini) [1009508]
- [mm] vmscan: do not continue scanning if reclaim was aborted for compaction (Rafael Aquini) [1009508]
- [ethernet] bnx2{,x}: Make module parameters readable (Neil Horman) [1062836]
- [ethernet] bnx2x: namespace and dead code cleanups (Neil Horman) [1062836]
- [drm] radeon: remove generic rptr/wptr functions (Steve Best) [1048290]
- [block] nvme: Namespace use after free on surprise removal (David Milburn) [1062640]
- [block] nvme: Correct uses of INIT_WORK (David Milburn) [1062640]
- [block] nvme: Include device and queue numbers in interrupt name (David Milburn) [1062640]
- [block] nvme: Add a pci_driver shutdown method (David Milburn) [1062640]

* Thu Feb 13 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-88.el7]
- [mm] hugetlb: correct missing private flag clearing (Steve Best) [1062671]
- [mm] hugetlb: return a reserved page to a reserved pool if failed (Steve Best) [1062671]
- [mm] hugetlb: fix subpool accounting handling (Steve Best) [1062671]
- [mm] hugetlb: protect reserved pages when soft offlining a hugepage (Steve Best) [1062671]
- [mm] hugetlb: decrement reserve count if VM_NORESERVE alloc page cache (Steve Best) [1062671]
- [mm] hugetlb: remove decrement_hugepage_resv_vma() (Steve Best) [1062671]
- [mm] hugetlb: clean-up alloc_huge_page() (Steve Best) [1062671]
- [mm] hugetlb: add VM_NORESERVE check in vma_has_reserves() (Steve Best) [1062671]
- [mm] hugetlb: do not use a page in page cache for cow optimization (Steve Best) [1062671]
- [s390] uapi: fix struct statfs64 definition (Hendrik Brueckner) [1060191]
- [ethernet] myri10ge: Add support for ndo_busy_poll (Stanislaw Gruszka) [1059561]
- [ethernet] be2net: add dma_mapping_error() check for dma_map_page() (Ivan Vecera) [995992]
- [infiniband] srp: Avoid offlining operational SCSI devices (Doug Ledford) [1046103]
- [infiniband] srp: Remove target from list before freeing Scsi_Host structure (Doug Ledford) [1046103]
- [infiniband] srp: Add change_queue_depth and change_queue_type support (Doug Ledford) [1046103]
- [infiniband] srp: Make queue size configurable (Doug Ledford) [1046103]
- [infiniband] srp: Introduce srp_alloc_req_data() (Doug Ledford) [1046103]
- [infiniband] srp: Export sgid to sysfs (Doug Ledford) [1046103]
- [infiniband] srp: Add periodic reconnect functionality (Doug Ledford) [1046103]
- [scsi] scsi_transport_srp: Add periodic reconnect support (Doug Ledford) [1046103]
- [infiniband] srp: Start timers if a transport layer error occurs (Doug Ledford) [1046103]
- [infiniband] srp: Use SRP transport layer error recovery (Doug Ledford) [1046103]
- [scsi] scsi_transport_srp: Add transport layer error handling (Doug Ledford) [1046103]
- [infiniband] srp: Keep rport as long as the IB transport layer (Doug Ledford) [1046103]
- [infiniband] srp: Make transport layer retry count configurable (Doug Ledford) [1046103]
- [infiniband] srp: Let srp_abort() return FAST_IO_FAIL if TL offline (Doug Ledford) [1046103]
- [infiniband] srp: Bump driver version and release date (Doug Ledford) [1046103]
- [infiniband] srp: Make HCA completion vector configurable (Doug Ledford) [1046103]
- [infiniband] srp: Maintain a single connection per I_T nexus (Doug Ledford) [1046103]
- [infiniband] srp: Fail I/O fast if target offline (Doug Ledford) [1046103]
- [infiniband] srp: Skip host settle delay (Doug Ledford) [1046103]
- [infiniband] srp: Avoid skipping srp_reset_host() after a transport error (Doug Ledford) [1046103]
- [infiniband] srp: Fix remove_one crash due to resource exhaustion (Doug Ledford) [1046103]
- [infiniband] iser-target: Move INIT_WORK setup into isert_create_device_ib_res (Andy Grover) [1051179]
- [infiniband] iser-target: fix error return code in isert_create_device_ib_res() (Andy Grover) [1051179]
- [target] Fix delayed Task Aborted Status (TAS) handling bug (Andy Grover) [1051179]
- [x86] cpu: Always print SMP information in /proc/cpuinfo (Takahiro MUNEDA) [1062485]
- [x86] add rh_cpuinfo_x86 shadow struct (Prarit Bhargava) [1010325]
- [mm] thp: move preallocated PTE page table on move_huge_pmd() (Rik van Riel) [1063404]
- [mm] numa: initialise numa balancing after jump label initialisation (Rik van Riel) [1059459]
- [firmware] efivars: check for EFI_RUNTIME_SERVICES (Kyle McMartin) [1058525]

* Tue Feb 11 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-87.el7]
- [fs] nfs: fix mm page leak at nfs_symlink() (Rafael Aquini) [1060565]
- [kernel] sched/balancing: Periodically decay max cost of idle balance (Larry Woodman) [1031475]
- [kernel] sched/balancing: Consider max cost of idle balance per sched domain (Larry Woodman) [1031475]
- [kernel] sched: Reduce overestimating rq->avg_idle (Larry Woodman) [1031475]
- [fs] vfs: make sure we don't have a stale root path if unlazy_walk() fails (Rafael Aquini) [1031475]
- [fs] dcache: get/release read lock in read_seqbegin_or_lock() & friend (Rafael Aquini) [1031475]
- [fs] split read_seqretry_or_unlock(), convert d_walk() to resulting primitives (Rafael Aquini) [1031475]
- [lib] seqlock: Add a new locking reader type (Rafael Aquini) [1031475]
- [fs] dcache: Translating dentry into pathname without taking rename_lock (Rafael Aquini) [1031475]
- [fs] vfs: fix dentry RCU to refcounting possibly sleeping dput() (Rafael Aquini) [1031475]
- [fs] vfs: use lockred "dead" flag to mark unrecoverably dead dentries (Rafael Aquini) [1031475]
- [fs] vfs: reorganize dput() memory accesses (Rafael Aquini) [1031475]
- [fs] vfs: reimplement d_rcu_to_refcount() using lockref_get_or_lock() (Rafael Aquini) [1031475]
- [fs] vfs: use lockref_get_not_zero() for optimistic lockless dget_parent() (Rafael Aquini) [1031475]
- [fs] vfs: make the dentry cache use the lockref infrastructure (Rafael Aquini) [1031475]
- [fs] vfs: constify dentry parameter in d_count() (Rafael Aquini) [1031475]
- [fs] helper for reading ->d_count (Rafael Aquini) [1031475]
- [lib] lockref: use arch_mutex_cpu_relax() in CMPXCHG_LOOP() (Rafael Aquini) [1031475]
- [lib] lockref: allow relaxed cmpxchg64 variant for lockless updates (Rafael Aquini) [1031475]
- [lib] lockref: use cmpxchg64 explicitly for lockless updates (Rafael Aquini) [1031475]
- [lib] lockref: add ability to mark lockrefs "dead" (Rafael Aquini) [1031475]
- [lib] lockref: fix docbook argument names (Rafael Aquini) [1031475]
- [lib] lockref: Relax in cmpxchg loop (Rafael Aquini) [1031475]
- [lib] lockref: implement lockless reference count updates using cmpxchg() (Rafael Aquini) [1031475]
- [lib] lockref: uninline lockref helper functions (Rafael Aquini) [1031475]
- [lib] lockref: add 'lockref_get_or_lock() helper (Rafael Aquini) [1031475]
- [lib] Add new lockref infrastructure reference implementation (Rafael Aquini) [1031475]
- [s390] kdump: Increase crashkernel=auto base reservation from 128M to 160M (Baoquan He) [1052769]
- [scsi] Derive the FLUSH_TIMEOUT from the basic I/O timeout (Fam Zheng) [1047563]
- [acpi] Enhance ACPI warning for memory/IO address conflicts (Prarit Bhargava) [1047974]

* Mon Feb 10 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-86.el7]
- [scsi] hpsa: mark hpsa as a tech preview (Tomas Henzl) [1061210]
- [x86] mark known Intel processors as supported (Prarit Bhargava) [920766]
- [drm] mgag200: fix oops in cursor code (Dave Airlie) [1044701 1045159 1052739]
- [kernel] audit: printk USER_AVC messages when audit isn't enabled (Richard Guy Briggs) [1051539]
- [cpufreq] Do not hold driver module references for additional policy CPUs (Prarit Bhargava) [1043788]
- [cpufreq] Remove extra variables from cpufreq_add_dev_symlink() (Prarit Bhargava) [1043788]
- [net] tuntap: Fix for a race in accessing numqueues (Jason Wang) [1056399]
- [mm] numa: add a sysctl for numa_balancing (Rik van Riel) [1059782]
- [pci] Create 'pci_driver_rh' KABI shadowing structure (Myron Stowe) [1053796]
- [pci] Convert 'pci_bus' allocations and frees (Myron Stowe) [1053796]
- [pci] Create 'pci_bus_rh' KABI shadowing structure (Myron Stowe) [1053796]
- [pci] Convert specific 'pci_dev' related constructs (Myron Stowe) [1053796]
- [pci] Convert 'pci_dev' allocations and frees (Myron Stowe) [1053796]
- [pci] Create 'pci_dev_rh' KABI shadowing structure (Myron Stowe) [1053796]
- [fs] proc/meminfo: provide estimated available memory (Luiz Capitulino) [1058977]
- [x86] apic, kexec: Add disable_cpu_apicid kernel parameter (Baoquan He) [994688]
- [drm] mgag200: fix typo causing bw limits to be ignored on some chips (Dave Airlie) [1045495]
- [drm] ast, cirrus, mgag200: use drm_can_sleep (Dave Airlie) [1056989]
- [mm] prevent setting of a value less than 0 to min_free_kbytes (Steve Best) [1050899]
- [powerpc] perf: BHRB filter configuration should follow the task (Steve Best) [1061191]
- [powerpc] perf: Ignore separate BHRB privilege state filter request (Steve Best) [1061191]
- [ethernet] cxgb4: Avoid disabling PCI device twice (Steve Best) [1055438]
- [ethernet] cxgb4: Don't retrieve stats during recovery (Steve Best) [1055438]

* Fri Feb 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-85.el7]
- [kernel] errno: remove "NFS" from descriptions in comments (Eric Sandeen) [1009682]
- [md] dm-cache: do not add migration to completed list before unhooking bio (Mike Snitzer) [1057197]
- [md] dm-cache: move hook_info into common portion of per_bio_data structure (Mike Snitzer) [1057197]
- [powerpc] Add debug checks to catch invalid cpu-to-node mappings (Steve Best) [1042526]
- [powerpc] Fix the setup of CPU-to-Node mappings during CPU online (Steve Best) [1042526]
- [md] avoid deadlock when dirty buffers during md_stop (Jes Sorensen) [1060027]
- [powerpc] Fix transactional FP/VMX/VSX unavailable handlers (Steve Best) [1052083]
- [powerpc] Don't corrupt transactional state when using FP/VMX in kernel (Steve Best) [1052083]
- [powerpc] Reclaim two unused thread_info flag bits (Steve Best) [1052083]
- [powerpc] Reset MSR_LE on signal entry (Steve Best) [1052083]
- [powerpc] Wrap MSR macros with parentheses (Steve Best) [1052083]
- [powerpc] Make flush_fp_to_thread() nop when CONFIG_PPC_FPU is disabled (Steve Best) [1052083]
- [powerpc] math-emu: Move the flush FPU state function into do_mathemu (Steve Best) [1052083]
- [powerpc] math-emu: Allow math-emu to be used for HW FPU (Steve Best) [1052083]
- [powerpc] remove the unused function disable_kernel_fp() (Steve Best) [1052083]
- [powerpc] Restore dbcr0 on user space exit (Steve Best) [1052083]
- [powerpc] Provide for giveup_fpu/altivec to save state in alternate location (Steve Best) [1052083]
- [powerpc] Put FP/VSX and VR state into structures (Steve Best) [1052083]
- [powerpc] kvm: Don't corrupt guest state when kernel uses VMX (Steve Best) [1052083]
- [powerpc] Fix VRSAVE handling (Steve Best) [1052083]
- [powerpc] Fix a number of sparse warnings (Steve Best) [1052083]
- [powerpc] Align thread->fpr to 16 bytes (Steve Best) [1052083]

* Tue Feb 04 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-84.el7]
- [s390] Unrevert kvm support patches (Jarod Wilson) [1035261]
- [security] selinux: Fix possible NULL pointer dereference in selinux_inode_permission() (Eric Sandeen) [829715]
- [scsi] qla2xxx: Correctly set the read_optrom pointer for ISP8044 (Chad Dupuis) [1057643]
- [scsi] bnx2fc: Fixed scsi_remove_target soft lockup when rmmod bnx2x (Maurizio Lombardi) [1031770]
- [scsi] config: remove LSI Logic New Generation RAID Device Drivers (Tomas Henzl) [979031]
- [scsi] qla4xxx: v5.04.00.03.07.00-k0 (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Recreate chap data list during get chap operation (Chad Dupuis) [1049707]
- [scsi] qla4xxx: overflow in qla4xxx_set_chap_entry() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix memory leak in qla4xxx_destroy_ddb (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix sparse warnings (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Handle IPv6 AEN notifications (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Update print statements in func qla4xxx_do_dpc() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Update print statements in func qla4xxx_eh_abort() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Update print statements in qla4xxx_mailbox_command() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Updated print for device login, logout path (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Remove unused code from qla4xxx_set_ifcb() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix failure of mbox 0x31 (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Reduce rom-lock contention during reset recovery (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Driver not able to collect minidump for ISP84xx (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix pending IO completion in reset path before initiating chip reset (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix processing response queue during probe (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix failure of IDC Time Extend mailbox command (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Clear DDB index map upon connection close failure (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Return correct error status from func qla4xxx_request_irqs() (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fixed AER reset sequence for ISP83xx/ISP84xx (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Correctly handle msleep_interruptible (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Rename ACB_STATE macros with IP_ADDRSTATE macros (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Use IDC_CTRL bit1 directly instead of AF_83XX_NO_FWDUMP flag (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Fix comments in code (Chad Dupuis) [1049707]
- [scsi] qla4xxx: Print WARN_ONCE() if iSCSI function presence bit removed (Chad Dupuis) [1049707]
- [scsi] qla4xxx: ISP8xxx: Correct retry of adapter initialization (Chad Dupuis) [1049707]
- [scsi] hpsa: allow SCSI mid layer to handle unit attention (Tomas Henzl) [1056703]
- [scsi] hpsa: do not require board "not ready" status after hard reset (Tomas Henzl) [1056703]
- [scsi] hpsa: enable unit attention reporting (Tomas Henzl) [1056703]
- [scsi] hpsa: rename scsi prefetch field (Tomas Henzl) [1056703]
- [scsi] hpsa: use workqueue instead of kernel thread for lockup detection (Tomas Henzl) [1056703]
- [scsi] hpsa: fix pci-ids (Tomas Henzl) [1056703]

* Mon Feb 03 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-83.el7]
- [tools] perf/stat: Add perf stat --transaction (Prarit Bhargava) [829878]
- [kernel] perf: Add Haswell ULT model number used in Macbook Air and other systems (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Support full width counting (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Add mem-loads/stores support for Haswell (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Support Haswell/v4 LBR format (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Move NMI clearing to end of PMI handler (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Add Haswell PEBS support (Prarit Bhargava) [829878]
- [kernel] perf_event_intel: Add Haswell PEBS record support (Prarit Bhargava) [829878]
- [md] dm-log-userspace: allow mark requests to piggyback on flush requests (Mike Snitzer) [1057197]
- [md] dm-space-map-metadata: fix bug in resizing of thin metadata (Mike Snitzer) [1057197]
- [md] dm-cache: add policy name to status output (Mike Snitzer) [1057197]
- [md] dm-thin: fix pool feature parsing (Mike Snitzer) [1057197]
- [md] dm-sysfs: fix a module unload race (Mike Snitzer) [1057197]
- [md] dm-snapshot: use dm-bufio prefetch (Mike Snitzer) [1057197]
- [md] dm-snapshot: use dm-bufio (Mike Snitzer) [1057197]
- [md] dm-snapshot: prepare for switch to using dm-bufio (Mike Snitzer) [1057197]
- [md] dm-snapshot: use GFP_KERNEL when initializing exceptions (Mike Snitzer) [1057197]
- [pci] Rename PCI_VC_PORT_REG1/2 to PCI_VC_PORT_CAP1/2 (Alex Williamson) [1053168]
- [pci] Add Virtual Channel to save/restore support (Alex Williamson) [1053168]
- [pci] Add support for save/restore of extended capabilities (Alex Williamson) [1053168]
- [pci] Add pci_wait_for_pending() (refactor pci_wait_for_pending_transaction()) (Alex Williamson) [1053168]
- [s390] increase CONFIG_NR_CPUS limit (Hendrik Brueckner) [1043827]
- [s390] sclp: fix size of sclp_cpu_info structure (Hendrik Brueckner) [1043827]
- [mm] create a separate slab for page->ptl allocation (Rik van Riel) [1058896]
- [mm] properly separate the bloated ptl from the regular case (Rik van Riel) [1058896]
- [mm] dynamically allocate page->ptl if it cannot be embedded to struct page (Rik van Riel) [1058896]
- [mm] x86: handle pgtable_page_ctor() fail (Rik van Riel) [1058896]
- [mm] s390: handle pgtable_page_ctor() fail (Rik van Riel) [1058896]
- [mm] powerpc: handle pgtable_page_ctor() fail (Rik van Riel) [1058896]
- [mm] allow pgtable_page_ctor() to fail (Rik van Riel) [1058896]
- [mm] x86: add missed pgtable_pmd_page_ctor/dtor calls for preallocated pmds (Rik van Riel) [1058896]
- [mm] x86: enable split page table lock for PMD level (Rik van Riel) [1058896]
- [mm] implement split page table lock for PMD level (Rik van Riel) [1058896]
- [mm] convert the rest to new page table lock api (Rik van Riel) [1058896]
- [mm] hugetlb: convert hugetlbfs to use split pmd lock (Rik van Riel) [1058896]
- [mm] hugetlb: grab a page_table_lock after page_cache_release (Rik van Riel) [1058896]
- [mm] thp: do not access mm->pmd_huge_pte directly (Rik van Riel) [1058896]
- [mm] thp: move ptl taking inside page_check_address_pmd() (Rik van Riel) [1058896]
- [mm] thp: change pmd_trans_huge_lock() to return taken lock (Rik van Riel) [1058896]
- [mm] introduce api for split page table lock for PMD level (Rik van Riel) [1058896]
- [mm] convert mm->nr_ptes to atomic_long_t (Rik van Riel) [1058896]
- [mm] rename USE_SPLIT_PTLOCKS to USE_SPLIT_PTE_PTLOCKS (Rik van Riel) [1058896]
- [mm] avoid increase sizeof(struct page) due to split page table lock (Rik van Riel) [1058896]
- [vfio] vfio-pci: Don't use device_lock around AER interrupt setup (Alex Williamson) [1045175]
- [vfio] vfio-pci: Use pci "try" reset interface (Alex Williamson) [1045175]
- [pci] Add pci_try_reset_function(), pci_try_reset_slot(), pci_try_reset_bus() (Alex Williamson) [1045175]
- [infiniband] make sure the src net is infiniband when create new link (Jay Fenlason) [1049143]

* Fri Jan 31 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-82.el7]
- [mm] Revisit tlb_flushall_shift tuning for page flushes except on IvyBridge (Rik van Riel) [1058886]
- [mm] change tlb_flushall_shift for IvyBridge (Rik van Riel) [1058886]
- [mm] Eliminate redundant page table walk during TLB range flushing (Rik van Riel) [1058886]
- [mm] Clean up inconsistencies when flushing TLB ranges (Rik van Riel) [1058886]
- [mm] thp: avoid PageUnevictable on active/inactive lru lists (Rafael Aquini) [982739]
- [mm] swap: clear PageActive before adding pages onto unevictable list (Rafael Aquini) [982739]
- [mm] remove lru parameter from __lru_cache_add and lru_cache_add_lru (Rafael Aquini) [982739]
- [mm] remove lru parameter from __pagevec_lru_add and remove parts of pagevec API (Rafael Aquini) [982739]
- [mm] activate !PageLRU pages on mark_page_accessed if page is on local pagevec (Rafael Aquini) [982739]
- [mm] pagevec: defer deciding which LRU to add a page to until pagevec drain time (Rafael Aquini) [982739]
- [mm] add tracepoints for LRU activation and insertions (Rafael Aquini) [982739]
- [kernel] audit: fix dangling keywords in audit_log_set_loginuid() output (Richard Guy Briggs) [1045670]
- [kernel] audit: don't generate loginuid log when audit disabled (Richard Guy Briggs) [1045670]
- [kernel] audit: fix type of sessionid in audit_set_loginuid() (Richard Guy Briggs) [1045670]
- [kernel] audit: audit feature to set loginuid immutable (Richard Guy Briggs) [1045670]
- [kernel] audit: audit feature to only allow unsetting the loginuid (Richard Guy Briggs) [1045670]
- [kernel] audit: allow unsetting the loginuid (with priv) (Richard Guy Briggs) [1045670]
- [kernel] audit: remove CONFIG_AUDIT_LOGINUID_IMMUTABLE (Richard Guy Briggs) [1045670]
- [kernel] audit: loginuid functions coding style (Richard Guy Briggs) [1045670]
- [kernel] audit: change decimal constant to macro for invalid uid (Richard Guy Briggs) [1045670]
- [mm] sched/numa: Turn some magic numbers into #defines (Rik van Riel) [1049096]
- [mm] sched/numa: Rename variables in task_numa_fault() (Rik van Riel) [1049096]
- [mm] sched/numa: Do statistics calculation using local variables only (Rik van Riel) [1049096]
- [mm] sched/numa: Normalize faults_cpu stats and weigh by CPU use (Rik van Riel) [1049096]
- [mm] sched/numa: Use active_nodes nodemask to limit numa migrations (Rik van Riel) [1049096]
- [mm] sched/numa: Build per numa_group active node mask from numa_faults_cpu statistics (Rik van Riel) [1049096]
- [mm] sched/numa: Track from which nodes NUMA faults are triggered (Rik van Riel) [1049096]
- [mm] sched/numa: Rename p->numa_faults to numa_faults_memory (Rik van Riel) [1049096]
- [mm] sched/numa: Remove p->numa_migrate_deferred (Rik van Riel) [1049096]
- [mm] sched: Calculate effective load even if local weight is 0 (Rik van Riel) [1049096]
- [net] ipv4: fix tunneled VM traffic over hw VXLAN/GRE GSO NIC (Michal Schmidt) [1031869]
- [net] netfilter: nf_nat: fix access to uninitialized buffer in IRC NAT helper (Daniel Borkmann) [1058782] {CVE-2014-1690}
- [net] packet: fix send path when running with proto == 0 (Jesper Brouer) [1058729]
- [net] packet: fix use after free race in send path when dev is released (Jesper Brouer) [1058729]
- [net] Fix memory leak if TPROXY used with TCP early demux (Florian Westphal) [1054483]
- [net] ipv6: simplify detection of first operational link-local address on interface (Jiri Pirko) [1047425]

* Thu Jan 30 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-81.el7]
- [infiniband] core: Resolve Ethernet L2 addresses when modifying QP (Doug Ledford) [1051187]
- [infiniband] ocrdma: Populate GID table with IP based gids (Doug Ledford) [1051187]
- [infiniband] ocrdma: Handle Ethernet L2 parameters for IP based GID addressing (Doug Ledford) [1051187]
- [infiniband] mlx4: Handle Ethernet L2 parameters for IP based GID addressing (Doug Ledford) [1051187]
- [infiniband] mlx4: Use IBoE (RoCE) IP based GIDs in the port GID table (Doug Ledford) [1051187]
- [infiniband] cma: IBoE (RoCE) IP based GID addressing (Doug Ledford) [1051187]
- [infiniband] core: Ethernet L2 attributes in verbs/cm structures (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix OCRDMA_GEN2_FAMILY macro definition (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix AV_VALID bit position (Doug Ledford) [1051187]
- [infiniband] ocrdma: enable build (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove redundant check in ocrdma_build_fr() (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix a crash in rmmod (Doug Ledford) [1051187]
- [infiniband] ocrdma: Silence an integer underflow warning (Doug Ledford) [1051187]
- [infiniband] Remove unnecessary semicolons (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix compiler warning about int/pointer size mismatch (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix passing wrong opcode to modify_srq (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fill PVID in UMC case (Doug Ledford) [1051187]
- [infiniband] ocrdma: Add ABI versioning support (Doug Ledford) [1051187]
- [infiniband] ocrdma: Consider multiple SGES in case of DPP (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix for displaying proper link speed (Doug Ledford) [1051187]
- [infiniband] ocrdma: Increase STAG array size (Doug Ledford) [1051187]
- [infiniband] ocrdma: Dont use PD 0 for userpace CQ DB (Doug Ledford) [1051187]
- [infiniband] ocrdma: FRMA code cleanup (Doug Ledford) [1051187]
- [infiniband] ocrdma: For ERX2 irrespective of Qid, num_posted offset is 24 (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix to work with even a single MSI-X vector (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove the MTU check based on Ethernet MTU (Doug Ledford) [1051187]
- [infiniband] ocrdma: Add support for fast register work requests (FRWR) (Doug Ledford) [1051187]
- [infiniband] ocrdma: Create IRD queue fix (Doug Ledford) [1051187]
- [infiniband] ocrdma: Cache recv DB until QP moved to RTR (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove __packed (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove driver QP state machine (Doug Ledford) [1051187]
- [infiniband] ocrdma: Don't allow zero/invalid sgid usage (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove redundant dev reference (Doug Ledford) [1051187]
- [infiniband] ocrdma: Style and redundant code cleanup (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix several stack info leaks (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove unused include (Doug Ledford) [1051187]
- [infiniband] ocrdma: Fix error return code in ocrdma_set_create_qp_rq_cmd() (Doug Ledford) [1051187]
- [infiniband] ocrdma: Reorg structures to avoid padding (Doug Ledford) [1051187]
- [infiniband] ocrdma: Change macros to inline funtions (Doug Ledford) [1051187]
- [infiniband] ocrdma: Set bad_wr in error case (Doug Ledford) [1051187]
- [infiniband] ocrdma: Replace ocrdma_err with pr_err (Doug Ledford) [1051187]
- [infiniband] ocrdma: Use MCC_CREATE_EXT_V1 for MCC create (Doug Ledford) [1051187]
- [infiniband] ocrdma: Remove use_cnt for queues (Doug Ledford) [1051187]
- [infiniband] uverbs: Check access to userspace response buffer in extended command (Doug Ledford) [1051187]
- [infiniband] uverbs: Check input length in flow steering uverbs (Doug Ledford) [1051187]
- [infiniband] uverbs: Set error code when fail to consume all flow_spec items (Doug Ledford) [1051187]
- [infiniband] uverbs: Check reserved fields in create_flow (Doug Ledford) [1051187]
- [infiniband] uverbs: Check comp_mask in destroy_flow (Doug Ledford) [1051187]
- [infiniband] uverbs: Check reserved field in extended command header (Doug Ledford) [1051187]
- [infiniband] uverbs: New macro to set pointers to NULL if length is 0 in INIT_UDATA() (Doug Ledford) [1051187]
- [infiniband] core: const'ify inbuf in struct ib_udata (Doug Ledford) [1051187]
- [infiniband] iwcm: Don't touch cm_id after deref in rem_ref (Doug Ledford) [1051187]
- [infiniband] ucma: Convert use of typedef ctl_table to struct ctl_table (Doug Ledford) [1051187]
- [infiniband] cm: Convert to using idr_alloc_cyclic() (Doug Ledford) [1051187]
- [infiniband] core: Encorce MR access rights rules on kernel consumers (Doug Ledford) [1051187]
- [infiniband] cma: Remove unused argument and minor dead code (Doug Ledford) [1051187]
- [infiniband] ucma: Discard events for IDs not yet claimed by user space (Doug Ledford) [1051187]
- [infiniband] core: Add Cisco usNIC rdma node and transport types (Doug Ledford) [1051187]
- [infiniband] netlink: Remove superfluous RDMA_NL_GET_OP() masking (Doug Ledford) [1051187]
- [infiniband] core: Pass imm_data from ib_uverbs_send_wr to ib_send_wr correctly (Doug Ledford) [1051187]
- [infiniband] cma: Check for GID on listening device first (Doug Ledford) [1051187]
- [infiniband] cma: Use cached gids (Doug Ledford) [1051187]
- [infiniband] cma: Set IBoE SL (user-priority) by egress map when using vlans (Doug Ledford) [1051187]
- [infiniband] cma: Add IPv6 support for iWARP (Doug Ledford) [1051187]
- [infiniband] cma: Only call cma_save_ib_info() for CM REQs (Doug Ledford) [1051187]
- [infiniband] cma: Fix accessing invalid private data for UD (Doug Ledford) [1051187]
- [infiniband] cma: Fix gcc warning (Doug Ledford) [1051187]
- [infiniband] uverbs: Use get_unused_fd_flags(O_CLOEXEC) instead of get_unused_fd() (Doug Ledford) [1051187]
- [misc] drivers: avoid format string in dev_set_name (Doug Ledford) [1051187]
- [infiniband] core: Fix error return code in add_port() (Doug Ledford) [1051187]
- [infiniband] cma: Export AF_IB statistics (Doug Ledford) [1051187]
- [infiniband] ucma: Allow user space to specify AF_IB when joining multicast (Doug Ledford) [1051187]
- [infiniband] ucma: Allow user space to pass AF_IB into resolve (Doug Ledford) [1051187]
- [infiniband] ucma: Allow user space to bind to AF_IB (Doug Ledford) [1051187]
- [infiniband] ucma: Name changes to indicate only IP addresses supported (Doug Ledford) [1051187]
- [infiniband] ucma: Add ability to query GID addresses (Doug Ledford) [1051187]
- [infiniband] cma: Export cma_get_service_id() (Doug Ledford) [1051187]
- [infiniband] ucma: Support querying when IB paths are not reversible (Doug Ledford) [1051187]
- [infiniband] sa: Export function to pack a path record into wire format (Doug Ledford) [1051187]
- [infiniband] ucma: Support querying for AF_IB addresses (Doug Ledford) [1051187]
- [infiniband] cma: Only listen on IB devices when using AF_IB (Doug Ledford) [1051187]
- [infiniband] cma: Set qkey for AF_IB (Doug Ledford) [1051187]
- [infiniband] cma: Expose private data when using AF_IB (Doug Ledford) [1051187]
- [infiniband] cma: Merge cma_get/save_net_info (Doug Ledford) [1051187]
- [infiniband] cma: Remove unused SDP related code (Doug Ledford) [1051187]
- [infiniband] cma: Add support for AF_IB to cma_get_service_id() (Doug Ledford) [1051187]
- [infiniband] cma: Add support for AF_IB to rdma_resolve_route() (Doug Ledford) [1051187]
- [infiniband] cma: Add support for AF_IB to rdma_resolve_addr() (Doug Ledford) [1051187]
- [infiniband] cma: Verify that source and dest sa_family are the same (Doug Ledford) [1051187]
- [infiniband] cma: Restrict AF_IB loopback to binding to IB devices only (Doug Ledford) [1051187]
- [infiniband] cma: Add helper functions to return id address information (Doug Ledford) [1051187]
- [infiniband] cma: Do not modify sa_family when setting loopback address (Doug Ledford) [1051187]
- [infiniband] cma: Allow user to specify AF_IB when binding (Doug Ledford) [1051187]
- [infiniband] cma: Update port reservation to support AF_IB (Doug Ledford) [1051187]
- [infiniband] addr: Add AF_IB support to ip_addr_size (Doug Ledford) [1051187]
- [infiniband] cma: Include AF_IB in loopback and any address checks (Doug Ledford) [1051187]
- [infiniband] cma: Allow enabling reuseaddr in any state (Doug Ledford) [1051187]
- [infiniband] cma: Define native IB address (Doug Ledford) [1051187]
- [net] vlan: Fix header ops passthru when doing TX VLAN offload (Doug Ledford) [1051187]
- [net] vlan: Implement vlan_dev_get_egress_qos_mask as an inline (Doug Ledford) [1051187]
- [net] vlan: Provide read access to the vlan egress map (Doug Ledford) [1051187]
- [net] vlan: make vlan_dev_real_dev work over stacked vlans (Doug Ledford) [1051187]
- [net] vlan: cleanup the usage of vlan_dev_priv(dev) (Doug Ledford) [1051187]
- [ethernet] mlx4: Remove unnecessary validation for port number (Amir Vadai) [1030563]
- [ethernet] mlx4: Warn if device doesn't have enough PCI bandwidth (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: lower NAPI weight (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Start multicast join process only on active ports (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Add path query flushing in ipoib_ib_dev_cleanup (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Fix usage of uninitialized multicast objects (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Avoid flushing the driver workqueue on dev_down (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Fix deadlock between dev_change_flags() and __ipoib_dev_flush() (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Change CM skb memory allocation to be non-atomic during init (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Fix crash in dev_open error flow (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] ipoib: Fix race in deleting ipoib_neigh entries (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Only cycle port if HW timestamp config changes (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add PTP hardware clock (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix layout of struct mlx5_init_seg (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Flush cache workqueue before destroying it (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add netdev support for TCP/IP offloads of vxlan tunneling (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add basic support for TCP/IP offloads under tunneling (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Check port number for validity before accessing data (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add NAPI support for transmit side (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Ignore irrelevant hypervisor events (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Set CQE/EQE size to 64B by default (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Configure the XPS queue mapping on driver load (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Implement ndo_get_phys_port_id (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Expose physical port id as PF/VF capability (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Introduce nic_info new flag in QUERY_FUNC_CAP (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Rename QUERY_FUNC_CAP fields (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Remove zeroed out of explicit QUERY_FUNC_CAP fields (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Roll back round robin bitmap allocation commit for CQs, SRQs, and MPTs (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: destroy workqueue when driver fails to register (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Remove selftest TX queues empty condition (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Re-enable create_flow/destroy_flow uverbs (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: extended command: an improved infrastructure for uverbs commands (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Remove ib_uverbs_flow_spec structure from userspace (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Use a common header for uverbs flow_specs (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Make uverbs flow structure use names like verbs ones (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Rename 'flow' structs to match other uverbs structs (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: clarify overflow/underflow checks on ib_create/destroy_flow (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix page shift in create CQ for userspace (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx4: Fix device max capabilities check (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix list_del of empty list (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Remove dead code (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx4: Fix endless loop in resize CQ (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Use enum to indicate adapter page size (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Update opt param mask for RTS2RTS (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Remove "Always false" comparison (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Remove dead code in mr.c (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Change optimal_reclaimed_pages for better performance (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Clear reserved area in set_hca_cap() (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Support communicating arbitrary host page size to firmware (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Fix cleanup flow when DMA mapping fails (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix srq free in destroy qp (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Simplify mlx5_ib_destroy_srq (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix overflow check in IB_WR_FAST_REG_MR (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Multithreaded create MR (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix check of number of entries in create CQ (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Datapath structures are allocated per NUMA node (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: ICM pages are allocated on device NUMA node (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Datapath resources allocated dynamically (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add immediate activate for VGT->VST->VGT (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Initialize all mailbox buffers to zero before use (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Add RFS support in UDP (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Implement resource quota enforcement (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Fix quota handling in the QUERY_FUNC_CAP wrapper (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Structures and init/teardown for VF resource quotas (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Fix checking order in MR table init (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Don't fail reg/unreg vlan for older guests (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Resource tracker for reg/unreg vlans (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Use vlan id instead of vlan index for unregistration (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Fix reg/unreg vlan/mac to conform to the firmware spec (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Fix register/unreg vlan flow (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] core: Temporarily disable create_flow/destroy_flow uverbs (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Load higher level modules according to ports type (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Unused local variable in mlx4_opreq_action (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Fix typo, move similar defs to same location (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Clean the code to eliminate trivial build warnings (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Ensure proper synchronization accessing memory (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix alignment of reg umr gather buffers (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix eq names to display nicely in /proc/interrupts (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Fix error code translation from firmware to driver (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix opt param mask according to firmware spec (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix opt param mask for sq err to rts transition (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Disable atomic operations (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Keep polling to reclaim pages while any returned (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Avoid async events on invalid port number (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Decrease memory consumption of mr caches (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx5: Remove checksum on command interface commands (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix memory leak in mlx5_ib_create_srq (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [infiniband] mlx5: Fix send work queue size calculation (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Rename name of mlx4_en_rx_alloc members (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Check device state when setting coalescing (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [ethernet] mlx4: Reduce scope of local variables in mlx4_en_xmit (Amir Vadai) [1030563 1030565 1030568 1030570 1030571 1030573 1030575]
- [scsi] reserve extension space to prevent KABI breakages (Maurizio Lombardi) [1029903]
- [security] selinux: selinux_setprocattr()->ptrace_parent() needs rcu_read_lock() (Paul Moore) [800159]

* Mon Jan 27 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-80.el7]
- [misc] synchronize with upstream linux-3.10.y stable branch up to 3.10.24 (Veaceslav Falico) [1040946]
- [acpi] memhotplug: add parameter to disable memory hotplug (Prarit Bhargava) [1046555]
- [kernel] kdump: Increase x86 crashkernel=auto base reservation from 128M to 160M (Baoquan He) [1044832]
- [mfd] lpc_ich: Add support for Intel Avoton SoC (Prarit Bhargava) [1049638]
- [net] ipv6: send Change Status Report after DAD is completed (Flavio Leitner) [1049092]
- [mm] Revert: new shrinker count/scan API (Mike Snitzer) [1056647]
- [drm] Revert: convert shrinkers to new count/scan API (Mike Snitzer) [1056647]

* Thu Jan 23 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-79.el7]
- [virt] virtio-net: put virtio net header inline with data ("Michael S. Tsirkin") [990993]
- [virt] virtio: VIRTIO_F_ANY_LAYOUT feature ("Michael S. Tsirkin") [990993]
- [tools] turbostat: servers do not support uncore power register (Prarit Bhargava) [1037706]
- [alsa] pcsp: Fix the order of input device unregistration (Jaroslav Kysela) [1044022]
- [alsa] ak4114: Fix wrong register array size (Jaroslav Kysela) [1044022]
- [alsa] pcsp: Fix initialization with nopcm=1 (Jaroslav Kysela) [1044022]
- [alsa] opl3: Fix possible negative array index access (Jaroslav Kysela) [1044022]
- [alsa] tea575x-tuner: move HW init to a separate function (Jaroslav Kysela) [1044022]
- [alsa] ak4xx-adda: info leak in ak4xxx_capture_source_info() (Jaroslav Kysela) [1044022]
- [alsa] vx_core: off by one in vx_read_status() (Jaroslav Kysela) [1044022]
- [alsa] Remove the rest of *_set_drvdata(NULL) calls (Jaroslav Kysela) [1044022]
- [alsa] virmidi: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] serial-u16550: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] pcsp: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] mtpav: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] mpu401: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] ml403-ac97cr: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] aloop: Remove redundant platform_set_drvdata() (Jaroslav Kysela) [1044022]
- [alsa] firewire-lib: use inlune function to calculate frame bytes (Jaroslav Kysela) [1044022]
- [alsa] firewire-speakers: remove not-reused member from structure (Jaroslav Kysela) [1044022]
- [alsa] snd-firewire-lib: remove unused header inclusion (Jaroslav Kysela) [1044022]
- [alsa] firewire: fix error return code in scs_probe() (Jaroslav Kysela) [1044022]
- [alsa] hda: Add Dell headset detection quirk for three laptop models (Jaroslav Kysela) [1044022]
- [alsa] hda: Add enable_msi=0 workaround for four HP machines (Jaroslav Kysela) [1044022]
- [alsa] hda: Split verb definitions into sound/hda_verbs.h (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable stereo mix as default for AD and VIA codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: Ignore small negative LPIB delay correction (Jaroslav Kysela) [1044022]
- [alsa] hda: Add missing initialization of aamix paths (Jaroslav Kysela) [1044022]
- [alsa] hda: Allow capture-only configuration (Jaroslav Kysela) [1044022]
- [alsa] hda: skip depop delay before D3 for Haswell and Valleyview2 display codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Clean up async codec PM using standard async infrastructure (Jaroslav Kysela) [1044022]
- [alsa] hda: fixup ALC262 to skip depop delay before D3 on Intel BayleyBay (Jaroslav Kysela) [1044022]
- [alsa] hda: Always do delayed probes for HD-audio devices (Jaroslav Kysela) [1044022]
- [alsa] hda: allow a codec to define its own depop delay time (Jaroslav Kysela) [1044022]
- [alsa] hda: fixup ALC262 to remove depop delay on Intel BayleyBay board (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Remove depop delay for suspend and resume if applicable (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Add more codecs alias name for Dell (Jaroslav Kysela) [1044022]
- [alsa] hda: resume codecs in parallel (Jaroslav Kysela) [1044022]
- [alsa] hda: suspend codecs in parallel (Jaroslav Kysela) [1044022]
- [alsa] hda: Disable runtime PM when EPSS is unavailable (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable runtime PM on Panther Point (Jaroslav Kysela) [1044022]
- [alsa] hda: Refactor pm notification in hda_codec.c (Jaroslav Kysela) [1044022]
- [alsa] hda: Bind with HDMI codec parser automatically (Jaroslav Kysela) [1044022]
- [alsa] hda: Split the generic parser as an individual module (Jaroslav Kysela) [1044022]
- [alsa] hda: Add static DAC/pin mapping for AD1986A codec (Jaroslav Kysela) [1044022]
- [alsa] hda: One more Dell headset detection quirk (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix IEC958 ctl indexes for some simple HDMI devices (Jaroslav Kysela) [1044022]
- [alsa] hda: Mute all aamix inputs as default (Jaroslav Kysela) [1044022]
- [alsa] hda: Another Dell headset detection quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: A Dell headset detection quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove quirk for Dell Vostro 131 (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: fix uninitialized variable compile warning (Jaroslav Kysela) [1044022]
- [alsa] hda: fix mic issues on Acer Aspire E-572 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix silent output on MacBook Air 2,1 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix missing ELD info when using jackpoll_ms parameter (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: remove hp_automute_hook from alc283_fixup_chromebook (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Independent of model for HP (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix headset mic input after muted internal mic (Dell/Realtek) (Jaroslav Kysela) [1044022]
- [alsa] hda: Use always amps for auto-mute on AD1986A codec (Jaroslav Kysela) [1044022]
- [alsa] hda/analog: Handle inverted EAPD properly in vmaster hook (Jaroslav Kysela) [1044022]
- [alsa] hda: Another fixup for ASUS laptop with ALC660 codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix complete_all() timing in deferred probes (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix bad EAPD setup for HP machines with AD1984A (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix silent output on ASUS W7J laptop (Jaroslav Kysela) [1044022]
- [alsa] hda: Add mono speaker quirk for Dell Inspiron 5439 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add LFE chmap to ASUS ET2700 (Jaroslav Kysela) [1044022]
- [alsa] hda: Initialize missing bass speaker pin for ASUS AIO ET2700 (Jaroslav Kysela) [1044022]
- [alsa] hda: limit mic boost on Asus UX31[A,E] (Jaroslav Kysela) [1044022]
- [alsa] hda: Check leaf nodes to find aamix amps (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix hp-mic mode without VREF bits (Jaroslav Kysela) [1044022]
- [alsa] hda: Create Headhpone Mic Jack Mode when really needed (Jaroslav Kysela) [1044022]
- [alsa] usb: use multiple packets per urb for Wireless USB inbound audio (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable mute/mic-mute LEDs for more Thinkpads with Conexant codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Drop bus->avoid_link_reset flag (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Set pcbeep amp for ALC668 (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Add support of ALC231 codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Set current_headset_type to ALC_HEADSET_TYPE_ENUM (Jaroslav Kysela) [1044022]
- [alsa] hda: Provide missing pin configs for VAIO with ALC260 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add headset quirk for Dell Inspiron 3135 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix the headphone jack detection on Sony VAIO TX (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix missing bass speaker on ASUS N550 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix unbalanced runtime PM notification at resume (Jaroslav Kysela) [1044022]
- [alsa] hda: A casual Dell Headset quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: Also enable mute/micmute LED control for "Lenovo dock" fixup (Jaroslav Kysela) [1044022]
- [alsa] hda: Select FW_LOADER from CONFIG_SND_HDA_CODEC_CA0132_DSP (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable mute/mic-mute LEDs for more Thinkpads with Realtek codec (Jaroslav Kysela) [1044022]
- [alsa] hda: load EQ params into IDT codec on HP bNB13 systems (Jaroslav Kysela) [1044022]
- [alsa] jack: Unregister input device at disconnection (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: add front jack channel selector for EMU0204 (Jaroslav Kysela) [1044022]
- [alsa] hda: Don't clear the power state at snd_hda_codec_reset() (Jaroslav Kysela) [1044022]
- [alsa] hda: Control EAPD for Master volume on Lenovo N100 (Jaroslav Kysela) [1044022]
- [alsa] hda: Don't turn off EAPD for headphone on Lenovo N100 (Jaroslav Kysela) [1044022]
- [alsa] hda: Check keep_eapd_on before inv_eapd (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix Line Out automute on Realtek multifunction jacks (Jaroslav Kysela) [1044022]
- [alsa] compress_core: don't return -EBADFD from poll if paused (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix wrong baseline length in ATI/AMD generated ELD (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Skip out-of-range latency values in AMD ELD generator (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Add error-checking to some codec reads (Jaroslav Kysela) [1044022]
- [alsa] usb: Fix wrong mapping of RLC and RRC channels (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Use TFx channel positions instead of FxH (Jaroslav Kysela) [1044022]
- [alsa] hda: Control SPDIF out pin on MacBookPro 11,2 (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Add new codec ALC255/ALC3234 UAJ supported (Jaroslav Kysela) [1044022]
- [alsa] hda: Apply MacBook fixups for CS4208 correctly (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Make fixup regs persist after resume (Jaroslav Kysela) [1044022]
- [alsa] hda_intel: ratelimit "spurious response" message (Jaroslav Kysela) [1044022]
- [alsa] hda: Get rid of AMD HDMI exception in hdmi_present_sense() (Jaroslav Kysela) [1044022]
- [alsa] ice1724: Fix compile warning with CONFIG_PROC_FS=n (Jaroslav Kysela) [1044022]
- [alsa] hda: block HDMI jack reports while repolling (Jaroslav Kysela) [1044022]
- [alsa] hda: Add a block_report flag to jacks (Jaroslav Kysela) [1044022]
- [alsa] hda: Delay HDMI presence reports while waiting for ELD information (Jaroslav Kysela) [1044022]
- [alsa] compress: fix drain calls blocking other compress functions (Jaroslav Kysela) [1044022]
- [alsa] hda: Another Dell headset quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: Add pincfg fixup for ASUS W5A (Jaroslav Kysela) [1044022]
- [alsa] hda: Add support for CX20952 (Jaroslav Kysela) [1044022]
- [alsa] lx6464es: Fix pointer cast compile warnings (Jaroslav Kysela) [1044022]
- [alsa] hda: Limit mic boost and add mute LED for an HP machine (Jaroslav Kysela) [1044022]
- [alsa] hda: Make sure mute LEDs stay on during runtime suspend (Realtek) (Jaroslav Kysela) [1044022]
- [alsa] ctxfi: Use WARN_ON() instead of BUG_ON() (Jaroslav Kysela) [1044022]
- [alsa] intel8x0: Fix chmap application (Jaroslav Kysela) [1044022]
- [alsa] hda: Apply GPIO setup for MacBooks with CS4208 (Jaroslav Kysela) [1044022]
- [alsa] hda: Name Haswell HDMI controllers better (Jaroslav Kysela) [1044022]
- [alsa] hda: Force buffer alignment for Haswell HDMI controllers (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable Thinkpad mute/micmute LEDs for Realtek (Jaroslav Kysela) [1044022]
- [alsa] hda: add device IDs for AMD Evergreen/Northern Islands HDMI (Jaroslav Kysela) [1044022]
- [alsa] hda: Introduce the bitmask for excluding output volume (Jaroslav Kysela) [1044022]
- [alsa] hda: Add sanity check of vmaster slave dB steps (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix possible zero-division (Jaroslav Kysela) [1044022]
- [alsa] usb: Don't trust the channel config if the channel count changed (Jaroslav Kysela) [1044022]
- [alsa] usb: For class 2 devices, use channel map from altsettings (Jaroslav Kysela) [1044022]
- [alsa] usb: supply channel maps even when wChannelConfig is unspecified (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable SPDIF for Acer TravelMate 6293 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add Device IDs for Intel Wildcat Point-LP PCH (Jaroslav Kysela) [1044022]
- [alsa] hda: rename function not_share_unassigned_cvt() (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Disallow unsupported 2ch remapping on NVIDIA codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: not choose assigned converters for unused pins of Valleyview (Jaroslav Kysela) [1044022]
- [alsa] hda: Add extra chmap for 2.1 outputs on ASUS laptops (Jaroslav Kysela) [1044022]
- [alsa] hda: Disable AA-loopback on ALC283 Chromebook (Jaroslav Kysela) [1044022]
- [alsa] lola: Fix uninitialized variable access in error message (Jaroslav Kysela) [1044022]
- [alsa] ice1724: Fix uninitialized variable access (Jaroslav Kysela) [1044022]
- [alsa] rme96: Return error code in PCM copy ops (Jaroslav Kysela) [1044022]
- [alsa] ali5451: Drop unused variable (Jaroslav Kysela) [1044022]
- [alsa] ad1889: Fix right attenuation proc output (Jaroslav Kysela) [1044022]
- [alsa] Use strlcpy() instead of strncpy() (Jaroslav Kysela) [1044022]
- [alsa] Limit the fallback card id string size (Jaroslav Kysela) [1044022]
- [alsa] memalloc: NULL-initialize in snd_malloc_dev_iram() (Jaroslav Kysela) [1044022]
- [alsa] memalloc: Make snd_{malloc|free}_dev_iram() static (Jaroslav Kysela) [1044022]
- [alsa] Optimize module name check (Jaroslav Kysela) [1044022]
- [alsa] pcm: Add fallthru comments (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove locally dead codes (Jaroslav Kysela) [1044022]
- [alsa] hda: Add a fallthru comment (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix possible NULL dereference in snd_hda_get_pin_label() (Jaroslav Kysela) [1044022]
- [alsa] 6fire: Fix probe of multiple cards (Jaroslav Kysela) [1044022]
- [alsa] memalloc: Yet another ifdef CONFIG_GENERIC_ALLOCATOR protection (Jaroslav Kysela) [1044022]
- [alsa] pcm_dmaengine: Remove hardcoded PCM formats (Jaroslav Kysela) [1044022]
- [alsa] hda: Sync EAPD with vmaster on AD1984A Thinkpads (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix silent headphone on Thinkpads with AD1984A codec (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Re-setup pin and infoframe on plug-in on all codecs (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Disable ramp-up/down for non-PCM on AMD codecs (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Add HBR bitstreaming support for ATI/AMD HDMI codecs (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Add ELD emulation for ATI/AMD codecs (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Add ATI/AMD multi-channel audio support (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Allow HDA patches to customize more operations (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Raise the delay for alc283_shutup (Jaroslav Kysela) [1044022]
- [alsa] compress: fix drain calls blocking other compress functions (Jaroslav Kysela) [1044022]
- [alsa] Add ifdef CONFIG_GENERIC_ALLOCATOR for SNDRV_DMA_TYPE_IRAM code (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix mute LED on HP laptops in runtime suspend (Jaroslav Kysela) [1044022]
- [alsa] hda: Add support of ALC285 / ALC293 codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: Add support of ALC255 codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove OOM message after input_allocate_device (Jaroslav Kysela) [1044022]
- [alsa] Add SoC on-chip internal ram support for DMA buffer allocation (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix typos in patch_hdmi.c (Jaroslav Kysela) [1044022]
- [alsa] hda: add codec ID for Valleyview2 display codec (Jaroslav Kysela) [1044022]
- [alsa] emu10k1: code refactoring (Jaroslav Kysela) [1044022]
- [alsa] hda: Move mutex from hda_eld to per_pin in HDMI codec driver (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix possible races in HDMI driver (Jaroslav Kysela) [1044022]
- [alsa] hda: Treat zero connection as non-error (Jaroslav Kysela) [1044022]
- [alsa] hda: add connection to thinkpad_acpi to control mute/micmute LEDs (Jaroslav Kysela) [1044022]
- [alsa] hda: add HDA_FIXUP_ACT_FREE action (Jaroslav Kysela) [1044022]
- [alsa] hdsp: info leak in snd_hdsp_hwdep_ioctl() (Jaroslav Kysela) [1044022]
- [alsa] Remove unnecessary semicolons (Jaroslav Kysela) [1044022]
- [alsa] hda: Sony VAIO Pro 13 (haswell) now has a working headset jack (Jaroslav Kysela) [1044022]
- [alsa] hda: Add a headset mic model for ALC269 and friends (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable surround speakers (when line out is also present) (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: Use module_usb_driver (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: support wireless devices in snd_usb_parse_datainterval (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: add support for wireless USB devices (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Tweak debug messages to be more useful (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix available channel maps missing from TLV (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix channel maps with less common speakers (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix unused slots being enabled in manual and non-PCM mappings (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix programmed active channel count (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: Fix incorrect default channel mapping for unusual CAs (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove unused endpoint flag EP_FLAG_ACTIVATED (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: rename alt_idx to altsetting (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: clear SUBSTREAM_FLAG_SYNC_EP_STARTED on error (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: void return type of snd_usb_endpoint_deactivate() (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: don't deactivate URBs on in-use EP (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove deactivate_endpoints() (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove unused parameter from sync_ep_set_params (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix mono speakers and headset mic on Dell Vostro 5470 (Jaroslav Kysela) [1044022]
- [alsa] snd-usb-caiaq: LED support for Maschine Controller (Jaroslav Kysela) [1044022]
- [alsa] ac97: Add ID for TI TLV320AIC27 codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable internal mic on a Thinkpad machine with ALC283 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix Internal Mic boost can't control with ALC283 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add fixup for MacBook Air 6,1 and 6,2 with CS4208 codec (Jaroslav Kysela) [1044022]
- [alsa] improve buffer size computations for USB PCM audio (Jaroslav Kysela) [1044022]
- [alsa] hda: not use assigned converters for all unused pins (Jaroslav Kysela) [1044022]
- [alsa] compress: Make sure we trigger STOP before closing the stream (Jaroslav Kysela) [1044022]
- [alsa] rme9652: Remove redundant break (Jaroslav Kysela) [1044022]
- [alsa] au88x0: Remove redundant break (Jaroslav Kysela) [1044022]
- [alsa] hda/ca0132: Staticize codec_send_command (Jaroslav Kysela) [1044022]
- [alsa] ctxfi: Staticize local symbols (Jaroslav Kysela) [1044022]
- [alsa] asihpi: a couple array out of bounds issues (Jaroslav Kysela) [1044022]
- [alsa] hda: Add CS4208 codec support for MacBook 6,1 and 6,2 (Jaroslav Kysela) [1044022]
- [alsa] hda: unmute pin amplifier in infoframe setup for Haswell (Jaroslav Kysela) [1044022]
- [alsa] hda: define is_haswell() to check if a display audio codec is Haswell (Jaroslav Kysela) [1044022]
- [alsa] hda: Add dock speaker support for ASUS TX300 (Jaroslav Kysela) [1044022]
- [alsa] snd/hda: add runtime suspend/resume on optimus support (Jaroslav Kysela) [1044022]
- [alsa] hda: Simplify CONFIG_SND_HDA_I915 condition (Jaroslav Kysela) [1044022]
- [alsa] hda: add device entry and inactive flag to unsolicited response (Jaroslav Kysela) [1044022]
- [alsa] hda: Haswell codec exposes device list/select info on pins (Jaroslav Kysela) [1044022]
- [alsa] hda: add device list & select info of display pins to codec proc file (Jaroslav Kysela) [1044022]
- [alsa] hda: add flags and routines to get devices selection info for DP1.2 MST (Jaroslav Kysela) [1044022]
- [alsa] treewide: Fix printks with 0x# (Jaroslav Kysela) [1044022]
- [alsa] alsa/rme96: Add missing inclusion of linux/vmalloc.h (Jaroslav Kysela) [1044022]
- [alsa] rme96: Check the return value of pci_enable_device() in resume callback (Jaroslav Kysela) [1044022]
- [alsa] hda: Add workarounds for pop-noise on Chromebook with ALC283 (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix ALC283 headphone pop-noise better (Jaroslav Kysela) [1044022]
- [alsa] rme96: Add PM support v3 (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Use enums in hdspm_tco_ltc_frames() (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Fix default value in SNDRV_HDSPM_IOCTL_GET_LTC (Jaroslav Kysela) [1044022]
- [alsa] pcm: Use snd_printd_ratelimit() (Jaroslav Kysela) [1044022]
- [alsa] pcm: Add snd_printd_ratelimit() (Jaroslav Kysela) [1044022]
- [alsa] hda: Try to allow haswell HDMI audio even without powerwell (Jaroslav Kysela) [1044022]
- [alsa] hda: Limit internal mic boost for a few more Thinkpad machines (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix the order of a quirk table (janitorial) (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix internal mic boost on three Thinkpad machines (Jaroslav Kysela) [1044022]
- [alsa] rme96: Add pcm stream synchronization (Jaroslav Kysela) [1044022]
- [alsa] hda: Mute the right widget in auto_mute_via_amp mode (Jaroslav Kysela) [1044022]
- [alsa] hda: Allow auto_mute_via_amp on bind mute controls (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: fix automatic Roland/Yamaha MIDI detection (Jaroslav Kysela) [1044022]
- [alsa] don't push static constants on stack for *ph (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: WARN_ON when alts is passed as NULL (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove implicit_fb from quirk (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove is_playback from implicit feedback quirks (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: do not initialize and check implicit_fb (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: reverse condition logic in set_sync_endpoint (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: move implicit fb quirks to separate function (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: separate sync endpoint setting from set_format (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove assignment from if condition (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove disabled debug code in set_format (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix jack gating when auto_{mute,mic} is suppressed (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix invalid multi-io creation on VAIO-Z laptops (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove analog mic pin override from STAC9228 dell-bios quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: WAKEEN feature enabling for runtime pm (Jaroslav Kysela) [1044022]
- [alsa] hda: jack poll once if jackpoll_interval==0 (Jaroslav Kysela) [1044022]
- [alsa] hda: Clearing jackpoll_interval avoid pending work (Jaroslav Kysela) [1044022]
- [alsa] usx2y: remove an unneeded check (Jaroslav Kysela) [1044022]
- [alsa] hda: use azx_writew() for 16-bit length register (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix the noise after suspend on ALC283 codec (Jaroslav Kysela) [1044022]
- [alsa] hda/realtek: Selectively call snd_hda_shutup_pins() (Jaroslav Kysela) [1044022]
- [alsa] hiface: return correct XRUN indication (Jaroslav Kysela) [1044022]
- [alsa] replace strict_strto*() with kstrto*() (Jaroslav Kysela) [1044022]
- [alsa] hda: Add snd_hda_jack_detect_state() helper function (Jaroslav Kysela) [1044022]
- [alsa] thinkpad-acpi: Add mute and mic-mute LED functionality (Jaroslav Kysela) [1044022]
- [alsa] hda: Headphone mic support for an Asus/Conexant device (Jaroslav Kysela) [1044022]
- [alsa] hdspm: remove unneeded semicolon (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: fix regression for fixed stream quirk (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove static quirks for AD1986A codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Drop a few other static quirks for AD1986A (Jaroslav Kysela) [1044022]
- [alsa] hda: Drop static quirk for Toshiba Satellite L40-10Q (Jaroslav Kysela) [1044022]
- [alsa] hda: Drop static quirks for other AD1986A Samsung machines (Jaroslav Kysela) [1044022]
- [alsa] hda: Convert static quirks for AD1986A Samsung laptops (Jaroslav Kysela) [1044022]
- [alsa] hda: Convert the static quirk for Samsung Q1 Ultra (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove static quirks for AD1988 codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove static quirks for AD1981 and AD1983 codecs (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove static quirks for AD1884/1984 & variants (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove static quirks for AD1882 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add fixup for HP TouchSmart with AD1984A codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Add fixup for Lenovo Thinkpad with AD1984 codec (Jaroslav Kysela) [1044022]
- [alsa] hda: Add GPIO control to AD1884 HP fixup (Jaroslav Kysela) [1044022]
- [alsa] hda: Move azx_first_init() into azx_probe_continue() (Jaroslav Kysela) [1044022]
- [alsa] hda: Fix runtime PM check (Jaroslav Kysela) [1044022]
- [alsa] hda: Add power-welll support for haswell HDA (Jaroslav Kysela) [1044022]
- [alsa] hda: Keep halting ALC5505 DSP (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Added some comments and control register documentation (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Use snd_ctl_enum_info() in snd_hdspm_info_autosync_ref (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Use snd_ctl_enum_info() for texts_autosync (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Use snd_ctl_enum_info for most text arrays (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Enable TCO support (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Report external sample rate to userspace (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Introduce hdspm_external_rate_to_enum() helper function (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Include TCO and Sync-In in proc output (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Enable TCO/Sync-In in snd_hdspm_put_sync_ref() (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Enable TCO input in hdspm_external_sample_rate() (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Ignore float/int format bit (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Enable AES32 in hdspm_get_tco_sample_rate (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Enable AES32 in hdspm_get_wc_sample_rate (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add prototype declarations (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Introduce hdspm_get_aes_sample_rate() (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Add TCO and Sync-In text entries (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aio: Drop superfluous HDSPM_AUTOSYNC_REF (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Cosmetics, no real change (Jaroslav Kysela) [1044022]
- [alsa] hdspm/aes32: Fix TCO sync check reporting (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Create TCO readout function (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Fix S/PDIF Sync status and frequency on RME AIO (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add support for AEBs on RME AIO (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Enable AD/DA/PH gains and S/PDIF-Input select on AIO (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Introduce generic AIO tristate control (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Refactor ENUMERATED_CTL_INFO into function (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add S/PDIF, XLR, WCK48 and ADAT-in controls for RME AIO cards (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add S/PDIF and WCK48 controls for RME RayDAT (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Drop duplicate code in hdspm_set_system_clock_mode() (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Augment HDSPM_TOGGLE_SETTING for AIO/RayDAT (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Introduce hdspm_is_raydat_or_aio() (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add missing defines for RME AIO and RayDAT (Jaroslav Kysela) [1044022]
- [alsa] vmaster: Fix the regression of missing vmaster hook call (Jaroslav Kysela) [1044022]
- [alsa] hda: Add Dell SSID to support Headset Mic recording (Jaroslav Kysela) [1044022]
- [alsa] pcm_native: switch to fdget()/fdput() (Jaroslav Kysela) [1044022]
- [alsa] treewide: relase -> release (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: Add Audio Advantage Micro II (Jaroslav Kysela) [1044022]
- [alsa] Replace the magic number 44 with const (Jaroslav Kysela) [1044022]
- [alsa] hda: Add support for ALC5505 DSP power-save mode (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: add quirks for Roland QUAD/OCTO-CAPTURE (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: claim autodetected PCM interfaces all at once (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: remove superfluous Roland quirks (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: add MIDI port names for some Roland devices (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: add support for many Roland/Yamaha devices (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: detect implicit feedback on Roland devices (Jaroslav Kysela) [1044022]
- [alsa] usb-audio: store protocol version in struct audioformat (Jaroslav Kysela) [1044022]
- [alsa] pci: replace numeric with standard PM state macros (Jaroslav Kysela) [1044022]
- [alsa] hda: Add missing alc_inv_dmic_sync() call in alc269_resume() (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove superfluous stac_resume() (Jaroslav Kysela) [1044022]
- [alsa] hda/hdmi: poll eld at resume time (Jaroslav Kysela) [1044022]
- [alsa] hda: clean up code to reset hda link (Jaroslav Kysela) [1044022]
- [alsa] hda: Add In-driver connection info (Jaroslav Kysela) [1044022]
- [alsa] hda: Use auto_mute_via_amp=1 for VT1708 (Jaroslav Kysela) [1044022]
- [alsa] hda: Add auto_mute_via_amp flag to generic parser (Jaroslav Kysela) [1044022]
- [alsa] vmaster: Add snd_ctl_sync_vmaster() helper function (Jaroslav Kysela) [1044022]
- [alsa] hda: Remove unused variable (Jaroslav Kysela) [1044022]
- [alsa] hda: reset hda link during system/runtime suspend (Jaroslav Kysela) [1044022]
- [alsa] Add M2Tech hiFace USB-SPDIF driver (Jaroslav Kysela) [1044022]
- [alsa] usb: uniform style used in MODULE_SUPPORTED_DEVICE() (Jaroslav Kysela) [1044022]
- [alsa] snd-usb-6fire: use vmalloc buffers (Jaroslav Kysela) [1044022]
- [alsa] snd-usb-caiaq: use vmalloc buffers (Jaroslav Kysela) [1044022]
- [alsa] snd-usb-caiaq: remove the unused snd_card_used variable (Jaroslav Kysela) [1044022]
- [alsa] hda: Make Thinkpad X220-tablet use generic parser (Jaroslav Kysela) [1044022]
- [alsa] hda: Use snd_hda_check_power_state() in patch_hdmi.c (Jaroslav Kysela) [1044022]
- [alsa] hda: Avoid choose same converter for unused pins (Jaroslav Kysela) [1044022]
- [alsa] hda: Haswell converter power state D0 verify (Jaroslav Kysela) [1044022]
- [alsa] ua101: convert __list_for_each usage to list_for_each (Jaroslav Kysela) [1044022]
- [alsa] usx2y: remove some old dead code (Jaroslav Kysela) [1044022]
- [alsa] hda: Don't take unresponsive D3 transition too serious (Jaroslav Kysela) [1044022]
- [alsa] hda: Introduce bit flags to snd_hda_codec_read/write() (Jaroslav Kysela) [1044022]
- [alsa] hda: Drop hard dependency on CONFIG_SND_DYNAMIC_MINORS (Jaroslav Kysela) [1044022]
- [alsa] hda/via: Use standard snd_hda_shutup_pins() (Jaroslav Kysela) [1044022]
- [alsa] hda: add mic fixup for ALC269VB on Ordissimo EVE2 (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Allow SingleSpeed WordClock when in DS/QS mode (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Refactor SS/DS/QS clock multiplier into function (Jaroslav Kysela) [1044022]
- [alsa] hdspm: Add support for 128-192kHz WordClock input (Jaroslav Kysela) [1044022]
- [alsa] es1968: Add radio support for MediaForte M56VAP (Jaroslav Kysela) [1044022]
- [alsa] pci: Remove superfluous pci_set_drvdata(pci, NULL) at remove (Jaroslav Kysela) [1044022]
- [alsa] hda: Enable mic-mute LED on more HP laptops (Jaroslav Kysela) [1044022]
- [alsa] Add kconfig to specify the max card numbers (Jaroslav Kysela) [1044022]
- [alsa] Fix the default suffix string with high card number (Jaroslav Kysela) [1044022]
- [alsa] Constify the snd_pcm_substream struct ops field (Jaroslav Kysela) [1044022]
- [alsa] hda: add PCI IDs for Intel BayTrail (Jaroslav Kysela) [1044022]
- [alsa] Fix assignment of 0/1 to bool variables (Jaroslav Kysela) [1044022]

* Tue Jan 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-78.el7]
- [scsi] hpsa: remove cancelled ID's and add a new one (Tomas Henzl) [1040644]
- [scsi] hpsa: bump driver version to 3.4.2-1 (Tomas Henzl) [1040644]
- [scsi] hpsa: add 4 new PCI ID's for HP Gen9 servers (Tomas Henzl) [1040644]

* Tue Jan 21 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-77.el7]
- [s390] revert kvm support patches (Jarod Wilson) [1035261 1049469]
- [block] nvme: Disable admin queue on init failure (David Milburn) [1049584]
- [block] nvme: Dynamically allocate partition numbers (David Milburn) [1049584]
- [block] nvme: Async IO queue deletion (David Milburn) [1049584]
- [block] nvme: Surprise removal handling (David Milburn) [1049584]
- [block] nvme: Abort timed out commands (David Milburn) [1049584]
- [block] nvme: Schedule reset for failed controllers (David Milburn) [1049584]
- [block] nvme: Device resume error handling (David Milburn) [1049584]
- [block] nvme: Cache dev->pci_dev in a local pointer (David Milburn) [1049584]
- [block] nvme: Fix lockdep warnings (David Milburn) [1049584]
- [block] nvme: compat SG_IO ioctl (David Milburn) [1049584]
- [block] nvme: remove deprecated IRQF_DISABLED (David Milburn) [1049584]
- [block] nvme: Avoid shift operation when writing cq head doorbell (David Milburn) [1049584]
- [block] nvme-core: replace dma_set_mask()+dma_set_coherent_mask() with new helper (David Milburn) [1049584]
- [ethernet] be2net: update driver version to 10.0.x (Ivan Vecera) [1054092]
- [ethernet] be2net: cleanup wake-on-lan code (Ivan Vecera) [1054092]
- [ethernet] be2net: use GET_MAC_LIST cmd to query mac-address from a pmac-id (Ivan Vecera) [1054092]
- [ethernet] be2net: do not use frag index in the RX-compl entry (Ivan Vecera) [1054092]
- [ethernet] be2net: Remove "10Gbps" from driver description string (Ivan Vecera) [1054092]
- [ethernet] be2net: fix incorrect setting of cmd_privileges for VFs (Ivan Vecera) [1054092]
- [ethernet] be2net: ignore mac-addr set call for an already programmed mac-addr (Ivan Vecera) [1054092]
- [ethernet] be2net: do not call be_set/get_fw_log_level() on Skyhawk-R (Ivan Vecera) [1054092]
- [ethernet] be2net: Log the profile-id used by FW during driver initialization (Ivan Vecera) [1054092]
- [ethernet] be2net: don't set "pport" field when querying "pvid" (Ivan Vecera) [1054092]
- [ethernet] be2net: Use MCC_CREATE_EXT_V1 cmd for Skyhawk-R (Ivan Vecera) [1054092]
- [infiniband] qib: Convert qib_user_sdma_pin_pages() to use get_user_pages_fast() (Jay Fenlason) [725023]
- [infiniband] qib: Improve SDMA performance (Jay Fenlason) [725023]
- [infiniband] qib: Fix txselect regression (Jay Fenlason) [725023]
- [infiniband] qib: Fix checkpatch __packed warnings (Jay Fenlason) [725023]
- [infiniband] qib: fix (some) dcache abuses (Jay Fenlason) [725023]
- [infiniband] qib: Remove GENERIC_HARDIRQ config option (Jay Fenlason) [725023]
- [infiniband] qib: Move COUNTER_MASK definition within qib_mad.h header guards (Jay Fenlason) [725023]
- [infiniband] qib: Clean up unnecessary MSI/MSI-X capability find (Jay Fenlason) [725023]
- [infiniband] qib: Make qib_driver static (Jay Fenlason) [725023]
- [infiniband] qib: Add err_decode() call for ring dump (Jay Fenlason) [725023]
- [infiniband] qib: Log all SDMA errors unconditionally (Jay Fenlason) [725023]
- [infiniband] qib: Fix module-level leak (Jay Fenlason) [725023]
- [infiniband] qib: New transmitter tunning settings for Dell 1.1 backplane (Jay Fenlason) [725023]
- [infiniband] qib: Add qp_stats debug file (Jay Fenlason) [725023]
- [infiniband] qib: Add per-context stats interface (Jay Fenlason) [725023]
- [infiniband] qib: Convert opcode counters to per-context (Jay Fenlason) [725023]
- [infiniband] qib: Optimize CQ callbacks (Jay Fenlason) [725023]
- [infiniband] qib: Add dual-rail NUMA awareness for PSM processes (Jay Fenlason) [725023]
- [infiniband] qib: Add optional NUMA affinity (Jay Fenlason) [725023]
- [infiniband] qib: Update minor version number (Jay Fenlason) [725023]
- [infiniband] qib: Remove atomic_inc_not_zero() from QP RCU (Jay Fenlason) [725023]
- [infiniband] qib: Add DCA support (Jay Fenlason) [725023]
- [infiniband] qib: avoid format string in dev_set_name (Jay Fenlason) [725023]
- [tools] power/turbostat: Support Silvermont (Lenny Szubowicz) [1048051]
- [ethernet] bnx2: Update version to 2.2.5 (Neil Horman) [1051172]
- [ethernet] bnx2: Report MDI/MDIX status to ethtool (Neil Horman) [1051172]
- [ethernet] bnx2: Enable auto-mdix when autoneg is disabled (Neil Horman) [1051172]
- [ethernet] bnx2: Advertise nothing when speed is forced (Neil Horman) [1051172]
- [ethernet] bnx2: calls skb_set_hash (Neil Horman) [1051172]
- [ethernet] bnx2: remove unnecessary pci_set_drvdata() (Neil Horman) [1051172]
- [ethernet] bnx2: Miscellaneous conversions to ETH_ALEN (Neil Horman) [1051172]
- [kernel] thermal: Disable power limit notification interrupt by default (Prarit Bhargava) [1050198]
- [kernel] thermal: Delete power-limit-notification console messages (Prarit Bhargava) [1050198]
- [x86] mce: Fix mce_start_timer semantics (Prarit Bhargava) [1045845]
- [x86] Add check for number of available vectors before CPU down (Prarit Bhargava) [1045845]
- [ethernet] i40evf: fix s390 build failure due to implicit prefetch.h (Stefan Assmann) [1053147]
- [ethernet] i40evf: A0 silicon specific (Stefan Assmann) [1053147]
- [ethernet] i40evf: add driver to kernel build system (Stefan Assmann) [1053147]
- [ethernet] i40evf: init code and hardware support (Stefan Assmann) [1053147]
- [ethernet] i40evf: driver core headers (Stefan Assmann) [1053147]
- [ethernet] i40evf: virtual channel interface (Stefan Assmann) [1053147]
- [ethernet] i40evf: core ethtool functionality (Stefan Assmann) [1053147]
- [ethernet] i40evf: transmit and receive functionality (Stefan Assmann) [1053147]
- [ethernet] i40evf: main driver core (Stefan Assmann) [1053147]
- [pci] Never treat a VF as a multifunction device (Alex Williamson) [1049716]

* Fri Jan 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-76.el7]
- [scsi] aacraid: kdump fix (Rich Bono) [1019091]
- [scsi] lpfc: update version for 8.3.7.34.3p driver release (Rob Evers) [1025854]
- [scsi] lpfc: Fixed unassigned variable in ELS timeout message (Rob Evers) [1025854]
- [scsi] lpfc: Fixed incorrect allocation of iDiags directories/files in debugfs (Rob Evers) [1025854]
- [scsi] lpfc: Fix kernel panics from corrupted ndlp list (Rob Evers) [1025854]
- [scsi] lpfc: Fix Crash in lpfc_els_timeout_handler (Rob Evers) [1025854]
- [scsi] lpfc: Fixed stopped FCF discovery on failed FCF record read (Rob Evers) [1025854]
- [scsi] lpfc: Fixed IO hang when in msi mode (Rob Evers) [1025854]
- [scsi] lpfc: Fix wrong assignment in lpfc_debugfs.c (Rob Evers) [1025854]
- [scsi] lpfc: Fix typo on NULL assignment (Rob Evers) [1025854]
- [scsi] lpfc: Update lpfc version for 8.3.7.34.1p driver release (Rob Evers) [1025854]
- [scsi] lpfc: Fixed not processing task management IOCB response status (Rob Evers) [1025854]
- [scsi] lpfc: Fixed spinlock hang (Rob Evers) [1025854]
- [scsi] lpfc: Fixed invalid Total_Data_Placed value received for els and ct command responses (Rob Evers) [1025854]
- [scsi] lpfc: Fixed invalid fcp_rsp length fir FCP_ICMND (Rob Evers) [1025854]
- [scsi] lpfc: Fixed invalid mailbox timeouts (Rob Evers) [1025854]
- [scsi] lpfc: Fixed spinlock inversion problem (Rob Evers) [1025854]
- [scsi] lpfc: Fix crash after xri limit is reached (Rob Evers) [1025854]
- [scsi] lpfc: remove unnecessary read of PCI_CAP_ID_EXP (Rob Evers) [1025854]

* Fri Jan 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-75.el7]
- [kernel] audit: log task info on feature change (Richard Guy Briggs) [1050425]
- [kernel] keys: correct alignment of system_certificate_list content in assembly file (Hendrik Brueckner) [1038139]
- [kernel] system_certificate: use real contents instead of macro GLOBAL() (Hendrik Brueckner) [1038139]
- [kernel] audit: don't generate audit feature changed log when audit disabled (Richard Guy Briggs) [1045668]
- [kernel] audit: fix incorrect order of log new and old feature (Richard Guy Briggs) [1045668]
- [kernel] selinux: apply selinux checks on new audit message types (Richard Guy Briggs) [1045668]
- [kernel] audit: implement generic feature setting and retrieving (Richard Guy Briggs) [1045668]
- [s390] smp: improve setup of possible cpu mask (Hendrik Brueckner) [1052906]
- [iommu] intel-iommu: fix off-by-one in pagetable freeing (Myron Stowe) [1048955]
- [mm] page_alloc: honor min_free_kbytes set by user (Steve Best) [1047779]
- [kernel] mutex: Do not unnecessarily deal with waiters (Larry Woodman) [1031475]
- [ethernet] tg3: Update version to 3.136 (Ivan Vecera) [1048557]
- [ethernet] tg3: Poll cpmu link state on APE + ASF enabled devices (Ivan Vecera) [1048557]
- [ethernet] tg3: Set the MAC clock to the fastest speed during boot code load (Ivan Vecera) [1048557]
- [ethernet] tg3: Add unicast filtering support (Ivan Vecera) [1048557]
- [ethernet] tg3: Refactor __tg3_set_mac_addr() (Ivan Vecera) [1048557]
- [ethernet] tg3: Expand 4g_overflow_test workaround to skb fragments of any size (Ivan Vecera) [1048557]
- [ethernet] tg3: Initialize REG_BASE_ADDR at PCI config offset 120 to 0 (Ivan Vecera) [1048557]
- [ethernet] tg3: Update version to 3.135 (Ivan Vecera) [1048557]
- [ethernet] tg3: Expand multicast drop counter miscounting fix to 5762 (Ivan Vecera) [1048557]
- [ethernet] tg3: Fix bit definition for the nvram Auto Power Down setting (Ivan Vecera) [1048557]
- [ethernet] tg3: Add flag to disable 1G Half Duplex advertisement (Ivan Vecera) [1048557]
- [ethernet] tg3: Don't add rxbds_empty to rx_over_errors (Ivan Vecera) [1048557]
- [ethernet] tg3: Give up chip reset and carrier loss handling if PCI device is not present (Ivan Vecera) [1048557]
- [ethernet] tg3: Validate hwtstamp_config completely before applying it (Ivan Vecera) [1048557]
- [ethernet] tg3: avoid double-freeing of rx data memory (Ivan Vecera) [1048557]
- [ethernet] bnx2x: fix DMA unmapping of TSO split BDs (Michal Schmidt) [1043794]
- [ethernet] bnx2x: fix VLAN configuration for VFs (Michal Schmidt) [1038666]
- [ethernet] bnx2x: fix AFEX memory overflow (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Clean before update RSS arrives (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Correct number of MSI-X vectors for VFs (Michal Schmidt) [1038666]
- [ethernet] bnx2x: limit number of interrupt vectors for 57711 (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix KR2 work-around detection of BCM8073 (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix incorrect link-up report (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix Duplex setting for 54618se (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix passive DAC cable detection (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix 578xx-KR 1G link (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Fix build with SRIOV disabled (Michal Schmidt) [1038666]
- [ethernet] bnx2x: add VF Multicast filters support (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Add num of VFs to Management statistics (Michal Schmidt) [1038666]
- [ethernet] bnx2x: no error when RSS configuration fails (Michal Schmidt) [1038666]
- [ethernet] bnx2x: add Big-Endian ethtool comment (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Add AER support (missing bits) (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Add support for Multi-Function UNDI (Michal Schmidt) [1038666]
- [ethernet] bnx2x: downgrade "valid ME register value" message level (Michal Schmidt) [1038666]
- [ethernet] bnx2x: cleanup skb_set_hash (Michal Schmidt) [1038666]
- [ethernet] bnx2x: calls skb_set_hash (Michal Schmidt) [1038666]
- [ethernet] bnx2x: avoid null pointer dereference when enabling SR-IOV (Michal Schmidt) [1038666]
- [ethernet] bnx2x: add TSO support for SIT tunnels (Michal Schmidt) [1038666]
- [ethernet] bnx2x: add TSO support for IPIP (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Prevent "timeout waiting for state X" (Michal Schmidt) [1038666]
- [ethernet] bnx2x: prevent CFC attention (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Prevent panic during DMAE timeout (Michal Schmidt) [1038666]
- [ethernet] bnx2x: Clean the sp rtnl task upon unload (Michal Schmidt) [1038666]
- [ethernet] bnx2x: replace dma_set_mask()+dma_set_coherent_mask() with new helper (Michal Schmidt) [1038666]
- [misc] list: introduce list_next_entry() and list_prev_entry() (Michal Schmidt) [1038666]
- [virt] kvm: fix apic_base enable check (Marcelo Tosatti) [1053143]
- [virt] kvm: fix x86 emulation of "movzbl bpl, eax" (Marcelo Tosatti) [1053143]
- [virt] kvm: limit PIT timer frequency (Marcelo Tosatti) [1053143]
- [virt] kvm: fix tsc catchup issue with tsc scaling (Marcelo Tosatti) [1053143]
- [virt] kvm: handle invalid root_hpa everywhere (Marcelo Tosatti) [1053143]
- [virt] kvm/mmu: handle invalid root_hpa at __direct_map (Marcelo Tosatti) [1053143]
- [virt] kvm/vmx: fix use after free of vmx->loaded_vmcs (Marcelo Tosatti) [1053143]
- [virt] kvm: Fix APIC map calculation after re-enabling (Marcelo Tosatti) [1053143]
- [virt] kvm: emulate SAHF instruction (Marcelo Tosatti) [1053143]
- [virt] flags: Rename X86_EFLAGS_BIT1 to X86_EFLAGS_FIXED (Marcelo Tosatti) [1053143]
- [virt] kvm: Mapping IOMMU pages after updating memslot (Marcelo Tosatti) [1053143]
- [fs] aio: checking for NULL instead of IS_ERR (Motohiro Kosaki) [995323]

* Fri Jan 17 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-74.el7]
- [net] bridge: Fix memory leak when deleting bridge with vlan filtering enabled (Vlad Yasevich) [1031068]
- [net] bridge: Call vlan_vid_del for all vids at nbp_vlan_flush (Vlad Yasevich) [1031068]
- [net] bridge: Use vlan_vid_[add/del] instead of direct ndo_vlan_rx_[add/kill]_vid calls (Vlad Yasevich) [1031068]
- [net] ipv6: add link-local, sit and loopback address with INFINITY_LIFE_TIME (Jiri Pirko) [1054095]
- [net] ipv6: don't install anycast address for /128 addresses on routers (Jiri Pirko) [1054095]
- [net] ipv6: addrconf: fix preferred lifetime state-changing behavior while valid_lft is infinity (Jiri Pirko) [1054095]
- [net] ipv4: processing ancillary IP_TOS or IP_TTL (Francesco Fusco) [1054160]
- [net] ipv4: IP_TOS and IP_TTL can be specified as ancillary data (Francesco Fusco) [1054160]
- [net] netfilter: synproxy: correct wscale option passing (Jesper Brouer) [1054076]
- [net] netfilter: synproxy: send mss option to backend (Jesper Brouer) [1054076]
- [net] ipv6: addrconf: don't cleanup prefix route for IFA_F_NOPREFIXROUTE (Jiri Pirko) [1052884]
- [net] ipv6: addrconf: add IFA_F_NOPREFIXROUTE flag to suppress creation of IP6 routes (Jiri Pirko) [1052884]
- [net] ipv6: addrconf spelling fixes (Jiri Pirko) [1052884]
- [net] ipv6: unneccessary to get address prefix in addrconf_get_prefix_route (Jiri Pirko) [1052884]
- [net] bridge: apply multicast snooping to IPv6 link-local, too (Francesco Fusco) [1051501]
- [net] bridge: prevent flooding IPv6 packets that do not have a listener (Francesco Fusco) [1051501]
- [net] ipv6: don't call fib6_run_gc() until routing is ready (Florian Westphal) [1052111]
- [net] ipv6: always set the new created dst's from in ip6_rt_copy (Neil Horman) [1050828]
- [net] vxlan: Mark vxlan_dev flags with VXLAN_F_IPV6 properly (Thomas Graf) [1049141]
- [net] netfilter: RHEL7 kABI prepare struct netns_ct (Jesper Brouer) [1030994]
- [net] reorder struct netns_ct for better cache-line usage (Jesper Brouer) [1030994]
- [net] ipv6: release dst properly in ipip6_tunnel_xmit (Michal Schmidt) [1038708]
- [net] ipv6: sit: update mtu check to take care of gso packets (Michal Schmidt) [1038708]
- [net] ipv6: sit: add GSO/TSO support (Michal Schmidt) [1038708]
- [net] ipv6: gso: make ipv6_gso_segment() stackable (Michal Schmidt) [1038708]
- [net] ipv6: wire up skb->encapsulation (Michal Schmidt) [1038708]
- [net] ipip: add GSO/TSO support (Michal Schmidt) [1038708]
- [net] inet: fix a UFO regression (Michal Schmidt) [1038708]
- [net] inet: restore gso for vxlan (Michal Schmidt) [1038708]
- [net] ipv4: gso: make inet_gso_segment() stackable (Michal Schmidt) [1038708]
- [net] ipv4: gso: send_check() & segment() cleanups (Michal Schmidt) [1038708]
- [net] generalize skb_segment() (Michal Schmidt) [1038708]
- [net] ipv4: generalize gre_handle_offloads (Michal Schmidt) [1038708]

* Thu Jan 16 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-73.el7]
- [kernel] audit: audit_log_start running on auditd should not stop (Richard Guy Briggs) [1019895]
- [kernel] audit: drop audit_cmd_lock in AUDIT_USER family of cases (Richard Guy Briggs) [1019895]
- [security] smack: call WARN_ONCE() instead of calling audit_log_start() (Richard Guy Briggs) [1019895]
- [security] selinux: call WARN_ONCE() instead of calling audit_log_start() (Richard Guy Briggs) [1019895]
- [virt] vfio: Convert control interface to misc driver (Alex Williamson) [1044595]
- [virt] vfio: Reserve minor for VFIO (Alex Williamson) [1044595]
- [ethernet] qlcnic: Update version to 5.3.48.1 (Chad Dupuis) [1048773]
- [ethernet] qlcnic: Fix bug in Tx completion path (Chad Dupuis) [1048773]
- [ethernet] qlcnic: Fix usage of netif_tx_{wake, stop} api during link change (Chad Dupuis) [1048773]
- [ethernet] qlcnic: Fix system hang while running traffic and bringing interface down (Chad Dupuis) [1048773]
- [virt] hyperv/netvsc: don't flush peers notifying work during setting mtu (Jason Wang) [1040785 983434]
- [virt] hyperv: Fix race between probe and open calls (Jason Wang) [983434]
- [s390] kvm: mark as Tech Preview (Hendrik Brueckner) [1049469]
- [x86] irq: Fix do_IRQ() interrupt warning for cpu hotplug retriggered irqs (Prarit Bhargava) [1052179]
- [kernel] audit: log on errors from filter user rules (Richard Guy Briggs) [1034446]
- [x86] uv: Add GRU distributed mode mappings (George Beshers) [1032365]
- [iommu] dmar: Modify warn_invalid_dmar() message to do a less loud warning (Prarit Bhargava) [968249]
- [dma] ioat: Modify ioat3_dca_init() message to do a less loud warning (Prarit Bhargava) [968235]

* Wed Jan 15 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-72.el7]
- [ethernet] sfc: fix sparse non static symbol warning (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Fix RX drop filters for EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add PTP counters to ethtool stats (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Changed the statistic name emerg_{fetch, wait} to hlb_{fetch, wait} (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: remove unused 'enum efx_rx_alloc_method' (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: remove unused 'refcnt' from efx_rx_page_state (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Implement efx_nic_type::filter_clear_rx operation for EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Allow filter removal only with exactly matching priority (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Don't refer to 'stack' in filter implementation (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Change priority and flags for automatic MAC filters (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Change efx_nic_type::rx_push_indir_table to push hash key as well (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add more information to many warnings using WARN() and netdev_WARN() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Remove unnecessary condition for processing the TX timestamp queue (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Don't clear timestamps in efx_ptp_rx() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Enable PTP clock and timestamping for all functions on EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Associate primary and secondary functions of controller (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Store VPD serial number at probe time (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add RX packet timestamping for EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Copy RX prefix into skb head area in efx_rx_mk_skb() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: split setup of hardware timestamping into NIC-type operation (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add support for SFC9100 timestamp format (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Tidy up PTP synchronization code (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: PTP - tidy up unused/useless variables (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Remove kernel-doc for efx_ptp_data fields not present in this version (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Initialise efx_ptp_data::phc_clock_info from a static template (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Do not use MAC address as clock name (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Store flags from MC_CMD_DRV_ATTACH for later use (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Remove dependency of PTP on having a dedicated channel (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Split PTP multicast filter insertion/removal out of efx_ptp_{start, stop}() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Return EBUSY for filter insertion on EF10, matching Falcon/Siena (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Expose NVRAM_PARTITION_TYPE_LICENSE on EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Fold efx_flush_all() into efx_stop_port() and update comments (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Map MCDI error MC_CMD_ERR_ENOTSUP to Linux EOPNOTSUPP (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Log all unexpected MCDI errors (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add new sensor names (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Revise sensor names to be more understandable and consistent (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Report units in sensor warnings (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Correct RX dropped count for drops while interface is down (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Make initial fill of RX descriptors synchronous (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Tighten the check for RX merged completion events (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add MC BISTs to ethtool offline self test on EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Update MCDI protocol definitions (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Demote "MC Scheduler error" messages (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Poll for MCDI completion once before timeout occurs (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Refactor efx_mcdi_poll() by introducing efx_mcdi_poll_once() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: RX buffer allocation takes prefix size into account in IP header alignment (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Maintain current frequency adjustment when applying a time offset (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Stop/re-start PTP when stopping/starting the datapath (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Rate-limit log message for PTP packets without a matching timestamp event (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc/ptp: Moderate log message on event queue overflow (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add length checks to efx_xmit_with_hwtstamp() and efx_ptp_is_ptp_tx() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: remove unnecessary pci_set_drvdata() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Implement the SIOCGHWTSTAMP ioctl (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: replace dma_set_mask()+dma_set_coherent_mask() with new helper (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Fix DMA unmapping issue with firmware assisted TSO (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Only bind to EF10 functions with the LinkCtrl and Trusted flags (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add PM and RXDP drop counters to ethtool stats (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add definitions for new stats counters and capability flag (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Refactor EF10 stat mask code to allow for more conditional stats (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Fix internal indices of ethtool stats for EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add rmb() between reading stats and generation count to ensure consistency (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Increase MCDI status timeout to 250ms (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Wait for MC reboot to complete before scheduling driver reset (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Remove extern from function prototypes (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Support ARFS for IPv6 flows (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Use TX PIO for sufficiently small packets (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Introduce inline functions to simplify TX insertion (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Separate out queue-empty check from efx_nic_may_push_tx_desc() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Allocate and link PIO buffers; map them with write-combining (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Implement firmware-assisted TSO for EF10 (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Fold tso_get_head_fragment() into tso_start() (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Add EF10 registers to register dump (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: efx_ef10_filter_update_rx_scatter() can be static (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: efx_ethtool_get_ts_info() can be static (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Reinitialise and re-validate datapath caps after MC reboot (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Clean up validation of datapath capabilities (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Reset derived rx_bad_bytes statistic when EF10 MC is rebooted (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Disable PTP on EF10 until we're ready to handle inline RX timestamps (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Minimal support for 40G link speed (Nikolay Aleksandrov) [1028038]
- [net] net_tstamp: Add SIOCGHWTSTAMP ioctl to match SIOCSHWTSTAMP (Nikolay Aleksandrov) [1028038]
- [net] socket: Merge multiple implementations of ifreq::ifr_data conversion (Nikolay Aleksandrov) [1028038]
- [net] socket: Fix minor information leak in siocdevprivate_ioctl() (Nikolay Aleksandrov) [1028038]
- [net] net_tstamp: Improve kernel-doc for struct hwtstamp_config (Nikolay Aleksandrov) [1028038]
- [ethernet] sfc: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Nikolay Aleksandrov) [1028038]
- [virt] virtio-net: fix refill races during restore (Jason Wang) [1040802]
- [virt] virtio: delete napi structures from netdev before releasing memory (Jason Wang) [1040802]
- [virt] virtio-net: make all RX paths handle errors consistently (Jason Wang) [1032457]
- [virt] virtio_net: fix error handling for mergeable buffers (Jason Wang) [1032457]
- [firmware] efi-pstore: Make efi-pstore return a unique id (Seiji Aguchi) [1039150]
- [firmware] efivars, efi-pstore: Hold off deletion of sysfs entry until the scan is completed (Seiji Aguchi) [1039145]
- [firmware] efi-pstore: Cocci spatch "memdup.spatch" (Seiji Aguchi) [1039145]
- [virt] kvm/svm: nested virt support off by default (Marcelo Tosatti) [1034974]
- [x86] uv: Fix NULL pointer dereference in uv_flush_tlb_others() (George Beshers) [1049559]
- [fs] kill anon_inode_getfile_private() (Motohiro Kosaki) [995323]
- [fs] rework aio migrate pages to use aio fs (Motohiro Kosaki) [995323]
- [fs] take anon inode allocation to libfs.c (Motohiro Kosaki) [995323]
- [fs] libfs: get exports to definitions of objects being exported (Motohiro Kosaki) [995323]
- [fs] aio: fix use-after-free in aio_migratepage (Motohiro Kosaki) [995323]
- [fs] aio: remove unnecessary debugging from aio_free_ring() (Motohiro Kosaki) [995323]
- [fs] aio: fix race in ring buffer page lookup introduced by page migration support (Motohiro Kosaki) [995323]
- [fs] aio: fix build when migration is disabled (Motohiro Kosaki) [995323]
- [fs] aio: Add support to aio ring pages migration (Motohiro Kosaki) [995323]
- [fs] anon_inode: Introduce a new lib function anon_inode_getfile_private() (Motohiro Kosaki) [995323]

* Tue Jan 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-71.el7]
- [md] dm-cache: add block sizes and total cache blocks to status output (Mike Snitzer) [1049591]
- [md] dm-btree: add dm_btree_find_lowest_key (Mike Snitzer) [1049591]
- [md] dm-space-map-metadata: fix extending the space map (Mike Snitzer) [1049591]
- [md] dm-space-map-common: make sure new space is used during extend (Mike Snitzer) [1049591]
- [md] dm: wait until embedded kobject is released before destroying a device (Mike Snitzer) [1049591]
- [md] dm: remove pointless kobject comparison in dm_get_from_kobject (Mike Snitzer) [1049591]
- [md] dm-snapshot: call destroy_work_on_stack() to pair with INIT_WORK_ONSTACK() (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: introduce three promotion threshold tunables (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: use list_del_init instead of list_del + INIT_LIST_HEAD (Mike Snitzer) [1049591]
- [md] dm-thin: fix set_pool_mode exposed pool operation races (Mike Snitzer) [1049591]
- [md] dm-thin: eliminate the no_free_space flag (Mike Snitzer) [1049591]
- [md] dm-thin: add error_if_no_space feature (Mike Snitzer) [1049591]
- [md] dm-thin: requeue bios to DM core if no_free_space and in read-only mode (Mike Snitzer) [1049591]
- [md] dm-thin: cleanup and improve no space handling (Mike Snitzer) [1049591]
- [md] dm-thin: log info when growing the data or metadata device (Mike Snitzer) [1049591]
- [md] dm-thin: handle metadata failures more consistently (Mike Snitzer) [1049591]
- [md] dm-thin: factor out check_low_water_mark and use bools (Mike Snitzer) [1049591]
- [md] dm-thin: add mappings to end of prepared_* lists (Mike Snitzer) [1049591]
- [md] dm-thin: return error from alloc_data_block if pool is not in write mode (Mike Snitzer) [1049591]
- [md] dm-thin: use bool rather than unsigned for flags in structures (Mike Snitzer) [1049591]
- [md] dm-persistent-data: cleanup dm-thin specific references in text (Mike Snitzer) [1049591]
- [md] dm-space-map-metadata: limit errors in sm_metadata_new_block (Mike Snitzer) [1049591]
- [md] dm-delay: use per-bio data instead of a mempool and slab cache (Mike Snitzer) [1049591]
- [md] dm-table: remove unused buggy code that extends the targets array (Mike Snitzer) [1049591]
- [md] dm-thin: fix discard support to a previously shared block (Mike Snitzer) [1049591]
- [md] dm-thin: initialize dm_thin_new_mapping returned by get_next_mapping (Mike Snitzer) [1049591]
- [md] dm-array: fix a reference counting bug in shadow_ablock (Mike Snitzer) [1049591]
- [md] dm-space-map: disallow decrementing a reference count below zero (Mike Snitzer) [1049591]
- [md] dm-stats: initialize read-only module parameter (Mike Snitzer) [1049591]
- [md] dm-bufio: initialize read-only module parameters (Mike Snitzer) [1049591]
- [md] dm-cache: actually resize cache (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: fix promotions to occur as expected (Mike Snitzer) [1049591]
- [md] dm-thin: allow pool in read-only mode to transition to read-write mode (Mike Snitzer) [1049591]
- [md] dm-thin: re-establish read-only state when switching to fail mode (Mike Snitzer) [1049591]
- [md] dm-thin: always fallback the pool mode if commit fails (Mike Snitzer) [1049591]
- [md] dm-thin: switch to read-only mode if metadata space is exhausted (Mike Snitzer) [1049591]
- [md] dm-thin: switch to read only mode if a mapping insert fails (Mike Snitzer) [1049591]
- [md] dm-space-map-metadata: return on failure in sm_metadata_new_block (Mike Snitzer) [1049591]
- [md] dm-table: fail dm_table_create on dm_round_up overflow (Mike Snitzer) [1049591]
- [md] dm-snapshot: avoid snapshot space leak on crash (Mike Snitzer) [1049591]
- [md] dm-delay: fix a possible deadlock due to shared workqueue (Mike Snitzer) [1049591]
- [md] dm-cache: resolve small nits and improve Documentation (Mike Snitzer) [1049591]
- [md] dm-cache: add cache block invalidation support (Mike Snitzer) [1049591]
- [md] dm-cache: add remove_cblock method to policy interface (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: reduce memory requirements (Mike Snitzer) [1049591]
- [md] dm-cache-metadata: check the metadata version when reading the superblock (Mike Snitzer) [1049591]
- [md] dm-cache: add passthrough mode (Mike Snitzer) [1049591]
- [md] dm-cache: cache shrinking support (Mike Snitzer) [1049591]
- [md] dm-cache: promotion optimisation for writes (Mike Snitzer) [1049591]
- [md] dm-cache: be much more aggressive about promoting writes to discarded blocks (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: implement writeback_work() and mq_{set, clear}_dirty() (Mike Snitzer) [1049591]
- [md] dm-cache: optimize commit_if_needed (Mike Snitzer) [1049591]
- [md] dm-space-map-disk: optimise sm_disk_dec_block (Mike Snitzer) [1049591]
- [md] dm: fix Kconfig menu indentation (Mike Snitzer) [1049591]
- [md] dm: allow remove to be deferred (Mike Snitzer) [1049591]
- [md] dm-table: print error on preresume failure (Mike Snitzer) [1049591]
- [md] dm-crypt: add TCW IV mode for old CBC TCRYPT containers (Mike Snitzer) [1049591]
- [md] dm-crypt: properly handle extra key string in initialization (Mike Snitzer) [1049591]
- [md] dm-cache: log error message if dm_kcopyd_copy() fails (Mike Snitzer) [1049591]
- [md] dm-cache: use cell_defer() boolean argument consistently (Mike Snitzer) [1049591]
- [md] dm-cache: return -EINVAL if the user specifies unknown cache policy (Mike Snitzer) [1049591]
- [md] dm-cache-metadata: return bool from __superblock_all_zeroes (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: a few small fixes (Mike Snitzer) [1049591]
- [md] dm-cache-policy: remove return from void policy_remove_mapping (Mike Snitzer) [1049591]
- [md] dm-cache: improve efficiency of quiescing flag management (Mike Snitzer) [1049591]
- [md] dm-cache: fix a race condition between queuing new migrations and quiescing for a shutdown (Mike Snitzer) [1049591]
- [md] dm-cache: io destined for the cache device can now serve as tick bios (Mike Snitzer) [1049591]
- [md] dm-cache-policy-mq: protect residency method with existing mutex (Mike Snitzer) [1049591]
- [md] dm-array: fix bug in growing array (Mike Snitzer) [1049591]
- [md] dm-mpath: requeue I/O during pg_init (Mike Snitzer) [1049591]
- [md] dm-mpath: fix race condition between multipath_dtr and pg_init_done (Mike Snitzer) [1049591]
- [md] dm: allocate buffer for messages with small number of arguments using GFP_NOIO (Mike Snitzer) [1049591]
- [ethernet] be2net: fix max_evt_qs calculation for BE3 in SR-IOV config (Ivan Vecera) [1049512]
- [ethernet] be2net: increase the timeout value for loopback-test FW cmd (Ivan Vecera) [1049512]
- [ethernet] be2net: disable RSS when number of RXQs is reduced to 1 via set-channels (Ivan Vecera) [1049512]
- [ethernet] be2net: slight optimization of addr compare (Ivan Vecera) [1049512]
- [ethernet] be2net: calls skb_set_hash (Ivan Vecera) [1049512]
- [net] Add function to set the rxhash (Ivan Vecera) [1049512]
- [ethernet] be2net: Free/delete pmacs (in be_clear()) only if they exist (Ivan Vecera) [1049512]
- [ethernet] be2net: Fix Lancer error recovery to distinguish FW download (Ivan Vecera) [1049512]
- [ethernet] be2net: Avoid programming permenant MAC by BE3-R VFs (Ivan Vecera) [1049512]
- [ethernet] be2net: set coalesce-wm in CQ_CREATE_V2 cmd (Ivan Vecera) [1049512]
- [ethernet] be2net: Disabling and enabling interrupts in suspend and resume (Ivan Vecera) [1049512]
- [ethernet] be2net: Delete secondary unicast MAC addresses during be_close (Ivan Vecera) [1049512]
- [ethernet] be2net: Fix unconditional enabling of Rx interface options (Ivan Vecera) [1049512]
- [ethernet] be2net: replace dma_set_mask()+dma_set_coherent_mask() with new helper (Ivan Vecera) [1049512]

* Tue Jan 14 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-70.el7]
- [scsi] qla4xxx: v5.04.00.02.07.00-k0 (Chad Dupuis) [948116]
- [scsi] qla4xxx: Add support for additional network parameters settings (Chad Dupuis) [1006152]
- [scsi] qla4xxx: v5.04.00.01.07.00-k0 (Chad Dupuis) [1006152]
- [scsi] qla4xxx: Add support to get CHAP details for flash target session (Chad Dupuis) [1006152]
- [scsi] qla4xxx: Add support to set CHAP entries (Chad Dupuis) [1006152]
- [scsi] qla4xxx: Use offset based on adapter type to set CHAP entry in flash (Chad Dupuis) [1006152]
- [scsi] iscsi_transport: Additional parameters for network settings (Chad Dupuis) [948116]
- [scsi] iscsi_transport: Remove net param enum values (Chad Dupuis) [948116]
- [scsi] scsi_transport_iscsi: Add support to set CHAP entries (Chad Dupuis) [1006152]
- [scsi] Update documentation for scsi eh patchset (Ewan Milne) [987784]
- [scsi] Set the minimum valid value of 'eh_deadline' as 0 (Ewan Milne) [987784]
- [scsi] Unlock accesses to eh_deadline (Ewan Milne) [987784]
- [scsi] improved eh timeout handler (Ewan Milne) [987784]
- [scsi] Fix erratic device offline during EH (Ewan Milne) [987784]
- [scsi] scsi_error: Escalate to LUN reset if abort fails (Ewan Milne) [987784]
- [scsi] Adjust eh_deadline changes to match final upstream version (Ewan Milne) [987784]
- [scsi] Disable WRITE SAME for RAID and virtual host adapter drivers (Ewan Milne) [1010379]
- [scsi] pm80xx: Removing redundant code snippets (Rich Bono) [1044113]
- [scsi] pm80xx: Tasklets synchronization fix (Rich Bono) [1044113]
- [scsi] pm8001: clean up unnecessary MSI/MSI-X capability find (Rich Bono) [1044113]
- [scsi] pm8001: use pdev->pm_cap instead of pci_find_capability(.., PCI_CAP_ID_PM) (Rich Bono) [1044113]
- [scsi] pm80xx: Module author addition (Rich Bono) [1044113]
- [scsi] pm80xx: Resetting the phy state (Rich Bono) [1044113]
- [scsi] pm80xx: Fix for direct attached device (Rich Bono) [1044113]
- [net] cnic: Add a signature to indicate valid doorbell offset (Maurizio Lombardi) [1051181]
- [scsi] bfa: Driver version upgrade to 3.2.23.0 (Vijay Guvva) [1032723]
- [scsi] bfa: Fix smatch warnings (Vijay Guvva) [1032723]
- [scsi] bfa: change FC_ELS_TOV to 20sec (Vijay Guvva) [1032723]
- [scsi] bfa: Observed auto D-port mode instead of manual (Vijay Guvva) [1032723]
- [scsi] bfa: Fix for bcu or hcm faa query hang (Vijay Guvva) [1032723]
- [scsi] bfa: LUN discovery issue in direct attach mode (Vijay Guvva) [1032723]
- [scsi] bfa: Register port with SCSI even on port init failure (Vijay Guvva) [1032723]
- [scsi] bfa: Firmware patch simplification (Vijay Guvva) [1032723]
- [ethernet] bna: Fix build due to missing use of dma_unmap_len_set() (Ivan Vecera) [1030679]
- [ethernet] bna: Update the Driver Version to 3.2.23.0 (Ivan Vecera) [1030679]
- [ethernet] bna: Firmware Patch Simplification (Ivan Vecera) [1030679]
- [ethernet] bna: Embed SKB Length in TX Vector (Ivan Vecera) [1030679]
- [ethernet] bna: Handle the TX Setup Failures (Ivan Vecera) [1030679]
- [ethernet] bna: Add NULL Check Before Dereferencing TCB (Ivan Vecera) [1030679]
- [ethernet] bna: CQ Read Fix (Ivan Vecera) [1030679]
- [ethernet] bna: RX Processing and Config Changes (Ivan Vecera) [1030679]
- [ethernet] bna: Enable Multi Buffer RX (Ivan Vecera) [1030679]
- [ethernet] bna: RX Filter Enhancements (Ivan Vecera) [1030679]
- [ethernet] bna: Fix Filter Add Del (Ivan Vecera) [1030679]
- [ethernet] bna: Set Get IOC fw State (Ivan Vecera) [1030679]
- [ethernet] bna: Add software timestamping support (Ivan Vecera) [1030679]
- [ethernet] bna: make local variable static (Ivan Vecera) [1030679]
- [ethernet] bna: remove unnecessary pci_set_drvdata() (Ivan Vecera) [1030679]
- [ethernet] bna: remove unnecessary pci_set_drvdata() (Ivan Vecera) [1030679]
- [ethernet] bna: Remove extern from function prototypes (Ivan Vecera) [1030679]
- [ethernet] bna: fix 32-bit DMA mask handling (Ivan Vecera) [1030679]
- [kernel] dma-api: provide a helper to set both DMA and coherent DMA masks (Ivan Vecera) [1030679]

* Mon Jan 13 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-69.el7]
- [firmware] efi: generalize efi_get_memory_map() (George Beshers) [973417]
- [firmware] efi: Rename __get_map() to efi_get_memory_map() (George Beshers) [973417]
- [x86] EFI stub support for large memory maps (George Beshers) [973417]
- [x86] efi: Allow efi_free() to be called with size of 0 (George Beshers) [973417]
- [x86] efi: use efi_get_memory_map() to get final map for x86 (George Beshers) [973417]
- [x86] efi: Rename memory allocation/free functions (George Beshers) [973417]
- [x86] efi: Add system table pointer argument to shared functions (George Beshers) [973417]
- [x86] efi: Move common EFI stub code from x86 arch code to common location (George Beshers) [973417]
- [x86] efi: Add proper definitions for some EFI function pointers (George Beshers) [973417]
- [x86] efi: correct call to free_pages (George Beshers) [973417]
- [ethernet] i40e: correctly setup ARQ descriptors (Stefan Assmann) [1011561]
- [ethernet] i40e: remove redundant AQ enable (Stefan Assmann) [1011561]
- [ethernet] i40e: Enable/Disable PF switch LB on SR-IOV configure changes (Stefan Assmann) [1011561]
- [ethernet] i40e: whitespace paren and comment tweaks (Stefan Assmann) [1011561]
- [ethernet] i40e: rework shadow ram read functions (Stefan Assmann) [1011561]
- [ethernet] i40e: check MAC type before any REG access (Stefan Assmann) [1011561]
- [ethernet] i40e: move PF ID init from PF reset to SC init (Stefan Assmann) [1011561]
- [ethernet] i40e: Reduce range of interrupt reg in reg test (Stefan Assmann) [1011561]
- [ethernet] i40e: update firmware api to 1.1 (Stefan Assmann) [1011561]
- [ethernet] i40e: Add code to wait for FW to complete in reset path (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version (Stefan Assmann) [1011561]
- [ethernet] i40e: Allow VF to set already assigned MAC address (Stefan Assmann) [1011561]
- [ethernet] i40e: Stop accepting any VLAN tag on VLAN 0 filter set (Stefan Assmann) [1011561]
- [ethernet] i40e: Do not enable broadcast promiscuous by default (Stefan Assmann) [1011561]
- [ethernet] i40e: Expose AQ debugfs hooks (Stefan Assmann) [1011561]
- [ethernet] i40e: Do not allow AQ calls from ndo-ops (Stefan Assmann) [1011561]
- [ethernet] i40e: check asq alive before notify (Stefan Assmann) [1011561]
- [ethernet] i40e: Admin queue shutdown fixes (Stefan Assmann) [1011561]
- [ethernet] i40e: Hide the Port VLAN VLAN ID (Stefan Assmann) [1011561]
- [ethernet] i40e: use correct struct for get and update vsi params (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix VF driver MAC address configuration (Stefan Assmann) [1011561]
- [ethernet] i40e: support VFs on PFs other than 0 (Stefan Assmann) [1011561]
- [ethernet] i40e: acknowledge VFLR when disabling SR-IOV (Stefan Assmann) [1011561]
- [ethernet] i40e: don't allocate zero size (Stefan Assmann) [1011561]
- [ethernet] i40e: use struct assign instead of memcpy (Stefan Assmann) [1011561]
- [ethernet] i40e: Do not enable default port on the VEB (Stefan Assmann) [1011561]
- [ethernet] i40e: avoid unnecessary register read (Stefan Assmann) [1011561]
- [ethernet] i40e: fix whitespace (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix SR-IOV VF port VLAN (Stefan Assmann) [1011561]
- [ethernet] i40e: Record dma buffer info for dummy packets (Stefan Assmann) [1011561]
- [ethernet] i40e: remove un-necessary io-write (Stefan Assmann) [1011561]
- [ethernet] i40e: Remove unnecessary prototypes (Stefan Assmann) [1011561]
- [ethernet] i40e: I40E_FLAG_MQ_ENABLED is not used (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix ring allocation (Stefan Assmann) [1011561]
- [ethernet] i40e: catch unset q_vector (Stefan Assmann) [1011561]
- [ethernet] i40e: keep allocated memory in structs (Stefan Assmann) [1011561]
- [ethernet] i40e: fix error handling when alloc of vsi array fails (Stefan Assmann) [1011561]
- [ethernet] i40e: reinit buffer size each time (Stefan Assmann) [1011561]
- [ethernet] i40e: use functions to enable and disable icr 0 (Stefan Assmann) [1011561]
- [ethernet] i40e: add header file flag _I40E_TXRX_H_ (Stefan Assmann) [1011561]
- [ethernet] i40e: guard against vf message races (Stefan Assmann) [1011561]
- [ethernet] i40e: fix constant cast issues (Stefan Assmann) [1011561]
- [ethernet] i40e: Change the ethtool NVM read method to use AQ (Stefan Assmann) [1011561]
- [ethernet] i40e: fix mac address checking (Stefan Assmann) [1011561]
- [ethernet] i40e: Dump the whole NVM, not half (Stefan Assmann) [1011561]
- [ethernet] i40e: report VF MAC addresses correctly (Stefan Assmann) [1011561]
- [ethernet] i40e: update led set args (Stefan Assmann) [1011561]
- [ethernet] i40e: make a define from a large constant (Stefan Assmann) [1011561]
- [ethernet] i40e: be more informative (Stefan Assmann) [1011561]
- [ethernet] i40e: fix error return (Stefan Assmann) [1011561]
- [ethernet] i40e: remove chatty log messages (Stefan Assmann) [1011561]
- [ethernet] i40e: remove redundant code (Stefan Assmann) [1011561]
- [ethernet] i40e: refactor VF reset flow (Stefan Assmann) [1011561]
- [ethernet] i40e: move i40e_reset_vf (Stefan Assmann) [1011561]
- [ethernet] i40e: Rx checksum offload for VXLAN (Stefan Assmann) [1011561]
- [ethernet] i40e: Implementation of VXLAN ndo's (Stefan Assmann) [1011561]
- [ethernet] i40e: fix curly brace use and return type (Stefan Assmann) [1011561]
- [ethernet] i40e: add wake-on-lan support (Stefan Assmann) [1011561]
- [ethernet] i40e: Populate and check pci bus speed and width (Stefan Assmann) [1011561]
- [uapi] pci_regs: Add PCI bus link speed and width defines (Stefan Assmann) [1011561]
- [ethernet] i40e: Suppress HMC error to Interrupt message level (Stefan Assmann) [1011561]
- [ethernet] i40e: using for_each_set_bit to simplify the code (Stefan Assmann) [1011561]
- [ethernet] i40e: make functions static and remove dead code (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix off by one in i40e_dbg_command_write (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version number (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix wrong mask bits being used in misc interrupt (Stefan Assmann) [1011561]
- [ethernet] i40e: more print_hex_dump use (Stefan Assmann) [1011561]
- [ethernet] i40e: fix up scanf decoders (Stefan Assmann) [1011561]
- [ethernet] i40e: simplify error messages for dump descriptor (Stefan Assmann) [1011561]
- [ethernet] i40e: prevent null pointer exception in dump descriptor (Stefan Assmann) [1011561]
- [ethernet] i40e: Fix dump output from debugfs calls (Stefan Assmann) [1011561]
- [ethernet] i40e: Remove FCoE in i40e_virtchnl_pf.c code (Stefan Assmann) [1011561]
- [ethernet] i40e: support for suspend and resume (Stefan Assmann) [1011561]
- [ethernet] i40e: rtnl_lock in reset path fixes (Stefan Assmann) [1011561]
- [ethernet] i40e: Add basic support for get/set channels for RSS (Stefan Assmann) [1011561]
- [ethernet] i40e: function to reconfigure RSS queues and rebuild (Stefan Assmann) [1011561]
- [ethernet] i40e: reinit flow for the main VSI (Stefan Assmann) [1011561]
- [ethernet] i40e: use same number of queues as CPUs (Stefan Assmann) [1011561]
- [ethernet] i40e: trivial fixes (Stefan Assmann) [1011561]
- [ethernet] i40e: init flow control settings to disabled (Stefan Assmann) [1011561]
- [ethernet] i40e: Tell the stack about our actual number of queues (Stefan Assmann) [1011561]
- [ethernet] i40e: fix pf reset after offline test (Stefan Assmann) [1011561]
- [ethernet] i40e: fix up some of the ethtool connection reporting (Stefan Assmann) [1011561]
- [ethernet] i40e: fix null dereference (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version number (Stefan Assmann) [1011561]
- [ethernet] i40e: remove and fix confusing define name (Stefan Assmann) [1011561]
- [ethernet] i40e: complain about out-of-range descriptor request (Stefan Assmann) [1011561]
- [ethernet] i40e: loopback info and set loopback fix (Stefan Assmann) [1011561]
- [ethernet] i40e: restrict diag test messages (Stefan Assmann) [1011561]
- [ethernet] i40e: Add a new variable to track number of pf instances (Stefan Assmann) [1011561]
- [ethernet] i40e: add num_VFs message (Stefan Assmann) [1011561]
- [ethernet] i40e: refactor ethtool tests (Stefan Assmann) [1011561]
- [ethernet] i40e: clear test state bit after all ethtool tests (Stefan Assmann) [1011561]
- [ethernet] i40e: only set up the rings to be used (Stefan Assmann) [1011561]
- [ethernet] i40e: Enable all PCTYPEs except FCOE for RSS (Stefan Assmann) [1011561]
- [ethernet] i40e: refactor reset code (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version (Stefan Assmann) [1011561]
- [ethernet] i40e: whitespace (Stefan Assmann) [1011561]
- [ethernet] i40e: enable early hardware support (Stefan Assmann) [1011561]
- [ethernet] i40e: Add flag for L2 VEB filtering (Stefan Assmann) [1011561]
- [ethernet] i40e: get media type during link info (Stefan Assmann) [1011561]
- [ethernet] i40e: check multi-bit state correctly (Stefan Assmann) [1011561]
- [ethernet] i40e: separate TSYNVALID and TSYNINDX fields in Rx descriptor (Stefan Assmann) [1011561]
- [ethernet] i40e: sync header files with hardware (Stefan Assmann) [1011561]
- [ethernet] i40e: restrict diag test length (Stefan Assmann) [1011561]
- [ethernet] i40e: add support for triggering EMPR (Stefan Assmann) [1011561]
- [ethernet] i40e: add interrupt test (Stefan Assmann) [1011561]
- [ethernet] i40e: default debug mask setting (Stefan Assmann) [1011561]
- [ethernet] i40e: fix debugging messages (Stefan Assmann) [1011561]
- [ethernet] i40e: properly add VF MAC addresses (Stefan Assmann) [1011561]
- [ethernet] i40e: retry call on timeout (Stefan Assmann) [1011561]
- [ethernet] i40e: select reset counters correctly (Stefan Assmann) [1011561]
- [ethernet] i40e: allow one more vector for VFs (Stefan Assmann) [1011561]
- [ethernet] i40e: firmware version fields offsets update (Stefan Assmann) [1011561]
- [ethernet] i40e: simplify aq head-tail-len setups (Stefan Assmann) [1011561]
- [ethernet] i40e: clear AQ head and tail registers (Stefan Assmann) [1011561]
- [ethernet] i40e: register file updates (Stefan Assmann) [1011561]
- [ethernet] i40e: set pf_id based on device and function numbers (Stefan Assmann) [1011561]
- [ethernet] i40e: fix error return code in i40e_probe() (Stefan Assmann) [1011561]
- [ethernet] i40e: remove unused including <linux/version.h> (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version (Stefan Assmann) [1011561]
- [ethernet] i40e: use pf_id for pf function id in qtx_ctl (Stefan Assmann) [1011561]
- [ethernet] i40e: check vsi ptrs before dumping them (Stefan Assmann) [1011561]
- [ethernet] i40e: reorder block declarations in debugfs (Stefan Assmann) [1011561]
- [ethernet] i40e: tweaking icr0 handling for legacy irq (Stefan Assmann) [1011561]
- [ethernet] i40e: refactor fdir setup function (Stefan Assmann) [1011561]
- [ethernet] i40e: fix sign extension issue (Stefan Assmann) [1011561]
- [ethernet] i40e: fix use of untrusted scalar value warning (Stefan Assmann) [1011561]
- [ethernet] i40e: clamp debugfs nvm read command (Stefan Assmann) [1011561]
- [ethernet] i40e: debugfs fixups (Stefan Assmann) [1011561]
- [ethernet] i40e: fixup legacy interrupt handling (Stefan Assmann) [1011561]
- [ethernet] i40e: assign correct vector to VF (Stefan Assmann) [1011561]
- [ethernet] i40e: don't free nonexistent rings (Stefan Assmann) [1011561]
- [ethernet] i40e: do not flush after re-enabling interrupts (Stefan Assmann) [1011561]
- [ethernet] i40e: Bump version (Stefan Assmann) [1011561]
- [ethernet] i40e: Add support for 64 bit netstats (Stefan Assmann) [1011561]
- [ethernet] i40e: Move rings from pointer to array to array of pointers (Stefan Assmann) [1011561]
- [ethernet] i40e: Replace ring container array with linked list (Stefan Assmann) [1011561]
- [ethernet] i40e: Move q_vectors from pointer to array to array of pointers (Stefan Assmann) [1011561]
- [ethernet] i40e: Split bytes and packets from Rx/Tx stats (Stefan Assmann) [1011561]
- [ethernet] i40e: Add support for Tx byte queue limits (Stefan Assmann) [1011561]
- [ethernet] i40e: Drop dead code and flags from Tx hotpath (Stefan Assmann) [1011561]
- [ethernet] i40e: clean up Tx fast path (Stefan Assmann) [1011561]
- [ethernet] i40e: Do not directly increment Tx next_to_use (Stefan Assmann) [1011561]
- [ethernet] i40e: Cleanup Tx buffer info layout (Stefan Assmann) [1011561]
- [ethernet] i40e: Drop unused completed stat (Stefan Assmann) [1011561]
- [ethernet] i40e: Link code updates (Stefan Assmann) [1011561]
- [ethernet] i40e: clean up coccicheck reported errors (Stefan Assmann) [1011561]
- [ethernet] i40e: better return values (Stefan Assmann) [1011561]
- [ethernet] i40e: convert ret to aq_ret (Stefan Assmann) [1011561]
- [ethernet] i40e: small clean ups from review (Stefan Assmann) [1011561]
- [ethernet] i40e: use common failure flow (Stefan Assmann) [1011561]
- [net] sunrpc/rpc_pipe: fix cleanup of dummy gssd directory when notification fails (Jeff Layton) [1048105]
- [net] sunrpc: add an "info" file for the dummy gssd pipe (Jeff Layton) [1048105]
- [net] sunrpc/rpc_pipe: remove the clntXX dir if creating the pipe fails (Jeff Layton) [1048105]
- [fs] nfs: fix do_div() warning by instead using sector_div() (Steve Dickson) [769365]
- [misc] MAINTAINERS: Update contact information for Trond Myklebust (Steve Dickson) [769365]
- [fs] nfs: Prevent a 3-way deadlock between layoutreturn, open and state recovery (Steve Dickson) [769365]
- [net] sunrpc: do not fail gss proc NULL calls with EACCES (Steve Dickson) [769365]
- [fs] nfs: close needs to handle NFS4ERR_ADMIN_REVOKED (Steve Dickson) [769365]
- [fs] nfs: Update list of irrecoverable errors on DELEGRETURN (Steve Dickson) [769365]
- [fs] nfs: wait on recovery for async session errors (Steve Dickson) [769365]
- [fs] nfs: Fix a warning in nfs_setsecurity (Steve Dickson) [769365]
- [fs] nfs: Enabling v4.2 should not recompile nfsd and lockd (Steve Dickson) [769365]
- [fs] nfs: fix pnfs Kconfig defaults (Steve Dickson) [769365]
- [fs] nfs: correctly report misuse of "migration" mount option (Steve Dickson) [769365]
- [ethernet] igb: fix driver reload with VF assigned to guest (Stefan Assmann) [986817]
- [net] sunrpc: Cleanup xs_destroy() (Steve Dickson) [769365]
- [net] sunrpc: close a rare race in xs_tcp_setup_socket (Steve Dickson) [769365]
- [net] sunrpc: remove duplicated include from clnt.c (Steve Dickson) [769365]
- [fs] nfs: use IS_ROOT not DCACHE_DISCONNECTED (Steve Dickson) [769365]
- [net] sunrpc: Fix buffer overflow checking in gss_encode_v0_msg/gss_encode_v1_msg (Steve Dickson) [769365]
- [net] sunrpc: gss_alloc_msg - choose _either_ a v0 message or a v1 message (Steve Dickson) [769365]
- [net] sunrpc: remove an unnecessary if statement (Steve Dickson) [769365]
- [fs] nfs: Remove useless 'error' assignment (Steve Dickson) [769365]
- [net] sunrpc: comment typo fix (Steve Dickson) [769365]
- [net] sunrpc: Add correct rcu_dereference annotation in rpc_clnt_set_transport (Steve Dickson) [769365]
- [fs] nfs: add support for multiple sec= mount options (Steve Dickson) [769365]
- [fs] nfs: stop using NFS_MOUNT_SECFLAVOUR server flag (Steve Dickson) [769365]
- [fs] nfs: cache parsed auth_info in nfs_server (Steve Dickson) [769365]
- [fs] nfs: separate passed security flavs from selected (Steve Dickson) [769365]
- [fs] nfs: make nfs_find_best_sec static (Steve Dickson) [769365]
- [fs] nfs: Fix possible endless state recovery wait (Steve Dickson) [769365]
- [fs] nfs: Set EXCHGID4_FLAG_SUPP_MOVED_MIGR (Steve Dickson) [769365]
- [fs] nfs: Handle SEQ4_STATUS_LEASE_MOVED (Steve Dickson) [769365]
- [fs] nfs: Handle NFS4ERR_LEASE_MOVED during async RENEW (Steve Dickson) [769365]
- [fs] nfs: Migration support for RELEASE_LOCKOWNER (Steve Dickson) [769365]
- [fs] nfs: Implement support for NFS4ERR_LEASE_MOVED (Steve Dickson) [769365]
- [fs] nfs: Support NFS4ERR_LEASE_MOVED recovery in state manager (Steve Dickson) [769365]
- [fs] nfs: Add method to detect whether an FSID is still on the server (Steve Dickson) [769365]
- [fs] nfs: Handle NFS4ERR_MOVED during delegation recall (Steve Dickson) [769365]
- [fs] nfs: Add migration recovery callouts in nfs4proc.c (Steve Dickson) [769365]
- [fs] nfs: Rename "stateid_invalid" label (Steve Dickson) [769365]
- [fs] nfs: Re-use exit code in nfs4_async_handle_error() (Steve Dickson) [769365]
- [fs] nfs: Add basic migration support to state manager thread (Steve Dickson) [769365]
- [fs] nfs: Add a super_block backpointer to the nfs_server struct (Steve Dickson) [769365]
- [fs] nfs: Add method to retrieve fs_locations during migration recovery (Steve Dickson) [769365]
- [fs] nfs: Export _nfs_display_fhandle() (Steve Dickson) [769365]
- [fs] nfs: Introduce a vector of migration recovery ops (Steve Dickson) [769365]
- [fs] nfs: Add functions to swap transports during migration recovery (Steve Dickson) [769365]
- [fs] nfs: Add nfs4_update_server (Steve Dickson) [769365]
- [net] sunrpc: Add a helper to switch the transport of an rpc_clnt (Steve Dickson) [769365]
- [net] sunrpc: Modify synopsis of rpc_client_register() (Steve Dickson) [769365]
- [fs] nfs: don't reprocess cached open CLAIM_PREVIOUS (Steve Dickson) [769365]
- [fs] nfs: Fix state reference counting in _nfs4_opendata_reclaim_to_nfs4_state (Steve Dickson) [769365]
- [fs] nfs: don't fail on missing fattr in open recover (Steve Dickson) [769365]
- [fs] nfs: fix NULL dereference in open recover (Steve Dickson) [769365]
- [fs] nfs: Don't change the security label as part of open reclaim (Steve Dickson) [769365]
- [fs] nfs: Remove zeroing state kern warnings (Steve Dickson) [769365]
- [net] sunrpc: call_connect_status should recheck bind and connect status on error (Steve Dickson) [769365]
- [net] sunrpc: Remove redundant initialisations of request rq_bytes_sent (Steve Dickson) [769365]
- [net] sunrpc: Fix RPC call retransmission statistics (Steve Dickson) [769365]
- [fs] nfs: Ensure that we disable the resend timeout for NFSv4 (Steve Dickson) [769365]
- [net] sunrpc: Add RPC task and client level options to disable the resend timeout (Steve Dickson) [769365]
- [net] sunrpc: Clean up - convert xprt_prepare_transmit to return a bool (Steve Dickson) [769365]
- [net] sunrpc: Clear the request rq_bytes_sent field in xprt_release_write (Steve Dickson) [769365]
- [net] sunrpc: Don't set the request connect_cookie until a successful transmit (Steve Dickson) [769365]
- [net] sunrpc: Only update the TCP connect cookie on a successful connect (Steve Dickson) [769365]
- [net] sunrpc: Enable the keepalive option for TCP sockets (Steve Dickson) [769365]
- [fs] nfs: Fix a use-after-free situation in _nfs4_proc_getlk() (Steve Dickson) [769365]
- [wireless] iwlwifi: enable shadow registers for 7000 (Stanislaw Gruszka) [1016320]
- [wireless] iwlwifi: support BSS only (Stanislaw Gruszka) [1016320]
- [fs] gfs2: Increase i_writecount during gfs2_setattr_chown (Robert S Peterson) [1049045]
- [mm] thp: give transparent hugepage code a separate copy_page (Rik van Riel) [1044367]
- [kernel] time: menu governor broken when nohz=off (George Beshers) [1043652]
- [s390] perf: fix compile error (undefined reference sie_exit) (Hendrik Brueckner) [1035261]
- [s390] mm: page_table_realloc returns failure (Hendrik Brueckner) [1035261]
- [virt] virtio-net: Set RXCSUM feature if GUEST_CSUM is available (Hendrik Brueckner) [1035261]
- [s390] kvm: Add helper function for setting condition code (Hendrik Brueckner) [1035261]
- [s390] kvm: Make KVM_HVA_ERR_BAD usable on s390 (Hendrik Brueckner) [1035261]
- [s390] kvm: use cookies for ioeventfd (Hendrik Brueckner) [1035261]
- [s390] kvm/kvm-io: support cookies (Hendrik Brueckner) [1035261]
- [s390] kvm: fix pfmf non-quiescing control handling (Hendrik Brueckner) [1035261]
- [s390] kvm: Fix sparse warnings in priv.c (Hendrik Brueckner) [1035261]
- [s390] kvm: declare virtual HW facilities (Hendrik Brueckner) [1035261]
- [s390] kvm: fix task size check (Hendrik Brueckner) [1035261]
- [s390] kvm: allow sie enablement for multi-threaded programs (Hendrik Brueckner) [1035261]
- [s390] qeth: Increase default MTU for OSA devices (Hendrik Brueckner) [1035261]
- [s390] kvm: Fixed priority of execution in STSI (Hendrik Brueckner) [1035261]
- [s390] kvm: Reworked LCTL and LCTLG instructions (Hendrik Brueckner) [1035261]
- [s390] kvm: Check for access exceptions during TPI (Hendrik Brueckner) [1035261]
- [s390] kvm: Check for PSTATE when handling DIAGNOSE (Hendrik Brueckner) [1035261]
- [s390] kvm: Privileged operation checks moved to instruction handlers (Hendrik Brueckner) [1035261]
- [s390] kvm: Privileged operation check for TPROT (Hendrik Brueckner) [1035261]
- [s390] kvm: Renamed PGM_PRIVILEGED_OPERATION (Hendrik Brueckner) [1035261]
- [s390] kvm: Fix epsw instruction decoding (Hendrik Brueckner) [1035261]
- [s390] kvm: Use common waitqueue (Hendrik Brueckner) [1035261]
- [s390] kvm: code cleanup to use common vcpu slab cache (Hendrik Brueckner) [1035261]
- [s390] kvm: Detect if perf samples belong to KVM host or guest (Hendrik Brueckner) [1035261]
- [s390] kvm: guest large pages (Hendrik Brueckner) [1035261]
- [s390] kvm: avoid automatic sie reentry (Hendrik Brueckner) [1035261]
- [s390] kvm: Kick guests out of sie if prefix page host pte is touched (Hendrik Brueckner) [1035261]
- [s390] kvm: Provide a way to prevent reentering SIE (Hendrik Brueckner) [1035261]
- [s390] kvm: Mark if a cpu is in SIE (Hendrik Brueckner) [1035261]
- [s390] kvm: rename RCP_xxx defines to PGSTE_xxx (Hendrik Brueckner) [1035261]
- [s390] kvm: fix psw rewinding in handle_skey (Hendrik Brueckner) [1035261]
- [s390] kvm: Provide function for setting the guest storage key (Hendrik Brueckner) [1035261]
- [s390] facility: decompose test_facility() (Hendrik Brueckner) [1035261]

* Mon Jan 13 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-68.el7]
- [kernel] perf: Account freq events globally (Jeremy Eder) [1025775]
- [kernel] perf: Roll back callchain buffer refcount under the callchain mutex (Jeremy Eder) [1025775]
- [kernel] watchdog: Make it work under full dynticks (Jeremy Eder) [1025775]
- [kernel] watchdog: Boot-disable by default on full dynticks (Jeremy Eder) [1025775]
- [kernel] watchdog: Rename confusing state variable (Jeremy Eder) [1025775]
- [kernel] watchdog: Register / unregister watchdog kthreads on sysctl control (Jeremy Eder) [1025775]
- [kernel] perf: Implement finer grained full dynticks kick (Jeremy Eder) [1025775]
- [kernel] perf: Account freq events per cpu (Jeremy Eder) [1025775]
- [kernel] perf: Migrate per cpu event accounting (Jeremy Eder) [1025775]
- [kernel] perf: Split the per-cpu accounting part of the event accounting code (Jeremy Eder) [1025775]
- [kernel] perf: Factor out event accounting code to account_event()/__free_event() (Jeremy Eder) [1025775]
- [kernel] perf: Sanitize get_callchain_buffer() (Jeremy Eder) [1025775]
- [kernel] perf: Fix branch stack refcount leak on callchain init failure (Jeremy Eder) [1025775]
- [tools] perf/test: Update command line callchain attribute tests (Jiri Olsa) [1036665]
- [tools] perf: Fixup mmap event consumption (Jiri Olsa) [1036665]
- [tools] perf/top: Split -G and --call-graph (Jiri Olsa) [1036665]
- [tools] perf/record: Split -g and --call-graph (Jiri Olsa) [1036665]
- [tools] perf/hists: Add color overhead for stdio output buffer (Jiri Olsa) [1036665]
- [tools] perf: Fix up /proc/PID/maps parsing (Jiri Olsa) [1036665]
- [tools] perf/script: Fix mem leak due to missing Py_DECREFs on dict entries (Jiri Olsa) [1036665]
- [tools] perf: Disable PERF_RECORD_MMAP2 support (Jiri Olsa) [1036665]
- [tools] perf/scripting/perl: Fix build error on Fedora 12 (Jiri Olsa) [1036665]
- [tools] perf/probe: Fix to initialize fname always before use it (Jiri Olsa) [1036665]
- [tools] perf/session: Fix infinite loop on invalid perf.data file (Jiri Olsa) [1036665]
- [tools] perf: Fix installation of libexec components (Jiri Olsa) [1036665]
- [tools] perf/probe: Fix to find line information for probe list (Jiri Olsa) [1036665]
- [tools] perf: Fix libaudit test (Jiri Olsa) [1036665]
- [tools] perf/stat: Set child_pid after perf_evlist__prepare_workload() (Jiri Olsa) [1036665]
- [tools] perf: Add default handler for mmap2 events (Jiri Olsa) [1036665]
- [tools] perf/symbols: Demangle cloned functions (Jiri Olsa) [1036665]
- [tools] perf/machine: Fix path unpopulated in machine__create_modules() (Jiri Olsa) [1036665]
- [tools] perf: Explicitly add libdl dependency (Jiri Olsa) [1036665]
- [tools] perf/probe: Fix probing symbols with optimization suffix (Jiri Olsa) [1036665]
- [tools] perf/trace: Add mmap2 handler (Jiri Olsa) [1036665]
- [tools] perf/kmem: Make it work again on non NUMA machines (Jiri Olsa) [1036665]
- [tools] perf: Fix capabilities bitfield compatibility in 'struct perf_event_mmap_page' (Jiri Olsa) [1036665]
- [tools] perf: Fix old GCC build error in trace-event-parse.c:parse_proc_kallsyms() (Jiri Olsa) [1036665]
- [tools] perf/probe: Fix finder to find lines of given function (Jiri Olsa) [1036665]
- [tools] perf/session: Check for SIGINT in more loops (Jiri Olsa) [1036665]
- [tools] perf: Fix compile with libelf without get_phdrnum (Jiri Olsa) [1036665]
- [tools] perf: Fix buildid cache handling of kallsyms with kcore (Jiri Olsa) [1036665]
- [tools] perf/annotate: Fix objdump line parsing offset validation (Jiri Olsa) [1036665]
- [tools] perf: Fill in new definitions for madvise()/mmap() flags (Jiri Olsa) [1036665]
- [tools] perf: Sharpen the libaudit dependencies test (Jiri Olsa) [1036665]
- [tools] perf: Add attr->mmap2 support (Jiri Olsa) [1036665]
- [tools] perf/kvm: Fix sample_type manipulation (Jiri Olsa) [1036665]
- [tools] perf/evlist: Fix id pos in perf_evlist__open() (Jiri Olsa) [1036665]
- [tools] perf/trace: Handle perf.data files with no tracepoints (Jiri Olsa) [1036665]
- [tools] perf/session: Separate progress bar update when processing events (Jiri Olsa) [1036665]
- [tools] perf/trace: Check if MAP_32BIT is defined (Jiri Olsa) [1036665]
- [tools] perf/hists: Fix formatting of long symbol names (Jiri Olsa) [1036665]
- [tools] perf/evlist: Fix parsing with no sample_id_all bit set (Jiri Olsa) [1036665]
- [tools] perf: Add test for parsing with no sample_id_all bit (Jiri Olsa) [1036665]
- [tools] perf/trace: Check control+C more often (Jiri Olsa) [1036665]
- [tools] perf/trace: Tell arg formatters the arg index (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for open's flags arg (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for lseek's whence arg (Jiri Olsa) [1036665]
- [tools] perf: Fix symbol offset computation for some dsos (Jiri Olsa) [1036665]
- [tools] perf/list: Skip unsupported events (Jiri Olsa) [1036665]
- [tools] perf/tests: Add 'keep tracking' test (Jiri Olsa) [1036665]
- [tools] perf: Add support for PERF_COUNT_SW_DUMMY (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for futex 'operation' parm (Jiri Olsa) [1036665]
- [tools] perf/trace: Allow syscall arg formatters to mask args (Jiri Olsa) [1036665]
- [tools] perf/trace: Handle missing HUGEPAGE defines (Jiri Olsa) [1036665]
- [tools] perf/trace: Honor target pid / tid options when analyzing a file (Jiri Olsa) [1036665]
- [tools] perf/trace: Add option to analyze events in a file versus live (Jiri Olsa) [1036665]
- [tools] perf/evlist: Add tracepoint lookup by name (Jiri Olsa) [1036665]
- [tools] perf/tests: Add a sample parsing test (Jiri Olsa) [1036665]
- [tools] perf: Add a function to calculate sample event size (Jiri Olsa) [1036665]
- [tools] perf: Expand perf_event__synthesize_sample() (Jiri Olsa) [1036665]
- [tools] perf: Add missing 'abi' member to 'struct regs_dump' (Jiri Olsa) [1036665]
- [tools] perf: Add support for PERF_SAMPLE_IDENTIFIER (Jiri Olsa) [1036665]
- [tools] perf/evlist: Move perf_evlist__config() to a new source file (Jiri Olsa) [1036665]
- [tools] perf: Remove references to struct ip_event (Jiri Olsa) [1036665]
- [tools] perf/callchain: Remove unnecessary validation (Jiri Olsa) [1036665]
- [tools] perf/evsel: Tidy up sample parsing overflow checking (Jiri Olsa) [1036665]
- [tools] perf: change machine__findnew_thread() to set thread pid (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Fixup jobserver setup (Jiri Olsa) [1036665]
- [tools] perf: Add pid to struct thread (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for madvise behaviour/advice parm (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for mmap flags parm (Jiri Olsa) [1036665]
- [tools] perf/trace: Add beautifier for mmap prot parm (Jiri Olsa) [1036665]
- [tools] perf/trace: Allow overiding the formatting of syscall fields (Jiri Olsa) [1036665]
- [tools] perf/trace: Add aliases to remaining syscalls of the sys_enter_newfoo (Jiri Olsa) [1036665]
- [tools] perf/trace: Allow printing syscall return values in hex (Jiri Olsa) [1036665]
- [tools] perf/trace: Simplify sys_exit return printing (Jiri Olsa) [1036665]
- [tools] perf/trace: Introduce syscall arg formatters (Jiri Olsa) [1036665]
- [tools] perf/trace: Hide sys_exit messages about syscall id = -1 (Jiri Olsa) [1036665]
- [tools] perf/trace: Add --verbose option (Jiri Olsa) [1036665]
- [tools] perf/trace: Support ! in -e expressions (Jiri Olsa) [1036665]
- [tools] perf: Don't install scripting files files when disabled (Jiri Olsa) [1036665]
- [tools] perf: Sample after exit loses thread correlation (Jiri Olsa) [1036665]
- [tools] perf/trace: Make command line arguments consistent with perf-record (Jiri Olsa) [1036665]
- [tools] perf/trace: Implement -o/--output filename (Jiri Olsa) [1036665]
- [tools] perf: Add debug prints (Jiri Olsa) [1036665]
- [tools] perf: Re-implement debug print function for linking python/perf.so (Jiri Olsa) [1036665]
- [tools] perf: Try to increase the file descriptor limits on EMFILE (Jiri Olsa) [1036665]
- [tools] perf/kvm: Remove force option to cmd_record (Jiri Olsa) [1036665]
- [tools] perf/trace: Allow specifying which syscalls to trace (Jiri Olsa) [1036665]
- [tools] perf: Improve robustness of topology parsing code (Jiri Olsa) [1036665]
- [tools] perf/tests: Fix compile failure on do_sort_something (Jiri Olsa) [1036665]
- [tools] perf: Remove filter parameter of thread__find_addr_map() (Jiri Olsa) [1036665]
- [tools] perf: Remove filter parameter of thread__find_addr_location() (Jiri Olsa) [1036665]
- [tools] perf: Remove filter parameter of perf_event__preprocess_sample() (Jiri Olsa) [1036665]
- [tools] perf/annotate: Set the machines symbol filter (Jiri Olsa) [1036665]
- [tools] perf/mem: Remove unused symbol filter member (Jiri Olsa) [1036665]
- [tools] perf/report: Set the machines symbol filter (Jiri Olsa) [1036665]
- [tools] perf/top: Set the machines symbol filter (Jiri Olsa) [1036665]
- [tools] perf/machine: Add symbol filter to struct machine (Jiri Olsa) [1036665]
- [tools] perf/session: Change perf_session__has_traces to actually check for tracepoints (Jiri Olsa) [1036665]
- [tools] perf/evsel: Add option to limit stack depth in callchain dumps (Jiri Olsa) [1036665]
- [tools] perf/evsel: Add option to print stack trace on single line (Jiri Olsa) [1036665]
- [tools] perf/tool: Simplify options to perf_evsel__print_ip (Jiri Olsa) [1036665]
- [tools] perf/sched: Remove sched_process_fork tracepoint (Jiri Olsa) [1036665]
- [tools] perf/sched: Remove sched_process_exit tracepoint (Jiri Olsa) [1036665]
- [tools] perf/sched: Remove thread lookup in sample handler (Jiri Olsa) [1036665]
- [tools] perf/sched: Simplify arguments to read_events (Jiri Olsa) [1036665]
- [tools] perf/kvm: Update documentation with live command (Jiri Olsa) [1036665]
- [tools] perf/kvm: Option to print events that exceed a duration (Jiri Olsa) [1036665]
- [tools] perf/machine: Do not require /lib/modules/* on a guest (Jiri Olsa) [1036665]
- [tools] perf/tests: Add tests of new pinned modifier (Jiri Olsa) [1036665]
- [tools] perf: Add support for pinned modifier (Jiri Olsa) [1036665]
- [tools] perf/ui/gtk: Fix segmentation fault on perf_hpp__for_each_format loop (Jiri Olsa) [1036665]
- [tools] perf/kvm: Add option to analyze specific VM (Jiri Olsa) [1036665]
- [tools] perf/kvm: Add min and max stats to display (Jiri Olsa) [1036665]
- [tools] perf/kvm: Add live mode (Jiri Olsa) [1036665]
- [tools] perf/session: Export queue_event function (Jiri Olsa) [1036665]
- [tools] perf/annotate: Fix typo (Jiri Olsa) [1036665]
- [tools] perf/annotate: Improve description of '?' hotkey (Jiri Olsa) [1036665]
- [tools] perf/annotate: Add call target name if it is missing (Jiri Olsa) [1036665]
- [tools] perf/annotate: Remove nop at end of annotation (Jiri Olsa) [1036665]
- [tools] perf/annotate: Put dso name in symbol annotation title (Jiri Olsa) [1036665]
- [tools] perf/annotate: Allow disassembly using /proc/kcore (Jiri Olsa) [1036665]
- [tools] perf/tests: Add kcore to the object code reading test (Jiri Olsa) [1036665]
- [tools] perf/tests: Adjust the vmlinux symtab matches kallsyms test again (Jiri Olsa) [1036665]
- [tools] perf/symbols: Add support for reading from /proc/kcore (Jiri Olsa) [1036665]
- [tools] perf: Make it possible to read object code from kernel modules (Jiri Olsa) [1036665]
- [tools] perf/tests: Adjust the vmlinux symtab matches kallsyms test (Jiri Olsa) [1036665]
- [tools] perf: Make it possible to read object code from vmlinux (Jiri Olsa) [1036665]
- [tools] perf/symbols: Load kernel maps before using (Jiri Olsa) [1036665]
- [tools] perf/tests: Add test for reading object code (Jiri Olsa) [1036665]
- [tools] perf/symbols: avoid SyS kernel syscall aliases (Jiri Olsa) [1036665]
- [tools] perf/stat: Flush output after each line in interval mode (Jiri Olsa) [1036665]
- [tools] perf/stat: Add support for --initial-delay option (Jiri Olsa) [1036665]
- [tools] perf/evsel: Add support for enabling counters (Jiri Olsa) [1036665]
- [tools] perf/evlist: Remove obsolete dummy execve (Jiri Olsa) [1036665]
- [tools] perf/kvm: Split out tracepoints from record args (Jiri Olsa) [1036665]
- [tools] perf/session: Export a few functions for event processing (Jiri Olsa) [1036665]
- [tools] perf/stats: Add max and min stats (Jiri Olsa) [1036665]
- [tools] perf/top: move CONSOLE_CLEAR to header file (Jiri Olsa) [1036665]
- [tools] perf/util: Add parse_nsec_time() function (Jiri Olsa) [1036665]
- [tools] perf/python: Remove duplicate TID bit from mask (Jiri Olsa) [1036665]
- [tools] perf/trace: Beautify 'connect' result (Jiri Olsa) [1036665]
- [tools] perf: Fix compile of util/tsc.c (Jiri Olsa) [1036665]
- [tools] perf/evsel: Actually show symbol offset in stack trace when requested (Jiri Olsa) [1036665]
- [tools] perf: Add test for converting perf time to/from TSC (Jiri Olsa) [1036665]
- [tools] perf: Move weight back to common sort keys (Jiri Olsa) [1036665]
- [tools] perf/tests: Add broken install-* tests into tests/make (Jiri Olsa) [1036665]
- [tools] perf/tests: Add 'make install/install-bin' tests into tests/make (Jiri Olsa) [1036665]
- [tools] perf/tests: Add DESTDIR=TMP_DEST tests/make variable (Jiri Olsa) [1036665]
- [tools] perf/tests: Rename TMP to TMP_O tests/make variable (Jiri Olsa) [1036665]
- [tools] perf/tests: Run ctags/cscope make tests only with needed binaries (Jiri Olsa) [1036665]
- [tools] perf: Fix build with perl 5.18 (Jiri Olsa) [1036665]
- [tools] perf: Support callchain sorting based on addresses (Jiri Olsa) [1036665]
- [tools] perf/bench: Fix memcpy benchmark for large sizes (Jiri Olsa) [1036665]
- [tools] perf/evsel: Handle ENODEV on default cycles event (Jiri Olsa) [1036665]
- [tools] perf/script: Fix named threads support (Jiri Olsa) [1036665]
- [tools] perf/header: Recognize version number for perf data file (Jiri Olsa) [1036665]
- [tools] perf/header: Introduce feat_offset into perf_header (Jiri Olsa) [1036665]
- [tools] perf/header: Remove attr_offset from perf_header (Jiri Olsa) [1036665]
- [tools] perf/header: Remove data_offset seek as it's not needed (Jiri Olsa) [1036665]
- [tools] perf/session: Use session->fd instead of passing fd as argument (Jiri Olsa) [1036665]
- [tools] perf/symbols: Do not apply symfs for an absolute vmlinux path (Jiri Olsa) [1036665]
- [tools] perf: Fix 'make tools/perf' (Jiri Olsa) [1036665]
- [tools] perf: Remove event types framework completely (Jiri Olsa) [1036665]
- [tools] perf/record: Remove event types pushing (Jiri Olsa) [1036665]
- [tools] perf: Remove event types from perf data file (Jiri Olsa) [1036665]
- [tools] perf/timechart: Remove event types framework only user (Jiri Olsa) [1036665]
- [tools] perf/timechart: Use traceevent lib event-parse.h include (Jiri Olsa) [1036665]
- [tools] perf: Move hist_entry__period_snprintf into stdio code (Jiri Olsa) [1036665]
- [tools] perf/report/top: Add option to collapse undesired parts of call graph (Jiri Olsa) [1036665]
- [tools] perf/list: List kernel supplied event aliases (Jiri Olsa) [1036665]
- [tools] perf: Default to cpu// for events v5 (Jiri Olsa) [1036665]
- [tools] perf: struct thread has a tid not a pid (Jiri Olsa) [1036665]
- [tools] perf: Validate perf event header size (Jiri Olsa) [1036665]
- [tools] perf/evlist: Tidy duplicated munmap code (Jiri Olsa) [1036665]
- [tools] perf: Add const specifier to perf_pmu__find name parameter (Jiri Olsa) [1036665]
- [tools] perf/inject: Add missing 'finished_round' (Jiri Olsa) [1036665]
- [tools] perf: Fix missing tool parameter (Jiri Olsa) [1036665]
- [tools] perf/inject: Remove unused parameter (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Set rules hint for the hist browser (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Add a double-click handler for callchains (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Make column headers resizable (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Display callchain overhead also (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Add support for callchains (Jiri Olsa) [1036665]
- [tools] perf/gtk/hists: Use GtkTreeStore instead of GtkListStore (Jiri Olsa) [1036665]
- [tools] perf/sched: Move struct perf_sched definition out of cmd_sched() (Jiri Olsa) [1036665]
- [tools] perf/util: Remove unused enum and macro in trace-event.h (Jiri Olsa) [1036665]
- [tools] perf/util: No need to call read_trace_init() in tracing_data_header() (Jiri Olsa) [1036665]
- [tools] perf/util: Rename read_*() functions in trace-event-info.c (Jiri Olsa) [1036665]
- [tools] perf/script: Adopt latency_format variable (Jiri Olsa) [1036665]
- [tools] perf/util: Get rid of unused header_page_* variables (Jiri Olsa) [1036665]
- [tools] perf/util: Parse header_page to get proper long size (Jiri Olsa) [1036665]
- [tools] perf/util: Skip reading header_event file (Jiri Olsa) [1036665]
- [tools] perf/util: Make file/host_bigendian variable local (Jiri Olsa) [1036665]
- [tools] perf/util: Save long size of traced system (Jiri Olsa) [1036665]
- [tools] perf/util: Save page size in a trace file to pevent (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Port kbuffer parser routines (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Add page_size field to pevent (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Add trace_seq_reset() (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Add const qualifier to string arguments (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Get rid of unused gui target (Jiri Olsa) [1036665]
- [tools] lib/traceevent: Remove unused install targets (Jiri Olsa) [1036665]
- [tools] perf/parse events: Demystify memory allocations (Jiri Olsa) [1036665]
- [tools] perf/tests: Make terms a stack variable in test_term (Jiri Olsa) [1036665]
- [tools] perf: Don't free list head in parse_events__free_terms (Jiri Olsa) [1036665]
- [tools] perf/evlist: Fix use of uninitialized variable (Jiri Olsa) [1036665]
- [tools] perf/report: Fix perf_session__delete removal (Jiri Olsa) [1036665]
- [tools] perf: Do not elide parent symbol column (Jiri Olsa) [1036665]
- [tools] perf/util: Use evsel->name to get tracepoint_paths (Jiri Olsa) [1036665]
- [tools] perf/util: Move debugfs/tracing helper functions to util.c (Jiri Olsa) [1036665]
- [tools] perf: Remove callchain_cursor_reset call (Jiri Olsa) [1036665]
- [tools] perf: Add methods for setting/retrieving priv element of thread struct (Jiri Olsa) [1036665]
- [tools] perf: Use default include path notation for libtraceevent headers (Jiri Olsa) [1036665]
- [tools] perf/tests: Make TEST_ASSERT_VAL global (Jiri Olsa) [1036665]
- [tools] perf: Remove cwd from perf_session struct (Jiri Olsa) [1036665]
- [tools] perf/top: Add --objdump option (Jiri Olsa) [1036665]
- [tools] perf: Rename cpu_map__all() to cpu_map__empty() (Jiri Olsa) [1036665]
- [tools] perf: Update ABI comment (Jiri Olsa) [1036665]
- [tools] perf: Fix UAPI export of PERF_EVENT_IOC_ID (Jiri Olsa) [1036665]
- [tools] perf: Add a dummy software event to keep tracking (Jiri Olsa) [1036665]
- [tools] perf: Fix up MMAP2 buffer space reservation (Jiri Olsa) [1036665]
- [tools] perf: Add attr->mmap2 attribute to an event (Jiri Olsa) [1036665]
- [tools] perf: make events stream always parsable (Jiri Olsa) [1036665]
- [tools] perf/x86: Add ability to calculate TSC from perf sample timestamps (Jiri Olsa) [1036665]
- [tools] perf: Fix broken union in 'struct perf_event_mmap_page' (Jiri Olsa) [1036665]
- [tools] perf: Update perf_event_type documentation (Jiri Olsa) [1036665]
- [tools] perf: Remove the 'match' callback for auxiliary events processing (Jiri Olsa) [1036665]
- [edac] amd64_edac: Correct erratum 505 range (Kim Naru) [1013820]
- [edac] mce_amd: Add an MCE signature for new Fam15h models (Kim Naru) [1013820]
- [edac] amd64_edac: Fix incorrect wraparounds (Kim Naru) [1013820]
- [edac] amd64_edac: Get rid of boot_cpu_data accesses (Kim Naru) [1013820]
- [edac] amd64_edac: Add ECC decoding support for newer F15h model (Kim Naru) [1013820]
- [block] blk-mq: Don't reserve a tag for flush request (Mike Snitzer) [1048301]
- [lib] percpu_ida: fix a live lock (Mike Snitzer) [1048301]
- [net] ipv4: loopback device: ignore value changes after device is upped (Jiri Pirko) [1040347]
- [net] netfilter: only warn once on wrong seqadj usage (Jesper Brouer) [1031968]
- [net] ipvs: correct usage/allocation of seqadj ext in ipvs (Jesper Brouer) [1031968]
- [net] netfilter: WARN about wrong usage of sequence number adjustments (Jesper Brouer) [1031968]
- [net] vxlan: use custom ndo_change_mtu handler (Daniel Borkmann) [1039848]
- [net] Loosen constraints for recalculating checksum in skb_segment() (Vlad Yasevich) [1042762]
- [net] core: convert class code to use dev_groups (Jiri Benc) [1037452]
- [net] ptp: convert class code to use dev_groups (Jiri Benc) [1037452]

* Tue Jan 07 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-67.el7]
- [s390] time, vdso: fix clock_gettime for CLOCK_MONOTONIC (Hendrik Brueckner) [1036677]
- [s390] vdso: ectg gettime support for CLOCK_THREAD_CPUTIME_ID (Hendrik Brueckner) [1036677]
- [s390] vdso: fix access-list entry initialization (Hendrik Brueckner) [1036677]
- [s390] time, vdso: convert to the new update_vsyscall interface (Hendrik Brueckner) [1036677]

* Mon Jan 06 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-66.el7]
- [net] netfilter: fix wrong byte order in nf_ct_seqadj_set internal information (Jesper Brouer) [1045360]
- [net] br: fix use of ->rx_handler_data in code executed on non-rx_handler path (Jiri Pirko) [1039118]
- [net] openvswitch: Use flow hash during flow lookup operation (Francesco Fusco) [1043536]
- [net] openvswitch: TCP flags matching support (Francesco Fusco) [1043536]
- [net] openvswitch: Widen TCP flags handling (Francesco Fusco) [1043536]
- [net] openvswitch: Enable all GSO features on internal port (Francesco Fusco) [1043536]
- [net] openvswitch: collect mega flow mask stats (Francesco Fusco) [1043536]
- [net] openvswitch: Simplify mega-flow APIs (Francesco Fusco) [1043536]
- [net] openvswitch: Move mega-flow list out of rehashing struct (Francesco Fusco) [1043536]
- [net] openvswitch: Restructure datapath.c and flow.c (Francesco Fusco) [1043536]
- [net] openvswitch: remove duplicated include from vport-gre.c (Francesco Fusco) [1043536]
- [net] openvswitch: remove duplicated include from vport-vxlan.c (Francesco Fusco) [1043536]
- [net] openvswitch: Move flow table rehashing to flow install (Francesco Fusco) [1043536]
- [net] openvswitch: flow: fix potential illegal memory access in __parse_flow_nlattrs (Francesco Fusco) [1043536]
- [net] openvswitch: Fix alignment of struct sw_flow_key (Francesco Fusco) [1043536]
- [net] add BUG_ON if kernel advertises msg_namelen > sizeof(struct sockaddr_storage) (Florian Westphal) [1039870] {CVE-2013-7266 CVE-2013-7267 CVE-2013-7268 CVE-2013-7269 CVE-2013-7270 CVE-2013-7271}
- [net] rework recvmsg handler msg_name and msg_namelen logic (Florian Westphal) [1039870] {CVE-2013-7266 CVE-2013-7267 CVE-2013-7268 CVE-2013-7269 CVE-2013-7270 CVE-2013-7271}
- [acpi] acpi_gpio: protect against future KABI breakage (Prarit Bhargava) [1037769]
- [acpi] processor: Introduce apic_id in struct processor to save parsed APIC id (Prarit Bhargava) [1037769]
- [edac] sb_edac: add support for Ivy Bridge (Aristeu Rozanski) [1029153]
- [edac] sb_edac: avoid decoding the same error multiple times (Aristeu Rozanski) [1029153]
- [edac] sb_edac: rename mci_bind_devs() (Aristeu Rozanski) [1029153]
- [edac] sb_edac: enable multiple PCI id tables to be used (Aristeu Rozanski) [1029153]
- [edac] sb_edac: rework sad_pkg (Aristeu Rozanski) [1029153]
- [edac] sb_edac: allow different interleave lists (Aristeu Rozanski) [1029153]
- [edac] sb_edac: allow different dram_rule arrays (Aristeu Rozanski) [1029153]
- [edac] sb_edac: isolate TOHM retrieval (Aristeu Rozanski) [1029153]
- [edac] sb_edac: rename pci_br (Aristeu Rozanski) [1029153]
- [edac] sb_edac: isolate TOLM retrieval (Aristeu Rozanski) [1029153]
- [edac] sb_edac: make RANK_CFG_A value part of sbridge_info (Aristeu Rozanski) [1029153]
- [s390] time: revert direct ktime path for s390 clockevent device (Hendrik Brueckner) [1036682]
- [security] keys: fix uninitialized persistent_keyring_register_sem (Steve Best) [1030472]
- [sched] idle: Fix the idle polling state logic (Jeremy Eder) [1038152]
- [misc] enclosure: fix WARN_ON in dual path device removing (Steve Best) [1030291]
- [security] keys: Pre-clear struct key on allocation (David Howells) [1032980]
- [powerpc] eeh: Use interruptible sleep in keehd (Steve Best) [1044378]

* Thu Jan 02 2014 Jarod Wilson <jarod@redhat.com> [3.10.0-65.el7]
- [md] fix calculation of stacking limits on level change (Jes Sorensen) [1033479]
- [x86] better solution for x86 single cpu support check (Prarit Bhargava) [1032604]
- [kernel] sched: Fix asymmetric scheduling for POWER7 (Steve Best) [1032796]
- [fs] writeback: Fix data corruption on NFS (Jeff Layton) [1042112]
- [fs] writeback: do not sync data dirtied after sync start (Jeff Layton) [1042112]
- [fs] writeback: fix race that cause writeback hung (Jeff Layton) [1042112]
- [fs] writeback: make writeback_inodes_wb static (Jeff Layton) [1042112]
- [fs] writeback: fix occasional slow sync(1) (Jeff Layton) [1042112]
- [fs] writeback: don't check force_wait to handle bdi->work_list (Jeff Layton) [1042112]
- [fs] fs-writeback: make wb_do_writeback() as static (Jeff Layton) [1042112]
- [fs] writeback: Do not sort b_io list only because of block device inode (Jeff Layton) [1042112]
- [fs] sync: don't block the flusher thread waiting on IO (Jeff Layton) [1042112]
- [security] selinux: process labeled IPsec TCP SYN-ACK packets properly in selinux_ip_postroute() (Paul Moore) [1040183]
- [security] selinux: look for IPsec labels on both inbound and outbound packets (Paul Moore) [1040183]
- [security] selinux: handle TCP SYN-ACK packets correctly in selinux_ip_postroute() (Paul Moore) [1040183]
- [security] selinux: handle TCP SYN-ACK packets correctly in selinux_ip_output() (Paul Moore) [1040183]
- [s390] signal: always restore saved runtime instrumentation psw bit (Hendrik Brueckner) [1029884]
- [s390] fix handling of runtime instrumentation psw bit (Hendrik Brueckner) [1029884]
- [platform] asus-nb-wmi: set wapf=4 for ASUSTeK COMPUTER INC. 1015E/U (Prarit Bhargava) [1043248]
- [platform] asus-nb-wmi: ignore ALS notification key code (Prarit Bhargava) [1043248]
- [fs] gfs2: Fix slab memory leak in gfs2_bufdata (Robert S Peterson) [1038123]
- [fs] gfs2: Fix use-after-free race when calling gfs2_remove_from_ail (Robert S Peterson) [1038123]
- [virt] kvm: fix guest-initiated crash with x2apic (Andrew Jones) [1042101] {CVE-2013-6376}
- [drm] qxl: fix memory leak in release list handling (Dave Airlie) [1035564]
- [scsi] ipr: Increase msi-x interrupt vectors to 16 (Steve Best) [1038501]

* Tue Dec 17 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-64.el7]
- [powerpc] powernv: Don't crash if there are no OPAL consoles (Steve Best) [1033086]
- [powerpc] powernv: Reserve the correct PE number (Steve Best) [1033086]
- [powerpc] powernv: Add PE to its own PELTV (Steve Best) [1033086]
- [powerpc] eeh: Output PHB3 diag-data (Steve Best) [1033086]
- [powerpc] powernv: Double size of log blob (Steve Best) [1033086]
- [powerpc] eeh: Output error number (Steve Best) [1033086]
- [powerpc] powernv: Support inbound error injection (Steve Best) [1033086]
- [powerpc] powernv: Enable EEH for PHB3 (Steve Best) [1033086]
- [powerpc] eeh: Fix undefined variable (Steve Best) [1033086]
- [powerpc] pci: Remove duplicate check in pcibios_fixup_bus() (Steve Best) [1033086]
- [powerpc] powernv: Needn't IO segment map for PHB3 (Steve Best) [1033086]
- [powerpc] powernv: Check primary PHB through ID (Steve Best) [1033086]
- [powerpc] powernv: Fetch PHB bus range from dev-tree (Steve Best) [1033086]
- [powerpc] powernv: Free PHB instance upon error (Steve Best) [1033086]
- [powerpc] eeh: Introdce flag to protect sysfs (Steve Best) [1033086]
- [powerpc] eeh: Fix unbalanced enable for IRQ (Steve Best) [1033086]
- [powerpc] eeh: Don't use pci_dev during BAR restore (Steve Best) [1033086]
- [powerpc] eeh: Use partial hotplug for EEH unaware drivers (Steve Best) [1033086]
- [powerpc] pci: Partial tree hotplug support (Steve Best) [1033086]
- [powerpc] eeh: Use safe list traversal when walking EEH devices (Steve Best) [1033086]
- [powerpc] eeh: Keep PE during hotplug (Steve Best) [1033086]
- [pci] hotplug: Don't need to remove from EEH cache twice (Steve Best) [1033086]
- [powerpc] pci: Override pcibios_release_device() (Steve Best) [1033086]
- [powerpc] eeh: Export functions for hotplug (Steve Best) [1033086]
- [powerpc] eeh: Remove reference to PCI device (Steve Best) [1033086]
- [powerpc] powernv: Use dev-node in PCI config accessors (Steve Best) [1033086]
- [powerpc] eeh: Avoid build warnings (Steve Best) [1033086]
- [powerpc] eeh: Refactor the output message (Steve Best) [1033086]
- [powerpc] eeh: Fix address catch for PowerNV (Steve Best) [1033086]
- [powerpc] powernv: Replace variables with flags (Steve Best) [1033086]
- [powerpc] eeh: Check PCIe link after reset (Steve Best) [1033086]
- [powerpc] eeh: Don't collect PCI-CFG data on PHB (Steve Best) [1033086]
- [powerpc] eeh: Debugfs for error injection (Steve Best) [1033086]
- [powerpc] powernv: Debugfs directory for PHB (Steve Best) [1033086]
- [powerpc] eeh: Register OPAL notifier for PCI error (Steve Best) [1033086]
- [powerpc] powernv/opal: Disable OPAL notifier upon poweroff (Steve Best) [1033086]
- [powerpc] powernv/opal: Notifier for OPAL events (Steve Best) [1033086]
- [powerpc] eeh: Allow to check fenced PHB proactively (Steve Best) [1033086]
- [powerpc] eeh: Enable EEH check for config access (Steve Best) [1033086]
- [powerpc] eeh: Initialization for PowerNV (Steve Best) [1033086]
- [powerpc] eeh: PowerNV EEH backends (Steve Best) [1033086]
- [powerpc] eeh: I/O chip next error (Steve Best) [1033086]
- [powerpc] eeh: I/O chip PE log and bridge setup (Steve Best) [1033086]
- [powerpc] eeh: I/O chip PE reset (Steve Best) [1033086]
- [powerpc] eeh: I/O chip EEH state retrieval (Steve Best) [1033086]
- [powerpc] eeh: I/O chip EEH enable option (Steve Best) [1033086]
- [powerpc] eeh: I/O chip post initialization (Steve Best) [1033086]
- [powerpc] eeh: EEH backend for P7IOC (Steve Best) [1033086]
- [powerpc] eeh: Sync OPAL API with firmware (Steve Best) [1033086]
- [powerpc] eeh: EEH core to handle special event (Steve Best) [1033086]
- [powerpc] eeh: Export confirm_error_lock (Steve Best) [1033086]
- [powerpc] eeh: Allow to purge EEH events (Steve Best) [1033086]
- [powerpc] eeh: Trace time on first error for PE (Steve Best) [1033086]
- [powerpc] eeh: Single kthread to handle events (Steve Best) [1033086]
- [powerpc] eeh: Delay EEH probe during hotplug (Steve Best) [1033086]
- [powerpc] eeh: Refactor eeh_reset_pe_once() (Steve Best) [1033086]
- [powerpc] eeh: EEH post initialization operation (Steve Best) [1033086]
- [powerpc] eeh: Make eeh_init() public (Steve Best) [1033086]
- [powerpc] eeh: Trace PCI bus from PE (Steve Best) [1033086]
- [powerpc] eeh: Make eeh_pe_get() public (Steve Best) [1033086]
- [powerpc] eeh: Make eeh_phb_pe_get() public (Steve Best) [1033086]
- [powerpc] eeh: Move common part to kernel directory (Steve Best) [1033086]
- [powerpc] eeh: Cleanup for EEH core (Steve Best) [1033086]
- [powerpc] eeh: Enhance converting EEH dev (Steve Best) [1033086]
- [s390] crypto: Fix aes-xts parameter corruption (Hendrik Brueckner) [1039937]
- [fs] aio: restore locking of ioctx list on removal (Mateusz Guzik) [1013373]
- [virt] kvm: Convert vapic synchronization to _cached functions (Andrew Jones) [1042092] {CVE-2013-6368}
- [virt] kvm: Fix potential divide by 0 in lapic (Andrew Jones) [1042084] {CVE-2013-6367}
- [virt] kvm: Improve create VCPU parameter (Andrew Jones) [1042074] {CVE-2013-4587}
- [cpufreq] check cpufreq driver is valid and cpufreq isn't disabled in cpufreq_get() (Jan Stancek) [1040409]
- [block] blk-mq: fix memory leaks on unplugging block device (Mike Snitzer) [1040675]
- [block] blk-mq: fix use-after-free of request (Mike Snitzer) [1040675]
- [block] blk-mq: fix dereference of rq->mq_ctx if allocation fails (Mike Snitzer) [1040675]
- [block] blk-mq: add blktrace insert event trace (Mike Snitzer) [1040675]
- [block] blk-mq: ensure that we set REQ_IO_STAT so diskstats work (Mike Snitzer) [1040675]
- [mm] numa: write pte_numa pte back to the page tables (Rik van Riel) [1040200]
- [mm] migrate: fix set cpupid on page migration twice against thp (Rik van Riel) [1040200]
- [mm] numa: Guarantee that tlb_flush_pending updates are visible before page table updates (Rik van Riel) [1040200]
- [sched] fix the theoretical signal_wake_up() vs schedule() race (Rik van Riel) [1040200]
- [sched] Add tracepoints related to NUMA task migration (Rik van Riel) [1040200]
- [mm] numa: Do not automatically migrate KSM pages (Rik van Riel) [1040200]
- [mm] numa: Trace tasks that fail migration due to rate limiting (Rik van Riel) [1040200]
- [mm] numa: Limit scope of lock for NUMA migrate rate limiting (Rik van Riel) [1040200]
- [mm] numa: Make NUMA-migrate related functions static (Rik van Riel) [1040200]
- [mm] numa: Defer TLB flush for THP migration as long as possible (Rik van Riel) [1040200]
- [mm] fix TLB flush race between migration, and change_protection_range (Rik van Riel) [1040200]
- [mm] numa: Avoid unnecessary disruption of NUMA hinting during migration (Rik van Riel) [1040200]
- [mm] numa: Clear numa hinting information on mprotect (Rik van Riel) [1040200]
- [sched] numa: Skip inaccessible VMAs (Rik van Riel) [1040200]
- [mm] numa: Avoid unnecessary work on the failure path (Rik van Riel) [1040200]
- [mm] numa: Ensure anon_vma is locked to prevent parallel THP splits (Rik van Riel) [1040200]
- [mm] numa: Do not clear PTE for pte_numa update (Rik van Riel) [1040200]
- [mm] numa: Do not clear PMD during PTE update scan (Rik van Riel) [1040200]
- [mm] Clear pmd_numa before invalidating (Rik van Riel) [1040200]
- [mm] numa: Call MMU notifiers on THP migration (Rik van Riel) [1040200]
- [mm] numa: Serialise parallel get_user_page against THP migration (Rik van Riel) [1040200]
- [mm] numa: return the number of base pages altered by protection changes (Rik van Riel) [1040200]

* Mon Dec 16 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-63.el7]
- [net] ipv6: router reachability probing (Jiri Benc) [1032118]
- [net] ipv6: remove the unnecessary statement in find_match() (Jiri Benc) [1032118]
- [net] arp/neighbour.h: Remove extern from function prototypes (Jiri Benc) [1032118]
- [net] netfilter: tproxy: fix build with IP6_NF_IPTABLES=n (Jiri Benc) [1035295]
- [net] netfilter: tproxy: remove nf_tproxy_core.h (Jiri Benc) [1035295]
- [net] netfilter: tproxy: remove nf_tproxy_core, keep tw sk assigned to skb (Jiri Benc) [1035295]
- [net] neigh: ipv6: respect default values set before an address is assigned to device (Jiri Pirko) [1040347]
- [net] neigh: restore old behaviour of default parms values (Jiri Pirko) [1040347]
- [net] neigh: use tbl->family to distinguish ipv4 from ipv6 (Jiri Pirko) [1040347]
- [net] neigh: wrap proc dointvec functions (Jiri Pirko) [1040347]
- [net] neigh: convert parms to an array (Jiri Pirko) [1040347]
- [net] net: neighbour: Remove CONFIG_ARPD (Jiri Pirko) [1040347]
- [net] ndisc: bool initializations should use true and false (Jiri Pirko) [1040347]
- [net] ipv4: add support for IFA_FLAGS nl attribute (Jiri Pirko) [1021871]
- [net] ipv6: addrconf: revert /proc/net/if_inet6 ifa_flag format (Jiri Pirko) [1021871]
- [net] ipv6: addrconf: introduce IFA_F_MANAGETEMPADDR to tell kernel to manage temporary addresses (Jiri Pirko) [1021871]
- [net] ipv6: addrconf: extend ifa_flags to u32 (Jiri Pirko) [1021871]
- [net] ipv6: Remove privacy config option (Jiri Pirko) [1021871]
- [net] ipv6: fix leaking uninitialized port number of offender sockaddr (Florian Westphal) [1035884] {CVE-2013-6405}
- [net] inet: fix addr_len/msg->msg_namelen assignment in recv_error and rxpmtu functions (Florian Westphal) [1035884] {CVE-2013-6405}
- [net] inet: prevent leakage of uninitialized memory to user in recv syscalls (Florian Westphal) [1035884] {CVE-2013-6405}
- [net] rename busy poll MIB counter (Michal Schmidt) [1038631]
- [net] rename CONFIG_NET_LL_RX_POLL to CONFIG_NET_RX_BUSY_POLL (Michal Schmidt) [1038631]
- [net] fix a compile error when CONFIG_NET_LL_RX_POLL is not set (Michal Schmidt) [1038631]
- [net] af_packet: block BH in prb_shutdown_retire_blk_timer() (Veaceslav Falico) [1034605]

* Mon Dec 16 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-62.el7]
- [scsi] pm80xx: remove unneeded NULL check (Rich Bono) [1019457]
- [scsi] pm80xx: Fix for 32 bit compilation warning (Rich Bono) [1019457]
- [scsi] pm80xx: Firmware logging support (Rich Bono) [1019457]
- [scsi] pm80xx: Phy settings support for motherboard controller (Rich Bono) [1019457]
- [scsi] pm80xx: IButton security feature support for motherboard controllers (Rich Bono) [1019457]
- [scsi] pm80xx: Print SAS address of IO failed device (Rich Bono) [1019457]
- [scsi] pm80xx: 4G boundary fix (Rich Bono) [1019457]
- [scsi] pm80xx: Queue rotation logic for inbound and outbound queues (Rich Bono) [1019457]
- [scsi] pm80xx: Set device state response logic fix (Rich Bono) [1019457]
- [scsi] pm80xx: Display controller BIOS version (Rich Bono) [1019457]
- [scsi] pm80xx: Indirect SMP request fix (Rich Bono) [1019457]
- [scsi] pm80xx: Device id changes to support series 8 controllers (Rich Bono) [1019457]
- [scsi] bfa: firmware update to 3.2.1.1 (Vijay Guvva) [726968]
- [scsi] bfa: Update the driver version to 3.2.21.1 (Vijay Guvva) [726968]
- [scsi] bfa: Chinook quad port 16G FC HBA claim issue (Vijay Guvva) [726968]
- [scsi] bfa: switch to fixed_size_llseek() (Vijay Guvva) [726968]
- [scsi] bfa: Fix crash when symb name set for offline vport (Vijay Guvva) [726968]
- [scsi] bfa: dis-associate bfa path_tov with dev_loss_tmo (Vijay Guvva) [726968]
- [scsi] bfa: Support for chinook-quad port card (Vijay Guvva) [726968]
- [scsi] bfa: fix endianess issue for firmware stats (Vijay Guvva) [726968]
- [scsi] bfa: Fix bug_on condition in RPSC rsp handling (Vijay Guvva) [726968]
- [scsi] bfa: Allow rsp queue process during ioc disable (Vijay Guvva) [726968]
- [scsi] bfa: firmware statistics update (Vijay Guvva) [726968]
- [scsi] bfa: fru vpd date update changes (Vijay Guvva) [726968]
- [scsi] bfa: driver compatibility with 32bit libs (Vijay Guvva) [726968]
- [scsi] bfa: kdump fix on 815 and 825 adapters (Vijay Guvva) [726968]
- [scsi] bfa: Fix FDISC timeout handling (Vijay Guvva) [726968]
- [scsi] bfa: Fix 1860 port initialize when ATC is enabled (Vijay Guvva) [726968]
- [scsi] bfa: FDMI enhancements (Vijay Guvva) [726968]
- [scsi] bfa: Fix WARN_ON condition check (Vijay Guvva) [726968]
- [scsi] bfa: Add dynamic diagnostic port support (Vijay Guvva) [726968]
- [scsi] bfa: Forward Error Correction status query (Vijay Guvva) [726968]
- [scsi] bfa: Support for FC BB credit recovery (Vijay Guvva) [726968]
- [scsi] bfa: Fixes for 0-terminated strncpy and possible null pointer dereference (Vijay Guvva) [726968]
- [scsi] bfa: fix for FC Direct Attach LUN discovery failure (Vijay Guvva) [726968]
- [scsi] bfa: fix faulty handling of events in lps sm (Vijay Guvva) [726968]
- [maintainers] Add maintainer info for bnx2i (Maurizio Lombardi) [725065]
- [scsi] bnx2i: Update version and copyright year 2013 (Maurizio Lombardi) [725065]
- [s390] uaccess: add missing page table walk range check (Hendrik Brueckner) [1036690]
- [fs] nfsd: don't try to reuse an expired DRC entry off the list (Jeff Layton) [1036971]
- [fs] nfsd: when reusing an existing repcache entry, unhash it first (Jeff Layton) [1036971]
- [s390] pci: implement hotplug notifications (Hendrik Brueckner) [1030312]
- [s390] pci: implement pcibios_remove_bus (Hendrik Brueckner) [1030312]
- [s390] pci: improve handling of bus resources (Hendrik Brueckner) [1030312]
- [s390] pci: cleanup function information block (Hendrik Brueckner) [1030312]
- [s390] pci: remove CONFIG_PCI_DEBUG dependancy (Hendrik Brueckner) [1030312]
- [s390] pci: message cleanup (Hendrik Brueckner) [1030312]
- [s390] pci: implement hibernation hooks (Hendrik Brueckner) [1030312]

* Thu Dec 12 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-61.el7]
- [ethernet] cxgb3: Fix warning about using rcu_dereference when not in a rcu-locked section (Veaceslav Falico) [1038494]
- [fs] btrfs: relocate csums properly with prealloc extents (Eric Sandeen) [1030074]
- [fs] btrfs: release path before starting transaction in can_nocow_extent (Eric Sandeen) [1030074]
- [fs] btrfs: fix oops caused by the space balance and dead roots (Eric Sandeen) [1030074]
- [fs] btrfs: insert orphan roots into fs radix tree (Eric Sandeen) [1030074]
- [fs] btrfs: limit delalloc pages outside of find_delalloc_range (Eric Sandeen) [1030074]
- [fs] btrfs: Fix crash due to not allocating integrity data for a bioset (Eric Sandeen) [1030074]
- [fs] btrfs: fix a use-after-free bug in btrfs_dev_replace_finishing (Eric Sandeen) [1030074]
- [fs] btrfs: eliminate races in worker stopping code (Eric Sandeen) [1030074]
- [fs] btrfs: fix crash of compressed writes (Eric Sandeen) [1030074]
- [fs] btrfs: fix transid verify errors when recovering log tree (Eric Sandeen) [1030074]
- [fs] vfs: fix subtle use-after-free of pipe_inode_info (Steve Best) [1033905]
- [powerpc] signals: Mark VSX not saved with small contexts (Steve Best) [1019549]
- [security] selinux: correct locking in selinux_netlbl_socket_connect() (Paul Moore) [991605]
- [net] xfrm: Fix potential null pointer dereference in xdst_queue_output (Herbert Xu) [1034891]
- [net] ipv6: introduce function to find route for redirect (Jiri Pirko) [1035996]
- [net] ipv6: handle Redirect ICMP Message with no Redirected Header option (Jiri Pirko) [1035996]

* Fri Dec 06 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-60.el7]
- [misc] synchronize with upstream linux-3.10.y stable branch up to 3.10.20 (Veaceslav Falico) [1034281]
- [s390] allow to set gcc -mtune flag (Hendrik Brueckner) [1032642]
- [net] team: fix master carrier set when user linkup is enabled (Jiri Pirko) [1035258]
- [net] openvswitch: fix vport-netdev unregister (Francesco Fusco) [1004267]

* Thu Dec 05 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-59.el7]
- [pci] Fix whitespace, capitalization, and spelling errors (Myron Stowe) [1033834]
- [pci] Remove duplicate pci_disable_device() from pcie_portdrv_remove() (Myron Stowe) [1033834]
- [pci] Enable upstream bridges even for VFs on virtual buses (Myron Stowe) [1033834]
- [pci] Add pci_upstream_bridge() (Myron Stowe) [1033834]
- [pci] Add x86_msi.msi_mask_irq() and msix_mask_irq() (Myron Stowe) [1033834]
- [pci] Warn on driver probe return value greater than zero (Myron Stowe) [1033834]
- [pci] Drop warning about drivers that don't use pci_set_master() (Myron Stowe) [1033834]
- [pci] Workaround missing pci_set_master in pci drivers (Myron Stowe) [1033834]
- [powerpc] pci: Use pci_is_pcie() to simplify code fix (Myron Stowe) [1033834]
- [pci] Update pcie_ports 'auto' behavior for non-ACPI platforms (Myron Stowe) [1033834]
- [pci] Report pci_pme_active() kmalloc failure (Myron Stowe) [1033834]
- [pci] Fail MSI/MSI-X initialization if device is not in PCI_D0 (Myron Stowe) [1033834]
- [x86] pci: Coalesce multiple overlapping host bridge windows (Myron Stowe) [1033834]
- [misc] MAINTAINERS: Add arch/x86/pci to PCI file patterns (Myron Stowe) [1033834]
- [pci] pm: Remove pci_pm_complete() (Myron Stowe) [1033834]
- [pci] Add pci_dev_show_local_cpu() to simplify code (Myron Stowe) [1033834]
- [pci] Make pci_dev_pm_ops static (Myron Stowe) [1033834]
- [pci] Make pci_bus_attrs, pci_dev_attrs, dev_rescan_attr, dev_remove_attr, vga_attr static (Myron Stowe) [1033834]
- [pci] convert bus code to use dev_groups (Myron Stowe) [1033834]
- [pci] convert bus code to use drv_groups (Myron Stowe) [1033834]
- [pci] convert bus code to use bus_groups (Myron Stowe) [1033834]
- [drm] radeon: use pcie_get_readrq() and pcie_set_readrq() to simplify code (Myron Stowe) [1033834]
- [infiniband] qib: Drop qib_tune_pcie_caps() and qib_tune_pcie_coalesce() return values (Myron Stowe) [1033834]
- [pci] Remove unused PCI_MSIX_FLAGS_BIRMASK definition (Myron Stowe) [1033834]
- [pci] acpiphp_ibm: Convert to dynamic debug (Myron Stowe) [1033834]
- [pci] acpiphp: Convert to dynamic debug (Myron Stowe) [1033834]
- [pci] Remove Intel Haswell D3 delays (Myron Stowe) [1033834]
- [pci] Pass type, width, and prefetchability for window alignment (Myron Stowe) [1033834]
- [pci] Document reason for using pci_is_root_bus() (Myron Stowe) [1033834]
- [pci] Use pci_is_root_bus() to check for root bus (Myron Stowe) [1033834]
- [pci] Remove unused "is_pcie" from pci_dev structure (Myron Stowe) [1033834]
- [pci] Update pci_find_slot() description in pci.txt (Myron Stowe) [1033834]
- [scsi] qla2xxx: Use standard PCIe Capability Link register field names (Myron Stowe) [1033834]
- [pci] Fix comment typo, remove unnecessary !! in pci_is_pcie() (Myron Stowe) [1033834]
- [pci] Drop "setting latency timer" messages (Myron Stowe) [1033834]
- [infiniband] qib: Use pcie_set_mps() and pcie_get_mps() to simplify code (Myron Stowe) [1033834]
- [infiniband] qib: Use pci_is_root_bus() to check whether it is a root bus (Myron Stowe) [1033834]
- [pci] Export pcie_set_mps() and pcie_get_mps() (Myron Stowe) [1033834]
- [acpi] Decode _OSC bitmasks symbolically (Myron Stowe) [1033834]
- [acpi] Separate out _OSC "we don't support enough services" path (Myron Stowe) [1033834]
- [acpi] Separate out _OSC "PCIe port services disabled" path (Myron Stowe) [1033834]
- [acpi] Skip _OSC control tests if _OSC support call failed (Myron Stowe) [1033834]
- [acpi] Run _OSC only once for OSPM feature support (Myron Stowe) [1033834]
- [acpi] Split _OSC "support" and "control" flags into separate variables (Myron Stowe) [1033834]
- [acpi] Move _OSC stuff from acpi_pci_root_add() to negotiate_os_control() (Myron Stowe) [1033834]
- [acpi] Drop unnecessary _OSC existence tests (Myron Stowe) [1033834]
- [pci] Name _OSC #defines more consistently (Myron Stowe) [1033834]
- [acpi] Write OSC_PCI_CONTROL_MASKS like OSC_PCI_SUPPORT_MASKS (Myron Stowe) [1033834]
- [acpi] Remove unused OSC_PCI_NATIVE_HOTPLUG (Myron Stowe) [1033834]
- [acpi] Tidy acpi_run_osc() declarations (Myron Stowe) [1033834]
- [acpi] Rename OSC_QUERY_TYPE to OSC_QUERY_DWORD (Myron Stowe) [1033834]
- [acpi] Write _OSC bit field definitions in hex (Myron Stowe) [1033834]
- [powerpc] pci: Use pci_is_pcie() to simplify code (Myron Stowe) [1033834]
- [scsi] qla2xxx: Use pcie_is_pcie() to simplify code (Myron Stowe) [1033834]
- [scsi] csiostor: Use pcie_capability_clear_and_set_word() to simplify (Myron Stowe) [1033834]
- [scsi] bfa: Use pcie_set()/get_readrq() to simplify code (Myron Stowe) [1033834]
- [x86] pci: Use cached pci_dev->pcie_cap to simplify code (Myron Stowe) [1033834]
- [pci] Use pci_is_pcie() to simplify code (Myron Stowe) [1033834]
- [ethernet] be2net: call napi_disable() for all event queues (Ivan Vecera) [1032872]
- [mm] get rid of unnecessary pageblock scanning in setup_zone_migrate_reserve (Motohiro Kosaki) [1023873]
- [s390] mm: handle asce-type exceptions as normal page fault (Hendrik Brueckner) [1033645]
- [s390] 3270: fix missing device_destroy() call (Hendrik Brueckner) [1032553]
- [s390] boot: Install bzImage as default kernel image (Hendrik Brueckner) [1032548]
- [x86] perf: Fix shared register mutual exclusion enforcement (Jiri Olsa) [1032093]
- [mm] readahead: fix sequential read cache miss detection (Rik van Riel) [1032279]
- [block] fix a race between request completion and timeout handling (Jeff Moyer) [1032138]
- [s390] mm: correct tlb flush on page table upgrade (Hendrik Brueckner) [1029601]

* Wed Dec 04 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-58.el7]
- [pci] msi: add default MSI operations for !HAVE_GENERIC_HARDIRQS platforms (Myron Stowe) [1034514]
- [of] of_pci: add registry of MSI chips (Myron Stowe) [1034514]
- [pci] Introduce new MSI chip infrastructure (Myron Stowe) [1034514]
- [pci] remove ARCH_SUPPORTS_MSI kconfig option (Myron Stowe) [1034514]
- [pci] use weak functions for MSI arch-specific functions (Myron Stowe) [1034514]
- [of] of_pci: Add of_pci_parse_bus_range() function (Myron Stowe) [1034514]
- [of] of_pci: Add of_pci_get_devfn() function (Myron Stowe) [1034514]
- [fs] sysfs: sysfs_create_groups returns a value (Myron Stowe) [1034491]
- [fs] sysfs: add sysfs_create/remove_groups for when SYSFS is not enabled (Myron Stowe) [1034491]
- [fs] sysfs/group: fix up kerneldoc (Myron Stowe) [1034491]
- [fs] sysfs/group: update copyright to add myself and the LF (Myron Stowe) [1034491]
- [fs] sysfs/group: add kerneldoc for sysfs_remove_group (Myron Stowe) [1034491]
- [fs] sysfs/group: fix up broken string coding style (Myron Stowe) [1034491]
- [fs] sysfs/group: fix up some * coding style issues (Myron Stowe) [1034491]
- [fs] sysfs/group: fix trailing whitespace (Myron Stowe) [1034491]
- [fs] sysfs/group: move EXPORT_SYMBOL_GPL() to the proper location (Myron Stowe) [1034491]
- [fs] sysfs: add sysfs_create/remove_groups() (Myron Stowe) [1034491]
- [base] bus_type: add bus_groups (Myron Stowe) [1034491]
- [base] bus_type: add drv_groups (Myron Stowe) [1034491]
- [base] bus_type: add dev_groups (Myron Stowe) [1034491]
- [ethernet] e1000e: fix overrun of PHY RAR array (John Green) [1031123]
- [kernel] perf/ftrace: Fix paranoid level for enabling function tracer (Jiri Olsa) [1027778] {CVE-2013-2930}
- [powerpc] kdump: Adding symbols in vmcoreinfo to facilitate dump filtering (Steve Best) [1025746]
- [s390] block/dasd: hold request queue sysfs lock when calling elevator_init() (Tomoki Sekiyama) [1030615]
- [block] elevator: acquire q->sysfs_lock in elevator_change() (Tomoki Sekiyama) [1030615]
- [block] elevator: Fix a race in elevator switching and dm device initialization (Tomoki Sekiyama) [1030615]
- [s390] vtime: correct idle time calculation (Hendrik Brueckner) [1029891]
- [s390] time: fix get_tod_clock_ext inline assembly (Hendrik Brueckner) [1029891]
- [s390] time: correct use of store clock fast (Hendrik Brueckner) [1029891]
- [s390] time: return with irqs disabled from psw_idle (Hendrik Brueckner) [1029891]
- [s390] fix save and restore of the floating-point-control register (Hendrik Brueckner) [1029602]
- [s390] compat, signal: change return values to -EFAULT (Hendrik Brueckner) [1029602]
- [net] flow_dissector: fail on evil iph->ihl (Jason Wang) [1007955] {CVE-2013-4348}

* Tue Nov 26 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-57.el7]
- [acpi] Correct faulty check of Secure Level in acpi_os_get_root_pointer() (Lenny Szubowicz) [1034598]

* Tue Nov 26 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-56.el7]
- [net] netfilter: push reasm skb through instead of original frag skbs (Jiri Pirko) [1032012]
- [net] ip6_output: fragment outgoing reassembled skb properly (Jiri Pirko) [1032012]
- [net] ipv6: fix headroom calculation in udp6_ufo_fragment (Jiri Pirko) [1030016] {CVE-2013-4563}
- [net] macvtap: limit head length of skb allocated (Jason Wang) [1029380]
- [net] tuntap: limit head length of skb allocated (Jason Wang) [1029380]
- [fs] nfs: check if gssd is running before attempting to use krb5i auth in SETCLIENTID call (Jeff Layton) [998616]
- [net] sunrpc: replace sunrpc_net->gssd_running flag with a more reliable check (Jeff Layton) [998616]
- [net] sunrpc: create a new dummy pipe for gssd to hold open (Jeff Layton) [998616]
- [s390] scm_block: do not hide eadm subchannel dependency (Hendrik Brueckner) [1032542]
- [s390] qeth: avoid buffer overflow in snmp ioctl (Hendrik Brueckner) [1029890]
- [s390] zfcpdump: Add support for XFS (Hendrik Brueckner) [1028103]
- [x86] setup: print out a message if !ACPI (Prarit Bhargava) [1033181]
- [cpufreq] intel_pstate: skip the driver if ACPI has power mgmt option (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Add static declarations to internal functions (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Add Baytrail support (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Refactor driver to support CPUs with different MSR layouts (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Correct calculation of min pstate value (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Improve accuracy by not truncating until final result (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Fix type mismatch warning (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Fix max_perf_pct on resume (Prarit Bhargava) [1031793]
- [cpufreq] add new routine cpufreq_verify_within_cpu_limits() (Prarit Bhargava) [1031793]
- [cpufreq] Optimize cpufreq_frequency_table_verify() (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: fix no_turbo (Prarit Bhargava) [1031793]
- [cpufreq] intel_pstate: Add Haswell CPU models (Prarit Bhargava) [1031793]
- [cpufreq] Drop the owner field from struct cpufreq_driver (Prarit Bhargava) [1031793]
- [cpufreq] Use rwsem for protecting critical sections (Prarit Bhargava) [1031793]
- [cpufreq] delete __cpuinit usage from all cpufreq files (Prarit Bhargava) [1031793]
- [powerpc] ppc64 address space capped at 32TB, mmap randomisation disabled (Steve Best) [1031762]

* Thu Nov 21 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-55.el7]
- [kernel] hung_task: add method to reset detector (Marcelo Tosatti) [987202]
- [virt] pvclock: detect watchdog reset at pvclock read (Marcelo Tosatti) [987202]
- [fs] cifs: stop trying to use virtual circuits (Sachin Prabhu) [1026387]
- [security] keys: Fix keyring content gc scanner (David Howells) [1030482]
- [fs] ext4: fix warning in ext4_da_update_reserve_space() (Lukas Czerner) [1022185]
- [fs] quota: provide interface for readding allocated space into reserved space (Lukas Czerner) [1022185]
- [fs] nfs: don't retry detect_trunking with RPC_AUTH_UNIX more than once (Jeff Layton) [1030404]
- [net] sunrpc: Avoid deep recursion in rpc_release_client (Jeff Layton) [1030404]
- [net] sunrpc: Fix a data corruption issue when retransmitting RPC calls (Jeff Layton) [1030062]
- [fs] nfs: Remove redundant checks in nfs_setsecurity+nfs4_label_init_security (Jeff Layton) [1030725]
- [fs] nfs: Sanity check the server reply in _nfs4_server_capabilities (Jeff Layton) [1030725]
- [fs] nfs: encode_readdir - only ask for labels when doing readdirplus (Jeff Layton) [1030725]
- [fs] nfs: set security label when revalidating inode (Jeff Layton) [1030725]
- [fs] nfs: Fix a mismatch between Linux labeled NFS and the NFSv4.2 spec (Jeff Layton) [1030725]
- [misc] synchronize with upstream linux-3.10.y stable branch up to 3.10.18 (Veaceslav Falico) [1028210]

* Thu Nov 21 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-54.el7]
- [fs] gfs2: Fix ref count bug relating to atomic_open (Robert S Peterson) [1032800]

* Mon Nov 18 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-53.el7]
- [ethernet] mlx4: Fix pages never dma unmapped on rx (Steve Best) [1030192]
- [kernel] Add method for displaying affection for Red Hat (Prarit Bhargava) [1025450]
- [powerpc] Fix fatal SLB miss when restoring PPR (Steve Best) [1027633]
- [fs] gfs2: Implement a "rgrp has no extents longer than X" scheme (Robert S Peterson) [1019462]
- [fs] gfs2: Drop inadequate rgrps from the reservation tree (Robert S Peterson) [1019462]
- [fs] gfs2: If requested is too large, use the largest extent in the rgrp (Robert S Peterson) [1019462]
- [fs] gfs2: Add allocation parameters structure (Robert S Peterson) [1019462]
- [security] keys: Fix error handling in big_key instantiation (David Howells) [1029877]
- [kernel] move get_online_cpus/put_online_cpus locking out (Rik van Riel) [1027267]
- [kernel] sched/numa: Cure update_numa_stats() vs. hotplug (Rik van Riel) [1027267]
- [kernel] sched/numa: Fix NULL pointer dereference in task_numa_migrate() (Rik van Riel) [1028100]
- [scsi] hpsa: remove P822se PCI ID (Tomas Henzl) [1029009]
- [scsi] hpsa: correct gen9 PCI IDs (Tomas Henzl) [1029009]
- [scsi] scsi_dh_alua: ALUA handler attach should succeed while TPG is transitioning (Ewan Milne) [1020355]
- [scsi] scsi_dh_alua: ALUA check sense should retry device internal reset unit attention (Ewan Milne) [1020355]
- [scsi] scsi_debug: fix endianness bug in sdebug_build_parts() (Maurizio Lombardi) [1017128]
- [block] blk-mq: don't disallow request merges for req->special being set (Mike Snitzer) [1016109]
- [block] blk-mq: mq plug list breakage (Mike Snitzer) [1016109]
- [block] blk-mq: fix for flush deadlock (Mike Snitzer) [1016109]
- [block] blk-mq: add blk_mq_stop_hw_queues (Mike Snitzer) [1016109]
- [block] blk-mq: fix permissions for ipi_redirect sysfs attribute (Mike Snitzer) [1016109]
- [block] blk-mq: zero out ctx_map during initialization (Mike Snitzer) [1016109]
- [block] blk-mq: cache rq->q (Mike Snitzer) [1016109]
- [block] blk-mq: use a separate plug list for blk-mq requests (Mike Snitzer) [1016109]
- [block] blk-mq: switch to percpu-ida for tag management (Mike Snitzer) [1016109]
- [lib] percpu_ida: add an API to return free tags (Mike Snitzer) [1016109]
- [lib] percpu_ida: add percpu_ida_for_each_free (Mike Snitzer) [1016109]
- [lib] percpu_ida: make percpu_ida percpu size/batch configurable (Mike Snitzer) [1016109]
- [lib] idr: Percpu ida (Mike Snitzer) [1016109]
- [block] blk-mq: call exit_hctx on hw queue teardown (Mike Snitzer) [1016109]
- [lib] percpu_counter: __this_cpu_write() doesn't need to be protected by spinlock (Mike Snitzer) [1016109]
- [block] blk-mq: fix blk_mq_start_stopped_hw_queues from irq context (Mike Snitzer) [1016109]
- [block] blk-mq: cleanup blk_mq_bio_to_request (Mike Snitzer) [1016109]
- [block] blk-mq: kill blk_mq_finish_request (Mike Snitzer) [1016109]
- [block] blk-mq: always complete bios in blk_mq_complete_request (Mike Snitzer) [1016109]
- [block] blk-mq: dont call blk_mq_free_request from blk_mq_finish_request (Mike Snitzer) [1016109]
- [block] blk-mq: more careful bio completion (Mike Snitzer) [1016109]
- [block] use blk-exec.c infrastructure for blk-mq (Mike Snitzer) [1016109]
- [block] make blk_get_put_request work for blk-mq drivers (Mike Snitzer) [1016109]
- [block] remove request ref_count (Mike Snitzer) [1016109]
- [block] blk-mq: Lower minimum queue depth from 4 to 1 (Mike Snitzer) [1016109]
- [block] blk-mq: Do not fail blk_mq_reg::queue_depth value of zero (Mike Snitzer) [1016109]
- [block] blk-mq: Do not allocate more cache entries than used (Mike Snitzer) [1016109]
- [block] blk-mq: Check queue depth is valid (Mike Snitzer) [1016109]
- [block] blk-mq: Sanity check reserved tags (Mike Snitzer) [1016109]

* Fri Nov 15 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-52.el7]
- [x86] trace: Change user|kernel_page_fault to page_fault_user|kernel (Seiji Aguchi) [726853]
- [x86] trace: Add page fault tracepoints (Seiji Aguchi) [726853]
- [x86] trace: Delete __trace_alloc_intr_gate() (Seiji Aguchi) [726853]
- [x86] trace: Register exception handler to trace IDT (Seiji Aguchi) [726853]
- [x86] trace: Remove __alloc_intr_gate() (Seiji Aguchi) [726853]
- [kernel] audit: call audit_bprm() only once to add AUDIT_EXECVE information (Richard Guy Briggs) [1010367]
- [kernel] audit: move audit_aux_data_execve contents into audit_context union (Richard Guy Briggs) [1010367]
- [kernel] audit: remove unused envc member of audit_aux_data_execve (Richard Guy Briggs) [1010367]
- [kernel] audit: Kill the unused struct audit_aux_data_capset (Richard Guy Briggs) [1010367]
- [fs] gfs2: fix dentry leaks (Abhijith Das) [1010350]
- [fs] gfs2: d_splice_alias() can't return error (Abhijith Das) [1010350]
- [fs] atomic_open: take care of EEXIST in no-open case with O_CREAT|O_EXCL in fs/namei.c (Abhijith Das) [1010350]
- [fs] vfs: don't set FILE_CREATED before calling ->atomic_open() (Abhijith Das) [1010350]
- [fs] nfs: set FILE_CREATED (Abhijith Das) [1010350]
- [fs] gfs2: set FILE_CREATED (Abhijith Das) [1010350]
- [fs] vfs: improve i_op->atomic_open() documentation (Abhijith Das) [1010350]
- [net] svcrpc: set cr_gss_mech from gss-proxy as well as legacy upcall (J. Bruce Fields) [1026643]
- [mm] zbud: fix condition check on allocation size (Jerome Marchand) [1009496]
- [kernel] sched: Optimize task_sched_runtime() (Larry Woodman) [986058]
- [x86] setup: add a customer friendly message for single cpu systems (Prarit Bhargava) [1009066]
- [x86] efi: Disable secure boot if shim is in insecure mode (Lenny Szubowicz) [1004888]
- [kernel] modsign: Support not importing certs from db (Lenny Szubowicz) [1004888]
- [kernel] modsign: Import certificates from UEFI Secure Boot (Lenny Szubowicz) [1004888]
- [kernel] keys: Add a system blacklist keyring (Lenny Szubowicz) [1004888]
- [crypto] asymmetric_keys: Add an EFI signature blob parser and key loader (Lenny Szubowicz) [1004888]
- [kernel] efi: Add EFI signature data types (Lenny Szubowicz) [1004888]
- [kernel] hibernate: Disable if securelevel above zero (Lenny Szubowicz) [903815]
- [x86] efi: Add EFI_SECURE_BOOT bit (Lenny Szubowicz) [903815]
- [x86] Add option to automatically set securelevel when in Secure Boot mode (Lenny Szubowicz) [903815]
- [platform] asus-wmi: Restrict debugfs interface when securelevel is set (Lenny Szubowicz) [903815]
- [x86] Restrict MSR access when securelevel is set (Lenny Szubowicz) [903815]
- [kernel] uswsusp: Disable when securelevel is set (Lenny Szubowicz) [903815]
- [kernel] kexec: Disable at runtime if securelevel has been set (Lenny Szubowicz) [903815]
- [acpi] Ignore acpi_rsdp kernel parameter when securelevel is set (Lenny Szubowicz) [903815]
- [acpi] Limit access to custom_method if securelevel is set (Lenny Szubowicz) [903815]
- [char] mem: Restrict /dev/mem and /dev/kmem when securelevel is set (Lenny Szubowicz) [903815]
- [x86] Lock down IO port access when securelevel is enabled (Lenny Szubowicz) [903815]
- [pci] Lock down BAR access when securelevel is enabled (Lenny Szubowicz) [903815]
- [x86] Enforce module signatures when securelevel is greater than 0 (Lenny Szubowicz) [903815]
- [kernel] Add BSD-style securelevel support (Lenny Szubowicz) [903815]

* Thu Nov 14 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-51.el7]
- [net] nfnetlink: do not ack malformed messages (Jiri Benc) [1023123]
- [net] netfilter: nft_compat: use _safe version of list_for_each (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: remove duplicated include from nf_tables_ipv4.c (Jiri Benc) [1023123]
- [net] netfilter: bridge: nf_tables: add filter chain type (Jiri Benc) [1023123]
- [net] netfilter: nft_nat: Fix endianness issue reported by sparse (Jiri Benc) [1023123]
- [net] netfilter: bridge: fix nf_tables bridge dependencies with main core (Jiri Benc) [1023123]
- [net] nf_tables: mark as Tech Preview (Jiri Benc) [1023123]
- [net] nf_tables: stuff structures to preserve kABI in the future (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add ARP filtering support (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add trace support (Jiri Benc) [1023123]
- [net] netfilter: nfnetlink: add batch support and use it from nf_tables (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add insert operation (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: complete net namespace support (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: Add support for IPv6 NAT (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add support for dormant tables (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: nft_payload: fix transport header base (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add compatibility layer for x_tables (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: convert built-in tables/chains to chain types (Jiri Benc) [1023123]
- [net] netfilter: nft_payload: add optimized payload implementation for small loads (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add optimized data comparison for small values (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: expression ops overloading (Jiri Benc) [1023123]
- [net] netfilter: nf_tables: add netlink set API (Jiri Benc) [1023123]
- [net] netfilter: add nftables (Jiri Benc) [1023123]
- [net] netfilter: nf_nat: move alloc_null_binding to nf_nat_core.c (Jiri Benc) [1023123]
- [net] netfilter: pass hook ops to hookfn (Jiri Benc) [1023123]
- [net] netlink: fix splat in skb_clone with large messages (Jiri Benc) [1023123]
- [net] netlink: allow large data transfers from user-space (Jiri Benc) [1023123]

* Wed Nov 13 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-50.el7]
- [virt] hyperv/vmbus: Fix a bug in channel rescind code (Jason Wang) [1017564]
- [virt] hyperv: Fix wrong check for synic_event_page (Jason Wang) [1017564]
- [virt] hyperv/vmbus: fix vmbus_recvpacket_raw() return code (Jason Wang) [1017564]
- [virt] hyperv/input: add a driver to support Hyper-V synthetic keyboard (Jason Wang) [1017564]
- [virt] hyperv: Correctly guard the local APIC calibration code (Jason Wang) [1017564]
- [virt] hyperv: Get the local APIC timer frequency from the hypervisor (Jason Wang) [1017564]
- [kernel] stop_machine: fix race between stop_two_cpus and stop_cpus (Rik van Riel) [1023627]
- [video] fb: make fp_get_options name argument const (Rob Clark) [1018414]
- [drm] nouveau/device: recognise GK208 (Rob Clark) [1018414]
- [drm] nouveau/graph: fix a number of missing explicit array terminators (Rob Clark) [1018414]
- [drm] nouveau/disp: semi-complete link training sequence even if display disappears (Rob Clark) [1018414]
- [drm] nouveau/bios: some older boards have shorter displayport tables (Rob Clark) [1018414]
- [drm] nouveau/fbcon: bracket entrypoints with a per-device enabled check (Rob Clark) [1018414]
- [drm] nouveau/disp: reorder writes to lane current control regs (Rob Clark) [1018414]
- [drm] nouveau/disp: reorder writes to lane current control regs (Rob Clark) [1018414]
- [drm] nouveau/disp: log if DP link training fails (Rob Clark) [1018414]
- [drm] nouveau/disp: disable display underflow reporting at init (Rob Clark) [1018414]
- [drm] nouveau/clock: fix accidental limiting of pll coefficients (Rob Clark) [1018414]
- [drm] nouveau/device: use an additional bit from NV_PMC_BOOT_0 to identify chipset (Rob Clark) [1018414]
- [drm] nouveau/bios/init: return failure condition on invalid opcodes (Rob Clark) [1018414]
- [drm] nouveau/therm: ack any pending IRQ at init (Rob Clark) [1018414]
- [drm] nouveau/therm: kill some over-zealous debugging (Rob Clark) [1018414]
- [drm] radeon: don't use PACKET2 on CIK (Rob Clark) [1018414]
- [drm] nouveau: split lock into list+exec and enable refcount locks (Rob Clark) [1018414]
- [drm] nouveau: convert event handler apis to split create/enable semantics (Rob Clark) [1018414]
- [drm] nouveau: share engine/channel constructor between implementations (Rob Clark) [1018414]
- [drm] nouveau: prepare for the sharing of constructors between implementations (Rob Clark) [1018414]
- [drm] nouveau: make vblank tracking data private to the implementations (Rob Clark) [1018414]
- [drm] nouveau: share engine/channel struct definitions between implementations (Rob Clark) [1018414]
- [drm] nouveau: Allow asymmetric nouveau_event_get/_put (Rob Clark) [1018414]
- [drm] nouveau: Move event index check from critical section (Rob Clark) [1018414]
- [drm] nouveau: Add priv field for event handlers (Rob Clark) [1018414]
- [drm] nouveau: off by one in nouveau_drm_vblank_enable() (Rob Clark) [1018414]
- [drm] backport to Linux 3.12-rc7 (Rob Clark) [1018414]
- [firmware] dmi: add support for exact DMI matches in addition to substring matching (Rob Clark) [1025360]
- [vga] vga_switcheroo: add driver control power feature (Rob Clark) [1025360]
- [mm] vmscan: new shrinker API (Rob Clark) [1025360]
- [kernel] Add arch_phys_wc_{add, del} to manipulate WC MTRRs if needed (Rob Clark) [1025360]
- [kernel] mutex: Move ww_mutex definitions to ww_mutex.h (Rob Clark) [1025360]
- [kernel] reservation: cross-device reservation support (Rob Clark) [1025360]
- [kernel] locking-selftests: Handle unexpected failures more strictly (Rob Clark) [1025360]
- [kernel] mutex: Add more w/w tests to test EDEADLK path handling (Rob Clark) [1025360]
- [kernel] mutex: Add more tests to lib/locking-selftest.c (Rob Clark) [1025360]
- [kernel] mutex: Add w/w tests to lib/locking-selftest.c (Rob Clark) [1025360]
- [kernel] mutex: Add w/w mutex slowpath debugging (Rob Clark) [1025360]
- [kernel] mutex: Add support for wound/wait style locks (Rob Clark) [1025360]
- [kernel] mutex: Make __mutex_fastpath_lock_retval return whether fastpath succeeded or not (Rob Clark) [1025360]

* Tue Nov 12 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-49.el7]
- [usb] misc/usb3503: Fix compile error due to incorrect regmap depedency (Don Zickus) [895641]
- [usb] storage: add quirk for mandatory READ_CAPACITY_16 (Don Zickus) [895641]
- [usb] serial/option: blacklist Olivetti Olicard200 (Don Zickus) [895641]
- [usb] quirks: add touchscreen that is dazzeled by remote wakeup (Don Zickus) [895641]
- [usb] quirks: add one device that cannot deal with suspension (Don Zickus) [895641]
- [usb] serial/option: add support for Inovia SEW858 device (Don Zickus) [895641]
- [usb] serial/ti_usb_3410_5052: add Abbott strip port ID to combined table as well (Don Zickus) [895641]
- [usb] support new huawei devices in option.c (Don Zickus) [895641]
- [usb] xhci: Fix spurious wakeups after S5 on Haswell (Don Zickus) [895641]
- [usb] xhci: fix write to USB3_PSSEN and XUSB2PRM pci config registers (Don Zickus) [895641]
- [usb] xhci: quirk for extra long delay for S4 (Don Zickus) [895641]
- [usb] xhci: Don't enable/disable RWE on bus suspend/resume (Don Zickus) [895641]
- [net] usbnet: fix handling padding packet (Don Zickus) [895641]
- [usb] imx21: accept very late isochronous URBs (Don Zickus) [895641]
- [usb] core: check usb device's state before sending a Set SEL control transfer (Don Zickus) [895641]
- [usb] xhci: Fix xHCI host issues on remote wakeup (Don Zickus) [1016889]
- [usb] serial/pl2303: distinguish between original and cloned HX chips (Don Zickus) [895641]
- [usb] fix typo in usb serial simple driver Kconfig (Don Zickus) [895641]
- [usb] core: fix incorrect type in assignment in descriptors_changed() (Don Zickus) [895641]
- [usb] core: compare and release one bos descriptor in usb_reset_and_verify_device() (Don Zickus) [895641]
- [usb] ehci: remove debugging statement with ehci statistics in ehci_stop() (Don Zickus) [895641]
- [usb] ehci: remove duplicate debug_async_open() prototype in ehci-dbg.c (Don Zickus) [895641]
- [usb] ehci: enable debugging code when CONFIG_DYNAMIC_DEBUG is set (Don Zickus) [895641]
- [usb] ehci: remove ehci_vdbg() verbose debugging statements (Don Zickus) [895641]
- [usb] xhci: Fix warning introduced by disabling runtime PM (Don Zickus) [1016889]
- [usb] storage: audit sysfs attribute permissions (Don Zickus) [895641]
- [usb] xhci: prevent "callbacks suppressed" when debug is not enabled (Don Zickus) [1016889]
- [usb] xhci: fix port BESL LPM capability checking (Don Zickus) [1016889]
- [usb] ohci: fix build error related to ohci_suspend/resume (Don Zickus) [895641]
- [usb] serial: clean up attribute permissions (Don Zickus) [895641]
- [usb] usbtmc: fix up attribute permissions (Don Zickus) [895641]
- [usb] core: be specific about attribute permissions (Don Zickus) [895641]
- [usb] core: use DRIVER_ATTR_RW() (Don Zickus) [895641]
- [usb] don't use bNbrPorts after initialization (Don Zickus) [895641]
- [usb] fail on usb_hub_create_port_device() errors (Don Zickus) [895641]
- [usb] fix cleanup after failure in hub_configure() (Don Zickus) [895641]
- [usb] ohci: add missing PCI PM callbacks to ohci-pci.c (Don Zickus) [895641]
- [usb] serial: fix stringify operator in usb-serial-simple (Don Zickus) [895641]
- [usb] wusbcore: Use usb_init_urb instead of creating the URB manually (Don Zickus) [895641]
- [usb] wusbcore: fix leak of urb in wa_xfer_destroy (Don Zickus) [895641]
- [usb] wusbcore: fix resource cleanup in error path in __wa_xfer_setup_segs (Don Zickus) [895641]
- [usb] wusbcore: clear RPIPE stall for control endpoints (Don Zickus) [895641]
- [usb] uss720: fix DMA-buffer allocation (Don Zickus) [895641]
- [usb] quatech2: fix port DMA-buffer allocations (Don Zickus) [895641]
- [usb] quatech2: fix serial DMA-buffer allocations (Don Zickus) [895641]
- [usb] keyspan: fix port DMA-buffer allocations (Don Zickus) [895641]
- [usb] keyspan: fix serial DMA-buffer allocations (Don Zickus) [895641]
- [usb] rh_call_control tbuf overflow fix (Don Zickus) [895641]
- [usb] host: add Kconfig option for EHSET (Don Zickus) [895641]
- [usb] serial/pl2303: improve the chip type detection/distinction (Don Zickus) [895641]
- [usb] serial/pl2303: improve the chip type information output on startup (Don Zickus) [895641]
- [usb] serial/pl2303: simplify the else-if contruct for type_1 chips in pl2303_startup() (Don Zickus) [895641]
- [usb] xhci: fix dma mask setup in xhci.c (Don Zickus) [1016889]
- [usb] xhci: trace debug statements related to ring expansion (Don Zickus) [1016889]
- [usb] xhci: trace debug messages related to driver initialization and unload (Don Zickus) [1016889]
- [usb] xhci: trace debug statements for urb cancellation (Don Zickus) [1016889]
- [usb] xhci: add xhci_cmd_completion trace event (Don Zickus) [1016889]
- [usb] xhci: add xhci_address_ctx trace event (Don Zickus) [1016889]
- [usb] xhci: add trace for debug messages related to endpoint reset (Don Zickus) [1016889]
- [usb] xhci: add trace for debug messages related to quirks (Don Zickus) [1016889]
- [usb] xhci: add trace for debug messages related to changing contexts (Don Zickus) [1016889]
- [usb] xhci: add traces for debug messages in xhci_address_device() (Don Zickus) [1016889]
- [usb] xhci: remove CONFIG_USB_XHCI_HCD_DEBUGGING and unused code (Don Zickus) [1016889]
- [usb] xhci: replace printk(KERN_DEBUG ...) (Don Zickus) [1016889]
- [usb] xhci: replace xhci_info() with xhci_dbg() (Don Zickus) [1016889]
- [usb] xhci: Add Device Tree support to XHCI Platform driver (Don Zickus) [1016889]
- [usb] serial/pl2303: add two comments concerning the supported baud rates with HX chips (Don Zickus) [895641]
- [usb] serial/pl2303: also use the divisor based baud rate encoding method for baud rates < 115200 with HX chips (Don Zickus) [895641]
- [usb] serial/pl2303: increase the allowed baud rate range for the divisor based encoding method (Don Zickus) [895641]
- [usb] serial/pl2303: move the two baud rate encoding methods to separate functions (Don Zickus) [895641]
- [usb] serial/pl2303: remove 500000 baud from the list of standard baud rates (Don Zickus) [895641]
- [usb] serial/pl2303: do not round to the next nearest standard baud rate for the divisor based baud rate encoding method (Don Zickus) [895641]
- [usb] serial/pl2303: fix the upper baud rate limit check for type_0/1 chips (Don Zickus) [895641]
- [usb] serial/pl2303: fix+improve the divsor based baud rate encoding method (Don Zickus) [895641]
- [usb] hwa: avoid constant suspend and resume on the root hub (Don Zickus) [895641]
- [usb] adutux: fix big-endian device-type reporting (Don Zickus) [895641]
- [usb] usbtmc: fix big-endian probe of Rigol devices (Don Zickus) [895641]
- [usb] wusbcore: clean up list locking in urb enqueue (Don Zickus) [895641]
- [usb] wusbcore: fix root hub hub_status_data to only return > 0 if status has actually changed (Don Zickus) [895641]
- [usb] ehci: Add support for SINGLE_STEP_SET_FEATURE test of EHSET (Don Zickus) [895641]
- [usb] hcd: Log error code if reset() fails (Don Zickus) [895641]
- [usb] misc/usb3503: Support operation with no I2C control (Don Zickus) [895641]
- [usb] misc/usb3503: Add USB3503A to the compatible list (Don Zickus) [895641]
- [usb] misc/usb3503: Default to hub mode (Don Zickus) [895641]
- [usb] misc/usb3503: Fix typos in error messages (Don Zickus) [895641]
- [usb] misc/usb3503: Factor out I2C probe (Don Zickus) [895641]
- [usb] misc/usb3503: Convert to regmap (Don Zickus) [895641]
- [usb] misc/usb3503: Actively manage Hub Connect GPIO (Don Zickus) [895641]
- [usb] misc/usb3503: Use gpio_set_value_cansleep() (Don Zickus) [895641]
- [usb] Move definition of USB_EHCI_BIG_ENDIAN_MMIO et al. out side of the ifs (Don Zickus) [895641]
- [usb] misc/usb3503: Convert to devm_ APIs (Don Zickus) [895641]
- [usb] serial: move the "simple" drivers into usb-serial-simple.c (Don Zickus) [895641]
- [net] usbnet: support DMA SG (Don Zickus) [895641]
- [usb] xhci: mark no_sg_constraint (Don Zickus) [1016889]
- [usb] introduce usb_device_no_sg_constraint() helper (Don Zickus) [895641]
- [usb] ehci: support running URB giveback in tasklet context (Don Zickus) [895641]
- [usb] ehci: improve interrupt qh unlink (Don Zickus) [895641]
- [usb] ehci: improve ehci_endpoint_disable (Don Zickus) [895641]
- [usb] hcd: support giveback of URB in tasklet context (Don Zickus) [895641]
- [usb] fix some scripts/kernel-doc warnings (Don Zickus) [895641]
- [usb] ehci: don't depend on hardware for tracking port resets and resumes (Don Zickus) [895641]
- [usb] ehci: keep better track of resuming ports (Don Zickus) [895641]
- [usb] pl2303: restrict the divisor based baud rate encoding method to the "HX" chip type (Don Zickus) [895641]
- [usb] refactor code for enabling/disabling remote wakeup (Don Zickus) [895641]
- [usb] simplify the interface of usb_get_status() (Don Zickus) [895641]
- [usb] xhci: add missing dma-mapping.h includes (Don Zickus) [895641]
- [net] usbnet: centralize computing of max rx/tx qlen (Don Zickus) [895641]
- [usb] serial: add driver for Suunto ANT+ USB device (Don Zickus) [895641]
- [usb] ohci_usb warn "irq nobody cared" on shutdown (Don Zickus) [895641]
- [usb] ohci-ep93xx: tidy up driver (*probe) and (*remove) (Don Zickus) [895641]
- [usb] ohci-ep93xx: use devm_clk_get() (Don Zickus) [895641]
- [usb] ohci-ep93xx: use platform_get_irq() (Don Zickus) [895641]
- [usb] ohci-ep93xx: use devm_ioremap_resource() (Don Zickus) [895641]
- [usb] usb-skeleton: add retry for nonblocking read (Don Zickus) [895641]
- [usb] usbtmc: convert to devm_kzalloc (Don Zickus) [895641]
- [usb] usbtmc: remove redundant braces (Don Zickus) [895641]
- [usb] usbtmc: call pr_err instead of plain printk (Don Zickus) [895641]
- [usb] usbtmc: remove trailing spaces (Don Zickus) [895641]
- [usb] usbfs: Allow printer class 'get_device_id' without needing to claim the intf (Don Zickus) [895641]
- [usb] remove redundant "#if" (Don Zickus) [895641]
- [usb] misc: EHSET Test Fixture device driver for host compliance (Don Zickus) [895641]
- [usb] clamp bInterval to allowed range (Don Zickus) [895641]
- [usb] atm/speedtch: be careful with bInterval (Don Zickus) [895641]
- [usb] cdc-acm: be careful with bInterval (Don Zickus) [895641]
- [usb] fix build warning in pci-quirks.h when CONFIG_PCI is not enabled (Don Zickus) [895641]
- [usb] xhci: Mark two functions __maybe_unused (Don Zickus) [895641]
- [usb] check sg buffer size in usb_submit_urb (Don Zickus) [895641]
- [usb] isp1362: move debug files from proc to debugfs (Don Zickus) [895641]
- [usb] sl811: move debug files from proc to debugfs (Don Zickus) [895641]
- [usb] remove unneeded idr.h include (Don Zickus) [895641]
- [usb] sl811: remove CONFIG_USB_DEBUG dependency (Don Zickus) [895641]
- [usb] isp116x: remove dependency on CONFIG_USB_DEBUG (Don Zickus) [895641]
- [usb] isp1362: remove CONFIG_USB_DEBUG dependency (Don Zickus) [895641]
- [usb] isp1362: remove _DBG() usage (Don Zickus) [895641]
- [usb] isp1362: remove unused _WARN_ON() calls (Don Zickus) [895641]
- [usb] isp1362: remove unused _BUG_ON() calls (Don Zickus) [895641]
- [usb] usbatm: remove CONFIG_USB_DEBUG dependancy (Don Zickus) [895641]
- [usb] usbatm: move the atm_dbg() call to use dynamic debug (Don Zickus) [895641]
- [usb] usbatm: don't rely on CONFIG_USB_DEBUG (Don Zickus) [895641]
- [usb] usbatm: remove unneeded trace printk calls (Don Zickus) [895641]
- [usb] usbatm: remove unused UDSL_ASSERT macro (Don Zickus) [895641]
- [usb] ti_usb_3410_5052: remove vendor/product module parameters (Don Zickus) [895641]
- [usb] ti_usb_3410_5052: remove unused wait queue (Don Zickus) [895641]
- [usb] ti_usb_3410_5052: kill private fifo (Don Zickus) [895641]
- [usb] safe_serial: remove vendor/product module parameters (Don Zickus) [895641]
- [usb] mos7840: remove broken chase implementation (Don Zickus) [895641]
- [usb] io_ti: move port initialisation to probe (Don Zickus) [895641]
- [usb] io_ti: kill private fifo (Don Zickus) [895641]
- [usb] io_edgeport: remove unused defines (Don Zickus) [895641]
- [usb] ftdi_sio: remove unused defines (Don Zickus) [895641]
- [usb] ftdi_sio: remove vendor/product module parameters (Don Zickus) [895641]
- [usb] ftdi_sio: remove redundant raise of DTR/RTS at open (Don Zickus) [895641]
- [usb] ftdi_sio: clean up device initialisation (Don Zickus) [895641]
- [usb] oti6858: do not call set_termios with uninitialised data (Don Zickus) [895641]
- [usb] pl2303: remove debugging noise (Don Zickus) [895641]
- [usb] pl2303: clean up set_termios (Don Zickus) [895641]
- [usb] pl2303: clean up baud-rate handling (Don Zickus) [895641]
- [usb] pl2303: refactor baud-rate handling (Don Zickus) [895641]
- [usb] console: remove unnecessary operations test (Don Zickus) [895641]
- [usb] console: use dev_dbg (Don Zickus) [895641]
- [usb] serial: set drain delay at port probe (Don Zickus) [895641]
- [usb] serial: clean up dtr_rts (Don Zickus) [895641]
- [usb] serial: remove hupping check from tiocmiwait (Don Zickus) [895641]
- [usb] serial: remove defensive test from set_termios (Don Zickus) [895641]
- [usb] misc: remove CONFIG_USB_DEBUG from Makefile (Don Zickus) [895641]
- [usb] adutux: remove direct calls to printk() (Don Zickus) [895641]
- [usb] adutux: remove custom debug macro and module parameter (Don Zickus) [895641]
- [usb] adutux: remove custom debug macro (Don Zickus) [895641]
- [usb] adutux: remove unneeded tracing macros (Don Zickus) [895641]
- [usb] legotower: remove direct calls to printk() (Don Zickus) [895641]
- [usb] legotower: remove custom debug macro and module parameter (Don Zickus) [895641]
- [usb] legousbtower: remove custom debug macro (Don Zickus) [895641]
- [usb] legotower: remove unneeded tracing macros (Don Zickus) [895641]
- [usb] ldusb: remove custom dbg_info() macro (Don Zickus) [895641]
- [usb] xhci: Correct misplaced newlines (Don Zickus) [1016889]
- [usb] xhci: refactor EHCI/xHCI port switching (Don Zickus) [1016889 970717]
- [usb] xhci: Report USB 2.1 link status for L1 (Don Zickus) [1016889]
- [usb] xhci: Refactor port status into a new function (Don Zickus) [1016889]
- [usb] xhci: add the suspend/resume functionality (Don Zickus) [1016889]
- [usb] move the definition of USB_MAXCHILDREN (Don Zickus) [895641]
- [usb] atm: avoid parsing names as kthread_run() format strings (Don Zickus) [895641]
- [usb] xhci: Add missing unlocks on error paths (Don Zickus) [895641]
- [usb] ehci-atmel: prepare clk before calling enable (Don Zickus) [895641]
- [usb] hwa: fix device probe failure (Don Zickus) [895641]
- [usb] wusbcore: add sysfs attribute for retry count (Don Zickus) [895641]
- [usb] wusbcore: add sysfs attribute for DNTS count and interval (Don Zickus) [895641]
- [usb] check usb_hub_to_struct_hub() return value (Don Zickus) [895641]
- [usb] ehci: Remove double assignment of .start in ehci_msp_hc_driver (Don Zickus) [895641]
- [usb] ehci: export ehci_handshake for ehci-hcd sub-drivers (Don Zickus) [895641]
- [usb] wusbcore: add scatter gather support (Don Zickus) [895641]
- [usb] cdc-acm: remove unneeded spin_lock_irqsave/restore on write path (Don Zickus) [895641]
- [usb] serial: increase the number of devices we support (Don Zickus) [895641]
- [usb] serial: make minor allocation dynamic (Don Zickus) [895641]
- [usb] xhci: remove BUG() in xhci_get_endpoint_type() (Don Zickus) [895641]
- [usb] xhci: Remove BUG in xhci_setup_addressable_virt_dev (Don Zickus) [895641]
- [usb] xhci: Remove BUG_ON in xhci_get_input_control_ctx (Don Zickus) [895641]
- [usb] xhci: Remove BUG_ON() in xhci_alloc_container_ctx (Don Zickus) [895641]
- [usb] ehci-platform: add pre_setup() method to platform data (Don Zickus) [895641]
- [usb] serial: add minor and port number (Don Zickus) [895641]
- [usb] wusbcore: ignore HWA_NOTIF_BPST_ADJ notifications (Don Zickus) [895641]
- [usb] wusbcore: add HWA-specific fields to usb_rpipe_descriptor (Don Zickus) [895641]
- [usb] wusbhc: disable suspend and resume on the root hub (Don Zickus) [895641]
- [usb] fix PTR_ERR translation in init_usb_class() (Don Zickus) [895641]
- [usb] wusbcore: reduce keepalive threshold from timeout/2 to timeout/3 (Don Zickus) [895641]
- [usb] host: make USB_ARCH_HAS_?HCI obsolete (Don Zickus) [895641]
- [usb] ohci: remove bogus #error (Don Zickus) [895641]
- [usb] add usb2 Link PM variables to sysfs and usb_device (Don Zickus) [895641]
- [usb] xhci: add USB2 Link power management BESL support (Don Zickus) [895641]
- [usb] xhci: define port register names and use them instead of magic numbers (Don Zickus) [895641]
- [usb] xhci: check usb2 port capabilities before adding hw link PM support (Don Zickus) [895641]
- [usb] xhci: unify parameter of xhci_msi_irq (Don Zickus) [895641]
- [usb] xhci-dbg: Display endpoint number and direction in context dump (Don Zickus) [895641]
- [usb] serial: pl2303 works at 500kbps (Don Zickus) [895641]
- [usb] ohci: add a name for the platform-private field (Don Zickus) [895641]
- [usb] ohci: make ohci-platform a separate driver (Don Zickus) [895641]
- [usb] misc/usb3503: Remove 100ms sleep on reset, conform to data sheet (Don Zickus) [895641]
- [usb] misc/usb3503: Fix up whitespace (Don Zickus) [895641]
- [usb] Allow the USB HCD to create Wireless USB root hubs (Don Zickus) [895641]
- [usb] serial: add support Infineon modem USB flashloader driver (Don Zickus) [895641]
- [usb] ohci: make ohci-pci a separate driver (Don Zickus) [895641]
- [usb] ohci: Generic changes to make ohci-pci a separate driver (Don Zickus) [895641]
- [usb] ohci: prepare to make ohci-hcd a library module (Don Zickus) [895641]
- [usb] fhci: upgrade the isochronous API (Don Zickus) [895641]
- [usb] imx21: upgrade the isochronous API (Don Zickus) [895641]
- [usb] serial: dump small buffers with help of *ph (Don Zickus) [895641]
- [usb] host: remove leftover release_mem_region (Don Zickus) [895641]
- [usb] misc/usb3503: Adding device tree entry 'disabled-ports' (Don Zickus) [895641]
- [usb] misc/usb3503: Add to select the ports to disable (Don Zickus) [895641]
- [usb] ehci: Only sleep for post-resume handover if devices use persist (Don Zickus) [895641]
- [usb] message: Fixed parenthesis error in sizeof function (Don Zickus) [895641]
- [usb] message: fixed error 'no space before bracket' (Don Zickus) [895641]
- [usb] devio: fixed error 'do not use assignment in if condition' (Don Zickus) [895641]
- [usb] devio: Fixed macro parenthesis error (Don Zickus) [895641]
- [usb] devio: fixed warning 'use <linux/uacces.h> instead <asm/uacces.h>' (Don Zickus) [895641]
- [usb] usbtmc: Change magic number to constant (Don Zickus) [895641]
- [usb] usbtmc: usbtmc_read sends multiple TMC header based on rigol_quirk (Don Zickus) [895641]
- [usb] usbtmc: Set rigol_quirk if device is listed (Don Zickus) [895641]
- [usb] usbtmc: TMC request code segregated from usbtmc_read (Don Zickus) [895641]
- [usb] usbtmc: Add flag rigol_quirk to usbtmc_device_data (Don Zickus) [895641]
- [usb] storage/alauda: initialize variables directly (Don Zickus) [895641]
- [usb] storage/sddr09: initialize variables directly (Don Zickus) [895641]
- [usb] fsl: add missing platform_driver owner (Don Zickus) [895641]
- [usb] quatech2: Staticize local symbol (Don Zickus) [895641]
- [usb] misc: Fixed assignment error in if statement (Don Zickus) [895641]
- [usb] misc: Added space after closing brace in adutux.c (Don Zickus) [895641]
- [usb] misc: Added space after comma in adutux.c (Don Zickus) [895641]
- [usb] misc: Reformatted pointer variables in adutux.c (Don Zickus) [895641]
- [usb] misc: Removed space before tabs in adutux.c (Don Zickus) [895641]
- [usb] misc: Replaced deprecated preprocessor in adutux.c (Don Zickus) [895641]
- [fs] nfsd: fix discarded security labels on setattr (J. Bruce Fields) [1025832]
- [fs] nfs: fix inverted test for delegation in nfs4_reclaim_open_state (Jeff Layton) [1025457]
- [x86] kdump: crashkernel=X try to reserve below 896M first, then try below 4G, then MAXMEM (Chao WANG) [994685]
- [kernel] audit: format user messages to size of MAX_AUDIT_MESSAGE_LENGTH (Richard Guy Briggs) [1019913]
- [kernel] audit_alloc: clear TIF_SYSCALL_AUDIT if !audit_context (Richard Guy Briggs) [1026043]

* Fri Nov 08 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-48.el7]
- [ethernet] qlcnic: Update version to 5.3.48 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Implement ndo_get_phys_port_id for 82xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enable diagnostic test for multiple Tx queues (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enable Tx queue changes using ethtool for 82xx Series adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Multi Tx queue support for 82xx Series adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update version to 5.3.47 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Add support for 84xx adapters to load firmware from file (Chad Dupuis) [725018]
- [ethernet] qlcnic: Loopback Inter Driver Communication AEN handler (Chad Dupuis) [725018]
- [ethernet] qlcnic: Add PVID support for 84xx adapters (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enable support for 844X adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update version to 5.2.46 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Dump mailbox command data when a command times out (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix driver initialization for 83xx adapters (Chad Dupuis) [725018]
- [ethernet] qlcnic: Flush mailbox command list when mailbox is not available (Chad Dupuis) [725018]
- [ethernet] qlcnic: Reinitialize mailbox data structures after firmware reset (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix diagnostic interrupt test for 83xx adapters (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix beacon state return status handling (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix set driver version command (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix for flash update failure on 83xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix link speed and duplex display for 83xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix link speed display for 82xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix external loopback test (Chad Dupuis) [725018]
- [ethernet] qlcnic: Removed adapter series name from warning messages (Chad Dupuis) [725018]
- [ethernet] qlcnic: Free up memory in error path (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix ingress MAC learning (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix MAC address filter issue on 82xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update version to 5.2.45 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enable mailbox interface in poll mode when interrupts are not available (Chad Dupuis) [725018]
- [ethernet] qlcnic: Replace poll mode mailbox interface with interrupt based mailbox interface (Chad Dupuis) [725018]
- [ethernet] qlcnic: Interrupt based driver firmware mailbox mechanism (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enhance diagnostic loopback error codes (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix diagnostic interrupt test for 83xx adapters (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix setting Guest VLAN (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix operation type and command type (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix initialization of work function (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix guest VLAN (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix releasing of Tx frag which was never mapped (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix dump template version mask (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix ethtool display for 83xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix panic while setting VF's MAC address (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix multicast packet handling for PF and VF (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix NULL pointer dereference in VF probe path (Chad Dupuis) [725018]
- [ethernet] qlcnic: Set __QLCNIC_DEV_UP in adapter state before enabling interrupts (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix invalid register offset calculation (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update version to 5.2.44 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Add support for 83xx suspend and resume (Chad Dupuis) [725018]
- [ethernet] qlcnic: Add support for 'set driver version' in 83XX (Chad Dupuis) [725018]
- [ethernet] qlcnic: Cleanup of structure qlcnic_hardware_context (Chad Dupuis) [725018]
- [ethernet] qlcnic: Add support for PEX DMA method to read memory section of adapter dump (Chad Dupuis) [725018]
- [ethernet] qlcnic: Minimize sleep duration within loopback diagnostic test (Chad Dupuis) [725018]
- [ethernet] qlcnic: Secondary unicast MAC address support (Chad Dupuis) [725018]
- [ethernet] qlcnic: Handle qlcnic_alloc_mbx_args() failure (Chad Dupuis) [725018]
- [ethernet] qlcnic: replace strict_strtoul() with kstrtoul() (Chad Dupuis) [725018]
- [ethernet] qlcnic: remove redundant D0 power state set (Chad Dupuis) [725018]
- [ethernet] qlcnic: Fix typo in printk (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update version to 5.2.43 (Chad Dupuis) [725018]
- [ethernet] qlcnic: Enhance virtual NIC logging (Chad Dupuis) [725018]
- [ethernet] qlcnic: qlcnic_get_board_name() function cleanup (Chad Dupuis) [725018]
- [ethernet] qlcnic: Implement GET_LED_STATUS command for 82xx adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: modify reset recovery path in diag mode (Chad Dupuis) [725018]
- [ethernet] qlcnic: diagnostics routine changes (Chad Dupuis) [725018]
- [ethernet] qlcnic: Convert nested if-else to switch-case (Chad Dupuis) [725018]
- [ethernet] qlcnic: Initialize trans_work and idc_aen_work at VF probe (Chad Dupuis) [725018]
- [ethernet] qlcnic: Remove qlcnic_config_npars module parameter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Update IRQ name for 8200 and 8300 Series adapter (Chad Dupuis) [725018]
- [ethernet] qlcnic: Disable INT-x interrupt for 83xx on driver unload (Chad Dupuis) [725018]
- [ethernet] qlcnic: Support spoof check config (Chad Dupuis) [725018]
- [x86] Fix x86 invalid cpu boot failure message (Prarit Bhargava) [1024731]
- [virt] virtio-net: refill only when device is up during setting queues (Jason Wang) [1016469]
- [crypto] crc-t10dif: add MODULE_SOFTDEP (Kyle McMartin) [968869]
- [crypto] crct10dif: Add fallback for broken initrds (Kyle McMartin) [968869]
- [crypto] crct10dif: Use PTR_RET (Kyle McMartin) [968869]
- [crypto] crct10dif: Simple correctness and speed test for CRCT10DIF hash (Kyle McMartin) [968869]
- [crypto] crct10dif: Glue code to cast accelerated CRCT10DIF assembly as a crypto transform (Kyle McMartin) [968869]
- [crypto] crct10dif: Accelerated CRC T10 DIF computation with PCLMULQDQ instruction (Kyle McMartin) [968869]
- [crypto] crct10dif: Wrap crc_t10dif function all to use crypto transform framework (Kyle McMartin) [968869]
- [kernel] modules: add support for soft module dependencies (Kyle McMartin) [968869]
- [misc] mei: don't get stuck in select during reset (Prarit Bhargava) [1025420]
- [misc] mei/bus: do not overflow the device name buffer (Prarit Bhargava) [1025420]
- [misc] mei: wake also writers on reset (Prarit Bhargava) [1025420]
- [misc] mei/hbm: fix typo in error message (Prarit Bhargava) [1025420]
- [misc] mei: check whether hw start has succeeded (Prarit Bhargava) [1025420]
- [misc] mei: check if the hardware reset succeeded (Prarit Bhargava) [1025420]
- [misc] mei: mei_cl_connect, don't multiply the timeout twice (Prarit Bhargava) [1025420]
- [misc] mei: do not override a client writing state when buffering (Prarit Bhargava) [1025420]
- [misc] mei: move mei_cl_irq_write_complete to client.c (Prarit Bhargava) [1025420]
- [misc] mei: support HBM versioning (Prarit Bhargava) [1025420]
- [nfc] mei_phy: Clean up file (Prarit Bhargava) [1025420]
- [misc] mei: move mei_cl_complete to client.c (Prarit Bhargava) [1025420]
- [misc] mei: revamp interrupt thread handlers (Prarit Bhargava) [1025420]
- [virt] virtio-net: correctly handle cpu hotplug notifier during resuming (Jason Wang) [1016996]
- [virt] virtio-net: don't respond to cpu hotplug notifier if we're not ready (Jason Wang) [1016996]
- [fs] nfs: fix handling of invalid mount options in nfs_remount (Jeff Layton) [1021538]
- [fs] nfs: reject version and minorversion changes on remount attempts (Jeff Layton) [1021538]
- [drm] qxl: avoid an oops in the deferred io code (Dave Airlie) [1003728 1026182]
- [drm] qxl: fix disabling extra monitors from client (Dave Airlie) [1026182]
- [drm] qxl: remove unnecessary check (Dave Airlie) [1026182]
- [drm] qxl: prefer the monitor config resolution (Dave Airlie) [1026182]
- [drm] copy mode type in drm_mode_connector_list_update() (Dave Airlie) [1026182]
- [drm] qxl: notify that the monitor config changed (Dave Airlie) [1026182]
- [drm] return if changed in drm_helper_hpd_irq_event() (Dave Airlie) [1026182]
- [block] rsxx: Fix possible kernel panic with invalid config (Steve Best) [1024550]
- [block] rsxx: Disallow discards from being unmapped (Steve Best) [1024550]
- [virt] hid-hyperv: convert alloc+memcpy to memdup (Jason Wang) [1026618]
- [virt] hyperv/storvsc: Increase the value of STORVSC_MAX_IO_REQUESTS (Jason Wang) [1026618]
- [virt] hyperv/storvsc: Support FC devices (Jason Wang) [1026618]
- [virt] hyperv: Add the GUID fot synthetic fibre channel device (Jason Wang) [1026618]
- [virt] hyperv/storvsc: Implement multi-channel support (Jason Wang) [1026618]
- [virt] hyperv/storvsc: Update the storage protocol to win8 level (Jason Wang) [1026618]
- [virt] hyperv/storvsc: Increase the value of scsi timeout for storvsc devices (Jason Wang) [1026618]
- [virt] hyperv/vmbus: Terminate vmbus version negotiation on timeout (Jason Wang) [1026618]
- [virt] hv_util: Correctly support ws2008R2 and earlier (Jason Wang) [1026618]
- [virt] hyperv/vmbus: Do not attempt to negoatiate a new version prematurely (Jason Wang) [1026618]
- [virt] hyperv/vmbus: Fix a bug in the handling of channel offers (Jason Wang) [1026618]
- [virt] hyperv: remove HV_DRV_VERSION (Jason Wang) [1026618]
- [virt] hv_balloon: Initialize the transaction ID just before sending the packet (Jason Wang) [1026618]
- [virt] hv_util: Fix a bug in version negotiation code for util services (Jason Wang) [1026618]
- [virt] hyperv/vmbus: incorrect device name is printed when child device is unregistered (Jason Wang) [1026618]
- [virt] hyperv: allocate synic structures before hv_synic_init() (Jason Wang) [1026618]
- [virt] hyperv: check interrupt mask before read_index (Jason Wang) [1026618]
- [virt] hyperv/vmbus: Implement multi-channel support (Jason Wang) [1026618]

* Thu Nov 07 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-47.el7]
- [net] bridge: pass correct vlan id to multicast code (Vlad Yasevich) [912737]
- [net] bridge: Fix updating FDB entries when the PVID is applied (Vlad Yasevich) [912737]
- [net] bridge: Fix the way the PVID is referenced (Vlad Yasevich) [912737]
- [net] bridge: Apply the PVID to priority-tagged frames (Vlad Yasevich) [912737]
- [net] bridge: Don't use VID 0 and 4095 in vlan filtering (Vlad Yasevich) [912737]
- [net] bridge: Correctly clamp MAX forward_delay when enabling STP (Vlad Yasevich) [997814]
- [net] bridge: Clamp forward_delay when enabling STP (Vlad Yasevich) [997814]
- [net] ipv6: mld: introduce mld_{gq, ifc, dad}_stop_timer functions (Daniel Borkmann) [1023947]
- [net] ipv6: mld: refactor query processing into v1/v2 functions (Daniel Borkmann) [1023947]
- [net] ipv6: mld: similarly to MLDv2 have min max_delay of 1 (Daniel Borkmann) [1023947]
- [net] ipv6: mld: implement RFC3810 MLDv2 mode only (Daniel Borkmann) [1023947]
- [net] ipv6: mld: get rid of MLDV2_MRC and simplify calculation (Daniel Borkmann) [1023947]
- [net] ipv6: mld: clean up MLD_V1_SEEN macro (Daniel Borkmann) [1023947]
- [net] ipv6: mld: fix v1/v2 switchback timeout to rfc3810, 9.12. (Daniel Borkmann) [1023947]
- [net] ipv6: mcast: use defines for rfc3810/8.1 lengths (Daniel Borkmann) [1023947]
- [net] ipv6: *_start_timer: rather use unsigned long (Daniel Borkmann) [1023947]
- [net] ipv6: igmp6_event_query: use msecs_to_jiffies (Daniel Borkmann) [1023947]
- [net] ipv6: make unsolicited report intervals configurable for mld (Daniel Borkmann) [1023947]
- [net] ipv4, ipv6: send igmpv3/mld packets with TC_PRIO_CONTROL (Daniel Borkmann) [1023947]
- [net] bridge: disable snooping if there is no querier (Vlad Yasevich) [1019950]
- [net] unix: inherit SOCK_PASS{CRED, SEC} flags from socket to fix race (Daniel Borkmann) [1023964]

* Thu Nov 07 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-46.el7]
- [scsi] aacraid: missing capable() check in compat ioctl (Rich Bono) [1025840]
- [scsi] scsi_dh_rdac: Add new IBM 1813 product id to rdac devlist (Rob Evers) [1020969]
- [scsi] aic94xx: remove driver (Rich Bono) [978980]
- [scsi] qla4xxx: Populate local CHAP credentials for flash target sessions (Chad Dupuis) [1006158]
- [scsi] qla4xxx: Support setting of local CHAP index for flash target entry (Chad Dupuis) [1006158]
- [scsi] qla4xxx: Correct the check for local CHAP entry type (Chad Dupuis) [1006158]
- [scsi] qla4xxx: correctly update session discovery_parent_idx (Chad Dupuis) [1020197]
- [scsi] aacraid: avoid parsing names as kthread_run() format strings (Rich Bono) [752081]
- [scsi] hpsa: return 0 from driver probe function on success, not 1 (Tomas Henzl) [862713]
- [scsi] hpsa: remove unused Smart Array ID (Tomas Henzl) [862713]
- [scsi] hpsa: bump driver version to reflect changes (Tomas Henzl) [862713]
- [scsi] hpsa: housekeeping patch for device_id and product arrays (Tomas Henzl) [862713]
- [scsi] hpsa: add HP Smart Array Gen8 names (Tomas Henzl) [862713]
- [scsi] hpsa: add HP Smart Array Gen9 PCI ID's (Tomas Henzl) [862713]
- [treewide] Convert retrun typos to return (Tomas Henzl) [862713]
- [scsi] hpsa: fix warning with smp_processor_id() in preemptible (Tomas Henzl) [862713]
- [scsi] hpsa: remove unneeded variable (Tomas Henzl) [862713]
- [scsi] hpsa: fix a race in cmd_free/scsi_done (Tomas Henzl) [862713]

* Thu Nov 07 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-45.el7]
- [ethernet] tg3: remove unnecessary pci_set_drvdata() (Ivan Vecera) [1024060]
- [ethernet] tg3: Miscellaneous conversions to ETH_ALEN (Ivan Vecera) [1024060]
- [ethernet] tg3: use phylib when robo switch is in use (Ivan Vecera) [1024060]
- [netdrv] ssb: provide phy address for Gigabit Ethernet driver (Ivan Vecera) [1024060]
- [ethernet] tg3: add support a phy at an address different than 01 (Ivan Vecera) [1024060]
- [ethernet] tg3: Update version to 3.134 (Ivan Vecera) [1024060]
- [ethernet] tg3: Remove unnecessary spinlock (Ivan Vecera) [1024060]
- [ethernet] tg3: Appropriately classify interrupts during request_irq (Ivan Vecera) [1024060]
- [ethernet] tg3: Remove redundant if check (Ivan Vecera) [1024060]
- [ethernet] tg3: Remove if 0'd code (Ivan Vecera) [1024060]
- [ethernet] tg3: LED in shared mode does not blink during traffic (Ivan Vecera) [1024060]
- [ethernet] tg3: Add support for new 577xx device ids (Ivan Vecera) [1024060]
- [ethernet] tg3: Add function tg3_phy_shdw_write() (Ivan Vecera) [1024060]
- [ethernet] tg3: Use pci_dev pm_cap (Ivan Vecera) [1024060]
- [ethernet] tg3: Expand led off fix to include 5720 (Ivan Vecera) [1024060]
- [s390] cio: Introduce on-close CHSC IOCTLs (Hendrik Brueckner) [1022446]
- [s390] cio: Make /dev/chsc a single-open device (Hendrik Brueckner) [1022442]
- [s390] cio: Introduce generic synchronous CHSC IOCTL (Hendrik Brueckner) [1022441]
- [s390] sclp: Add SCLP character device driver (Hendrik Brueckner) [1022425]
- [virt] kvm: Create non-coherent DMA registeration (Alex Williamson) [1025470]
- [virt] kvm: Convert iommu_flags to iommu_noncoherent (Alex Williamson) [1025470]
- [virt] kvm: Add VFIO device (Alex Williamson) [1025470]
- [vfio] vfio_iommu_type1: fix bug caused by break in nested loop (Alex Williamson) [1025468]
- [vfio] fix documentation more (Alex Williamson) [1025468]
- [vfio] vfio-pci: PCI hot reset interface (Alex Williamson) [1025468]
- [vfio] vfio-pci: Test for extended config space (Alex Williamson) [1025468]
- [vfio] vfio-pci: Use fdget() rather than eventfd_fget() (Alex Williamson) [1025468]
- [vfio] Add O_CLOEXEC flag to vfio device fd (Alex Williamson) [1025468]
- [vfio] use get_unused_fd_flags(0) instead of get_unused_fd() (Alex Williamson) [1025468]
- [vfio] add external user support (Alex Williamson) [1025468]
- [vfio] fix documentation (Alex Williamson) [1025468]
- [block] blk-throttle: Enable hierarchy even when sane mount flag is not specified (Vivek Goyal) [1015648]
- [block] blk-throttle: implement proper hierarchy support (Vivek Goyal) [1015648]
- [block] blk-throttle: implement throtl_grp->has_rules[] (Vivek Goyal) [1015648]
- [block] blk-throttle: Account for child group's start time in parent while bio climbs up (Vivek Goyal) [1015648]
- [block] blk-throttle: add throtl_qnode for dispatch fairness (Vivek Goyal) [1015648]
- [block] blk-throttle: make throtl_pending_timer_fn() ready for hierarchy (Vivek Goyal) [1015648]
- [block] blk-throttle: make tg_dispatch_one_bio() ready for hierarchy (Vivek Goyal) [1015648]
- [block] blk-throttle: make blk_throtl_bio() ready for hierarchy (Vivek Goyal) [1015648]
- [block] blk-throttle: make blk_throtl_drain() ready for hierarchy (Vivek Goyal) [1015648]
- [block] blk-throttle: dispatch from throtl_pending_timer_fn() (Vivek Goyal) [1015648]
- [block] blk-throttle: implement dispatch looping (Vivek Goyal) [1015648]
- [block] blk-throttle: separate out throtl_service_queue->pending_timer from throtl_data->dispatch_work (Vivek Goyal) [1015648]
- [block] blk-throttle: set REQ_THROTTLED from throtl_charge_bio() and gate stats update with it (Vivek Goyal) [1015648]
- [block] blk-throttle: move bio_lists[], implement sq_to_tg(), sq_to_td() and throtl_log() (Vivek Goyal) [1015648]
- [block] blk-throttle: add throtl_service_queue->parent_sq (Vivek Goyal) [1015648]
- [block] blk-throttle: generalize update_disptime optimization in blk_throtl_bio() (Vivek Goyal) [1015648]
- [block] blk-throttle: move bio_lists[] blk-throttle: dispatch to throtl_data->service_queue.bio_lists[] (Vivek Goyal) [1015648]
- [block] blk-throttle: move bio_lists[] and friends to throtl_service_queue (Vivek Goyal) [1015648]
- [block] blk-throttle: add throtl_grp->service_queue (Vivek Goyal) [1015648]
- [block] blk-throttle: reorganize throtl_service_queue passed around as argument (Vivek Goyal) [1015648]
- [block] blk-throttle: pass around throtl_service_queue instead of throtl_data (Vivek Goyal) [1015648]
- [block] blk-throttle: add backlink pointer from throtl_grp to throtl_data (Vivek Goyal) [1015648]
- [block] blk-throttle: simplify throtl_grp flag handling (Vivek Goyal) [1015648]
- [block] blk-throttle: rename throtl_rb_root to throtl_service_queue (Vivek Goyal) [1015648]
- [block] blk-throttle: remove pointless throtl_nr_queued() optimizations (Vivek Goyal) [1015648]
- [block] blk-throttle: relocate throtl_schedule_delayed_work() (Vivek Goyal) [1015648]
- [block] blk-throttle: collapse throtl_dispatch() into the work function (Vivek Goyal) [1015648]
- [block] blk-throttle: remove deferred config application mechanism (Vivek Goyal) [1015648]
- [block] blk-throttle: remove spurious throtl_enqueue_tg() call from throtl_select_dispatch() (Vivek Goyal) [1015648]
- [block] blkcg: move bulk of blkcg_gq release operations to the RCU callback (Vivek Goyal) [1015648]
- [block] blkcg: invoke blkcg_policy->pd_init() after parent is linked (Vivek Goyal) [1015648]
- [block] blkcg: implement blkg_for_each_descendant_post() (Vivek Goyal) [1015648]
- [block] blkcg: move blkg_for_each_descendant_pre() to block/blk-cgroup.h (Vivek Goyal) [1015648]
- [block] blkcg: fix error return path in blkg_create() (Vivek Goyal) [1015648]
- [char] ipmi: Add MODULE_ALIAS for autoloading ipmi driver on ACPI systems (Shyam Iyer) [844867]

* Wed Nov 06 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-44.el7]
- [security] keys: Fix UID check in keyctl_get_persistent() (David Howells) [991110]
- [security] keys: fix error return code in big_key_instantiate() (David Howells) [991110]
- [powerpc] tm: Switch out userspace PPR and DSCR sooner (Steve Best) [1016823]
- [virt] kvm: fix KVM_SET_XCRS loop (Paolo Bonzini) [1007897]
- [virt] kvm: fix KVM_SET_XCRS for CPUs that do not support XSAVE (Paolo Bonzini) [1007897]
- [virt] kvm: only copy XSAVE state for the supported features (Paolo Bonzini) [1007897]
- [virt] kvm: prevent setting unsupported XSAVE states (Paolo Bonzini) [1007897]
- [virt] kvm: mask unsupported XSAVE entries from leaf 0Dh index 0 (Paolo Bonzini) [1007897]
- [ethernet] bnx2x: remove unnecessary pci_set_drvdata() (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Add ndo_get_phys_port_id support (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Change variable type to bool (Michal Schmidt) [1022068]
- [ethernet] bnx2x: skb_is_gso_v6() requires skb_is_gso() (Michal Schmidt) [1022068]
- [ethernet] bnx2x: use pcie_get_minimum_link() (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Add support for EXTPHY2 LED mode (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Change function prototype (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Don't disable/enable SR-IOV when loading (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Correct VF driver info (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Test nvram when interface is down (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Staticize local symbols (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Disable VF access on PF removal (Michal Schmidt) [1022068]
- [ethernet] bnx2x: prevent FW assert on low mem during unload (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Set NETIF_F_HIGHDMA unconditionally (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Don't pretend during register dump (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Lock DMAE when used by statistic flow (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Prevent null pointer dereference on error flow (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix config when SR-IOV and iSCSI are enabled (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix Coalescing configuration (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Unlock VF-PF channel on MAC/VLAN config error (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Prevent an illegal pointer dereference during panic (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix Maximum CoS estimation for VFs (Michal Schmidt) [1022068]
- [ethernet] bnx2x: record rx queue for LRO packets (Michal Schmidt) [1022068]
- [ethernet] bnx2x: handle known but unsupported VF messages (Michal Schmidt) [1022068]
- [ethernet] bnx2x: prevent masked MCP parities from appearing (Michal Schmidt) [1022068]
- [ethernet] bnx2x: prevent masking error from cnic (Michal Schmidt) [1022068]
- [ethernet] bnx2x: add missing VF resource allocation during init (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix support for VFs on some PFs (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Prevent mistaken hangup between driver & FW (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix 848xx duplex settings (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Specific Active-DAC is not detected on 57810 (Michal Schmidt) [1022068]
- [ethernet] bnx2x: 57840 non-external loopback test fail on 1G (Michal Schmidt) [1022068]
- [ethernet] bnx2x: KR2 disablement fix (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Generalize KR work-around (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix bnx2i and bnx2fc regressions (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Use pci_dev pm_cap (Michal Schmidt) [1022068]
- [ethernet] bnx2x: avoid atomic allocations during initialization (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Fix configuration of doorbell block (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Restore a call to config_init (Michal Schmidt) [1022068]
- [ethernet] bnx2x: fix broken compilation with CONFIG_BNX2X_SRIOV is not set (Michal Schmidt) [1022068]
- [ethernet] bnx2x: Add missing braces in bnx2x:bnx2x_link_initialize (Michal Schmidt) [1022068]
- [ethernet] bnx2x: VF RSS support - VF side (Michal Schmidt) [1022068]
- [ethernet] bnx2x: VF RSS support - PF side (Michal Schmidt) [1022068]
- [virt] hyperv-fb: add pci stub (Gerd Hoffmann) [1019185]
- [ethernet] ixgbevf: move API neg to reset path (Andy Gospodarek) [1023107]
- [ethernet] bna: firmware update to 3.2.1.1 (Ivan Vecera) [1007080]
- [fs] nfs: Fix a missing initialisation when reading the SELinux label (Jeff Layton) [1019591]
- [fs] nfs: fix oops when trying to set SELinux label (Jeff Layton) [1019591]
- [ethernet] r8169: remove unnecessary pci_set_drvdata() (Ivan Vecera) [1025463]
- [ethernet] r8169: fix invalid register dump (Ivan Vecera) [1025463]
- [ethernet] r8169: remember WOL preferences on driver load (Ivan Vecera) [1025463]
- [ethernet] r8169, sis190: remove unnecessary length check (Ivan Vecera) [1025463]
- [ethernet] r8169: remove "PHY reset until link up" log spam (Ivan Vecera) [1025463]
- [ethernet] r8169: fix lockdep warning when removing interface (Ivan Vecera) [1025463]
- [ethernet] r8169: add a new chip for RTL8411 (Ivan Vecera) [1025463]
- [ethernet] be2net: Make lancer_wait_ready() static (Ivan Vecera) [1025412]
- [ethernet] be2net: Remove interface type (Ivan Vecera) [1025412]
- [ethernet] be2net: add support for ndo_busy_poll (Ivan Vecera) [1025412]
- [ethernet] be2net: Warn users of possible broken functionality on BE2 cards with very old FW versions with latest driver (Ivan Vecera) [1025412]
- [ethernet] be2net: remove unnecessary pci_set_drvdata() (Ivan Vecera) [1025412]
- [ethernet] be2net: Rework PCIe error report log messaging (Ivan Vecera) [1025412]
- [ethernet] be2net: change the driver version number to 4.9.224.0 (Ivan Vecera) [1025412]
- [ethernet] be2net: Display RoCE specific counters in ethtool -S (Ivan Vecera) [1025412]
- [ethernet] be2net: Call version 2 of GET_STATS ioctl for Skyhawk-R (Ivan Vecera) [1025412]
- [ethernet] be2net: add a counter for pkts dropped in xmit path (Ivan Vecera) [1025412]
- [ethernet] be2net: fix adaptive interrupt coalescing (Ivan Vecera) [1025412]
- [ethernet] be2net: call ENABLE_VF cmd for Skyhawk-R too (Ivan Vecera) [1025412]
- [ethernet] be2net: Create single TXQ on BE3-R 1G ports (Ivan Vecera) [1025412]
- [ethernet] be2net: pass if_id for v1 and V2 versions of TX_CREATE cmd (Ivan Vecera) [1025412]
- [ethernet] be2net: Call be_vf_setup() even when VFs are enbaled from previous load (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix to display the VLAN priority for a VF (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix to configure VLAN priority for a VF interface (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix to allow VLAN configuration on VF interfaces (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix number of VLANs supported in UMC mode for BE3-R (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix VLAN promiscuous mode programming (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix the size of be_nic_res_desc structure (Ivan Vecera) [1025412]
- [ethernet] be2net: Fix to prevent Tx stall on SH-R when packet size < 32 (Ivan Vecera) [1025412]
- [ethernet] be2net: Remove extern from function prototypes (Ivan Vecera) [1025412]
- [ethernet] be2net: missing variable initialization (Ivan Vecera) [1025412]
- [drm] cirrus: do not attempt to acquire a reservation while in an interrupt handler (Gerd Hoffmann) [1017433]
- [drm] cirrus: Invalidate page tables when pinning a BO (Gerd Hoffmann) [1017433]
- [virt] kvm: introduce guest count uevent (Paolo Bonzini) [1004799]
- [ata] libahci: fix turning on LEDs in ahci_start_port() (David Milburn) [1024388]
- [kernel] audit: do not reject all AUDIT_INODE filter types (Richard Guy Briggs) [985971]
- [fs] fuse: drop dentry on failed revalidate (Brian Foster) [1006514]
- [fs] fuse: clean up return in fuse_dentry_revalidate() (Brian Foster) [1006514]
- [fs] fuse: use d_materialise_unique() (Brian Foster) [1006514]
- [fs] sysfs: use check_submounts_and_drop() (Brian Foster) [1006514]
- [fs] nfs: use check_submounts_and_drop() (Brian Foster) [1006514]
- [fs] gfs2: use check_submounts_and_drop() (Brian Foster) [1006514]
- [fs] vfs: check unlinked ancestors before mount (Brian Foster) [1006514]
- [fs] vfs: check submounts and drop atomically (Brian Foster) [1006514]
- [fs] vfs: add d_walk() (Brian Foster) [1006514]
- [fs] vfs: restructure d_genocide() (Brian Foster) [1006514]
- [powerpc] Only save/restore SDR1 if in hypervisor mode (Steve Best) [1018639]
- [wireless] brcmsmac: Further reduce log spam from tx phy messages (John Green) [974223]
- [wireless] brcmsmac: Reduce log spam in heavy tx, make err print in debug (John Green) [974223]

* Wed Nov 06 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-43.el7]
- [misc] synchronize with upstream linux-3.10.y stable branch up to 3.10.17 (Veaceslav Falico) [1006938]

* Tue Nov 05 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-42.el7]
- [kernel] keys: align system_certificate_list (Jan Stancek) [985961]
- [security] keys: Fix keyring quota misaccounting on key replacement and unlink (David Howells) [1017806 991110]
- [security] keys: Fix a race between negating a key and reading the error set (David Howells) [991110]
- [security] keys: Make BIG_KEYS boolean (David Howells) [991110]
- [crypto] x.509: remove possible code fragility, enumeration values not handled (David Howells) [985961]
- [crypto] x.509: add module description and license (David Howells) [985961]
- [lib] mpi: add module description and license (David Howells) [985961]
- [security] keys: initialize root uid and session keyrings early (David Howells) [985961]
- [crypto] keys: verify a certificate is signed by a 'trusted' key (David Howells) [985961]
- [kernel] keys: Make the system 'trusted' keyring viewable by userspace (David Howells) [985961]
- [crypto] keys: Set the asymmetric-key type default search method (David Howells) [985961]
- [security] keys: Add a 'trusted' flag and a 'trusted only' flag (David Howells) [985961]
- [kernel] keys: Separate the kernel signature checking keyring from module signing (David Howells) [985961]
- [kernel] keys: Have make canonicalise the paths of the X.509 certs better to deduplicate (David Howells) [985961]
- [kernel] modsign: Load *.x509 files into kernel keyring (David Howells) [985961]
- [crypto] x.509: Remove certificate date checks (David Howells) [985961]
- [crypto] x.509: Handle certificates that lack an authorityKeyIdentifier field (David Howells) [985961]
- [crypto] x.509: Check the algorithm IDs obtained from parsing an X.509 certificate (David Howells) [985961]
- [crypto] x.509: Embed public_key_signature struct and create filler function (David Howells) [985961]
- [crypto] x.509: struct x509_certificate needs struct tm declaring (David Howells) [985961]
- [crypto] keys: Store public key algo ID in public_key_signature struct (David Howells) [985961]
- [crypto] keys: Split public_key_verify_signature() and make available (David Howells) [985961]
- [crypto] keys: Store public key algo ID in public_key struct (David Howells) [985961]
- [crypto] keys: Move the algorithm pointer array from x509 to public_key.c (David Howells) [985961]
- [crypto] keys: Rename public key parameter name arrays (David Howells) [985961]
- [security] keys: Add per-user_namespace registers for persistent per-UID kerberos caches (David Howells) [991110]
- [security] keys: Implement a big key type that can save to tmpfs (David Howells) [991110]
- [security] keys: Expand the capacity of a keyring (David Howells) [1014573 985961]
- [lib] assoc_array: Add a generic associative array implementation (David Howells) [1014573 985961]
- [security] keys: Drop the permissions argument from __keyring_search_one() (David Howells) [1014573 985961]
- [security] keys: Define a __key_get() wrapper to use rather than atomic_inc() (David Howells) [1014573 985961]
- [security] keys: Search for auth-key by name rather than target key ID (David Howells) [1014573 985961]
- [security] keys: Introduce a search context structure (David Howells) [1014573 985961]
- [security] keys: Consolidate the concept of an 'index key' for key access (David Howells) [1014573 985961]
- [security] keys: key_is_dead() should take a const key pointer argument (David Howells) [1014573 985961]
- [security] keys: Use bool in make_key_ref() and is_key_possessed() (David Howells) [1014573 985961]
- [security] keys: Skip key state checks when checking for possession (David Howells) [1014573 985961 991110]

* Fri Nov 01 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-41.el7]
- [net] bonding: ensure that TLB mode's active slave has correct mac filter (Veaceslav Falico) [1017573]
- [net] netfilter: synproxy: fix BUG_ON triggered by corrupt TCP packets (Jesper Brouer) [1015035]
- [net] proc_fs: print UIDs as unsigned int (Francesco Fusco) [996122]
- [net] ipv6: Unify {raw,udp}6_sock_seq_show (Francesco Fusco) [996122]
- [scsi] qla4xxx: Fix memory leak in func qla4_84xx_config_acb() (Chad Dupuis) [998557]
- [scsi] qla4xxx: 5.04.00.00.07.00-k0 (Chad Dupuis) [998557]
- [scsi] qla4xxx: Update driver version to 5.04.00-k1 (Chad Dupuis) [998557]
- [scsi] qla4xxx: Return error if minidump data collection fails (Chad Dupuis) [998557]
- [scsi] qla4xxx: Fix the minidump data collection check in for loop (Chad Dupuis) [998557]
- [scsi] qla4xxx: Add pex-dma support for capturing minidump (Chad Dupuis) [998557]
- [scsi] qla4xxx: Update driver version to 5.04.00-k0 (Chad Dupuis) [998557]
- [scsi] qla4xxx: Update Copyright header (Chad Dupuis) [998557]
- [scsi] qla4xxx: Implementation of ACB configuration during Loopback for ISP8042 (Chad Dupuis) [998557]
- [scsi] qla4xxx: Added support for ISP8042 (Chad Dupuis) [998557]
- [scsi] qla4xxx: Update driver version to 5.03.00-k11 (Chad Dupuis) [948123]
- [scsi] qla4xxx: Export more firmware info in sysfs (Chad Dupuis) [948123]
- [scsi] qla4xxx: Only BIOS boot target entries should be at index 0 and 1 (Chad Dupuis) [948123]
- [scsi] qla4xxx: discovery_parent_idx can be shown without any check (Chad Dupuis) [948123]
- [scsi] qla4xxx: Set IPv6 traffic class if device type is IPv6 (Chad Dupuis) [948123]
- [scsi] qla4xxx: Use discovery_parent_idx instead of discovery_parent_type (Chad Dupuis) [948123]
- [scsi] qla4xxx: Allow removal of failed session using logout (Chad Dupuis) [948123]
- [scsi] qla4xxx: Update driver version to 5.03.00-k10 (Chad Dupuis) [948118]
- [scsi] qla4xxx: Exporting new attrs for iscsi session and connection in sysfs (Chad Dupuis) [948118]
- [scsi] libiscsi: Add missing prints for session and connection sysfs attrs (Chad Dupuis) [948118]
- [scsi] libiscsi: Added new boot entries in the session sysfs (Chad Dupuis) [948118]
- [fs] nfs: inform the VM about pages being committed or unstable (Jerome Marchand) [1009508]
- [mm] vmscan: take page buffers dirty and locked state into account (Jerome Marchand) [1009508]
- [mm] vmscan: treat pages marked for immediate reclaim as zone congestion (Jerome Marchand) [1009508]
- [mm] vmscan: move direct reclaim wait_iff_congested into shrink_list (Jerome Marchand) [1009508]
- [mm] vmscan: set zone flags before blocking (Jerome Marchand) [1009508]
- [mm] vmscan: stall page reclaim after a list of pages have been processed (Jerome Marchand) [1009508]
- [mm] vmscan: stall page reclaim and writeback pages based on dirty/writepage pages encountered (Jerome Marchand) [1009508]
- [mm] vmscan: move logic from balance_pgdat() to kswapd_shrink_zone() (Jerome Marchand) [1009508]
- [mm] vmscan: check if kswapd should writepage once per pgdat scan (Jerome Marchand) [1009508]
- [mm] vmscan: block kswapd if it is encountering pages under writeback (Jerome Marchand) [1009508]
- [mm] vmscan: have kswapd writeback pages based on dirty pages encountered, not priority (Jerome Marchand) [1009508]
- [mm] vmscan: do not allow kswapd to scan at maximum priority (Jerome Marchand) [1009508]
- [mm] vmscan: decide whether to compact the pgdat based on reclaim progress (Jerome Marchand) [1009508]
- [mm] vmscan: flatten kswapd priority loop (Jerome Marchand) [1009508]
- [mm] vmscan: obey proportional scanning requirements for kswapd (Jerome Marchand) [1009508]
- [mm] vmscan: limit the number of pages kswapd reclaims at each priority (Jerome Marchand) [1009508]
- [iommu] Remove stack trace from broken irq remapping warning (Neil Horman) [1012860]
- [kernel] audit: remove newline accidentally added during session id helper refactor (Richard Guy Briggs) [1010438]
- [security] audit: suppress stock memalloc failure warnings since already managed (Richard Guy Briggs) [1016852]
- [kernel] ntp: Make periodic RTC update more reliable (Prarit Bhargava) [1010351]

* Wed Oct 30 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-40.el7]
- [virt] kvm/ppc/Book3S: Fix compile error in XICS emulation (Veaceslav Falico) [1006938]
- [block] rsxx: fix Kernel Panic caused by mapping Discards (Steve Best) [1013995]
- [block] rsxx: Moving pci_map_page to prevent overflow (Steve Best) [1011024]
- [block] rsxx: Handling failed pci_map_page on PowerPC and double free (Steve Best) [1011024]
- [block] rsxx: Adding in debugfs entries (Steve Best) [1002025]
- [block] rsxx: Fixes incorrect stats calculation (Steve Best) [1002025]
- [block] rsxx: Adding EEH check inside cregs timeout (Steve Best) [1002025]
- [block] rsxx: Adapter address space sanity check (Steve Best) [1002025]
- [block] rsxx: Fixes DLPAR add kernel panic if partition still mounted (Steve Best) [1002025]
- [block] rsxx: Changing the adapter name to the official name (Steve Best) [1002025]
- [block] rsxx: Adding in sync_start module paramenter (Steve Best) [1002025]
- [block] rsxx: Allow block size to be determined by configuration (Steve Best) [1002025]
- [block] rsxx: Fixes soft-lockup issues during DMAs (Steve Best) [1002025]
- [block] rsxx: Restructured DMA cancel scheme (Steve Best) [1002025]
- [block] rsxx: Individual workqueues for interruptible events (Steve Best) [1002025]
- [md] Fix skipping recovery for read-only arrays (Jes Sorensen) [1016694]
- [kernel] nohz: Include local CPU in full dynticks global kick (Jarod Wilson) [988015]
- [kernel] nohz: Optimize full dynticks's sched hooks with static keys (Jarod Wilson) [988015]
- [kernel] nohz: Optimize full dynticks state checks with static keys (Jarod Wilson) [988015]
- [kernel] nohz: Rename a few state variables (Jarod Wilson) [988015]
- [kernel] vtime: Always debug check snapshot source _before_ updating it (Jarod Wilson) [988015]
- [kernel] vtime: Always scale generic vtime accounting results (Jarod Wilson) [988015]
- [kernel] vtime: Optimize full dynticks accounting off case with static keys (Jarod Wilson) [988015]
- [kernel] vtime: Describe overriden functions in dedicated arch headers (Jarod Wilson) [988015]
- [kernel] hardirq: Split preempt count mask definitions (Jarod Wilson) [988015]
- [kernel] context_tracking: Split low level state headers (Jarod Wilson) [988015]
- [kernel] vtime: Fix racy cputime delta update (Jarod Wilson) [988015]
- [kernel] vtime: Remove a few unneeded generic vtime state checks (Jarod Wilson) [988015]
- [kernel] context_tracking: User/kernel broundary cross trace events (Jarod Wilson) [988015]
- [kernel] context_tracking: Optimize context switch off case with static keys (Jarod Wilson) [988015]
- [kernel] context_tracking: Optimize guest APIs off case with static key (Jarod Wilson) [988015]
- [kernel] context_tracking: Optimize main APIs off case with static key (Jarod Wilson) [988015]
- [kernel] context_tracking: Ground setup for static key use (Jarod Wilson) [988015]
- [kernel] context_tracking: Remove full dynticks' hacky dependency on wide context tracking (Jarod Wilson) [988015]
- [kernel] nohz: Only enable context tracking on full dynticks CPUs (Jarod Wilson) [988015]
- [kernel] context_tracking: Fix runtime CPU off-case (Jarod Wilson) [988015]
- [kernel] vtime: Update a few comments (Jarod Wilson) [988015]
- [kernel] context_tracking: Fix guest accounting with native vtime (Jarod Wilson) [988015]
- [kernel] sched: Consolidate open coded preemptible() checks (Jarod Wilson) [988015]
- [kernel] nohz: fix compile warning in tick_nohz_init() (Jarod Wilson) [988015]
- [kernel] nohz: Do not warn about unstable tsc unless user uses nohz_full (Jarod Wilson) [988015]
- [kernel] nohz: Remove obsolete check for full dynticks CPUs to be RCU nocbs (Jarod Wilson) [988015]
- [kernel] nohz: Warn if the machine can not perform nohz_full (Jarod Wilson) [988015]
- [md] raid5: avoid finding "discard" stripe (Jes Sorensen) [1023485]
- [md] raid5: set bio bi_vcnt 0 for discard request (Jes Sorensen) [1023485]
- [powerpc] make lorax work again (Steve Best) [1022797]

* Tue Oct 29 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-39.el7]
- [netdrv] cnic: Fix crash in cnic_bnx2x_service_kcq() (Maurizio Lombardi) [1011203]
- [scsi] bnx2fc: Bump version from 1.0.14 to 2.4.1 (Maurizio Lombardi) [1011211]
- [scsi] bnx2fc: hung task timeout warning observed when rmmod bnx2x with active FCoE targets (Maurizio Lombardi) [1011211]
- [scsi] bnx2fc: Fixed a SCSI CMD cmpl race condition between ABTS and CLEANUP (Maurizio Lombardi) [1011211]
- [scsi] Allow error handling timeout to be specified (Ewan Milne) [1020944]
- [scsi] be2iscsi: Bump driver version (Rob Evers) [726165]
- [scsi] be2iscsi: Fix SGL posting for unaligned ICD values (Rob Evers) [726165]
- [scsi] be2iscsi: Fix AER handling in driver (Rob Evers) [726165]
- [scsi] be2iscsi: Invalidate WRB in Abort/Reset Path (Rob Evers) [726165]
- [scsi] be2iscsi: Fix Insufficient Buffer Error returned in MBX Completion (Rob Evers) [726165]
- [scsi] be2iscsi: Fix log level for protocol specific logs (Rob Evers) [726165]
- [scsi] be2iscsi: Fix MSIx creation for SKH-R adapter (Rob Evers) [726165]
- [scsi] be2iscsi: Display Port Identifier for each iSCSI function (Rob Evers) [726165]
- [scsi] be2iscsi: Dispaly CID available for connection offload (Rob Evers) [726165]
- [scsi] be2iscsi: Fix chute cleanup during drivers unload (Rob Evers) [726165]
- [scsi] be2iscsi: Fix connection offload to support Dual Chute (Rob Evers) [726165]
- [scsi] be2iscsi: Fix CID allocation/freeing to support Dual chute mode (Rob Evers) [726165]
- [scsi] be2iscsi: Fix WRB_Q posting to support Dual Chute mode (Rob Evers) [726165]
- [scsi] be2iscsi: Fix SGL Initilization and posting Pages for Dual Chute (Rob Evers) [726165]
- [scsi] be2iscsi: Fix Template HDR support for Dual Chute mode (Rob Evers) [726165]
- [scsi] be2iscsi: Fix changes in ASYNC Path for SKH-R adapter (Rob Evers) [726165]
- [scsi] be2iscsi: Config parameters update for Dual Chute Support (Rob Evers) [726165]
- [scsi] be2iscsi: Fix soft lock up issue during UE or if FW taking time to respond (Rob Evers) [726165]
- [scsi] be2iscsi: Fix locking mechanism in Unsol Path (Rob Evers) [726165]
- [scsi] be2iscsi: Fix negotiated parameters upload to FW (Rob Evers) [726165]
- [scsi] be2iscsi: Fix repeated issue of MAC ADDR get IOCTL (Rob Evers) [726165]
- [scsi] be2iscsi: Fix the MCCQ count leakage (Rob Evers) [726165]
- [scsi] be2iscsi: Fix Template HDR IOCTL (Rob Evers) [726165]
- [scsi] lpfc: Update lpfc version for 8.3.7.31.1p driver release (Rob Evers) [726157]
- [scsi] lpfc: Fixed issue of task management commands having a fixed timeout (Rob Evers) [726157]
- [scsi] lpfc: Fixed inconsistent spin lock usage (Rob Evers) [726157]
- [scsi] lpfc: Fix driver's abort loop functionality to skip IOs already getting aborted (Rob Evers) [726157]
- [scsi] lpfc: Fixed failure to allocate SCSI buffer on PPC64 platform for SLI4 devices (Rob Evers) [726157]
- [scsi] lpfc: Fix WARN_ON when driver unloads (Rob Evers) [726157]
- [scsi] lpfc: Avoided making pci bar ioremap call during dual-chute WQ/RQ pci bar selection (Rob Evers) [726157]
- [scsi] lpfc: Fixed driver iocbq structure's iocb_flag field running out of space (Rob Evers) [726157]
- [scsi] lpfc: Fix crash on driver load due to cpu affinity logic (Rob Evers) [726157]
- [scsi] lpfc: Fixed logging format of setting driver sysfs attributes hard to interpret (Rob Evers) [726157]
- [scsi] lpfc: Fixed back to back RSCNs discovery failure (Rob Evers) [726157]
- [scsi] lpfc: Fixed race condition between BSG I/O dispatch and timeout handling (Rob Evers) [726157]
- [scsi] lpfc: Fixed function mode field defined too small for not recognizing dual-chute mode (Rob Evers) [726157]
- [scsi] lpfc: Back out data count, (residual fcfi_parm) fix for bad target (Rob Evers) [726157]
- [scsi] lpfc: Fixed mailbox memory leak (Rob Evers) [726157]
- [scsi] lpfc: Fix random errors using first burst (Rob Evers) [726157]
- [scsi] lpfc: Fixed not able to log informational messages at early stage of driver init time (Rob Evers) [726157]
- [scsi] lpfc: Fixed using unsafe linked list macro for walking and deleting linked list (Rob Evers) [726157]
- [scsi] lpfc: Removed obsolete fcp_eq_count and fcp_wq_count driver attributes (Rob Evers) [726157]
- [scsi] lpfc: Update copyrights for 8.3.41 modifications (Rob Evers) [726157]
- [scsi] lpfc: Fixed the format of some log message fields (Rob Evers) [726157]
- [scsi] lpfc: Add first burst support to driver (Rob Evers) [726157]
- [scsi] lpfc: Fixed not able to perform PCI function reset when board was not in online mode (Rob Evers) [726157]
- [scsi] lpfc: Fixed failure in setting SLI3 board mode (Rob Evers) [726157]
- [scsi] lpfc: Fixed SLI3 failing FCP write on check-condition no-sense with residual zero (Rob Evers) [726157]
- [scsi] lpfc: Fixed support for 128 byte WQEs (Rob Evers) [726157]
- [scsi] lpfc: Ensure driver properly zeros unused fields in SLI4 mailbox commands (Rob Evers) [726157]
- [scsi] lpfc: Fixed max value of lpfc_lun_queue_depth (Rob Evers) [726157]
- [scsi] lpfc: Fixed Receive Queue varied frame size handling (Rob Evers) [726157]
- [scsi] lpfc: Fix mailbox byteswap issue on PPC (Rob Evers) [726157]
- [scsi] lpfc: Fixed freeing of iocb when internal loopback times out (Rob Evers) [726157]
- [scsi] lpfc: Update Copyrights to 2013 for 8.3.38, 8.3.39, and 8.3.40 modifications (Rob Evers) [726157]
- [scsi] lpfc: Fixed a race condition between SLI host and port failed FCF rediscovery (Rob Evers) [726157]
- [scsi] lpfc: Fixed issue mailbox wait routine failed to issue dump memory mbox command (Rob Evers) [726157]
- [scsi] lpfc: Fixed system panic due to unsafe walking and deleting linked list (Rob Evers) [726157]
- [scsi] lpfc: Fixed FCoE connection list vlan identifier and add FCF list debug (Rob Evers) [726157]
- [scsi] lpfc: Clarified the behavior of the lpfc_max_luns module parameter (Rob Evers) [726157]
- [scsi] lpfc: Fix to allow OCM to report FEC status (Rob Evers) [726157]
- [scsi] lpfc: Fixed a missing return code in a logging message (Rob Evers) [726157]
- [scsi] lpfc: Fixed some logging message fields (Rob Evers) [726157]
- [scsi] lpfc: Fixed list corruption when lpfc_drain_tx runs (Rob Evers) [726157]
- [scsi] lpfc: Fix starting reference tag when calculating BG error (Rob Evers) [726157]
- [scsi] lpfc: Fix inconsistent list removal causes crash (Rob Evers) [726157]
- [scsi] lpfc: Fixed system panic during handling unsolicited receive buffer error condition (Rob Evers) [726157]
- [scsi] lpfc: Fix BlockGuard error checking (Rob Evers) [726157]
- [scsi] lpfc: Fixed crash during FCoE failover testing (Rob Evers) [726157]
- [scsi] lpfc: Fix lpfc_used_cpu to be more dynamic (Rob Evers) [726157]
- [scsi] megaraid_sas: Fix synchronization problem between sysPD IO path and AEN path (Tomas Henzl) [1019819]
- [scsi] megaraid_sas: fixes for few endianess issues (Tomas Henzl) [1019819]
- [scsi] megaraid_sas: addded support for big endian architecture (Tomas Henzl) [1005934]
- [scsi] megaraid_sas: Version and Changelog update (Tomas Henzl) [1005934]
- [scsi] megaraid_sas: Add High Availability clustering support using shared Logical Disks (Tomas Henzl) [1005934]
- [scsi] megaraid_sas: fix memory leak if SGL has zero length entries (Tomas Henzl) [1005934]
- [scsi] megaraid_sas: Changelog and driver version update (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Add support to differentiate between iMR vs MR Firmware (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Add support for Uneven Span PRL11 (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Add support for Extended MSI-x vectors for 12Gb/s controller (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Set IoFlags to enable Fast Path for JBODs for 12 Gb/s controllers (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Add support to display Customer branding details in syslog (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Add support for MegaRAID Fury (device ID-0x005f) 12Gb/s controllers (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Set IO request timeout value provided by OS timeout for Tape devices (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Free event detail memory without device ID check (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Update balance count in driver to be in sync of firmware (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Fix the interrupt mask for Gen2 controller (Tomas Henzl) [726228]
- [scsi] megaraid_sas: Return DID_ERROR for SCSI IO, when controller is in critical h/w error (Tomas Henzl) [726228]
- [scsi] Add 'eh_deadline' to limit SCSI EH runtime (Ewan Milne) [988042]
- [scsi] remove check for 'resetting' (Ewan Milne) [988042]
- [scsi] dc395: Move 'last_reset' into internal host structure (Ewan Milne) [988042]
- [scsi] tmscsim: Move 'last_reset' into host structure (Ewan Milne) [988042]
- [scsi] advansys: Remove 'last_reset' references (Ewan Milne) [988042]
- [scsi] dpt_i2o: return SCSI_MLQUEUE_HOST_BUSY when in reset (Ewan Milne) [988042]
- [scsi] dpt_i2o: Remove DPTI_STATE_IOCTL (Ewan Milne) [988042]

* Tue Oct 29 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-38.el7]
- [net] ip_output: do skb ufo init for peeked non ufo skb as well (Jiri Pirko) [1014599]
- [net] ip6_output: do skb ufo init for peeked non ufo skb as well (Jiri Pirko) [1014599]
- [net] udp6: respect IPV6_DONTFRAG sockopt in case there are pending frames (Jiri Pirko) [1014599]
- [net] ipv6: udp packets following an UFO enqueued packet need also be handled by UFO (Jiri Pirko) [1011931] {CVE-2013-4387}
- [net] bonding: combine pr_debugs in bond_set_dev_addr into one (Nikolay Aleksandrov) [1020621]
- [net] bonding: when cloning a MAC use NET_ADDR_STOLEN (Nikolay Aleksandrov) [1020621]
- [net] bonding: remove unnecessary dev_addr_from_first member (Nikolay Aleksandrov) [1020621]
- [net] netfilter: nf_conntrack: use RCU safe kfree for conntrack extensions (Jesper Brouer) [1010252]
- [net] tcp: TSQ can use a dynamic limit (Jiri Pirko) [998775]
- [net] tcp: TSO packets automatic sizing (Jiri Pirko) [998775]
- [security] selinux: fix selinuxfs policy file on big endian systems (Eric Paris) [839671]
- [powerpc] Fix memory hotplug with sparse vmemmap (Steve Best) [805181]
- [powerpc] mm: Mark Memory Resources as busy (Steve Best) [805181]
- [tools] perf/bench: Fix failing assertions in numa bench (Petr Holasek) [1011923]
- [hid] pantherlord: heap overflow flaw (Radomir Vrbovsky) [1000436] {CVE-2013-2892}
- [powerpc] tm: Turn interrupts hard off in tm_reclaim() (Steve Best) [1017135]
- [powerpc] tm: Clear MSR RI in non-recoverable TM code (Steve Best) [1017135]
- [powerpc] perf: Fix handling of FAB events (Steve Best) [1015439]

* Thu Oct 24 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-37.el7]
- [fs] xfs: remove dead code from xlog_recover_inode_pass2 (Dave Chinner) [1001861]
- [fs] xfs: = vs == typo in ASSERT() (Dave Chinner) [1001861]
- [fs] xfs: don't assert fail on bad inode numbers (Dave Chinner) [1001861]
- [fs] xfs: aborted buf items can be in the AIL (Dave Chinner) [1001861]
- [fs] xfs: factor all the kmalloc-or-vmalloc fallback allocations (Dave Chinner) [1001861]
- [fs] xfs: fix memory allocation failures with ACLs (Dave Chinner) [1001861]
- [fs] xfs: ensure we copy buffer type in da btree root splits (Dave Chinner) [1001861]
- [fs] xfs: set remote symlink buffer type for recovery (Dave Chinner) [1001861]
- [fs] xfs: recovery of swap extents operations for CRC filesystems (Dave Chinner) [1001861]
- [fs] xfs: swap extents operations for CRC filesystems (Dave Chinner) [1001861]
- [fs] xfs: check magic numbers in dir3 leaf verifier first (Dave Chinner) [1001861]
- [fs] xfs: fix some minor sparse warnings (Dave Chinner) [1001861]
- [fs] xfs: fix endian warning in xlog_recover_get_buf_lsn() (Dave Chinner) [1001861]
- [fs] xfs: XFS_MOUNT_QUOTA_ALL needed by userspace (Dave Chinner) [1001861]
- [fs] xfs: dtype changed xfs_dir2_sfe_put_ino to xfs_dir3_sfe_put_ino (Dave Chinner) [1001861]
- [fs] xfs: Fix wrong flag ASSERT in xfs_attr_shortform_getvalue (Dave Chinner) [1001861]
- [fs] xfs: finish removing IOP_* macros (Dave Chinner) [1001861]
- [fs] xfs: inode log reservations are too small (Dave Chinner) [1001861]
- [fs] xfs: check correct status variable for xfs_inobt_get_rec() call (Dave Chinner) [1001861]
- [fs] xfs: inode buffers may not be valid during recovery readahead (Dave Chinner) [1001861]
- [fs] xfs: check LSN ordering for v5 superblocks during recovery (Dave Chinner) [1001861]
- [fs] xfs: btree block LSN escaping to disk uninitialised (Dave Chinner) [1001861]
- [fs] xfs: Assertion failed: first <= last && last < BBTOB(bp->b_length), file: fs/xfs/xfs_trans_buf.c, line: 568 (Dave Chinner) [1001861]
- [fs] xfs: fix bad dquot buffer size in log recovery readahead (Dave Chinner) [1001861]
- [fs] xfs: don't account buffer cancellation during log recovery readahead (Dave Chinner) [1001861]
- [fs] xfs: check for underflow in xfs_iformat_fork() (Dave Chinner) [1001861]
- [fs] xfs: xfs_dir3_sfe_put_ino can be static (Dave Chinner) [1001861]
- [fs] xfs: introduce object readahead to log recovery (Dave Chinner) [1001861]
- [fs] xfs: Simplify xfs_ail_min() with list_first_entry_or_null() (Dave Chinner) [1001861]
- [fs] xfs: Register hotcpu notifier after initialization (Dave Chinner) [1001861]
- [fs] xfs: add xfs sb v4 support for dirent filetype field (Dave Chinner) [1001861]
- [fs] xfs: Add write support for dirent filetype field (Dave Chinner) [1001861]
- [fs] xfs: Add read-only support for dirent filetype field (Dave Chinner) [1001861]
- [fs] xfs: Add support for the Q_XGETQSTATV (Dave Chinner) [1001861]
- [fs] quota: Add a new quotactl command Q_XGETQSTATV (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_mountfs() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_sb_quiet_read_verify() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xlog_recover_do_dquot_buffer() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_log_unmount_write() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_ifree_cluster() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_ialloc_ag_select() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_extent_busy_update_extent() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_setsize_buftarg_early() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_bmap_punch_delalloc_range() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_bmap_last_before() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_bmap_validate_ret() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_bmap_count_tree() (Dave Chinner) [1001861]
- [fs] xfs: rename bio_add_buffer() to xfs_bio_add_buffer() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xlog_find_head() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xlog_recover_buffer_pass2() (Dave Chinner) [1001861]
- [fs] xfs: remove two unused macro definitions in xfs_linux.h (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_btree_get_iroot() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_iroot_realloc() (Dave Chinner) [1001861]
- [fs] xfs: remove one blank line in xfs_btree_make_block_unfull() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xlog_write_setup_copy() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_mod_incore_sb_unlocked() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_btree_lookup() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_buf_free() (Dave Chinner) [1001861]
- [fs] xfs: fix the comment of xfs_check_sizes() (Dave Chinner) [1001861]
- [fs] xfs: use reference counts to free clean buffer items (Dave Chinner) [1001861]
- [fs] xfs: split the CIL lock (Dave Chinner) [1001861]
- [fs] xfs: Combine CIL insert and prepare passes (Dave Chinner) [1001861]
- [fs] xfs: avoid CIL allocation during insert (Dave Chinner) [1001861]
- [fs] xfs: Reduce allocations during CIL insertion (Dave Chinner) [1001861]
- [fs] xfs: return log item size in IOP_SIZE (Dave Chinner) [1001861]
- [fs] xfs: free bp in xlog_find_tail() error path (Dave Chinner) [1001861]
- [fs] xfs: free bp in xlog_find_zeroed() error path (Dave Chinner) [1001861]
- [fs] xfs: avoid double-free in xfs_attr_node_addname (Dave Chinner) [1001861]
- [fs] xfs: call roundup_64() to calculate the min_logblks (Dave Chinner) [1001861]
- [fs] xfs: Validate log space at mount time (Dave Chinner) [1001861]
- [fs] xfs: Add xfs_log_rlimit.c (Dave Chinner) [1001861]
- [fs] xfs: Refactor xfs_ticket_alloc() to extract a new helper (Dave Chinner) [1001861]
- [fs] xfs: Get rid of all XFS_XXX_LOG_RES() macro (Dave Chinner) [1001861]
- [fs] xfs: refactor xfs_trans_reserve() interface (Dave Chinner) [1001861]
- [fs] xfs: Make writeid transaction use tr_writeid (Dave Chinner) [1001861]
- [fs] xfs: Introduce tr_fsyncts to m_reservation (Dave Chinner) [1001861]
- [fs] xfs: Introduce a new structure to hold transaction reservation items (Dave Chinner) [1001861]
- [fs] xfs: make struct xfs_perag kernel only (Dave Chinner) [1001861]
- [fs] xfs: move kernel specific type definitions to xfs.h (Dave Chinner) [1001861]
- [fs] xfs: xfs_filestreams.h doesn't need __KERNEL__ (Dave Chinner) [1001861]
- [fs] xfs: remove __KERNEL__ check from xfs_dir2_leaf.c (Dave Chinner) [1001861]
- [fs] xfs: remove __KERNEL__ from debug code (Dave Chinner) [1001861]
- [fs] xfs: kill __KERNEL__ check for debug code in allocation code (Dave Chinner) [1001861]
- [fs] xfs: don't special case shared superblock mounts (Dave Chinner) [1001861]
- [fs] xfs: consolidate extent swap code (Dave Chinner) [1001861]
- [fs] xfs: consolidate xfs_utils.c (Dave Chinner) [1001861]
- [fs] xfs: consolidate xfs_rename.c (Dave Chinner) [1001861]
- [fs] xfs: kill xfs_vnodeops.[ch] (Dave Chinner) [1001861]
- [fs] xfs: fix issues that cause userspace warnings (Dave Chinner) [1001861]
- [fs] xfs: minor cleanups (Dave Chinner) [1001861]
- [fs] xfs: create xfs_bmap_util.[ch] (Dave Chinner) [1001861]
- [fs] xfs: introduce xfs_sb.c for sharing with libxfs (Dave Chinner) [1001861]
- [fs] xfs: split out the remote symlink handling (Dave Chinner) [1001861]
- [fs] xfs: split out attribute fork truncation code into separate file (Dave Chinner) [1001861]
- [fs] xfs: split out attribute listing code into separate file (Dave Chinner) [1001861]
- [fs] xfs: reshuffle dir2 definitions around for userspace (Dave Chinner) [1001861]
- [fs] xfs: move getdents code into it's own file (Dave Chinner) [1001861]
- [fs] xfs: introduce xfs_inode_buf.c for inode buffer operations (Dave Chinner) [1001861]
- [fs] xfs: move unrelated definitions out of xfs_inode.h (Dave Chinner) [1001861]
- [fs] xfs: move inode fork definitions to a new header file (Dave Chinner) [1001861]
- [fs] xfs: split out transaction reservation code (Dave Chinner) [1001861]
- [fs] xfs: sync minor header differences needed by userspace (Dave Chinner) [1001861]
- [fs] xfs: introduce xfs_quota_defs.h (Dave Chinner) [1001861]
- [fs] xfs: introduce xfs_rtalloc_defs.h (Dave Chinner) [1001861]
- [fs] xfs: split out on-disk transaction definitions (Dave Chinner) [1001861]
- [fs] xfs: separate icreate log format definitions from xfs_icreate_item.h (Dave Chinner) [1001861]
- [fs] xfs: separate dquot on disk format definitions out of xfs_quota.h (Dave Chinner) [1001861]
- [fs] xfs: split out EFI/EFD log item format definition (Dave Chinner) [1001861]
- [fs] xfs: split out buf log item format definitions (Dave Chinner) [1001861]
- [fs] xfs: split out inode log item format definition (Dave Chinner) [1001861]
- [fs] xfs: separate out log format definitions (Dave Chinner) [1001861]
- [fs] xfs: di_flushiter considered harmful (Dave Chinner) [1001861]
- [fs] xfs: Start using pquotaino from the superblock (Dave Chinner) [1001861]
- [fs] xfs: Initialize all quota inodes to be NULLFSINO (Dave Chinner) [1001861]
- [fs] xfs: Fix a deadlock in xfs_log_commit_cil() code path (Dave Chinner) [1001861]
- [fs] xfs: fix assertion failure in xfs_vm_write_failed() (Dave Chinner) [1001861]
- [fs] xfs: Fix the logic check for all quotas being turned off (Dave Chinner) [1001861]
- [fs] xfs: Add pquota fields where gquota is used (Dave Chinner) [1001861]
- [fs] xfs: fix sgid inheritance for subdirectories inheriting default acls (Dave Chinner) [1001861]
- [fs] xfs: dquot log reservations are too small (Dave Chinner) [1001861]
- [fs] xfs: remove local fork format handling from xfs_bmapi_write() (Dave Chinner) [1001861]
- [fs] xfs: use get_unused_fd_flags(0) instead of get_unused_fd() (Dave Chinner) [1001861]
- [fs] xfs: clean up unused codes at xfs_bulkstat() (Dave Chinner) [1001861]
- [fs] xfs: use XFS_BMAP_BMDR_SPACE vs. XFS_BROOT_SIZE_ADJ (Dave Chinner) [1001861]
- [fs] xfs: Remove incore use of XFS_OQUOTA_ENFD and XFS_OQUOTA_CHKD (Dave Chinner) [1001861]
- [fs] xfs: Change xfs_dquot_acct to be a 2-dimensional array (Dave Chinner) [1001861]
- [fs] xfs: Code cleanup and removal of some typedef usage (Dave Chinner) [1001861]
- [fs] xfs: Replace macro XFS_DQ_TO_QIP with a function (Dave Chinner) [1001861]
- [fs] xfs: Replace macro XFS_DQUOT_TREE with a function (Dave Chinner) [1001861]
- [fs] xfs: Define a new function xfs_is_quota_inode() (Dave Chinner) [1001861]
- [fs] xfs: implement inode change count (Dave Chinner) [1001861]
- [fs] xfs: Use inode create transaction (Dave Chinner) [1001861]
- [fs] xfs: Inode create item recovery (Dave Chinner) [1001861]
- [fs] xfs: Inode create transaction reservations (Dave Chinner) [1001861]
- [fs] xfs: Inode create log items (Dave Chinner) [1001861]
- [fs] xfs: Introduce an ordered buffer item (Dave Chinner) [1001861]
- [fs] xfs: Introduce ordered log vector support (Dave Chinner) [1001861]
- [fs] xfs: xfs_ifree doesn't need to modify the inode buffer (Dave Chinner) [1001861]
- [fs] xfs: don't do IO when creating an new inode (Dave Chinner) [1001861]
- [fs] xfs: don't use speculative prealloc for small files (Dave Chinner) [1001861]
- [fs] xfs: plug directory buffer readahead (Dave Chinner) [1001861]
- [fs] xfs: add pluging for bulkstat readahead (Dave Chinner) [1001861]
- [fs] xfs: Remove dead function prototype xfs_sync_inode_grab() (Dave Chinner) [1001861]
- [fs] xfs: Remove the left function variable from xfs_ialloc_get_rec() (Dave Chinner) [1001861]
- [fs] xfs: check on-disk (not incore) btree root size in dfrag.c (Dave Chinner) [1001861]
- [fs] xfs: Remove XFS_MOUNT_RETERR (Dave Chinner) [1001861]
- [fs] xfs: Remove two dead transaction log reservaion macros (Dave Chinner) [1001861]
- [fs] xfs: return FIEMAP_EXTENT_UNKNOWN for delayed allocation extent (Dave Chinner) [1001861]
- [fs] xfs: fix the symbolic link assert in xfs_ifree (Dave Chinner) [1001861]
- [fs] xfs: Remove struct xfs_chash from xfs_mount (Dave Chinner) [1001861]
- [fs] xfs: Don't keep silent if sunit/swidth can not be changed via mount (Dave Chinner) [1001861]
- [fs] xfs: Remove redundant error variable from xfs_growfs_data_private() (Dave Chinner) [1001861]
- [fs] xfs: Convert use of typedef ctl_table to struct ctl_table (Dave Chinner) [1001861]
- [fs] xfs: Avoid pathological backwards allocation (Dave Chinner) [1001861]

* Wed Oct 23 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-36.el7]
- [fs] btrfs: create the uuid tree on remount rw (Eric Sandeen) [1010071]
- [fs] btrfs: change extent-same to copy entire argument struct (Eric Sandeen) [1010071]
- [fs] btrfs: dir_inode_operations should use btrfs_update_time also (Eric Sandeen) [1010071]
- [fs] btrfs: add btrfs prefix to kernel log output (Eric Sandeen) [1010071]
- [fs] btrfs: refuse to remount read-write after abort (Eric Sandeen) [1010071]
- [fs] btrfs: don't leak transaction in btrfs_sync_file() (Eric Sandeen) [1010071]
- [fs] btrfs: add the missing mutex unlock in write_all_supers() (Eric Sandeen) [1010071]
- [fs] btrfs: iput inode on allocation failure (Eric Sandeen) [1010071]
- [fs] btrfs: remove space_info->reservation_progress (Eric Sandeen) [1010071]
- [fs] btrfs: kill delay_iput arg to the wait_ordered functions (Eric Sandeen) [1010071]
- [fs] btrfs: fix worst case calculator for space usage (Eric Sandeen) [1010071]
- [fs] btrfs: improve replacing nocow extents (Eric Sandeen) [1010071]
- [fs] btrfs: drop dir i_size when adding new names on replay (Eric Sandeen) [1010071]
- [fs] btrfs: replay dir_index items before other items (Eric Sandeen) [1010071]
- [fs] btrfs: check roots last log commit when checking if an inode has been logged (Eric Sandeen) [1010071]
- [fs] btrfs: actually log directory we are fsync()'ing (Eric Sandeen) [1010071]
- [fs] btrfs: actually limit the size of delalloc range (Eric Sandeen) [1010071]
- [fs] btrfs: allocate the free space by the existed max extent size when ENOSPC (Eric Sandeen) [1010071]
- [fs] btrfs: add lockdep and tracing annotations for uuid tree (Eric Sandeen) [1010071]
- [fs] btrfs: show compiled-in config features at module load time (Eric Sandeen) [1010071]
- [fs] btrfs: more efficient inode tree replace operation (Eric Sandeen) [1010071]
- [fs] btrfs: do not add replace target to the alloc_list (Eric Sandeen) [1010071]
- [fs] btrfs: fixup error handling in btrfs_reloc_cow (Eric Sandeen) [1010071]
- [fs] btrfs: optimize key searches in btrfs_search_slot (Eric Sandeen) [1010071]
- [fs] btrfs: don't use an async starter for most of our workers (Eric Sandeen) [1010071]
- [fs] btrfs: only update disk_i_size as we remove extents (Eric Sandeen) [1010071]
- [fs] btrfs: fix deadlock in uuid scan kthread (Eric Sandeen) [1010071]
- [fs] btrfs: stop refusing the relocation of chunk 0 (Eric Sandeen) [1010071]
- [fs] btrfs: fix memory leak of uuid_root in free_fs_info (Eric Sandeen) [1010071]
- [fs] btrfs: reuse kbasename helper (Eric Sandeen) [1010071]
- [fs] btrfs: return btrfs error code for dev excl ops err (Eric Sandeen) [1010071]
- [fs] btrfs: allow partial ordered extent completion (Eric Sandeen) [1010071]
- [fs] btrfs: convert all bug_ons in free-space-cache.c (Eric Sandeen) [1010071]
- [fs] btrfs: add support for asserts (Eric Sandeen) [1010071]
- [fs] btrfs: adjust the fs_devices->missing count on unmount (Eric Sandeen) [1010071]
- [fs] btrfs: don't check for root_refs == 0 twice (Eric Sandeen) [1010071]
- [fs] btrfs: fix for patch "cleanup: don't check the same thing twice" (Eric Sandeen) [1010071]
- [fs] btrfs: get rid of one BUG() in write_all_supers() (Eric Sandeen) [1010071]
- [fs] btrfs: allocate prelim_ref with a slab allocater (Eric Sandeen) [1010071]
- [fs] btrfs: pass gfp_t to __add_prelim_ref() to avoid always using GFP_ATOMIC (Eric Sandeen) [1010071]
- [fs] btrfs: fix race conditions in BTRFS_IOC_FS_INFO ioctl (Eric Sandeen) [1010071]
- [fs] btrfs: fix race between removing a dev and writing sbs (Eric Sandeen) [1010071]
- [fs] btrfs: remove ourselves from the cluster list under lock (Eric Sandeen) [1010071]
- [fs] btrfs: do not clear our orphan item runtime flag on eexist (Eric Sandeen) [1010071]
- [fs] btrfs: fix send to deal with sparse files properly (Eric Sandeen) [1010071]
- [fs] btrfs: fix printing of non NULL terminated string (Eric Sandeen) [1010071]
- [fs] btrfs: Use z to format size_t (Eric Sandeen) [1010071]
- [fs] btrfs: Do not truncate sector_t on 32-bit with CONFIG_LBDAF=y (Eric Sandeen) [1010071]
- [fs] btrfs: PAGE_CACHE_SIZE is already unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make btrfs_header_chunk_tree_uuid() return unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make btrfs_header_fsid() return unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make btrfs_dev_extent_chunk_tree_uuid() return unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make btrfs_device_fsid() return unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make btrfs_device_uuid() return unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Format mirror_num as int (Eric Sandeen) [1010071]
- [fs] btrfs: Format PAGE_SIZE as unsigned long (Eric Sandeen) [1010071]
- [fs] btrfs: Make BTRFS_DEV_REPLACE_DEVID an unsigned long long constant (Eric Sandeen) [1010071]
- [fs] btrfs: Remove superfluous casts from u64 to unsigned long long (Eric Sandeen) [1010071]
- [fs] btrfs: fix memory leak of orphan block rsv (Eric Sandeen) [1010071]
- [fs] btrfs: rollback btrfs_device fields on umount (Eric Sandeen) [1010071]
- [fs] btrfs: add alloc_fs_devices and switch to it (Eric Sandeen) [1010071]
- [fs] btrfs: add btrfs_alloc_device and switch to it (Eric Sandeen) [1010071]
- [fs] btrfs: find_next_devid: root -> fs_info (Eric Sandeen) [1010071]
- [fs] btrfs: don't allow the replace procedure on read only filesystems (Eric Sandeen) [1010071]
- [fs] btrfs: reset force_compress on btrfs_file_defrag failure (Eric Sandeen) [1010071]
- [fs] btrfs: use __u64 in exported user headers (Eric Sandeen) [1010071]
- [fs] btrfs: add mount option to force UUID tree checking (Eric Sandeen) [1010071]
- [fs] btrfs: check UUID tree during mount if required (Eric Sandeen) [1010071]
- [fs] btrfs: introduce uuid-tree-gen field (Eric Sandeen) [1010071]
- [fs] btrfs: fill UUID tree initially (Eric Sandeen) [1010071]
- [fs] btrfs: maintain subvolume items in the UUID tree (Eric Sandeen) [1010071]
- [fs] btrfs: create UUID tree if required (Eric Sandeen) [1010071]
- [fs] btrfs: support printing UUID tree elements (Eric Sandeen) [1010071]
- [fs] btrfs: introduce a tree for items that map UUIDs to something (Eric Sandeen) [1010071]
- [fs] btrfs: mark some local function as 'static' (Eric Sandeen) [1010071]
- [fs] btrfs: get rid of sparse warnings (Eric Sandeen) [1010071]
- [fs] btrfs: don't miss inode ref items in BTRFS_IOC_INO_LOOKUP (Eric Sandeen) [1010071]
- [fs] btrfs: add missing error code to BTRFS_IOC_INO_LOOKUP handler (Eric Sandeen) [1010071]
- [fs] btrfs: remove reduplicate check when disabling quota (Eric Sandeen) [1010071]
- [fs] btrfs: move btrfs_free_qgroup_config() out of spin_lock and fix comments (Eric Sandeen) [1010071]
- [fs] btrfs: fix oops when writing dirty qgroups to disk (Eric Sandeen) [1010071]
- [fs] btrfs: fix send issues related to inode number reuse (Eric Sandeen) [1010071]
- [fs] btrfs: separate out tests into their own directory (Eric Sandeen) [1010071]
- [fs] btrfs: avoid starting a transaction in the write path (Eric Sandeen) [1010071]
- [fs] btrfs: fix heavy delalloc related deadlock (Eric Sandeen) [1010071]
- [fs] btrfs: fix the error handling wrt orphan items (Eric Sandeen) [1010071]
- [fs] btrfs: don't allow a subvol to be deleted if it is the default subovl (Eric Sandeen) [1010071]
- [fs] btrfs: skip subvol entries when checking if we've created a dir already (Eric Sandeen) [1010071]
- [fs] btrfs: offline dedupe (Eric Sandeen) [1010071]
- [fs] btrfs: Introduce extent_read_full_page_nolock() (Eric Sandeen) [1010071]
- [fs] btrfs: btrfs_ioctl_clone, Move clone code into it's own function (Eric Sandeen) [1010071]
- [fs] btrfs: abtract out range locking in clone ioctl() (Eric Sandeen) [1010071]
- [fs] btrfs: fix possible memory leak in find_parent_nodes() (Eric Sandeen) [1010071]
- [fs] btrfs: return ENOSPC when target space is full (Eric Sandeen) [1010071]
- [fs] btrfs: don't ignore errors from btrfs_run_delayed_items (Eric Sandeen) [1010071]
- [fs] btrfs: fix inode leak on kmalloc failure in tree-log.c (Eric Sandeen) [1010071]
- [fs] btrfs: allow compressed extents to be merged during defragment (Eric Sandeen) [1010071]
- [fs] btrfs: add mount option to set commit interval (Eric Sandeen) [1010071]
- [fs] btrfs: stop using GFP_ATOMIC when allocating rewind ebs (Eric Sandeen) [1010071]
- [fs] btrfs: deal with enomem in the rewind path (Eric Sandeen) [1010071]
- [fs] btrfs: check our parent dir when doing a compare send (Eric Sandeen) [1010071]
- [fs] btrfs: handle errors when doing slow caching (Eric Sandeen) [1010071]
- [fs] btrfs: add missing error handling to read_tree_block (Eric Sandeen) [1010071]
- [fs] btrfs: Fix leak in __btrfs_map_block error path (Eric Sandeen) [1010071]
- [fs] btrfs: add missing error check to find_parent_nodes (Eric Sandeen) [1010071]
- [fs] btrfs: optimize function btrfs_read_chunk_tree (Eric Sandeen) [1010071]
- [fs] btrfs: don't bug_on when we fail when cleaning up transactions (Eric Sandeen) [1010071]
- [fs] btrfs: change how we queue blocks for backref checking (Eric Sandeen) [1010071]
- [fs] btrfs: check to see if we have an inline item properly (Eric Sandeen) [1010071]
- [fs] btrfs: fix what bits we clear when erroring out from delalloc (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup arguments to extent_clear_unlock_delalloc (Eric Sandeen) [1010071]
- [fs] btrfs: use BTRFS_SUPER_INFO_SIZE macro at btrfs_read_dev_super() (Eric Sandeen) [1010071]
- [fs] btrfs: cache the extent map struct when reading several pages (Eric Sandeen) [1010071]
- [fs] btrfs: batch the extent state operation when reading pages (Eric Sandeen) [1010071]
- [fs] btrfs: batch the extent state operation in the end io handle of the read page (Eric Sandeen) [1010071]
- [fs] btrfs: don't cache the csum value into the extent state tree (Eric Sandeen) [1010071]
- [fs] btrfs: add branch prediction hints in the read page end IO function (Eric Sandeen) [1010071]
- [fs] btrfs: remove unnecessary argument of bio_readpage_error() (Eric Sandeen) [1010071]
- [fs] btrfs: add missing mounting options in btrfs_show_options() (Eric Sandeen) [1010071]
- [fs] btrfs: use u64 for subvolid when parsing mount options (Eric Sandeen) [1010071]
- [fs] btrfs: add sanity checks regarding to parsing mount options (Eric Sandeen) [1010071]
- [fs] btrfs: fix memory leak when allocating pages for p/q stripes failed in raid56 (Eric Sandeen) [1010071]
- [fs] btrfs: fix and cleanup some error paths in raid56 (Eric Sandeen) [1010071]
- [fs] btrfs: don't bother autodefragging if our root is going away (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup reloc roots properly on error (Eric Sandeen) [1010071]
- [fs] btrfs: reset ret in record_one_backref (Eric Sandeen) [1010071]
- [fs] btrfs: fix get set label blocking against balance (Eric Sandeen) [1010071]
- [fs] btrfs: Print key type in decimal everywhere (Eric Sandeen) [1010071]
- [fs] btrfs: update delayed ref tracepoints (Eric Sandeen) [1010071]
- [fs] btrfs: btrfs_read_block_groups, Use enums to index (Eric Sandeen) [1010071]
- [fs] btrfs: Cleanup for using BTRFS_SETGET_STACK instead of raw convert (Eric Sandeen) [1010071]
- [fs] btrfs: set qgroup_ulist to be null after calling ulist_free() (Eric Sandeen) [1010071]
- [fs] btrfs: add missing error checks to add_data_references (Eric Sandeen) [1010071]
- [fs] btrfs: make errors in btrfs_num_copies less noisy (Eric Sandeen) [1010071]
- [fs] btrfs: make free space caching faster with many non-inline extent references (Eric Sandeen) [1010071]
- [fs] btrfs: fall back to global reservation when removing subvolumes (Eric Sandeen) [1010071]
- [fs] btrfs: optimize btrfs_lookup_extent_info() (Eric Sandeen) [1010071]
- [fs] btrfs: Release uuid_mutex for shrink during device delete (Eric Sandeen) [1010071]
- [fs] btrfs: set lockdep class before locking new extent buffer (Eric Sandeen) [1010071]
- [fs] btrfs: return -1 when lzo compression makes data bigger (Eric Sandeen) [1010071]
- [fs] btrfs: stop using GFP_ATOMIC for the tree mod log allocations (Eric Sandeen) [1010071]
- [fs] btrfs: treewide: Add __GFP_NOWARN to k.alloc calls with v.alloc fallbacks (Eric Sandeen) [1010071]
- [fs] btrfs: don't loop on large offsets in readdir (Eric Sandeen) [1010071]
- [fs] btrfs: check to see if root_list is empty before adding it to dead roots (Eric Sandeen) [1010071]
- [fs] btrfs: release both paths before logging dir/changed extents (Eric Sandeen) [1010071]
- [fs] btrfs: allow splitting of hole em's when dropping extent cache (Eric Sandeen) [1010071]
- [fs] btrfs: make sure the backref walker catches all refs to our extent (Eric Sandeen) [1010071]
- [fs] btrfs: fix backref walking when we hit a compressed extent (Eric Sandeen) [1010071]
- [fs] btrfs: do not offset physical if we're compressed (Eric Sandeen) [1010071]
- [fs] btrfs: fix extent buffer leak after backref walking (Eric Sandeen) [1010071]
- [fs] btrfs: fix a bug of snapshot-aware defrag to make it work on partial extents (Eric Sandeen) [1010071]
- [fs] btrfs: fix file truncation if FALLOC_FL_KEEP_SIZE is specified (Eric Sandeen) [1010071]
- [fs] btrfs: fix wrong write offset when replacing a device (Eric Sandeen) [1010071]
- [fs] btrfs: re-add root to dead root list if we stop dropping it (Eric Sandeen) [1010071]
- [fs] btrfs: fix lock leak when resuming snapshot deletion (Eric Sandeen) [1010071]
- [fs] btrfs: update drop progress before stopping snapshot dropping (Eric Sandeen) [1010071]
- [fs] btrfs: wait ordered range before doing direct io (Eric Sandeen) [1010071]
- [fs] btrfs: only do the tree_mod_log_free_eb if this is our last ref (Eric Sandeen) [1010071]
- [fs] btrfs: hold the tree mod lock in __tree_mod_log_rewind (Eric Sandeen) [1010071]
- [fs] btrfs: make backref walking code handle skinny metadata (Eric Sandeen) [1010071]
- [fs] btrfs: fix crash regarding to ulist_add_merge (Eric Sandeen) [1010071]
- [fs] btrfs: fix several potential problems in copy_nocow_pages_for_inode (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup the code of copy_nocow_pages_for_inode() (Eric Sandeen) [1010071]
- [fs] btrfs: fix oops when recovering the file data by scrub function (Eric Sandeen) [1010071]
- [fs] btrfs: make the chunk allocator completely tree lockless (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup orphaned root orphan item (Eric Sandeen) [1010071]
- [fs] btrfs: fix wrong mirror number tuning (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup redundant code in btrfs_submit_direct() (Eric Sandeen) [1010071]
- [fs] btrfs: remove btrfs_sector_sum structure (Eric Sandeen) [1010071]
- [fs] btrfs: check if we can nocow if we don't have data space (Eric Sandeen) [1010071]
- [fs] btrfs: stop using try_to_writeback_inodes_sb_nr to flush delalloc (Eric Sandeen) [1010071]
- [fs] btrfs: use a percpu to keep track of possibly pinned bytes (Eric Sandeen) [1010071]
- [fs] btrfs: check for actual acls rather than just xattrs when caching no acl (Eric Sandeen) [1010071]
- [fs] btrfs: move btrfs_truncate_page to btrfs_cont_expand instead of btrfs_truncate (Eric Sandeen) [1010071]
- [fs] btrfs: optimize reada_for_balance (Eric Sandeen) [1010071]
- [fs] btrfs: optimize read_block_for_search (Eric Sandeen) [1010071]
- [fs] btrfs: unlock extent range on enospc in compressed submit (Eric Sandeen) [1010071]
- [fs] btrfs: fix the comment typo for btrfs_attach_transaction_barrier (Eric Sandeen) [1010071]
- [fs] btrfs: fix not being able to find skinny extents during relocate (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup backref search commit root flag stuff (Eric Sandeen) [1010071]
- [fs] btrfs: free csums when we're done scrubbing an extent (Eric Sandeen) [1010071]
- [fs] btrfs: fix transaction throttling for delayed refs (Eric Sandeen) [1010071]
- [fs] btrfs: stop waiting on current trans if we aborted (Eric Sandeen) [1010071]
- [fs] btrfs: wake up delayed ref flushing waiters on abort (Eric Sandeen) [1010071]
- [fs] btrfs: fix the code comments for LZO compression workspace (Eric Sandeen) [1010071]
- [fs] btrfs: fix broken nocow after balance (Eric Sandeen) [1010071]
- [fs] btrfs: more open-coded file_inode() (Eric Sandeen) [1010071]
- [fs] btrfs: exclude logged extents before replying when we are mixed (Eric Sandeen) [1010071]
- [fs] btrfs: put our inode if orphan cleanup fails (Eric Sandeen) [1010071]
- [fs] btrfs: add some missing iput()'s in btrfs_orphan_cleanup (Eric Sandeen) [1010071]
- [fs] btrfs: do not pin while under spin lock (Eric Sandeen) [1010071]
- [fs] btrfs: Cocci spatch "memdup.spatch" (Eric Sandeen) [1010071]
- [fs] btrfs: Cocci spatch "ptr_ret.spatch" (Eric Sandeen) [1010071]
- [fs] btrfs: fix qgroup rescan resume on mount (Eric Sandeen) [1010071]
- [fs] btrfs: avoid double free of fs_info->qgroup_ulist (Eric Sandeen) [1010071]
- [fs] btrfs: fix memory patcher through fs_info->qgroup_ulist (Eric Sandeen) [1010071]
- [fs] btrfs: simplify unlink reservations (Eric Sandeen) [1010071]
- [fs] btrfs: merge pending IO for tree log write back (Eric Sandeen) [1010071]
- [fs] btrfs: allow file data clone within a file (Eric Sandeen) [1010071]
- [fs] btrfs: remove unused code in btrfs_del_root (Eric Sandeen) [1010071]
- [fs] btrfs: kill replicate code in replay_one_buffer (Eric Sandeen) [1010071]
- [fs] btrfs: check if leaf's parent exists before pushing items around (Eric Sandeen) [1010071]
- [fs] btrfs: update new flags for tracepoint (Eric Sandeen) [1010071]
- [fs] btrfs: dont do log_removal in insert_new_root (Eric Sandeen) [1010071]
- [fs] btrfs: return error code in btrfs_check_trunc_cache_free_space() (Eric Sandeen) [1010071]
- [fs] btrfs: fix estale with btrfs send (Eric Sandeen) [1010071]
- [fs] btrfs: device delete to get errors from the kernel (Eric Sandeen) [1010071]
- [fs] btrfs: do delay iput in sync_fs (Eric Sandeen) [1010071]
- [fs] btrfs: make the state of the transaction more readable (Eric Sandeen) [1010071]
- [fs] btrfs: remove the time check in btrfs_commit_transaction() (Eric Sandeen) [1010071]
- [fs] btrfs: remove unnecessary varient ->num_joined in btrfs_transaction structure (Eric Sandeen) [1010071]
- [fs] btrfs: don't flush the delalloc inodes in the while loop if flushoncommit is set (Eric Sandeen) [1010071]
- [fs] btrfs: don't wait for all the writers circularly during the transaction commit (Eric Sandeen) [1010071]
- [fs] btrfs: remove the code for the impossible case in cleanup_transaction() (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup unnecessary assignment when cleaning up all the residual transaction (Eric Sandeen) [1010071]
- [fs] btrfs: just flush the delalloc inodes in the source tree before snapshot creation (Eric Sandeen) [1010071]
- [fs] btrfs: introduce per-subvolume ordered extent list (Eric Sandeen) [1010071]
- [fs] btrfs: introduce per-subvolume delalloc inode list (Eric Sandeen) [1010071]
- [fs] btrfs: introduce grab/put functions for the root of the fs/file tree (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup the similar code of the fs root read (Eric Sandeen) [1010071]
- [fs] btrfs: make the snap/subv deletion end more early when the fs is R/O (Eric Sandeen) [1010071]
- [fs] btrfs: move the R/O check out of btrfs_clean_one_deleted_snapshot() (Eric Sandeen) [1010071]
- [fs] btrfs: make the cleaner complete early when the fs is going to be umounted (Eric Sandeen) [1010071]
- [fs] btrfs: remove unnecessary ->s_umount in cleaner_kthread() (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup: don't check the same thing twice (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup, btrfs_read_fs_root_no_name() doesn't return NULL (Eric Sandeen) [1010071]
- [fs] btrfs: delete unused function (Eric Sandeen) [1010071]
- [fs] btrfs: remove useless copy in quota_ctl (Eric Sandeen) [1010071]
- [fs] btrfs: Minor format cleanup (Eric Sandeen) [1010071]
- [fs] btrfs: cleanup unused arguments in send.c (Eric Sandeen) [1010071]
- [fs] btrfs: add ioctl to wait for qgroup rescan completion (Eric Sandeen) [1010071]
- [fs] btrfs: introduce qgroup_ulist to avoid frequently allocating/freeing ulist (Eric Sandeen) [1010071]
- [fs] btrfs: show compiled-in config features at module load time (Eric Sandeen) [1010071]
- [fs] btrfs: move ifdef around sanity checks out of init_btrfs_fs (Eric Sandeen) [1010071]
- [fs] btrfs: add prefix to sanity tests messages (Eric Sandeen) [1010071]
- [fs] btrfs: add debug check for extent_io range alignment (Eric Sandeen) [1010071]
- [fs] btrfs: fix check on same raid type flag twice (Eric Sandeen) [1010071]
- [fs] btrfs: Fix typo in printk (Eric Sandeen) [1010071]
- [fs] btrfs: fix btrfs_extend_item() comment (Eric Sandeen) [1010071]

* Wed Oct 16 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-35.el7]
- [netdrv] mlx4: Fix handling of dma_map failure (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Notify user when TX ring in error state (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Disable global flow control when PFC enabled (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Coding style cleanup in mlx4_en_dcbnl_ieee_setpfc() (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Staticize local functions (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: VFs must ignore the enable_64b_cqe_eqe module param (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Don't give VFs MAC addresses which are derived from the PF MAC (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Respond to operation request by firmware (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Fix BlueFlame race (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: fix small memory leak on error (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Add HW enforcement to VF link state (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Dynamic VST to VST vlan/qos changes (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Fail device init if num_vfs is negative (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Add warning in case of command timeouts (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Replace sscanf() with kstrtoint() (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Remove an unnecessary test (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Add prints when TX timeout occurs (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Fix a race between napi poll function and RX ring cleanup (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Change log level from error to debug for vlan related messages (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Move register_netdev() to the end of initialization function (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Do not query stats when device port is down (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Fix resource leak in error flow (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: allow order-0 memory allocations in RX path (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Add support for busy poll (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Add VF link state support (Amir Vadai) [862498 868244 920465 978058 998202]
- [net] core: Add VF link state control (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: use __netdev_pick_tx instead of __skb_tx_hash in mlx4_en_select_queue (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: use one page fragment per incoming frame (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] ipoib: Fix pkey change flow for virtualization environments (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] ipoib: Make sure child devices use valid/proper pkeys (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Create QP1 using the pkey index which contains the default pkey (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] mlx4: Use default pkey when creating tunnel QPs (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Fix redundant pointer check in dealloc flow (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Fix possible memory leak in iser_create_frwr_pool() (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Introduce fast memory registration model (FRWR) (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Place the fmr pool into a union in iser's IB conn struct (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Handle unaligned SG in separate function (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Generalize rdma memory registration (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Accept session->cmds_max from user space (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Restructure allocation/deallocation of connection resources (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Use proper debug level value for info prints (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] iser: Add Discovery support (Amir Vadai) [862498 868244 920465 978058 998202]
- [scsi] libiscsi: Exporting new attrs for iscsi session and connection in sysfs (Amir Vadai) [862498 868244 920465 978058 998202]
- [scsi] scsi_transport_iscsi: Exporting new attrs for iscsi session and connection in sysfs (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Better checking of userspace values for receive flow steering (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] mlx4: Add receive flow steering support (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Export ib_create/destroy_flow through uverbs (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Infrastructure for extensible uverbs commands (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Add receive flow steering support (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Fixes to XRC reference counting in uverbs (Amir Vadai) [862498 868244 920465 978058 998202]
- [infiniband] core: Add locking around event dispatching on XRC target QPs (Amir Vadai) [862498 868244 920465 978058 998202]
- [netdrv] mlx4: Fix XRC QPs detection in the resource tracker (Amir Vadai) [862498 868244 920465 978058 998202]
- [powerpc] irq: Don't switch to irq stack from softirq stack (Steve Best) [1016454]
- [powerpc] hvsi: Increase handshake timeout from 200ms to 400ms (Steve Best) [1012654]
- [powerpc] zimage: make the "OF" wrapper support ePAPR boot (Steve Best) [1012654]
- [powerpc] pseries: Do not start secondaries in Open Firmware (Steve Best) [1012654]
- [powerpc] Make prom_init.c endian safe (Steve Best) [1012654]
- [powerpc] Remove ksp_limit on ppc64 (Steve Best) [1012654]
- [powerpc] irq: Run softirqs off the top of the irq stack (Steve Best) [1012654]
- [mm] avoid reinserting isolated balloon pages into LRU lists (Rafael Aquini) [1017445]
- [kernel] sched: fix race in migrate_swap_stop (Rik van Riel) [683513]
- [kernel] sched/numa: Retry task_numa_migrate() periodically (Rik van Riel) [683513]
- [kernel] sched/numa: Use unsigned longs for numa group fault stats (Rik van Riel) [683513]
- [kernel] sched/numa: Skip some page migrations after a shared fault (Rik van Riel) [683513]
- [kernel] sched/numa: Remove the numa_balancing_scan_period_reset sysctl (Rik van Riel) [683513]
- [kernel] sched/numa: Adjust scan rate in task_numa_placement (Rik van Riel) [683513]
- [kernel] sched/numa: Take false sharing into account when adapting scan rate (Rik van Riel) [683513]
- [kernel] sched/numa: Be more careful about joining numa groups (Rik van Riel) [683513]
- [kernel] sched/numa: Avoid migrating tasks that are placed on their preferred node (Rik van Riel) [683513]
- [kernel] sched/numa: Fix task or group comparison (Rik van Riel) [683513]
- [kernel] sched/numa: Decide whether to favour task or group weights based on swap candidate relationships (Rik van Riel) [683513]
- [kernel] sched/numa: Add debugging (Rik van Riel) [683513]
- [kernel] sched/numa: Prevent parallel updates to group stats during placement (Rik van Riel) [683513]
- [kernel] sched/numa: Call task_numa_free() from do_execve () (Rik van Riel) [683513]
- [kernel] sched/numa: Use group fault statistics in numa placement (Rik van Riel) [683513]
- [kernel] sched/numa: Stay on the same node if CLONE_VM (Rik van Riel) [683513]
- [mm] numa: Do not batch handle PMD pages (Rik van Riel) [683513]
- [mm] numa: Do not group on RO pages (Rik van Riel) [683513]
- [mm] numa: Copy cpupid on page migration (Rik van Riel) [683513]
- [kernel] sched/numa: Report a NUMA task group ID (Rik van Riel) [683513]
- [kernel] sched/numa: Use {cpu, pid} to create task groups for shared faults (Rik van Riel) [683513]
- [mm] numa: Change page last {nid, pid} into {cpu, pid} (Rik van Riel) [683513]
- [kernel] sched/numa: Fix placement of workloads spread across multiple nodes (Rik van Riel) [683513]
- [kernel] sched/numa: Favor placing a task on the preferred node (Rik van Riel) [683513]
- [kernel] sched/numa: Use a system-wide search to find swap/migration candidates (Rik van Riel) [683513]
- [kernel] sched/numa: Introduce migrate_swap() (Rik van Riel) [683513]
- [kernel] stop_machine: Introduce stop_two_cpus() (Rik van Riel) [683513]
- [mm] numa: Trap pmd hinting faults only if we would otherwise trap PTE faults (Rik van Riel) [683513]
- [kernel] sched/numa: Do not trap hinting faults for shared libraries (Rik van Riel) [683513]
- [kernel] sched/numa: Increment numa_migrate_seq when task runs in correct location (Rik van Riel) [683513]
- [kernel] sched/numa: Retry migration of tasks to CPU on a preferred node (Rik van Riel) [683513]
- [kernel] sched/numa: Avoid overloading CPUs on a preferred NUMA node (Rik van Riel) [683513]
- [kernel] numa: Limit NUMA scanning to migrate-on-fault VMAs (Rik van Riel) [683513]
- [kernel] sched/numa: Do not migrate memory immediately after switching node (Rik van Riel) [683513]
- [mm] sched/numa: Set preferred NUMA node based on number of private faults (Rik van Riel) [683513]
- [kernel] sched/numa: Remove check that skips small VMAs (Rik van Riel) [683513]
- [mm] numa: Scan pages with elevated page_mapcount (Rik van Riel) [683513]
- [kernel] sched/numa: Check current-> mm before allocating NUMA faults (Rik van Riel) [683513]
- [kernel] sched/numa: Add infrastructure for split shared/ private accounting of NUMA hinting faults (Rik van Riel) [683513]
- [kernel] sched/numa: Reschedule task on preferred NUMA node once selected (Rik van Riel) [683513]
- [kernel] sched/numa: Resist moving tasks towards nodes with fewer hinting faults (Rik van Riel) [683513]
- [kernel] sched/numa: Favour moving tasks towards the preferred node (Rik van Riel) [683513]
- [kernel] sched/numa: Update NUMA hinting faults once per scan (Rik van Riel) [683513]
- [kernel] sched/numa: Select a preferred node with the most numa hinting faults (Rik van Riel) [683513]
- [mm] sched/numa: Track NUMA hinting faults on per-node basis (Rik van Riel) [683513]
- [mm] sched/numa: Slow scan rate if no NUMA hinting faults are being recorded (Rik van Riel) [683513]
- [mm] sched/numa: Set the scan rate proportional to the memory usage of the task being scanned (Rik van Riel) [683513]
- [mm] sched/numa: Initialise numa_next_scan properly (Rik van Riel) [683513]
- [mm] sched/numa: Continue PTE scanning even if migrate rate limited (Rik van Riel) [683513]
- [mm] sched/numa: Mitigate chance that same task always updates PTEs (Rik van Riel) [683513]
- [mm] numa: Do not migrate or account for hinting faults on the zero page (Rik van Riel) [683513]
- [mm] Only flush TLBs if a transhuge PMD is modified for NUMA pte scanning (Rik van Riel) [683513]
- [mm] Do not flush TLB during protection change if !pte_present && !migration_entry (Rik van Riel) [683513]
- [mm] Account for a THP NUMA hinting update as one PTE update (Rik van Riel) [683513]
- [mm] Close races between THP migration and PMD numa clearing (Rik van Riel) [683513]
- [mm] numa: Sanitize task_numa_fault() callsites (Rik van Riel) [683513]
- [mm] Prevent parallel splits during THP migration (Rik van Riel) [683513]
- [mm] Wait for THP migrations to complete during NUMA hinting faults (Rik van Riel) [683513]
- [mm] numa: Do not account for a hinting fault if we raced (Rik van Riel) [683513]
- [mm] sched/numa: Fix comments (Rik van Riel) [683513]
- [mm] numa: Document automatic NUMA balancing sysctls (Rik van Riel) [683513]
- [kernel] sched: monolithic code dump of what is being pushed (Rik van Riel) [683513]
- [kernel] sched: Use an accessor to read the rq clock (Rik van Riel) [683513]
- [kernel] sched: fix NUMA balancing when !SCHED_DEBUG (Rik van Riel) [683513]
- [kernel] sched: Ensure update_cfs_shares() is called for parents of continuously-running tasks (Rik van Riel) [683513]
- [kernel] sched: Fix some kernel-doc warnings (Rik van Riel) [683513]
- [virt] kvm/vmx: do not check bit 12 of EPT violation exit qualification when undefined (Gleb Natapov) [1009441]
- [virt] kvm/vmx: set "blocked by NMI" flag if EPT violation happens during IRET from NMI (Gleb Natapov) [1009441]

* Fri Oct 11 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-34.el7]
- [netdrv] netxen_nic: Update version to 4.0.81 (Chad Dupuis) [725019]
- [netdrv] netxen_nic: clean up unnecessary MSI/MSI-X capability find (Chad Dupuis) [725019]
- [netdrv] netxen_nic: Convert mac address uses of 6 to ETH_ALEN (Chad Dupuis) [725019]
- [netdrv] netxen_nic: replace strict_strtoul() with kstrtoul() (Chad Dupuis) [725019]
- [netdrv] netxen_nic: Avoid mixed mode interrupts (Chad Dupuis) [725019]
- [netdrv] netxen_nic: netxen_setup_intr() function code cleanup (Chad Dupuis) [725019]
- [netdrv] netxen_nic: Log proper error message in case of mismatched adapter type (Chad Dupuis) [725019]
- [netdrv] netxen_nic: Log driver version with firmware version (Chad Dupuis) [725019]
- [tools] perf/diff: Add generic order option for compute sorting (Jiri Olsa) [1011529]
- [tools] perf/diff: Making compute functions static (Jiri Olsa) [1011529]
- [tools] perf/diff: Update perf diff documentation for multiple data comparison (Jiri Olsa) [1011529]
- [tools] perf/diff: Change diff command to work over multiple data files (Jiri Olsa) [1011529]
- [tools] perf/diff: Move columns into struct data__file (Jiri Olsa) [1011529]
- [tools] perf/diff: Move diff related columns into diff command (Jiri Olsa) [1011529]
- [tools] perf/diff: Display data file info ahead of the diff output (Jiri Olsa) [1011529]
- [tools] perf/hists: Marking dummy hists entries (Jiri Olsa) [1011529]
- [tools] perf/diff: Switching the base hists to be pairs head (Jiri Olsa) [1011529]
- [tools] perf/diff: Introducing diff_data object to hold files (Jiri Olsa) [1011529]
- [tools] perf: Centralize default columns init in perf_hpp__init (Jiri Olsa) [1011529]
- [tools] perf: Add struct perf_hpp_fmt into hpp callbacks (Jiri Olsa) [1011529]
- [s390] vmcore: use vmcore for zfcpdump (Hendrik Brueckner) [1012102]
- [fs] proc/vmcore: enable /proc/vmcore mmap for s390 (Hendrik Brueckner) [1012102]
- [s390] vmcore: implement remap_oldmem_pfn_range for s390 (Hendrik Brueckner) [1012102]
- [fs] proc/vmcore: introduce remap_oldmem_pfn_range() (Hendrik Brueckner) [1012102]
- [s390] vmcore: use ELF header in new memory feature (Hendrik Brueckner) [1012102]
- [fs] proc/vmcore: introduce ELF header in new memory feature (Hendrik Brueckner) [1012102]
- [fs] proc/vmcore: Disable mmap for s390 (Hendrik Brueckner) [1012102]
- [s390] kdump: Allow copy_oldmem_page() copy to virtual memory (Hendrik Brueckner) [1012102]
- [tracing] Add function probe to trigger a ftrace dump of current CPU trace (Jiri Olsa) [1011527]
- [tracing] Add function probe to trigger a ftrace dump to console (Jiri Olsa) [1011527]
- [virt] xen-gnt: prevent adding duplicate gnt callbacks (Radim Krcmar) [1013818]
- [x86] microcode_amd: Fix patch level reporting for family 15h (Prarit Bhargava) [1014400]
- [tty] Fix SIGTTOU not sent with tcflush() (Oleg Nesterov) [1012397]
- [powerpc] sysfs: Disable writing to PURR in guest mode (Steve Best) [1015450]
- [powerpc] vio: fix modalias_show return values (Prarit Bhargava) [1007924]
- [powerpc] Correct FSCR bit definitions (Steve Best) [1008893]
- [x86] microcode/amd: Fix early microcode loading (Jarod Wilson) [1016168]
- [x86] microcode/amd: Make cpu_has_amd_erratum() use the correct struct cpuinfo_x86 (Jarod Wilson) [1016168]
- [x86] microcode/amd: Fix error path in apply_microcode_amd() (Jarod Wilson) [1016168]
- [x86] microcode/amd: Another early loading fixup (Jarod Wilson) [1016168]
- [x86] microcode/amd: Allow multiple families' bin files appended together (Jarod Wilson) [1016168]
- [x86] microcode/amd: Make find_ucode_in_initrd() __init (Jarod Wilson) [1016168]
- [x86] microcode/amd: Fix warnings and errors on with CONFIG_MICROCODE=m (Jarod Wilson) [1016168]
- [x86] microcode/amd: Early microcode patch loading support for AMD (Jarod Wilson) [1016168]
- [x86] microcode/amd: Refactor functions to prepare for early loading (Jarod Wilson) [1016168]
- [x86] microcode: Vendor abstract out save_microcode_in_initrd() (Jarod Wilson) [1016168]
- [x86] microcode/intel: Correct typo in printk (Jarod Wilson) [1016168]
- [block] nvme: Update nvme_id_power_state with latest spec (David Milburn) [1005908]
- [block] nvme: Split header file into user-visible and kernel-visible pieces (David Milburn) [1005908]
- [block] nvme: Merge issue on character device bring-up (David Milburn) [1005908]
- [block] nvme: Handle ioremap failure (David Milburn) [1005908]
- [block] nvme: Add pci suspend/resume driver callbacks (David Milburn) [1005908]
- [block] nvme: Use normal shutdown (David Milburn) [1005908]
- [block] nvme: Separate controller init from disk discovery (David Milburn) [1005908]
- [block] nvme: Separate queue alloc/free from create/delete (David Milburn) [1005908]
- [block] nvme: Group pci related actions in functions (David Milburn) [1005908]
- [block] nvme: Disk stats for read/write commands only (David Milburn) [1005908]
- [block] nvme: Bring up cdev on set feature failure (David Milburn) [1005908]
- [block] nvme: Fix checkpatch issues (David Milburn) [1005908]
- [block] nvme: Namespace IDs are unsigned (David Milburn) [1005908]
- [block] nvme: Call nvme_process_cq from submission path (David Milburn) [1005908]
- [block] nvme: Remove "process_cq did something" message (David Milburn) [1005908]
- [block] nvme: Return correct value from interrupt handler (David Milburn) [1005908]
- [block] nvme: Disk IO statistics (David Milburn) [1005908]
- [block] nvme: Restructure MSI / MSI-X setup (David Milburn) [1005908]
- [block] nvme: Use kzalloc instead of kmalloc+memset (David Milburn) [1005908]

* Fri Oct 04 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-33.el7]
- [fs] nfs: Give "flavor" an initial value to fix a compile warning (Jeff Layton) [1009119]
- [fs] nfs: try SECINFO_NO_NAME flavs until one works (Jeff Layton) [1009119]
- [fs] nfs: Ensure memory ordering between nfs4_ds_connect and nfs4_fl_prepare_ds (Jeff Layton) [1009119]
- [fs] nfs: nfs4_fl_prepare_ds, fix bugs when the connect attempt fails (Jeff Layton) [1009119]
- [fs] nfs: Honour the 'opened' parameter in the atomic_open() filesystem method (Jeff Layton) [1009119]
- [net] sunrpc: rpcsec_gss, fix crash on destroying gss auth (Jeff Layton) [1009119]
- [net] sunrpc: No, I did not intend to create a 256KiB hashtable (Jeff Layton) [1009119]
- [net] sunrpc: Add missing kuids conversion for printing (Jeff Layton) [1009119]
- [fs] nfs: sp4_mach_cred, WARN_ON -> WARN_ON_ONCE (Jeff Layton) [1009119]
- [fs] nfs: sp4_mach_cred, no need to ref count creds (Jeff Layton) [1009119]
- [fs] nfs: fix SECINFO* use of put_rpccred (Jeff Layton) [1009119]
- [fs] nfs: sp4_mach_cred: ask for WRITE and COMMIT (Jeff Layton) [1009119]
- [fs] nfs: fix decode_free_stateid (Jeff Layton) [1009119]
- [fs] nfs: use mach cred for SECINFO_NO_NAME w/ integrity (Jeff Layton) [1009119]
- [fs] nfs: nfs_compare_super shouldn't check the auth flavour unless 'sec=' was set (Jeff Layton) [1009119]
- [fs] nfs: Allow security autonegotiation for submounts (Jeff Layton) [1009119]
- [fs] nfs: Disallow security negotiation for lookups when 'sec=' is specified (Jeff Layton) [1009119]
- [fs] nfs: Fix security auto-negotiation (Jeff Layton) [1009119]
- [fs] nfs: Clean up nfs_parse_security_flavors() (Jeff Layton) [1009119]
- [fs] nfs: Clean up the auth flavour array mess (Jeff Layton) [1009119]
- [fs] nfs: Use MDS auth flavor for data server connection (Jeff Layton) [1009119]
- [fs] nfs: Map NFS4ERR_WRONG_CRED to EPERM (Jeff Layton) [1009119]
- [fs] nfs: Add SP4_MACH_CRED write and commit support (Jeff Layton) [1009119]
- [fs] nfs: Add SP4_MACH_CRED stateid support (Jeff Layton) [1009119]
- [fs] nfs: Add SP4_MACH_CRED secinfo suppor (Jeff Layton) [1009119]
- [fs] nfs: Add SP4_MACH_CRED cleanup support (Jeff Layton) [1009119]
- [fs] nfs: Add state protection handler (Jeff Layton) [1009119]
- [fs] nfs: Minimal SP4_MACH_CRED implementation (Jeff Layton) [1009119]
- [net] sunrpc: Replace pointer values with task->tk_pid and rpc_clnt->cl_clid (Jeff Layton) [1009119]
- [net] sunrpc: Add an identifier for struct rpc_clnt (Jeff Layton) [1009119]
- [net] sunrpc: Ensure rpc_task->tk_pid is available for tracepoints (Jeff Layton) [1009119]
- [fs] nfs: Document the recover_lost_locks kernel parameter (Jeff Layton) [1009119]
- [fs] nfs: Don't try to recover NFSv4 locks when they are lost (Jeff Layton) [1009119]
- [net] sunrpc: Add tracepoints to help debug socket connection issues (Jeff Layton) [1009119]
- [fs] nfs: Fix warning introduced by NFSv4.0 transport blocking patches (Jeff Layton) [1009119]
- [fs] nfs: fix CONFIG_NFS_V4_1 not enabled "make C=2" warning (Jeff Layton) [1009119]
- [fs] nfs: Update session draining barriers for NFSv4.0 transport blocking (Jeff Layton) [1009119]
- [fs] nfs: Add nfs4_sequence calls for OPEN_CONFIRM (Jeff Layton) [1009119]
- [fs] nfs: Add nfs4_sequence calls for RELEASE_LOCKOWNER (Jeff Layton) [1009119]
- [fs] nfs: Enable nfs4_setup_sequence() for DELEGRETURN (Jeff Layton) [1009119]
- [fs] nfs: NFSv4.0 transport blocking (Jeff Layton) [1009119]
- [fs] nfs: Add a slot table to struct nfs_client for NFSv4.0 transport blocking (Jeff Layton) [1009119]
- [fs] nfs: Add global helper for releasing slot table resources (Jeff Layton) [1009119]
- [fs] nfs: Add global helper to set up a stand-along nfs4_slot_table (Jeff Layton) [1009119]
- [fs] nfs: Enable slot table helpers for NFSv4.0 (Jeff Layton) [1009119]
- [fs] nfs: Remove unused call_sync minor version op (Jeff Layton) [1009119]
- [fs] nfs: Add RPC callouts to start NFSv4.0 synchronous requests (Jeff Layton) [1009119]
- [fs] nfs: Common versions of sequence helper functions (Jeff Layton) [1009119]
- [fs] nfs: Clean up nfs4_setup_sequence() (Jeff Layton) [1009119]
- [fs] nfs: Rename nfs41_call_sync_data as a common data structure (Jeff Layton) [1009119]
- [fs] nfs: When displaying session slot numbers, use "u" consistently (Jeff Layton) [1009119]
- [fs] nfs: Ensure that rmdir() waits for sillyrenames to complete (Jeff Layton) [1009119]
- [fs] nfs: use the mach cred for SECINFO w/ integrity (Jeff Layton) [1009119]
- [net] sunrpc: refactor rpcauth_checkverf error returns (Jeff Layton) [1009119]
- [fs] nfs: avoid expired credential keys for buffered writes (Jeff Layton) [1009119]
- [net] sunrpc: new rpc_credops to test credential expiry (Jeff Layton) [1009119]
- [net] sunrpc: don't map EKEYEXPIRED to EACCES in call_refreshresult (Jeff Layton) [1009119]
- [fs] nfs: Fix up two use-after-free issues with the new tracing code (Jeff Layton) [1009119]
- [fs] nfs: remove incorrect "Lock reclaim failed!" warning (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging test_stateid events (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging slot table operations (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging layoutget/return/commit (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging reads and writes (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging getattr (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging the idmapper (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging delegations (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging rename (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging inode manipulations (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging lookup/create operations (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging file locking (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging file open (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging state management problems (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging NFS hard links (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging NFS rename and sillyrename issues (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging directory changes (Jeff Layton) [1009119]
- [fs] nfs: Add tracepoints for debugging generic file create events (Jeff Layton) [1009119]
- [fs] nfs: Add event tracing for generic NFS lookups (Jeff Layton) [1009119]
- [fs] nfs: Pass in lookup flags from nfs_atomic_open to nfs_lookup (Jeff Layton) [1009119]
- [fs] nfs: Add event tracing for generic NFS events (Jeff Layton) [1009119]
- [fs] nfs: refactor code for calculating the crc32 hash of a filehandle (Jeff Layton) [1009119]
- [fs] nfs: Clean up nfs_sillyrename() (Jeff Layton) [1009119]
- [fs] nfs: Fix an incorrect pointer declaration in decode_first_pnfs_layout_type (Jeff Layton) [1009119]
- [fs] nfs: Deal with a sparse warning in nfs_idmap_get_key() (Jeff Layton) [1009119]
- [fs] nfs: Deal with some more sparse warnings (Jeff Layton) [1009119]
- [fs] nfs: Deal with a sparse warning in nfs4_opendata_alloc (Jeff Layton) [1009119]
- [fs] nfs: Deal with a sparse warning in nfs3_proc_create (Jeff Layton) [1009119]
- [fs] nfs: Remove the NFSv4 "open optimisation" from nfs_permission (Jeff Layton) [1009119]
- [fs] nfs: Use clientid management rpc_clnt for secinfo_no_name (Jeff Layton) [1009119]
- [fs] nfs: Use clientid management rpc_clnt for secinfo (Jeff Layton) [1009119]
- [fs] nfs: Increase NFS4_DEF_SLOT_TABLE_SIZE (Jeff Layton) [1009119]
- [fs] nfs: Remove unused authflavour parameter from init_client (Jeff Layton) [1009119]
- [fs] nfs: Never use user credentials for lease renewal (Jeff Layton) [1009119]
- [fs] nfs: Use root's credential for lease management when keytab is missing (Jeff Layton) [1009119]
- [fs] nfs: Refuse mount attempts with proto=udp (Jeff Layton) [1009119]
- [fs] nfs: Fix nfs4_init_uniform_client_string for net namespaces (Jeff Layton) [1009119]
- [fs] nfs: Use the mount point rpc_clnt for layoutreturn (Jeff Layton) [1009119]
- [fs] nfs: Fix return type of nfs4_end_drain_session() stub (Jeff Layton) [1009119]
- [fs] nfs: encode_attrs should not backfill the bitmap and attribute length (Jeff Layton) [1009119]
- [net] sunrpc: Fix memory corruption issue on 32-bit highmem systems (Jeff Layton) [1009119]
- [fs] nfs: Remove unnecessary call to nfs_setsecurity in nfs_fhget() (Jeff Layton) [1009119]
- [fs] nfs: Fix the sync mount option for nfs4 mounts (Jeff Layton) [1009119]
- [fs] nfs: Fix writeback performance issue on cache invalidation (Jeff Layton) [1009119]
- [net] sunrpc: If the rpcbind channel is disconnected, fail the call to unregister (Jeff Layton) [1009119]
- [net] sunrpc: Don't auto-disconnect from the local rpcbind socket (Jeff Layton) [1009119]
- [hid] zeroplus: validate output report details (Frantisek Hrbata) [999907] {CVE-2013-2889}
- [hid] provide a helper for validating hid reports (Frantisek Hrbata) [999907] {CVE-2013-2889}
- [s390] zfcp: enable FCP hardware data router by default (Hendrik Brueckner) [980146]
- [scsi] csiostor: fix failure to communicate with firmware, error -110 (Jay Fenlason) [917907]
- [block] mtip32xx: add SRSI support (David Milburn) [842533]
- [misc] hpilo: Correct panic when an AUX iLO is detected (Nigel Croxon) [996603]
- [Documentation] add write up on module signing (Kyle McMartin) [905495]
- [net] netfilter: SYNPROXY: let unrelated packets continue (Jesper Brouer) [1007439]
- [net] netfilter: synproxy_core: fix warning in __nf_ct_ext_add_length() (Jesper Brouer) [1007439]
- [net] netfilter: more strict TCP flag matching in SYNPROXY (Jesper Brouer) [1007439]
- [net] netfilter: add IPv6 SYNPROXY target (Jesper Brouer) [1007439]
- [net] syncookies: export cookie_v6_init_sequence/cookie_v6_check (Jesper Brouer) [1007439]
- [net] netfilter: add SYNPROXY core/target (Jesper Brouer) [1007439]
- [net] syncookies: export cookie_v4_init_sequence/cookie_v4_check (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: make sequence number adjustments usuable without NAT (Jesper Brouer) [1007439]
- [net] netfilter: nf_defrag_ipv6.o included twice (Jesper Brouer) [1007439]
- [net] netfilter: ip[6]t_REJECT, tcp-reset using wrong MAC source if bridged (Jesper Brouer) [1007439]
- [net] netfilter: export xt_HMARK.h to userland (Jesper Brouer) [1007439]
- [net] netfilter: export xt_rpfilter.h to userland (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: fix uninitialized variable (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_queue: allow to attach expectations to conntracks (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: refactor ctnetlink_create_expect (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: fix tcp_in_window for Fast Open (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: don't send destroy events from iterator (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_{log, queue}, fix information leaks in netlink message (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPMSS: correct return value in tcpmss_mangle_packet (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPOPTSTRIP: fix possible off by one access (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPMSS: fix handling of malformed TCP header and options (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: use per-conntrack locking for sequence number adjustments (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: change sequence number adjustments to 32 bits (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: fix locking in nf_nat_seq_adjust() (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: remove duplicate code in ctnetlink (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: constify sk_buff argument to nf_ct_attach() (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: remove net_ratelimit() for LOG_INVALID() (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: fix incorrect NAT expectation dumping (Jesper Brouer) [1007439]
- [net] netfilter: Fix build errors with xt_socket.c (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: fix broken v0 support (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: add XT_SOCKET_NOWILDCARD flag (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: avoid large timeout for mid-stream pickup (Jesper Brouer) [1007439]
- [net] netfilter: check return code from nla_parse_tested (Jesper Brouer) [1007439]
- [net] Convert uses of typedef ctl_table to struct ctl_table (Jesper Brouer) [1007439]
- [net] netfilter: Implement RFC 1123 for FTP conntrack (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_queue: avoid peer_portid test (Jesper Brouer) [1007439]
- [net] netfilter: don't panic on error while walking through the init path (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: use IP early demux (Jesper Brouer) [1007439]
- [net] netfilter: xt_CT: optimize XT_CT_NOTRACK (Jesper Brouer) [1007439]
- [net] qdisc: fix build with !CONFIG_NET_SCHED (Jesper Brouer) [1000395]
- [net] qdisc: make args to qdisc_create_default const (Jesper Brouer) [1000395]
- [net] qdisc: allow setting default queuing discipline (Jesper Brouer) [1000395]
- [net] Remove extern from include/net/ scheduling prototypes (Jesper Brouer) [1000395]
- [net] htb: fix sign extension bug (Jesper Brouer) [1000395]
- [net] htb: refactor struct htb_sched fields for performance (Jesper Brouer) [1000395]
- [net] htb: reorder struct htb_class fields for performance (Jesper Brouer) [1000395]
- [net] htb: do not setup default rate estimators (Jesper Brouer) [1000395]
- [net] net_sched: add 64bit rate estimators (Jesper Brouer) [1000395]

* Fri Oct 04 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-32.el7]
- [net] netfilter: SYNPROXY: let unrelated packets continue (Jesper Brouer) [1007439]
- [net] netfilter: synproxy_core: fix warning in __nf_ct_ext_add_length() (Jesper Brouer) [1007439]
- [net] netfilter: more strict TCP flag matching in SYNPROXY (Jesper Brouer) [1007439]
- [net] netfilter: add IPv6 SYNPROXY target (Jesper Brouer) [1007439]
- [net] syncookies: export cookie_v6_init_sequence/cookie_v6_check (Jesper Brouer) [1007439]
- [net] netfilter: add SYNPROXY core/target (Jesper Brouer) [1007439]
- [net] syncookies: export cookie_v4_init_sequence/cookie_v4_check (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: make sequence number adjustments usuable without NAT (Jesper Brouer) [1007439]
- [net] netfilter: nf_defrag_ipv6.o included twice (Jesper Brouer) [1007439]
- [net] netfilter: ip[6]t_REJECT, tcp-reset using wrong MAC source if bridged (Jesper Brouer) [1007439]
- [net] netfilter: export xt_HMARK.h to userland (Jesper Brouer) [1007439]
- [net] netfilter: export xt_rpfilter.h to userland (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: fix uninitialized variable (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_queue: allow to attach expectations to conntracks (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: refactor ctnetlink_create_expect (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: fix tcp_in_window for Fast Open (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: don't send destroy events from iterator (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_{log, queue}, fix information leaks in netlink message (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPMSS: correct return value in tcpmss_mangle_packet (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPOPTSTRIP: fix possible off by one access (Jesper Brouer) [1007439]
- [net] netfilter: xt_TCPMSS: fix handling of malformed TCP header and options (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: use per-conntrack locking for sequence number adjustments (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: change sequence number adjustments to 32 bits (Jesper Brouer) [1007439]
- [net] netfilter: nf_nat: fix locking in nf_nat_seq_adjust() (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: remove duplicate code in ctnetlink (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: constify sk_buff argument to nf_ct_attach() (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: remove net_ratelimit() for LOG_INVALID() (Jesper Brouer) [1007439]
- [net] netfilter: ctnetlink: fix incorrect NAT expectation dumping (Jesper Brouer) [1007439]
- [net] netfilter: Fix build errors with xt_socket.c (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: fix broken v0 support (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: add XT_SOCKET_NOWILDCARD flag (Jesper Brouer) [1007439]
- [net] netfilter: nf_conntrack: avoid large timeout for mid-stream pickup (Jesper Brouer) [1007439]
- [net] netfilter: check return code from nla_parse_tested (Jesper Brouer) [1007439]
- [net] Convert uses of typedef ctl_table to struct ctl_table (Jesper Brouer) [1007439]
- [net] netfilter: Implement RFC 1123 for FTP conntrack (Jesper Brouer) [1007439]
- [net] netfilter: nfnetlink_queue: avoid peer_portid test (Jesper Brouer) [1007439]
- [net] netfilter: don't panic on error while walking through the init path (Jesper Brouer) [1007439]
- [net] netfilter: xt_socket: use IP early demux (Jesper Brouer) [1007439]
- [net] netfilter: xt_CT: optimize XT_CT_NOTRACK (Jesper Brouer) [1007439]
- [net] qdisc: fix build with !CONFIG_NET_SCHED (Jesper Brouer) [1000395]
- [net] qdisc: make args to qdisc_create_default const (Jesper Brouer) [1000395]
- [net] qdisc: allow setting default queuing discipline (Jesper Brouer) [1000395]
- [net] Remove extern from include/net/ scheduling prototypes (Jesper Brouer) [1000395]
- [net] htb: fix sign extension bug (Jesper Brouer) [1000395]
- [net] htb: refactor struct htb_sched fields for performance (Jesper Brouer) [1000395]
- [net] htb: reorder struct htb_class fields for performance (Jesper Brouer) [1000395]
- [net] htb: do not setup default rate estimators (Jesper Brouer) [1000395]
- [net] net_sched: add 64bit rate estimators (Jesper Brouer) [1000395]

* Mon Sep 30 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-31.el7]
- [watchdog] hpwdt: Patch to ignore auxilary iLO devices (Nigel Croxon) [996605]
- [s390] tx: allow program interruption filtering in user space (Hendrik Brueckner) [1006517]
- [block] add padding for kabi to block_device_operations (Don Zickus) [988500]
- [fs] gfs2: Don't flag consistency error if first mounter is a spectator (Robert S Peterson) [1004448]
- [tty] disassociate_ctty() sends the extra SIGCONT (Oleg Nesterov) [1011820]
- [x86] mm: Add memory tracking support for 1G hugepages (David Bulkow) [1000149]
- [tty] hvc_iucv: Disconnect IUCV connection when lowering DTR (Hendrik Brueckner) [1007571]
- [tty] hvc_console: Add DTR/RTS callback to handle HUPCL control (Hendrik Brueckner) [1007571]
- [netdrv] enic: update enic maintainers and driver (Stefan Assmann) [747385]
- [netdrv] enic: Exposing symbols for Cisco's low latency driver (Stefan Assmann) [747385]
- [netdrv] enic: Try DMA 64 first, then failover to DMA (Stefan Assmann) [747385]
- [netdrv] enic: record q_number and rss_hash for skb (Stefan Assmann) [747385]
- [netdrv] enic: Add multi tx support for enic (Stefan Assmann) [747385]
- [netdrv] enic: Generate notification of hardware crash (Stefan Assmann) [747385]
- [netdrv] enic: Add an interface for USNIC to interact with firmware (Stefan Assmann) [747385]
- [netdrv] enic: Adding support for Cisco Low Latency NIC (Stefan Assmann) [747385]
- [netdrv] enic: Move ethtool code to a separate file (Stefan Assmann) [747385]
- [netdrv] enic: release rtnl_lock on error-path (Stefan Assmann) [747385]
- [powerpc] perf: Power7 Update testing ABI to list CPI-stack events (Steve Best) [1009105]
- [powerpc] perf: Make Power7 events available for perf (Steve Best) [1009105]
- [powerpc] perf: fix a typo of a Power7 event name (Steve Best) [1009105]
- [tools] perf/tests: Add parse events tests for leader sampling (Jiri Olsa) [1011533]
- [tools] perf/tests: Add attr record group sampling test (Jiri Olsa) [1011533]
- [tools] perf: Add 'S' event/group modifier to read sample value (Jiri Olsa) [1011533]
- [tools] perf/evsel: Add PERF_SAMPLE_READ sample related processing (Jiri Olsa) [1011533]
- [tools] perf/evlist: Add perf_evlist__id2sid method to get event ID related data (Jiri Olsa) [1011533]
- [tools] perf/evlist: Fix event ID retrieval for group format read case (Jiri Olsa) [1011533]
- [tools] perf: Add support for parsing PERF_SAMPLE_READ sample type (Jiri Olsa) [1011533]
- [kernel] perf/evlist: Use PERF_EVENT_IOC_ID perf ioctl to read event id (Jiri Olsa) [1011533]
- [kernel] perf: Do not get values from disabled counters in group format read (Jiri Olsa) [1011533]
- [kernel] perf: Add PERF_EVENT_IOC_ID ioctl to return event ID (Jiri Olsa) [1011533]
- [kernel] add support for init_array constructors fix (Frantisek Hrbata) [824466]
- [kernel] add support for init_array constructors (Frantisek Hrbata) [824466]
- [kernel] gcov: compile specific gcov implementation based on gcc version (Frantisek Hrbata) [824466]
- [kernel] gcov: add support for gcc 47 gcov format fix 3 (Frantisek Hrbata) [824466]
- [kernel] gcov: add support for gcc 47 gcov format checkpatch fixes (Frantisek Hrbata) [824466]
- [kernel] gcov: add support for gcc 47 gcov format fix fix (Frantisek Hrbata) [824466]
- [kernel] gcov: add support for gcc 47 gcov format fix (Frantisek Hrbata) [824466]
- [kernel] gcov: add support for gcc 4.7 gcov format (Frantisek Hrbata) [824466]
- [kernel] gcov: move gcov structs definitions to a gcc version specific file (Frantisek Hrbata) [824466]

* Mon Sep 30 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-30.el7]
- [drm] qxl: add delayed fb operations (Dave Airlie) [1002056]
- [edac] Fix lockdep splat (Aristeu Rozanski) [967459]
- [mm] vmalloc: fix memleak in __vunmap (Jan Stancek) [1012358]
- [x86] perf_event_amd: Rework AMD PMU init code (Prarit Bhargava) [1000672]
- [md] dm: add reserved_bio_based_ios module parameter (Mike Snitzer) [1010450]
- [md] dm: add reserved_rq_based_ios module parameter (Mike Snitzer) [1010450]
- [md] dm: lower bio-based mempool reservation (Mike Snitzer) [1010450]
- [block] Add nr_bios to block_rq_remap tracepoint (Mike Snitzer) [1010450]
- [md] dm-mpath: disable WRITE SAME if it fails (Mike Snitzer) [987454]
- [md] dm-mpath: do not fail path on -ENOSPC (Mike Snitzer) [1010437]
- [scsi] Return ENODATA on medium error (Mike Snitzer) [1010437]
- [scsi] return ENOSPC on thin provisioning failure (Mike Snitzer) [1010437]
- [scsi] Set hostbyte status in scsi_check_sense() (Mike Snitzer) [1010437]
- [scsi] Document enhanced error codes (Mike Snitzer) [1010437]
- [md] dm-thin: do not expose non-zero discard limits if discards disabled (Mike Snitzer) [998421]
- [md] dm-snapshot: fix performance degradation due to small hash size (Mike Snitzer) [1010437]
- [md] dm-snapshot: workaround for a false positive lockdep warning (Mike Snitzer) [1010437]
- [md] dm-stripe: silence a couple sparse warnings (Mike Snitzer) [1010437]
- [md] dm-stats: fix possible counter corruption on 32-bit systems (Mike Snitzer) [1010437]
- [md] dm: add statistics support (Mike Snitzer) [1010437]
- [lib] math64: New separate div64_u64_rem helper (Mike Snitzer) [1010437]
- [md] dm-thin: always return -ENOSPC if no_free_space is set (Mike Snitzer) [1010437]
- [md] dm-ioctl: cleanup error handling in table_load (Mike Snitzer) [1010437]
- [md] dm-ioctl: increase granularity of type_lock when loading table (Mike Snitzer) [1010437]
- [md] dm-ioctl: prevent rename to empty name or uuid (Mike Snitzer) [1010437]
- [md] dm-thin: set pool read-only if breaking_sharing fails block allocation (Mike Snitzer) [1010437]
- [md] dm-thin: prefix pool error messages with pool device name (Mike Snitzer) [1010437]
- [md] dm: allow error target to replace bio-based and request-based targets (Mike Snitzer) [1010437]
- [md] dm-space-map: optimise sm_ll_dec and sm_ll_inc (Mike Snitzer) [1010437]
- [md] dm-btree: prefetch child nodes when walking tree for a dm_btree_del (Mike Snitzer) [1010437]
- [md] dm-btree: use pop_frame in dm_btree_del to cleanup code (Mike Snitzer) [1010437]
- [md] dm-cache: eliminate holes in cache structure (Mike Snitzer) [1010437]
- [md] dm-cache: fix stacking of geometry limits (Mike Snitzer) [1010437]
- [md] dm-thin: fix stacking of geometry limits (Mike Snitzer) [1010437]
- [md] dm-cache: add data block size limits to code and Documentation (Mike Snitzer) [1010437]
- [md] dm: stop using WQ_NON_REENTRANT (Mike Snitzer) [1010437]
- [md] dm-cache: avoid conflicting remove_mapping() in mq policy (Mike Snitzer) [1010437]
- [md] dm: optimize reorder structure (Mike Snitzer) [1010437]
- [md] dm: optimize use SRCU and RCU (Mike Snitzer) [1010437]
- [md] dm-bufio: submit writes outside lock (Mike Snitzer) [1010437]
- [md] dm-cache: fix arm link errors with inline (Mike Snitzer) [1010437]
- [md] dm-verity: use __ffs and __fls (Mike Snitzer) [1010437]
- [md] dm-flakey: correct ctr alloc failure mesg (Mike Snitzer) [1010437]
- [md] dm-verity: remove pointless comparison (Mike Snitzer) [1010437]
- [md] dm: use __GFP_HIGHMEM in __vmalloc (Mike Snitzer) [1010437]
- [md] dm-verity: fix inability to use a few specific devices sizes (Mike Snitzer) [1010437]
- [md] dm-ioctl: set noio flag to avoid __vmalloc deadlock (Mike Snitzer) [1010437]
- [md] dm-mpath: fix ioctl deadlock when no paths (Mike Snitzer) [1010437]
- [powerpc] Default arch idle could cede processor on pseries (Steve Best) [1008895]

* Wed Sep 25 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-29.el7]
- [s390] zfcp: remove access control tables interface (keep sysfs files) (Hendrik Brueckner) [1006516]
- [s390] zfcp: fix lock imbalance by reworking request queue locking (Hendrik Brueckner) [1006525]
- [s390] zfcp: fix schedule-inside-lock in scsi_device list loops (Hendrik Brueckner) [1006524]
- [x86] setup: avoid remapping data in parse_setup_data() (Nigel Croxon) [1004428]
- [hid] validate HID report id size (Frantisek Hrbata) [1000454] {CVE-2013-2888}
- [kernel] userns: prevent the use of user namespaces (Aristeu Rozanski) [993320]
- [crypto] x509: don't reject not-yet-valid keys (kyle mcmartin) [905910]
- [kernel] perf: Prevent race in unthrottling code (Jiri Olsa) [992941]
- [s390] pci: use adapter interrupt vector helpers (Hendrik Brueckner) [1005896]
- [s390] pci: cleanup function names (Hendrik Brueckner) [1005896]
- [s390] airq: introduce adapter interrupt vector helper (Hendrik Brueckner) [1005896]
- [s390] pci: use virtual memory for iommu bitmap (Hendrik Brueckner) [1005896]
- [s390] cio: fix unlocked access of global bitmap (Hendrik Brueckner) [1005896]
- [s390] pci: update function handle after resume from hibernate (Hendrik Brueckner) [1005896]
- [s390] pci: try harder to modify a function (Hendrik Brueckner) [1005896]
- [s390] pci: split lpf (Hendrik Brueckner) [1005896]
- [s390] hibernate: add early resume function (Hendrik Brueckner) [1005896]
- [s390] pci: add recover sysfs knob (Hendrik Brueckner) [1005896]
- [s390] pci: use claim_resource (Hendrik Brueckner) [1005896]
- [s390] pci/hotplug: convert to be builtin only (Hendrik Brueckner) [1005896]
- [s390] airq: simplify adapter interrupt code (Hendrik Brueckner) [1005896]
- [s390] qdio: cleanup chsc SADC usage (Hendrik Brueckner) [1005896]
- [s390] qdio: cleanup chsc SSQD usage (Hendrik Brueckner) [1005896]
- [s390] pci: remove per device debug attribute (Hendrik Brueckner) [1005896]
- [s390] pci: sysfs remove strlen (Hendrik Brueckner) [1005896]
- [s390] pci: remove pdev during unplug (Hendrik Brueckner) [1005896]
- [s390] pci: cleanup hotplug code (Hendrik Brueckner) [1005896]
- [s390] pci: implement pcibios_release_device (Hendrik Brueckner) [1005896]
- [s390] pci: use to_pci_dev (Hendrik Brueckner) [1005896]
- [netdrv] sfc: check for allocation failure (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Update copyright banners (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add support for Solarflare SFC9100 family (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Make efx_mcdi_{init, fini}() call efx_mcdi_drv_attach() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Allocate NVRAM partition ID range for PHY images (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add EF10 register and structure definitions (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Extend struct efx_tx_buffer to allow pushing option descriptors (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Use a global count of active queues instead of pending drains (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Prepare for RX scatter on EF10 (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Initialise IRQ moderation for all NIC types from efx_init_eventq() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Allow efx_nic_type::dimension_resources to fail (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Allow event queue initialisation to fail (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Document conditions for multicast replication vs filter replacement (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Implement asynchronous MCDI requests (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove unnecessary use of atomic_t (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Refactor efx_mcdi_rpc_start() and efx_mcdi_copyin() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add support for new board sensors (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Use extended MC_CMD_SENSOR_INFO and MC_CMD_READ_SENSORS (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Return an error code when a sensor is busy (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add support for reading packet length from prefix (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add TX merged completion counter (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Generalise packet hash lookup to support EF10 RX prefix (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rename EFX_PAGE_BLOCK_SIZE to EFX_VI_PAGE_SIZE and adjust comments (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove early call to efx_nic_type::reconfigure_mac in efx_reset_up() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: use MCDI epoch flag to improve MC reboot detection in the driver (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add EF10 support for TX/RX DMA error events handling (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add a function pointer to abstract write of host time into NIC shared memory (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: PTP MCDI requests need to initialise periph ID field (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Delegate MAC/NIC statistic description to efx_nic_type (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove driver-local struct ethtool_string (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove more left-overs from Falcon GMAC support (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move MTD operations into efx_nic_type (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move NIC-type-specific MTD partition date into separate structures (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Eliminate struct efx_mtd (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rename SPI stuff to show that it is Falcon-specific (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Cleanup Falcon-arch simple MAC filter state (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Define and use MCDI_POPULATE_DWORD_{1, 2, 3, 4, 5, 6, 7} (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add flag for stack-owned RX MAC filters (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Refactor Falcon-arch filter removal (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Make most filter operations NIC-type-specific (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Refactor Falcon-arch search limit reset (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Split Falcon-arch-specific and common filter state (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Extend and abstract efx_filter_spec to cover Huntington/EF10 (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Name the RX drop queue ID (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rename Falcon-arch filter implementation types and functions (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove unused filter_flags variables and efx_farch_filter_id_flags() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Do not assume efx_nic_type::ev_fini is idempotent (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: EFX_WORKAROUND_ALWAYS is really specific to Falcon-architecture (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Get rid of per-NIC-type phys_addr_channels and mem_map_size (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Update and improve kernel-doc for efx_mcdi_state & efx_mcdi_iface (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fix race in completion handling (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add support for MCDI v2 (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Update MCDI protocol definitions for EF10 (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Translate MCDI error numbers received in events (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move and rename Falcon/Siena common NIC operations (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Refactor queue teardown sequence to allow for EF10 flush behaviour (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove bogus call to efx_release_tx_buffers() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Stop RX refill before flushing RX queues (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Limit scope of a Falcon A1 IRQ workaround (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rework IRQ enable/disable (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Remove efx_process_channel_now() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rename Falcon-architecture register definitions (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Make struct efx_special_buffer less special (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add GFP flags to efx_nic_alloc_buffer() and make most callers allow blocking (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Make MCDI independent of Siena (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Make efx_mcdi_init() call efx_mcdi_handle_assertion() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Collect all MCDI port functions into mcdi_port.c (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move efx_mcdi_mac_reconfigure() to siena.c and rename (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move siena_reset_hw() and siena_map_reset_reason() into MCDI module (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Add and use MCDI_SET_QWORD() and MCDI_SET_ARRAY_QWORD() (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Ensure MCDI buffers, but not lengths, are dword aligned (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Use proper macros to declare and access MCDI arrays (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Introduce and use MCDI_CTL_SDU_LEN_MAX_V1 macro for Siena-specific code (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fill out the set of MCDI accessors (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Rationalise MCDI buffer accessors (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Introduce and use MCDI_DECLARE_BUF macro (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move more Falcon-specific code and definitions into falcon.c (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Move details of a Falcon bug workaround out of ethtool.c (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Use efx_mcdi_mon() to find efx_mcdi_mon structure from efx_nic (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: const-qualify source pointers for MMIO write functions (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fix lookup of default RX MAC filters when steered using ethtool (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Enable RX scatter for flows steered by RFS (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fix memory leak when discarding scattered packets (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Improve test for IOMMU in use (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fix IRQ cleanup in case of a probe failure (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Do not pass non-TCP packets into GRO code (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Define and set RX buffer flag for packets parsed as TCP (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Enable accelerated RFS on vlans (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Report software timestamping capabilities (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Increase size of RX SKB header area (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Enable RX checksum offload for packets not handled by GRO (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Fix EEH with legacy interrupts (Nikolay Aleksandrov) [1005248]
- [netdrv] sfc: Store port number in private data, not net_device::dev_id (Nikolay Aleksandrov) [1005248]

* Mon Sep 23 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-28.el7]
- [fs] namei: Add missing unlocks to error paths of mountpoint_last (Jeff Layton) [980172]
- [fs] autofs4: fix device ioctl mount lookup (Jeff Layton) [980172]
- [fs] namei: introduce kern_path_mountpoint() (Jeff Layton) [980172]
- [fs] namei: rename user_path_umountat() to user_path_mountpoint_at() (Jeff Layton) [980172]
- [fs] namei: take unlazy_walk() into umount_lookup_last() (Jeff Layton) [980172]
- [fs] vfs: allow umount to handle mountpoints without revalidating them (Jeff Layton) [980172]
- [acpi] apei: Soft-offline a page on firmware GHES notification (Janet Morgan) [984133]
- [acpi] apei: Add a boot option to disable ff mode for corrected errors (Janet Morgan) [984133]
- [mcheck] mce: Honour Firmware First for MCA banks listed in APEI HEST CMC (Janet Morgan) [984133]
- [fs] cifs: Respect epoch value from create lease context v2 (Sachin Prabhu) [1007981]
- [fs] cifs: Add create lease v2 context for SMB3 (Sachin Prabhu) [1007981]
- [fs] cifs: Move parsing lease buffer to ops struct (Sachin Prabhu) [1007981]
- [fs] cifs: Move creating lease buffer to ops struct (Sachin Prabhu) [1007981]
- [fs] cifs: Store lease state itself rather than a mapped oplock value (Sachin Prabhu) [1007981]
- [fs] cifs: Replace clientCanCache* bools with an integer (Sachin Prabhu) [1007981]
- [fs] cifs: quiet sparse compile warning (Sachin Prabhu) [1007981]
- [fs] cifs: Start using per session key for smb2/3 for signature generation (Sachin Prabhu) [1007981]
- [fs] cifs: Add a variable specific to NTLMSSP for key exchange (Sachin Prabhu) [1007981]
- [fs] cifs: Process post session setup code in respective dialect functions (Sachin Prabhu) [1007981]
- [fs] cifs: convert to use le32_add_cpu() (Sachin Prabhu) [1007981]
- [fs] cifs: Fix missing lease break (Sachin Prabhu) [1007981]
- [fs] cifs: Fix a memory leak when a lease break comes (Sachin Prabhu) [1007981]
- [fs] cifs: convert case-insensitive dentry ops to use new case conversion routines (Sachin Prabhu) [1007981]
- [fs] cifs: add new case-insensitive conversion routines that are based on wchar_t's (Sachin Prabhu) [1007981]
- [fs] cifs: Move and expand MAX_SERVER_SIZE definition (Sachin Prabhu) [1007981]
- [fs] cifs: Expand max share name length to 256 (Sachin Prabhu) [1007981]
- [fs] cifs: Move string length definitions to uapi (Sachin Prabhu) [1007981]
- [fs] cifs: Implement follow_link for nounix CIFS mounts (Sachin Prabhu) [1007981]
- [fs] cifs: Implement follow_link for SMB2 (Sachin Prabhu) [1007981]
- [fs] cifs: display iocharset= option in /proc/mounts (Sachin Prabhu) [1007981]
- [fs] cifs: create a new Documentation/ directory and move docfiles into it (Sachin Prabhu) [1007981]
- [fs] cifs: ensure that srv_mutex is held when dealing with ssocket pointer (Sachin Prabhu) [1007981]
- [fs] cifs: don't instantiate new dentries in readdir for inodes that need to be revalidated immediately (Sachin Prabhu) [1007981]
- [fs] cifs: set sb->s_d_op before calling d_make_root() (Sachin Prabhu) [1007981]
- [fs] cifs: file, initialize oparms.reconnect before using it (Sachin Prabhu) [1007981]
- [fs] cifs: Do not attempt to do cifs operations reading symlinks with SMB2 (Sachin Prabhu) [1007981]
- [fs] cifs: extend the buffer length enought for sprintf() using (Sachin Prabhu) [1007981]
- [fs] dlm: log an error for unmanaged lockspaces (David Teigland) [1008005]
- [acpi] acpi_ipmi, replace mutex with spin_lock_irqsave (Tony Camuso) [1007574]
- [kernel] sched: Micro-optimize the smart wake-affine logic (Larry Woodman) [947186]
- [kernel] sched: Implement smarter wake-affine logic (Larry Woodman) [947186]
- [net] sunrpc: rpcauth_create needs to know about rpc_clnt clone status (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Share all credential caches on a per-transport basis (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Share rpc_pipes when an rpc_clnt owns multiple rpcsec auth caches (Jeff Layton) [1002576]
- [net] sunrpc: Add a helper to allow sharing of rpc_pipefs directory objects (Jeff Layton) [1002576]
- [net] sunrpc: Remove the rpc_client->cl_dentry (Jeff Layton) [1002576]
- [fs] nfs: Convert idmapper to use the new framework for pipefs dentries (Jeff Layton) [1002576]
- [net] sunrpc: Remove the obsolete auth-only interface for pipefs dentry management (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Switch auth_gss to use the new framework for pipefs dentries (Jeff Layton) [1002576]
- [net] sunrpc: Add a framework to clean up management of rpc_pipefs directories (Jeff Layton) [1002576]
- [fs] nfs: Fix a potentially Oopsable condition in __nfs_idmap_unregister (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Fix an Oopsable condition when creating/destroying pipefs objects (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Further cleanups (Jeff Layton) [1002576]
- [net] sunrpc: Replace clnt->cl_principal (Jeff Layton) [1002576]
- [net] sunrpc: RPCSEC_GSS, Clean up upcall message allocation (Jeff Layton) [1002576]
- [net] sunrpc: Cleanup rpc_setup_pipedir (Jeff Layton) [1002576]
- [net] sunrpc: Remove unused struct rpc_clnt field cl_protname (Jeff Layton) [1002576]
- [net] sunrpc: Deprecate rpc_client->cl_protname (Jeff Layton) [1002576]
- [net] sunrpc/rpc_pipe: convert back to simple_dir_inode_operations (Jeff Layton) [1002576]
- [fs] libfs: make simple_lookup() usable for filesystems that set ->s_d_op (Jeff Layton) [1002576]
- [net] sunrpc: __rpc_lookup_create_exclusive, pass string instead of qstr (Jeff Layton) [1002576]
- [net] sunrpc: rpc_create_*_dir, don't bother with qstr (Jeff Layton) [1002576]

* Mon Sep 23 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-27.el7]
- [netdrv] i40e: include i40e in kernel proper (Stefan Assmann) [726825]
- [netdrv] i40e: debugfs interface (Stefan Assmann) [726825]
- [netdrv] i40e: init code and hardware support (Stefan Assmann) [726825]
- [netdrv] i40e: implement virtual device interface (Stefan Assmann) [726825]
- [netdrv] i40e: driver core headers (Stefan Assmann) [726825]
- [netdrv] i40e: driver ethtool core (Stefan Assmann) [726825]
- [netdrv] i40e: transmit, receive, and NAPI (Stefan Assmann) [726825]
- [netdrv] i40e: main driver core (Stefan Assmann) [726825]
- [netdrv] e1000e: balance semaphore put/get for 82573 (Dean Nelson) [726816]
- [netdrv] e1000e: resolve checkpatch JIFFIES_COMPARISON warning (Dean Nelson) [726816]
- [netdrv] e1000e: Avoid kernel crash during shutdown (Dean Nelson) [726816]
- [netdrv] e1000e: Add code to check for failure of pci_disable_link_state call (Dean Nelson) [726816]
- [netdrv] e1000e: cleanup whitespace in recent commit (Dean Nelson) [726816]
- [netdrv] e1000e: fix I217/I218 PHY initialization flow (Dean Nelson) [726816]
- [netdrv] e1000e: do not resume device from RPM suspend to read PHY status registers (Dean Nelson) [726816]
- [netdrv] e1000e: enable support for new device IDs (Dean Nelson) [726816]
- [netdrv] e1000e: ethtool unnecessarily takes device out of RPM suspend (Dean Nelson) [726816]
- [netdrv] e1000e: Tx hang on I218 when linked at 100Half and slow response at 10Mbps (Dean Nelson) [726816]
- [netdrv] e1000e: low throughput using 4K jumbos on I218 (Dean Nelson) [726816]
- [netdrv] e1000e: iAMT connections drop on driver unload when jumbo frames enabled (Dean Nelson) [726816]
- [netdrv] e1000e: disable ASPM L1 on 82583 (Dean Nelson) [726816]
- [netdrv] e1000e: Use marco instead of digit for defining e1000_rx_desc_packet_split (Dean Nelson) [726816]
- [netdrv] e1000e: Remove duplicate assignment of default rx/tx ring size (Dean Nelson) [726816]
- [netdrv] e1000e: restore call to pci_clear_master() (Dean Nelson) [726816]
- [netdrv] e1000e: Release mutex lock only if it has been initially acquired (Dean Nelson) [726816]
- [netdrv] e1000e: prevent warning from -Wunused-parameter (Dean Nelson) [726816]
- [netdrv] e1000e: cleanup whitespace (Dean Nelson) [726816]
- [netdrv] bna: Staticize local functions (Ivan Vecera) [978045]
- [netdrv] bna: switch to fixed_size_llseek() (Ivan Vecera) [978045]
- [fs] read_write: new helper, fixed_size_llseek() (Ivan Vecera) [978045]
- [netdrv] bna: Driver and Firmware Updated (Ivan Vecera) [978045]
- [netdrv] bna: Enahncement to Identify Default IOC Function (Ivan Vecera) [978045]
- [netdrv] bna: Fix Ucast Failure Handling (Ivan Vecera) [978045]
- [netdrv] bna: Clear Driver Config Flags When HW Resets (Ivan Vecera) [978045]
- [netdrv] tg3: Don't turn off led on 5719 serdes port 0 (Ivan Vecera) [1006987]
- [netdrv] tg3: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Ivan Vecera) [1006987]
- [netdrv] tg3: fix NULL pointer dereference in tg3_io_error_detected and tg3_io_slot_reset (Ivan Vecera) [1006987]
- [netdrv] tg3: clean up unnecessary MSI/MSI-X capability find (Ivan Vecera) [1006987]
- [netdrv] tg3: Fix warning from pci_disable_device() (Ivan Vecera) [1006987]
- [netdrv] tg3: Fix kernel crash (Ivan Vecera) [1006987]
- [netdrv] tg3: Update version to 3.133 (Ivan Vecera) [1006987]
- [netdrv] tg3: Fix UDP fragments treated as RMCP (Ivan Vecera) [1006987]
- [netdrv] tg3: Enable support for timesync gpio output (Ivan Vecera) [1006987]
- [netdrv] tg3: Implement the shutdown handler (Ivan Vecera) [1006987]
- [netdrv] tg3: Allow NVRAM programming when interface is down (Ivan Vecera) [1006987]
- [netdrv] tg3: Remove incorrect switch to aux power (Ivan Vecera) [1006987]
- [netdrv] tg3: Prevent system hang during repeated EEH errors (Ivan Vecera) [1006987]
- [netdrv] tg3: remove redundant pm init code (Ivan Vecera) [1006987]
- [netdrv] tg3: Remove unnecessary lock around tg3_flag_set (Ivan Vecera) [1006987]
- [netdrv] tg3: Fix misplaced empty line (Ivan Vecera) [1006987]
- [netdrv] tg3: Use descriptive label names in tg3_start (Ivan Vecera) [1006987]
- [netdrv] tg3: Make tg3_rings_reset() more concise (Ivan Vecera) [1006987]
- [netdrv] tg3: Simplify ring control block setup (Ivan Vecera) [1006987]
- [netdrv] tg3: Split APE driver state change out of boot reset signature update (Ivan Vecera) [1006987]
- [netdrv] tg3: Use module_pci_driver to register driver (Ivan Vecera) [1006987]
- [netdrv] tg3: Implement set/get_eee handlers (Ivan Vecera) [1006987]
- [netdrv] tg3: Simplify tg3_phy_eee_config_ok() by reusing tg3_eee_pull_config() (Ivan Vecera) [1006987]
- [netdrv] tg3: Add tg3_eee_pull_config() function (Ivan Vecera) [1006987]
- [netdrv] tg3: Add ethtool_eee struct and tg3_setup_eee() (Ivan Vecera) [1006987]
- [netdrv] be2net: set and query VEB/VEPA mode of the PF interface (Ivan Vecera) [726160]
- [netdrv] be2net: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Ivan Vecera) [726160]
- [netdrv] be2net: implement ethtool set/get_channel hooks (Ivan Vecera) [726160]
- [netdrv] be2net: refactor be_setup() to consolidate queue creation routines (Ivan Vecera) [726160]
- [netdrv] be2net: Fix be_cmd_if_create() to use MBOX if MCCQ is not created (Ivan Vecera) [726160]
- [netdrv] be2net: refactor be_get_resources() code (Ivan Vecera) [726160]
- [netdrv] be2net: Fixup profile management routines (Ivan Vecera) [726160]
- [netdrv] be2net: use EQ_CREATEv2 for SH-R (Ivan Vecera) [726160]
- [netdrv] be2net: Check for POST state in suspend-resume sequence (Ivan Vecera) [726160]
- [netdrv] be2net: fix disabling TX in be_close() (Ivan Vecera) [726160]
- [netdrv] be2net: Clear any capability flags that driver is not interested in (Ivan Vecera) [726160]
- [netdrv] be2net: update driver version (Ivan Vecera) [726160]
- [netdrv] be2net: Initialize "status" in be_cmd_get_die_temperature() (Ivan Vecera) [726160]
- [netdrv] be2net: fixup log msgs for async events (Ivan Vecera) [726160]
- [netdrv] be2net: Fix displaying supported speeds for BE2 (Ivan Vecera) [726160]
- [netdrv] be2net: don't limit max MAC and VLAN counts (Ivan Vecera) [726160]
- [netdrv] be2net: Do not call get_die_temperature cmd for VF (Ivan Vecera) [726160]
- [netdrv] be2net: Adding more speeds reported by get_settings (Ivan Vecera) [726160]
- [netdrv] be2net: Staticize local functions (Ivan Vecera) [726160]
- [netdrv] be2net: don't use dev_err when AER enabling fails (Ivan Vecera) [726160]
- [netdrv] be2net: delete primary MAC address while unloading (Ivan Vecera) [726160]
- [netdrv] be2net: use SET/GET_MAC_LIST for SH-R (Ivan Vecera) [726160]
- [netdrv] be2net: refactor MAC-addr setup code (Ivan Vecera) [726160]
- [netdrv] be2net: fix pmac_id for BE3 VFs (Ivan Vecera) [726160]
- [netdrv] be2net: allow VFs to program MAC and VLAN filters (Ivan Vecera) [726160]
- [netdrv] be2net: fix MAC address modification for VF (Ivan Vecera) [726160]
- [netdrv] be2net: replace numeric with standard PM state macros (Ivan Vecera) [726160]
- [netdrv] be2net: use pci_vfs_assigned()/pci_num_vf() instead of be_find_vfs() (Ivan Vecera) [726160]
- [netdrv] be2net: Implement initiate FW dump feature for Lancer (Ivan Vecera) [726160]
- [netdrv] be2net: Trim padded packets for Lancer (Ivan Vecera) [726160]
- [netdrv] be2net: Pad skb to meet min Tx pkt size in lancer (Ivan Vecera) [726160]
- [netdrv] be2net: cleanup be_get_drvinfo() (Ivan Vecera) [726160]
- [netdrv] be2net: refactor HW workarounds in be_xmit() (Ivan Vecera) [726160]
- [netdrv] mlx5: remove unused MLX5_DEBUG param in Kconfig (Amir Vadai) [864578]
- [netdrv] mlx5: Support MANAGE_PAGES and QUERY_PAGES firmware command changes (Amir Vadai) [864578]
- [netdrv] mlx5: remove health handler plugin (Amir Vadai) [864578]
- [infiniband] mlx5: Variable may be used uninitialized (Amir Vadai) [864578]
- [netdrv] mlx5: Implement new initialization sequence (Amir Vadai) [864578]
- [infiniband] mlx5: Fix stack info leak in mlx5_ib_alloc_ucontext() (Amir Vadai) [864578]
- [infiniband] mlx5: Fix error return code in init_one() (Amir Vadai) [864578]
- [netdrv] mlx5: fix error return code in mlx5_alloc_uuars() (Amir Vadai) [864578]
- [netdrv] mlx5: use after free in mlx5_cmd_comp_handler() (Amir Vadai) [864578]
- [netdrv] mlx5: Fix __udivdi3 when compiling for 32 bit arches (Amir Vadai) [864578]
- [netdrv] mlx5: Return -EFAULT instead of -EPERM (Amir Vadai) [864578]
- [netdrv] mlx5: Adjust hca_cap.uar_page_sz to conform to Connect-IB spec (Amir Vadai) [864578]
- [netdrv] mlx5: Fixes for sparse warnings (Amir Vadai) [864578]
- [infiniband] mlx5: Make profile[] static in main.c (Amir Vadai) [864578]
- [infiniband] mlx5: Add driver for Mellanox Connect-IB adapters (Amir Vadai) [864578]
- [infiniband] core: Add reserved values to enums for low-level driver use (Amir Vadai) [864578]

* Thu Sep 19 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-26.el7]
- [net] tuntap: correctly handle error in tun_set_iff() (Jiri Benc) [1007739] {CVE-2013-4343}
- [net] sctp: fix ipv6 ipsec encryption bug in sctp_v6_xmit (Daniel Borkmann) [998398] {CVE-2013-4350}
- [net] netlink: filter particular protocols from analyzers (Daniel Borkmann) [957721]
- [net] ipv6: accept tlv which includes only padding (Jiri Pirko) [990968]

* Thu Sep 19 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-25.el7]
- [scsi] mpt2sas: Bump driver version to v16.100.00.00 (Tomas Henzl) [736230]
- [scsi] mpt2sas: Remove phys on topology change (Tomas Henzl) [736230]
- [scsi] mpt2sas: Fix for kernel panic when driver loads with HBA connected to non LUN 0 configured expander (Tomas Henzl) [736230]
- [scsi] mpt2sas: when Async scanning is enabled then while scanning, devices are removed but their transport layer entries are not removed (Tomas Henzl) [736230]
- [scsi] mpt2sas: Infinite loop can occur if MPI2_IOCSTATUS_CONFIG_INVALID_PAGE is not returned (Tomas Henzl) [736230]
- [scsi] mpt2sas: The copyright in driver sources is updated for the year 2013 (Tomas Henzl) [736230]
- [scsi] mpt2sas: MPI2 Rev X (2.00.16) specifications (Tomas Henzl) [736230]
- [scsi] mpt2sas: Change in MPI2_RAID_ACTION_SYSTEM_SHUTDOWN_INITIATED notification methodology (Tomas Henzl) [736230]
- [scsi] mpt2sas: Null pointer deference possibility in mpt2sas_ctl_event_callback function (Tomas Henzl) [736230]
- [scsi] mpt2sas: fix cleanup on controller resource mapping failure (Tomas Henzl) [736230]
- [scsi] mpt2sas: fix for unused variable 'event_data' warning (Tomas Henzl) [736230]
- [scsi] mpt2sas: Calulate the Reply post queue depth calculation as per the MPI spec (Tomas Henzl) [736230]
- [scsi] mpt2sas: fix firmware failure with wrong task attribute (Tomas Henzl) [736230]
- [scsi] mpt2sas: Fix for device scan following host reset could get stuck in a infinite loop (Tomas Henzl) [736230]
- [scsi] mpt2sas: Update the timing requirements for issuing a Hard Reset (Tomas Henzl) [736230]
- [scsi] mpt2sas: MPI2 Rev W (2.00.15) specification (Tomas Henzl) [736230]
- [powerpc] Fix possible deadlock on page fault (Steve Best) [999374]
- [scsi] qla2xxx: Update driver version to 8.06.00.08.07.0-k (Chad Dupuis) [725014]
- [scsi] qla2xxx: Select link initialization option bits from current operating mode (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add loopback IDC-TIME-EXTEND aen handling support (Chad Dupuis) [725014]
- [scsi] qla2xxx: Set default critical temperature value in cases when ISPFX00 firmware doesn't provide it (Chad Dupuis) [725014]
- [scsi] qla2xxx: QLAFX00 make over temperature AEN handling informational, add log for normal temperature AEN (Chad Dupuis) [725014]
- [scsi] qla2xxx: Correct Interrupt Register offset for ISPFX00 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove handling of Shutdown Requested AEN from qlafx00_process_aen() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Send all AENs for ISPFx00 to above layers (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add changes in initialization for ISPFX00 cards with BIOS (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add changes to support extended IOs for ISPFX00 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add missing FCP statistics to sysfs interface (Chad Dupuis) [725014]
- [scsi] qla2xxx: Make log message that prints when a completion status requires a port down more readable (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add critical temperature handling for ISPFX00 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Notify ISPFX00 firmware when driver is unloaded or system is shut down (Chad Dupuis) [725014]
- [scsi] qla2xxx: Reconfigure thermal temperature (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add setting of driver version string for vendor application (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove QL_DEBUG_LEVEL_17 defines from qla_nx.c (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add ISPFX00 specific bus reset routine (Chad Dupuis) [725014]
- [scsi] qla2xxx: Perform warm reset every 2 minutes if firmware load fails for ISPFX00 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Set factory reset recovery timeout to 10 min. for ISPFX00 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Correct multiqueue offset calculations (Chad Dupuis) [725014]
- [scsi] qla2xxx: Fix incorrect test after list_for_each_entry() exits (Chad Dupuis) [725014]
- [scsi] qla2xxx: Add support for ISP8044 (Chad Dupuis) [725014]
- [scsi] qla2xxx: Print some variables to hexadecimal string via *phN format (Chad Dupuis) [725014]
- [scsi] qla2xxx: Fix sparse warnings in qlafx00_fxdisc_iocb function (Chad Dupuis) [725014]
- [scsi] qla2xxx: Properly set the tagging for commands (Chad Dupuis) [725014]
- [scsi] qla2xxx: Fix a memory leak in an error path of qla2x00_process_els() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove an unused variable from qla2x00_remove_one() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Fix qla2xxx_check_risc_status() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Help Coverity with analyzing ct_sns_pkt initialization (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove redundant assignments (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove a dead assignment in qla24xx_build_scsi_crc_2_iocbs() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove two superfluous tests (Chad Dupuis) [725014]
- [scsi] qla2xxx: Remove dead code in qla2x00_configure_hba() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Clean up qla84xx_mgmt_cmd() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Clean up qla24xx_iidma() (Chad Dupuis) [725014]
- [scsi] qla2xxx: Fix sparse warning from qla_mr.c and qla_iocb.c (Chad Dupuis) [725014]
- [scsi] qla2xxx: Do not take a second firmware dump when intentionally generating one (Chad Dupuis) [725014]
- [scsi] qla2xxx: Do not query FC statistics during chip reset (Chad Dupuis) [725014]
- [scsi] qla2xxx: Move qla2x00_free_device to the correct location (Chad Dupuis) [725014]
- [scsi] qla2xxx: Set the index in outstanding command array to NULL when cmd is aborted when the request timeout (Chad Dupuis) [725014]
- [scsi] qla2xxx: Clear the MBX_INTR_WAIT flag when the mailbox time-out happens (Chad Dupuis) [725014]
- [scsi] mpt3sas: Bump driver version to v02.100.00.00 (Tomas Henzl) [889435]
- [scsi] mpt3sas: Added a driver module parameter max_msix_vectors (Tomas Henzl) [889435]
- [scsi] mpt3sas: fix cleanup on controller resource mapping failure (Tomas Henzl) [889435]
- [scsi] mpt3sas: when async scanning is enabled then while scanning, devices are removed but their transport layer entries are not removed (Tomas Henzl) [889435]
- [scsi] mpt3sas: MPI2.5 Rev F v2.5.1.1 specification (Tomas Henzl) [889435]
- [scsi] mpt3sas: Infinite loops can occur if MPI2_IOCSTATUS_CONFIG_INVALID_PAGE is not returned (Tomas Henzl) [889435]
- [scsi] mpt3sas: fix for kernel panic when driver loads with HBA conected to non LUN 0 configured expander (Tomas Henzl) [889435]
- [scsi] mpt3sas: Updated the Hardware timing requirements (Tomas Henzl) [889435]
- [scsi] mpt3sas: 2013 source code copyright (Tomas Henzl) [889435]
- [netdrv] ixgbe: add support for older QSFP active DA cables (Andy Gospodarek) [726818]
- [netdrv] ixgbe: include QSFP PHY types in ixgbe_is_sfp() (Andy Gospodarek) [726818]
- [netdrv] ixgbe: add 1Gbps support for QSFP+ (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix SFF data dumps of SFP+ modules from an offset (Andy Gospodarek) [726818]
- [netdrv] ixgbe: cleanup some log messages (Andy Gospodarek) [726818]
- [netdrv] ixgbe: zero out mailbox buffer on init (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix link test when connected to 1Gbps link partner (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix incorrect limit value in ring transverse (Andy Gospodarek) [726818]
- [netdrv] ixgbe: Check return value on eeprom reads (Andy Gospodarek) [726818]
- [netdrv] ixgbe: disable link when adapter goes down (Andy Gospodarek) [726818]
- [netdrv] ixgbe: add support for quad-port x520 adapter (Andy Gospodarek) [726818]
- [netdrv] ixgbe: clear semaphore bits on timeouts (Andy Gospodarek) [726818]
- [netdrv] ixgbe: rename LL_EXTENDED_STATS to use queue instead of q (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix lockdep annotation issue for ptp's work item (Andy Gospodarek) [726818]
- [netdrv] ixgbe: call pcie_get_mimimum_link to check if device has enough bandwidth (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix SFF data dumps of SFP+ modules (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix semaphore lock for I2C read/writes on 82598 (Andy Gospodarek) [726818]
- [netdrv] ixgbe: bump version number (Andy Gospodarek) [726818]
- [netdrv] ixgbe: add new media type (Andy Gospodarek) [726818]
- [netdrv] ixgbe: fix fc autoneg ethtool reporting (Andy Gospodarek) [726818]
- [netdrv] ixgbe: Use pci_vfs_assigned instead of ixgbe_vfs_are_assigned (Andy Gospodarek) [726818]
- [netdrv] ixgbe: Retain VLAN filtering in promiscuous + VT mode (Andy Gospodarek) [726818]
- [netdrv] ixgbe: Fix Tx Hang issue with lldpad on 82598EB (Andy Gospodarek) [726818]
- [netdrv] ixgbe: Set the SW prio_tc values at initialization to the HW setting (Andy Gospodarek) [726818]
- [pci] expose pcie_link_speed and pcix_bus_speed arrays (Andy Gospodarek) [726818]
- [pci] move enum pcie_link_width into pci.h (Andy Gospodarek) [726818]
- [pci] Add function to obtain minimum link width and speed (Andy Gospodarek) [726818]
- [netdrv] cnic: Update version to 2.5.18 (Tomas Henzl) [725064]
- [netdrv] cnic: Eliminate local copy of pfid (Tomas Henzl) [725064]
- [netdrv] cnic: Eliminate CNIC_PORT macro and port_mode in local struct (Tomas Henzl) [725064]
- [netdrv] cnic: Redefine BNX2X_HW_CID using existing bnx2x macros (Tomas Henzl) [725064]
- [netdrv] cnic: Use CHIP_NUM macros from bnx2x.h (Tomas Henzl) [725064]
- [netdrv] cnic: Convert mac address uses of 6 to ETH_ALEN (Tomas Henzl) [725064]
- [netdrv] cnic: Update version to 2.5.17 and copyright year (Tomas Henzl) [725064]
- [netdrv] cnic: Add missing error checking for RAMROD_CMD_ID_CLOSE (Tomas Henzl) [725064]
- [netdrv] cnic: Update TCP options setup for iSCSI (Tomas Henzl) [725064]
- [netdrv] cnic: Reset tcp_flags during cnic_cm_create() (Tomas Henzl) [725064]
- [netdrv] cnic: Simplify cnic_release() (Tomas Henzl) [725064]
- [netdrv] cnic: Simplify netdev events handling (Tomas Henzl) [725064]

* Thu Sep 19 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-24.el7]
- [Documentation] kvm: Add documentation on Hypercalls and features used for PV spinlock (Andrew Jones) [981581]
- [virt] kvm: Simplify kvm_for_each_vcpu with kvm_irq_delivery_to_apic (Andrew Jones) [981581]
- [virt] kvm: Add a hypercall to KVM hypervisor to support pv-ticketlocks (Andrew Jones) [981581]
- [virt] kvm: Paravirtual ticketlocks support for linux guests running on KVM hypervisor (Andrew Jones) [981581]
- [virt] kvm: Add configuration support to enable debug information for KVM Guests (Andrew Jones) [981581]
- [virt] kvm: Add KICK_CPU and PV_UNHALT definition to uapi (Andrew Jones) [981581]
- [virt] pvticketlock: Allow interrupts to be enabled while blocking (Andrew Jones) [981581]
- [virt] ticketlock: Add slowpath logic (Andrew Jones) [981581]
- [kernel] jump_label: Split jumplabel ratelimit (Andrew Jones) [981581]
- [virt] pvticketlock: Use callee-save for lock_spinning (Andrew Jones) [981581]
- [virt] pvticketlocks: Add xen_nopvspin parameter to disable xen pv ticketlocks (Andrew Jones) [981581]
- [virt] pvticketlock: Xen implementation for PV ticket locks (Andrew Jones) [981581]
- [virt] xen: Defer spinlock setup until boot CPU setup (Andrew Jones) [981581]
- [virt] ticketlock: Collapse a layer of functions (Andrew Jones) [981581]
- [virt] ticketlock: Don't inline _spin_unlock when using paravirt spinlocks (Andrew Jones) [981581]
- [virt] spinlock: Replace pv spinlocks with pv ticketlocks (Andrew Jones) [981581]
- [fs] proc/vmcore: support mmap() on /proc/vmcore (Nigel Croxon) [990298]
- [fs] proc/vmcore: calculate vmcore file size from buffer size and total size of vmcore objects (Nigel Croxon) [990298]
- [fs] proc/vmcore: allow user process to remap ELF note segment buffer (Nigel Croxon) [990298]
- [fs] proc/vmcore: allocate ELF note segment in the 2nd kernel vmalloc memory (Nigel Croxon) [990298]
- [mm] vmalloc: introduce remap_vmalloc_range_partial (Nigel Croxon) [990298]
- [mm] vmalloc: make find_vm_area check in range (Nigel Croxon) [990298]
- [fs] proc/vmcore: treat memory chunks referenced by PT_LOAD program header entries in page-size boundary in vmcore_list (Nigel Croxon) [990298]
- [fs] proc/vmcore: allocate buffer for ELF headers on page-size alignment (Nigel Croxon) [990298]
- [fs] proc/vmcore: clean up read_vmcore() (Nigel Croxon) [990298]
- [mm] add PAGE_ALIGNED() helper (Nigel Croxon) [990298]
- [fs] nfs Fix up nfs4_proc_lookup_mountpoint (Jeff Layton) [1007357]
- [fs] nfs: Don't check lock owner compatability unless file is locked (part 2) (Jeff Layton) [1007035]
- [fs] nfs: Don't check lock owner compatibility in writes unless file is locked (Jeff Layton) [1007035]
- [pci] Remove pcie_cap_has_devctl() (Myron Stowe) [1005229]
- [pci] Support PCIe Capability Slot registers only for ports with slots (Myron Stowe) [1005229]
- [pci] Remove PCIe Capability version checks (Myron Stowe) [1005229]
- [pci] Allow PCIe Capability link-related register access for switches (Myron Stowe) [1005229]
- [pci] Add offsets of PCIe capability registers (Myron Stowe) [1005229]
- [pci] Tidy bitmasks and spacing of PCIe capability definitions (Myron Stowe) [1005229]
- [pci] Remove obsolete comment reference to pci_pcie_cap2() (Myron Stowe) [1005229]
- [pci] Clarify PCI_EXP_TYPE_PCI_BRIDGE comment (Myron Stowe) [1005229]
- [pci] Rename PCIe capability definitions to follow convention (Myron Stowe) [1005229]
- [pci] Warn if unsafe MPS settings detected (Myron Stowe) [1005229]
- [pci] Fix MPS peer-to-peer DMA comment syntax (Myron Stowe) [1005229]
- [pci] Disable decoding for BAR sizing only when it was actually enabled (Myron Stowe) [1005229]
- [pci] Add comment about needing pci_msi_off() even when CONFIG_PCI_MSI=n (Myron Stowe) [1005229]
- [pci] Add pcibios_pm_ops for optional arch-specific hibernate functionality (Myron Stowe) [1005229]
- [pci] Don't restrict MPS for slots below Root Ports (Myron Stowe) [1005229]
- [pci] Simplify MPS test for Downstream Port (Myron Stowe) [1005229]
- [pci] Remove unnecessary check for pcie_get_mps() failure (Myron Stowe) [1005229]
- [pci] Simplify pcie_bus_configure_settings() interface (Myron Stowe) [1005229]
- [pci] Drop "PCI-E" prefix from Max Payload Size message (Myron Stowe) [1005229]
- [pci] Add pci_probe_reset_slot() and pci_probe_reset_bus() (Myron Stowe) [1005229]
- [pci] Remove aer_do_secondary_bus_reset() (Myron Stowe) [1005229]
- [pci] Tune secondary bus reset timing (Myron Stowe) [1005229]
- [pci] Wake-up devices before saving config space for reset (Myron Stowe) [1005229]
- [pci] Add pci_reset_slot() and pci_reset_bus() (Myron Stowe) [1005229]
- [pci] Split out pci_dev lock/unlock and save/restore (Myron Stowe) [1005229]
- [pci] Add slot reset option to pci_dev_reset() (Myron Stowe) [1005229]
- [pci] pciehp: Add reset_slot() method (Myron Stowe) [1005229]
- [pci] Add hotplug_slot_ops.reset_slot() (Myron Stowe) [1005229]
- [pci] quirks: Use pci_wait_for_pending_transaction() instead of for loop (Myron Stowe) [1005229]
- [netdrv] bnx2x: Use pci_wait_for_pending_transaction() instead of for loop (Myron Stowe) [1005229]
- [pci] quirks: Enable Bus Master during Function-Level Reset on Chelsio (Myron Stowe) [1005229]
- [pci] Add pci_wait_for_pending_transaction() (Myron Stowe) [1005229]
- [pci] Add pci_reset_bridge_secondary_bus() (Myron Stowe) [1005229]
- [pci] Align bridge I/O windows as required by downstream devices & bridges (Myron Stowe) [1005229]
- [pci] Fix types in pbus_size_io() (Myron Stowe) [1005229]
- [pci] Add comments for pbus_size_mem() parameters (Myron Stowe) [1005229]
- [pci] Enumerate subordinate buses, not devices, in pci_bus_get_depth() (Myron Stowe) [1005229]
- [pci] Fix comment typo for pci_add_cap_save_buffer() (Myron Stowe) [1005229]
- [pci] Return -ENOSYS for SR-IOV operations on non-SR-IOV devices (Myron Stowe) [1005229]
- [pci] Update NumVFs register when disabling SR-IOV (Myron Stowe) [1005229]
- [pci] mmconfig: Check earlier for MMCONFIG region at address zero (Myron Stowe) [1005229]
- [pci] Assign resources for hot-added host bridge more aggressively (Myron Stowe) [1005229]
- [pci] Move resource reallocation code to non-__init (Myron Stowe) [1005229]
- [pci] Delay enabling bridges until they're needed (Myron Stowe) [1005229]
- [pci] Assign resources on a per-bus basis (Myron Stowe) [1005229]
- [pci] Enable unassigned resource reallocation on per-bus basis (Myron Stowe) [1005229]
- [pci] Turn on reallocation for unassigned resources with host bridge offset (Myron Stowe) [1005229]
- [pci] Look for unassigned resources on per-bus basis (Myron Stowe) [1005229]
- [pci] Drop temporary variable in pci_assign_unassigned_resources() (Myron Stowe) [1005229]
- [pci] Claim ACS support for AMD southbridge devices (Myron Stowe) [1005229]
- [pci] Differentiate ACS controllable from enabled (Myron Stowe) [1005229]
- [pci] Check all ACS features for multifunction downstream ports (Myron Stowe) [1005229]
- [pci] Convert class code to use dev_groups (Myron Stowe) [1005229]
- [pci] mrst: Cleanup checkpatch.pl warnings (Myron Stowe) [1005229]
- [pci] Rename "PCI Express support" kconfig title (Myron Stowe) [1005229]
- [pci] Fix comment typo in iov.c (Myron Stowe) [1005229]
- [fs] sysfs: use file mode defines from stat.h (Myron Stowe) [1005229]
- [fs] sysfs: add more helper macro's for (bin_)attribute(_groups) (Myron Stowe) [1005229]
- [misc] device: add default groups to struct class (Myron Stowe) [1005229]
- [misc] device: Introduce device_create_groups (Myron Stowe) [1005229]
- [fs] sysfs: prevent warning when only using binary attributes (Myron Stowe) [1005229]
- [fs] sysfs: add support for binary attributes in groups (Myron Stowe) [1005229]
- [misc] device: add RW and RO attribute macros (Myron Stowe) [1005229]
- [misc] sysfs: add BIN_ATTR macro (Myron Stowe) [1005229]
- [misc] sysfs: add ATTRIBUTE_GROUPS() macro (Myron Stowe) [1005229]
- [misc] sysfs: add __ATTR_RW() macro (Myron Stowe) [1005229]

* Tue Sep 17 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-23.el7]
- [kernel] kexec: improve logging when crashkernel=auto can't be satisfied (Steve Best) [989576]

* Fri Sep 13 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-22.el7]
- [netdrv] bnx2: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Neil Horman) [725061]
- [netdrv] bnx2: clean up unnecessary MSI/MSI-X capability find (Neil Horman) [725061]
- [netdrv] bnx2: Update version to 2.2.4 (Neil Horman) [725061]
- [netdrv] bnx2: Add pci shutdown handler (Neil Horman) [725061]
- [netdrv] bnx2: Use SIMPLE_DEV_PM_OPS (Neil Horman) [725061]
- [netdrv] bnx2: Refactor WoL setup into a separate function (Neil Horman) [725061]
- [netdrv] bnx2: Use kernel APIs for WoL and power state changes (Neil Horman) [725061]
- [netdrv] bnx2: Handle error condition in ->slot_reset() (Neil Horman) [725061]
- [netdrv] bnx2: use pdev->pm_cap instead of pci_find_capability(.., PCI_CAP_ID_PM) (Neil Horman) [725061]
- [netdrv] bnx2: Use module_pci_driver to register driver (Neil Horman) [725061]
- [netdrv] igb: Update version number (Stefan Assmann) [726817]
- [netdrv] igb: Implementation to report advertised/supported link on i354 devices (Stefan Assmann) [726817]
- [netdrv] igb: Get speed and duplex for 1G non_copper devices (Stefan Assmann) [726817]
- [netdrv] igb: Support to get 2_5G link status for appropriate media type (Stefan Assmann) [726817]
- [netdrv] igb: No PHPM support in i354 devices (Stefan Assmann) [726817]
- [netdrv] igb: M88E1543 PHY downshift implementation (Stefan Assmann) [726817]
- [netdrv] igb: New PHY_ID for i354 device (Stefan Assmann) [726817]
- [netdrv] igb: Implementation of 1-sec delay for i210 devices (Stefan Assmann) [726817]
- [netdrv] igb: Don't look for a PBA in the iNVM when flashless (Stefan Assmann) [726817]
- [netdrv] igb: Expose RSS indirection table for ethtool (Stefan Assmann) [726817]
- [netdrv] igb: Add macro for size of RETA indirection table (Stefan Assmann) [726817]
- [netdrv] igb: Fix get_fw_version function for all parts (Stefan Assmann) [726817]
- [netdrv] igb: Add device support for flashless SKU of i210 device (Stefan Assmann) [726817]
- [netdrv] igb: Refactor NVM read functions to accommodate devices with no flash (Stefan Assmann) [726817]
- [netdrv] igb: Refactor of init_nvm_params (Stefan Assmann) [726817]
- [netdrv] igb: Update MTU so that it is always at least a standard frame size (Stefan Assmann) [726817]
- [netdrv] igb: don't allow SR-IOV without MSI-X (Stefan Assmann) [726817]
- [netdrv] igb: Added rcu_lock to avoid race (Stefan Assmann) [726817]
- [netdrv] igb: Read register for latch_on without return value (Stefan Assmann) [726817]
- [netdrv] igb: Reset the link when EEE setting changed (Stefan Assmann) [726817]
- [netdrv] igb: fix vlan filtering in promisc mode when not in VT mode (Stefan Assmann) [726817]
- [netdrv] igb: relase -> release (Stefan Assmann) [726817]
- [netdrv] igb: Removed unused i2c function (Stefan Assmann) [726817]
- [netdrv] igb: Implementation of i210/i211 LED support (Stefan Assmann) [726817]
- [netdrv] igb: Fix possible panic caused by Rx traffic arrival while interface is down (Stefan Assmann) [726817]
- [netdrv] igb: Fix set_ethtool function to call update nvm for entire image (Stefan Assmann) [726817]
- [netdrv] igb: SerDes flow control setting (Stefan Assmann) [726817]
- [netdrv] igb: Support for SFP modules discovery (Stefan Assmann) [726817]
- [netdrv] igb: Add update to last_rx_timestamp in Rx rings (Stefan Assmann) [726817]
- [netdrv] igb: Changed LEDs blink mechanism to include designs using cathode (Stefan Assmann) [726817]
- [virt] kvm/mmu: avoid fast page fault fixing mmio page fault (Gleb Natapov) [981979]
- [virt] kvm/vmx: mark unusable segment as nonpresent (Gleb Natapov) [981979]
- [virt] kvm: get rid of $(addprefix ../../../virt/kvm/, ...) in Makefiles (Gleb Natapov) [981979]
- [virt] kvm: Fix RTC interrupt coalescing tracking (Gleb Natapov) [981979]
- [virt] kvm: Add a tracepoint write_tsc_offset (Gleb Natapov) [981979]
- [virt] kvm: Inform users of mmio generation wraparound (Gleb Natapov) [981979]
- [virt] kvm: document fast invalidate all mmio sptes (Gleb Natapov) [981979]
- [virt] kvm: document fast invalidate all pages (Gleb Natapov) [981979]
- [virt] kvm: document fast page fault (Gleb Natapov) [981979]
- [virt] kvm: document mmio page fault (Gleb Natapov) [981979]
- [virt] kvm: document write_flooding_count (Gleb Natapov) [981979]
- [virt] kvm: document clear_spte_count (Gleb Natapov) [981979]
- [virt] kvm: drop kvm_mmu_zap_mmio_sptes (Gleb Natapov) [981979]
- [virt] kvm: init kvm generation close to mmio wrap-around value (Gleb Natapov) [981979]
- [virt] kvm: add tracepoint for check_mmio_spte (Gleb Natapov) [981979]
- [virt] kvm: fast invalidate all mmio sptes (Gleb Natapov) [981979]
- [virt] kvm: make return value of mmio page fault handler more readable (Gleb Natapov) [981979]
- [virt] kvm: store generation-number into mmio spte (Gleb Natapov) [981979]
- [virt] kvm: retain more available bits on mmio spte (Gleb Natapov) [981979]
- [virt] kvm: update the documentation for reverse mapping of parent_pte (Gleb Natapov) [981979]
- [Documentation] kvm: fix section numbers (Gleb Natapov) [981979]
- [virt] kvm: handle idiv overflow at kvm_write_tsc (Gleb Natapov) [981979]
- [virt] kvm: reduce KVM_REQ_MMU_RELOAD when root page is zapped (Gleb Natapov) [981979]
- [virt] kvm: reclaim the zapped-obsolete page first (Gleb Natapov) [981979]
- [virt] kvm: collapse TLB flushes when zap all pages (Gleb Natapov) [981979]
- [virt] kvm: zap pages in batch (Gleb Natapov) [981979]
- [virt] kvm: do not reuse the obsolete page (Gleb Natapov) [981979]
- [virt] kvm: add tracepoint for kvm_mmu_invalidate_all_pages (Gleb Natapov) [981979]
- [virt] kvm: show mmu_valid_gen in shadow page related tracepoints (Gleb Natapov) [981979]
- [virt] kvm: use the fast way to invalidate all pages (Gleb Natapov) [981979]
- [virt] kvm: fast invalidate all pages (Gleb Natapov) [981979]
- [virt] kvm: drop unnecessary kvm_reload_remote_mmus (Gleb Natapov) [981979]
- [virt] kvm: drop calling kvm_mmu_zap_all in emulator_fix_hypercall (Gleb Natapov) [981979]
- [virt] kvm: exclude ioeventfd from counting kvm_io_range limit (Gleb Natapov) [981979]
- [virt] kvm: convert XADD to fastop (Gleb Natapov) [981979]
- [virt] kvm: drop unused old-style inline emulation (Gleb Natapov) [981979]
- [virt] kvm: convert DIV/IDIV to fastop (Gleb Natapov) [981979]
- [virt] kvm: convert single-operand MUL/IMUL to fastop (Gleb Natapov) [981979]
- [virt] kvm: Switch fastop src operand to RDX (Gleb Natapov) [981979]
- [virt] kvm: switch MUL/DIV to DstXacc (Gleb Natapov) [981979]
- [virt] kvm: decode extended accumulator explicity (Gleb Natapov) [981979]
- [virt] kvm: add support for writing back the source operand (Gleb Natapov) [981979]
- [virt] kvm: clenaup locking in mmu_free_roots() (Gleb Natapov) [981979]
- [virt] kvm: limit difference between kvmclock updates (Gleb Natapov) [981979]
- [virt] kvm: Remove support for reporting coalesced APIC IRQs (Gleb Natapov) [981979]
- [virt] kvm: Use kvm_mmu_sync_roots() in kvm_mmu_load() (Gleb Natapov) [981979]
- [virt] kvm: add missing misc_deregister() on error in kvm_init() (Gleb Natapov) [981979]

* Thu Sep 12 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-21.el7]
- [net] net_sched: fix a typo in htb_change_class() (Jesper Brouer) [998588]
- [net] tcp_probe: adapt tbuf size for recent changes (Daniel Borkmann) [1000470]
- [net] tcp_probe: allow more advanced ingress filtering by mark (Daniel Borkmann) [1000470]
- [net] tcp_probe: add IPv6 support (Daniel Borkmann) [1000470]
- [net] tcp_probe: kprobes: adapt jtcp_rcv_established signature (Daniel Borkmann) [1000470]
- [net] tcp_probe: also include rcv_wnd next to snd_wnd (Daniel Borkmann) [1000470]
- [lib] vsprintf: add IPv4/v6 generic p[Ii]S[pfs] format specifier (Daniel Borkmann) [1000470]
- [net] ipv6: fix potential use after free in tcp_v6_do_rcv (Jiri Benc) [1004165]
- [net] netlabel: use domain based selectors when address based selectors are not available (Paul Moore) [983949]

* Wed Sep 11 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-20.el7]
- [fs] gfs2: dirty inode correctly in gfs2_write_end (Benjamin Marzinski) [1004054]
- [netdrv] bnx2x: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Michal Schmidt) [819849]
- [netdrv] bnx2x: clean up unnecessary MSI/MSI-X capability find (Michal Schmidt) [819849]
- [netdrv] bnx2x: Revising locking scheme for MAC configuration (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix VF stats sync (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix VF memory leak unload (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix functionality of configuring vlan list (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix move FP memory deallocations (Michal Schmidt) [819849]
- [netdrv] bnx2x: vf mark stats started (Michal Schmidt) [819849]
- [netdrv] bnx2x: set VF DMAE when first function has 0 supported VFs (Michal Schmidt) [819849]
- [netdrv] bnx2x: Protect against VFs' ndos when SR-IOV is disabled (Michal Schmidt) [819849]
- [netdrv] bnx2x: prevent VF benign attentions (Michal Schmidt) [819849]
- [netdrv] bnx2x: Consider DCBX remote error (Michal Schmidt) [819849]
- [netdrv] bnx2x: Change DCB context handling (Michal Schmidt) [819849]
- [netdrv] bnx2x: dropless flow control not always functional (Michal Schmidt) [819849]
- [netdrv] bnx2x: prevent crash in shutdown flow with CNIC (Michal Schmidt) [819849]
- [netdrv] bnx2x: fix PTE write access error (Michal Schmidt) [819849]
- [netdrv] bnx2x: fix memory leak in VF (Michal Schmidt) [819849]
- [netdrv] bnx2x: update fairness parameters following DCB negotiation (Michal Schmidt) [819849]
- [netdrv] bnx2x: protect different statistics flows (Michal Schmidt) [819849]
- [netdrv] bnx2x: fix tunneling CSUM calculation (Michal Schmidt) [819849]
- [netdrv] bnx2x: fill in sane dump flag information (Michal Schmidt) [819849]
- [netdrv] bnx2x: fix dump flag handling (Michal Schmidt) [819849]
- [netdrv] bnx2x: remove zeroing of dump data buffer (Michal Schmidt) [819849]
- [netdrv] bnx2x: Remove sparse and coccinelle warnings (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix compilation with no IOV support (Michal Schmidt) [819849]
- [netdrv] bnx2x: Fix 20G KR2 support claims (Michal Schmidt) [819849]
- [netdrv] bnx2x: improve VF timings (Michal Schmidt) [819849]
- [netdrv] bnx2x: VF ndo sanity (Michal Schmidt) [819849]
- [netdrv] bnx2x: Improve PF behaviour toward VF (Michal Schmidt) [819849]
- [netdrv] bnx2x: remove redundant D0 power state set (Michal Schmidt) [819849]
- [netdrv] bnx2x: replace mechanism to check for next available packet (Michal Schmidt) [819849]
- [netdrv] bnx2x: add support for busy-poll (Michal Schmidt) [819849]
- [netdrv] bnx2x: fix a power state test (Michal Schmidt) [819849]
- [netdrv] bnx2x: semi-Semantic changes (Michal Schmidt) [819849]
- [netdrv] bnx2x: Revise prints (Michal Schmidt) [819849]
- [netdrv] bnx2x: Semantic removal and beautification (Michal Schmidt) [819849]
- [netdrv] bnx2x: Revise comments and alignment (Michal Schmidt) [819849]
- [netdrv] bnx2x: Semantic change of empty lines (Michal Schmidt) [819849]
- [netdrv] bnx2x: use XPS if possible for bnx2x_select_queue instead of pure hash (Michal Schmidt) [819849]
- [netdrv] bnx2x: Change to D3hot only on removal (Michal Schmidt) [819849]
- [netdrv] bnx2x: Implement PCI shutdown (Michal Schmidt) [819849]
- [netdrv] bnx2x: Count number of possible FCoE interfaces (Michal Schmidt) [819849]
- [netdrv] bnx2x: Ack unknown VF messages (Michal Schmidt) [819849]
- [netdrv] bnx2x: Add and correct PCI link speed prints (Michal Schmidt) [819849]
- [netdrv] bnx2x: Zero VFs starting MACs (Michal Schmidt) [819849]
- [netdrv] bnx2x: Enable `set_phys_id' for all functions (Michal Schmidt) [819849]
- [netdrv] bnx2x: Link-flap avoidance in switch dependent mode (Michal Schmidt) [819849]
- [netdrv] bnx2x: Add Private Flags Support (Michal Schmidt) [819849]
- [netdrv] bnx2x: dont reload on GRO change (Michal Schmidt) [819849]

* Tue Sep 10 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-19.el7]
- [crypto] nx: fix SHA-2 for chunks bigger than block size (Steve Best) [999606]
- [crypto] nx: fix GCM for zero length messages (Steve Best) [999606]
- [crypto] nx: fix XCBC for zero length messages (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-CCM (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-XCBC (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-GCM (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-CTR (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-CBC (Steve Best) [999606]
- [crypto] nx: fix limits to sg lists for AES-ECB (Steve Best) [999606]
- [crypto] nx: add offset to nx_build_sg_lists() (Steve Best) [999606]
- [virt] virtio_console: prevent use-after-free of port name in port unplug (Amit Shah) [990419]
- [virt] virtio_console: fix locking around send_sigio_to_port() (Amit Shah) [986968]
- [virt] virtio_console: add locking in port unplug path (Amit Shah) [990419]
- [virt] virtio_console: add locks around buffer removal in port unplug path (Amit Shah) [990419]
- [virt] virtio_console: return -ENODEV on all read operations after unplug (Amit Shah) [975716]
- [virt] virtio_console: fix raising SIGIO after port unplug (Amit Shah) [986968]
- [virt] virtio_console: clean up port data immediately at time of unplug (Amit Shah) [990419]
- [virt] virtio_console: fix race in port_fops_open() and port unplug (Amit Shah) [990419]
- [virt] virtio_console: fix race with port unplug and open/close (Amit Shah) [990419]
- [virt] virtio_console: Add pipe_lock/unlock for splice_write (Amit Shah) [987722]
- [virt] virtio_console: Quit from splice_write if pipe->nrbufs is 0 (Amit Shah) [987722]
- [scsi] Generate uevents on certain unit attention codes (Ewan Milne) [740795]
- [virt] kvm: update masterclock when kvmclock_offset is calculated (Marcelo Tosatti) [978425]
- [acpi] pci_root: Fix _OSC ordering to allow PCIe hotplug use when available (Neil Horman) [990078]

* Thu Sep 05 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-18.el7]
- [net] ipv4: make snmp_mib_free static inline (Amerigo Wang) [970585]
- [net] vxlan: include net/ip6_checksum.h for csum_ipv6_magic() (Amerigo Wang) [970585]
- [net] vxlan: fix flowi6_proto value (Amerigo Wang) [970585]
- [net] udp: unify skb_udp_tunnel_segment() and skb_udp6_tunnel_segment() (Amerigo Wang) [970585]
- [net] ipv6: Add generic UDP Tunnel segmentation (Amerigo Wang) [970585]
- [net] vxlan: add ipv6 proxy support (Amerigo Wang) [970585]
- [net] ipv6: move in6_dev_finish_destroy() into core kernel (Amerigo Wang) [970585]
- [net] ipv6: add include file to suppress sparse warnings (Amerigo Wang) [970585]
- [net] vxlan: add ipv6 route short circuit support (Amerigo Wang) [970585]
- [net] vxlan: add ipv6 support (Amerigo Wang) [970585]
- [net] ipv6: do not call ndisc_send_rs() with write lock (Amerigo Wang) [970585]
- [net] ipv6: export in6addr_loopback to modules (Amerigo Wang) [970585]
- [net] ipv6: export a stub for IPv6 symbols used by vxlan (Amerigo Wang) [970585]
- [net] ipv6: Remove extern function prototypes (Amerigo Wang) [970585]
- [net] ipv6: always hold idev->lock before mca_lock (Amerigo Wang) [970585]
- [net] ipv6: move ip6_local_out into core kernel (Amerigo Wang) [970585]
- [net] ipv6: move ip6_dst_hoplimit() into core kernel (Amerigo Wang) [970585]
- [net] udp: move GSO functions to udp_offload (Amerigo Wang) [970585]
- [net] tcp: move GRO/GSO functions to tcp_offload (Amerigo Wang) [970585]
- [net] tcp: use tcp_skb_mss helper in tcp_tso_segment (Amerigo Wang) [970585]
- [scsi] csgb4i: convert skb->transport_header into skb_transport_header(skb) (Amerigo Wang) [970585]
- [net] pass correct parameter to skb_headers_offset_update() (Amerigo Wang) [970585]
- [netdrv] cxgb3: Correct comparisons and calculations using skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [net] clean up skb headers code (Amerigo Wang) [970585]
- [net] Fix build warnings after mac_header and transport_header became __u16 (Amerigo Wang) [970585]
- [net] netfilter: Correct calculation using skb->tail and skb-network_header (Amerigo Wang) [970585]
- [net] Correct assignment of skb->network_header to skb->tail (Amerigo Wang) [970585]
- [net] sctp: Correct access to skb->{network, transport}_header (Amerigo Wang) [970585]
- [net] ipv4: Correct comparisons and calculations using skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [net] ipv6: Correct comparisons and calculations using skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [net] Correct comparisons and calculations using skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [netdrv] cxgb3: Correct comparisons and calculations using skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [netdrv] isdn: Correct comparison of skb->tail and skb-transport_header (Amerigo Wang) [970585]
- [net] Copy inner_protocol in copy_skb_header() (Amerigo Wang) [970585]
- [net] mpls: Add limited GSO support (Amerigo Wang) [970585]
- [net] Use 16bits for *_headers fields of struct skbuff (Amerigo Wang) [970585]

* Wed Sep 04 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-17.el7]
- [fs] lockd: Don't call utsname()->nodename from nlmclnt_setlockargs (Jan Stancek) [999289]
- [scsi] ipr: Add sereral new CCIN definitions for new adapters support (Steve Best) [1002200]
- [virt] x86/xen: Sync the CMOS RTC as well as the Xen wallclock (Radim Krcmar) [1003683]
- [virt] x86/xen: Sync the wallclock when the system time is set (Radim Krcmar) [1003683]
- [virt] x86: Increase precision of x86_platform.get/set_wallclock() (Radim Krcmar) [1003683]
- [powerpc] Don't Oops when accessing /proc/powerpc/lparcfg without hypervisor (Steve Best) [1002206]
- [virt] xen/smp: initialize IPI vectors before marking CPU online (Radim Krcmar) [1003683]
- [virt] xen/events: mask events when changing their VCPU binding (Radim Krcmar) [1003683]
- [virt] xen/events: initialize local per-cpu mask for all possible events (Radim Krcmar) [1003683]
- [virt] x86/xen: do not identity map UNUSABLE regions in the machine E820 (Radim Krcmar) [1003683]
- [virt] xen/evtchn: avoid a deadlock when unbinding an event channel (Radim Krcmar) [1003683]
- [virt] xenbus: frontend resume cleanup (Radim Krcmar) [1003683]
- [virt] xen-netfront: pull on receive skb may need to happen earlier (Radim Krcmar) [1003683]
- [virt] xen: Use more current logging styles (Radim Krcmar) [1003683]
- [virt] xen/time: remove blocked time accounting from xen "clockchip" (Radim Krcmar) [1003683]
- [virt] xen: Convert printks to pr_<level> (Radim Krcmar) [1003683]
- [virt] xen: ifdef CONFIG_HIBERNATE_CALLBACKS xen_*_suspend (Radim Krcmar) [1003683]
- [virt] xen-blkfront: set blk_queue_max_hw_sectors correctly (Radim Krcmar) [1003683]
- [virt] xen/io: new macro to detect whether there are too many requests on the ring (Radim Krcmar) [1003683]
- [virt] xen-netfront: use skb_partial_csum_set() to simplify the codes (Radim Krcmar) [1003683]
- [virt] xen/time: Free onlined per-cpu data structure if we want to online it again (Radim Krcmar) [1003683]
- [virt] xen/time: Check that the per_cpu data structure has data before freeing (Radim Krcmar) [1003683]
- [virt] xen/time: Don't leak interrupt name when offlining (Radim Krcmar) [1003683]
- [virt] xen/time: Encapsulate the struct clock_event_device in another structure (Radim Krcmar) [1003683]
- [virt] xen/spinlock: Don't leak interrupt name when offlining (Radim Krcmar) [1003683]
- [virt] xen/smp: Don't leak interrupt name when offlining (Radim Krcmar) [1003683]
- [virt] xen/smp: Set the per-cpu IRQ number to a valid default (Radim Krcmar) [1003683]
- [virt] xen/smp: Introduce a common structure to contain the IRQ name and interrupt line (Radim Krcmar) [1003683]
- [virt] xen/smp: Coalesce the free_irq calls in one function (Radim Krcmar) [1003683]
- [virt] xen-blkback: Use physical sector size for setup (Radim Krcmar) [1003683]
- [virt] xen-blkfront: Introduce a 'max' module parameter to alter the amount of indirect segments (Radim Krcmar) [1003683]
- [virt] xen/netif: document feature-split-event-channels (Radim Krcmar) [1003683]
- [virt] xen-netfront: split event channels support for Xen frontend driver (Radim Krcmar) [1003683]
- [virt] xen-netfront: avoid leaking resources when setup_netfront fails (Radim Krcmar) [1003683]
- [virt] xen-blkfront: use a different scatterlist for each request (Radim Krcmar) [1003683]
- [virt] xen-block: implement indirect descriptors (Radim Krcmar) [1003683]
- [acpi] Try harder to resolve _ADR collisions for bridges (Myron Stowe) [1003183]
- [cpufreq] rename ignore_nice as ignore_nice_load (Myron Stowe) [1003183]
- [acpi] processor: move try_offline_node() after acpi_unmap_lsapic() (Myron Stowe) [1003183]
- [acpi] Drop physical_node_id_bitmap from struct acpi_device (Myron Stowe) [1003183]
- [acpi] pm: Walk physical_node_list under physical_node_lock (Myron Stowe) [1003183]
- [acpi] video: improve quirk check in acpi_video_bqc_quirk() (Myron Stowe) [1003183]
- [kernel] freezer: set PF_SUSPEND_TASK flag on tasks that call freeze_processes (Myron Stowe) [1003183]
- [acpi] battery: Fix parsing _BIX return value (Myron Stowe) [1003183]
- [cpufreq] Fix cpufreq driver module refcount balance after suspend/resume (Myron Stowe) [1003183]
- [cpufreq] intel_pstate: Change to scale off of max P-state (Myron Stowe) [1003183]
- [acpi] video: ignore BIOS initial backlight value for Fujitsu E753 (Myron Stowe) [1003183]
- [pnp] acpi: avoid garbage in resource name (Myron Stowe) [1003183]
- [power] sleep: Fix comment typo in pm_wakeup.h (Myron Stowe) [1003183]
- [power] sleep: avoid 'autosleep' in shutdown progress (Myron Stowe) [1003183]
- [acpi] scan: Always call acpi_bus_scan() for bus check notifications (Myron Stowe) [1003183]
- [acpi] scan: Do not try to attach scan handlers to devices having them (Myron Stowe) [1003183]

* Tue Sep 03 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-16.el7]
- [powerpc] Avoid link stack corruption for MMU on exceptions (Steve Best) [999556]
- [virt] net/hyperv: Fix the NETIF_F_SG flag setting in netvsc (Jason Wang) [984810]
- [pci] Retry allocation of only the resource type that failed (Myron Stowe) [1001217]
- [pci] pciehp: Convert pciehp to be builtin only, not modular (Myron Stowe) [1001217]
- [pci] hotplug: Convert to be builtin only, not modular (Myron Stowe) [1001217]
- [pci] pciehp: Fix null pointer deref when hot-removing SR-IOV device (Myron Stowe) [1001217]

* Fri Aug 30 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-15.el7]
- [drm] qxl: backport updates from v3.11-rc1 (Dave Airlie) [979176]
- [drm] add hotspot support for cursors (Dave Airlie) [983312]
- [virt] x86: Correctly detect hypervisor (Jason Wang) [985743]
- [virt] kvm: Switch to use hypervisor_cpuid_base() (Jason Wang) [985743]
- [virt] xen: Switch to use hypervisor_cpuid_base() (Jason Wang) [985743]
- [virt] x86: Introduce hypervisor_cpuid_base() (Jason Wang) [985743]
- [net] sunrpc: prepare NFS for 2038 (Harshula Jayasuriya) [847926]
- [netdrv] macvtap: Ignore tap features when VNET_HDR is off (Vlad Yasevich) [1001053]
- [netdrv] macvtap: Correctly set tap features when IFF_VNET_HDR is disabled (Vlad Yasevich) [1001053]
- [netdrv] macvtap: simplify usage of tap_features (Vlad Yasevich) [1001053]

* Thu Aug 29 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-14.el7]
- [net] openvswitch: optimize flow compare and mask functions (Thomas Graf) [1002051]
- [net] openvswitch: Rename key_len to key_end (Thomas Graf) [1002051]
- [net] openvswitch: Add SCTP support (Thomas Graf) [1002051]
- [net] ipv6: Add NEXTHDR_SCTP to ipv6.h (Thomas Graf) [1002051]
- [net] sctp: Refactor SCTP skb checksum computation (Thomas Graf) [1002051]
- [net] sctp: prevent checksum.h from double inclusion (Thomas Graf) [1002051]
- [net] openvswitch: Mega flow implementation (Thomas Graf) [1002051]
- [net] openvswitch: Fix argument descriptions in vport.c (Thomas Graf) [1002051]
- [net] openvswitch: link upper device for port devices (Thomas Graf) [1002051]
- [net] openvswitch: Use non rcu hlist_del() flow table entry (Thomas Graf) [1002051]
- [net] openvswitch: Use RCU lock for dp dump operation (Thomas Graf) [1002051]
- [net] openvswitch: Use RCU lock for flow dump operation (Thomas Graf) [1002051]
- [net] ipv6: prevent race between address creation and removal (Jiri Benc) [991392]
- [net] ipv6: move peer_addr init into ipv6_add_addr() (Jiri Benc) [991392]
- [net] ipv6: use ipv6_addr_scope() helper (Jiri Benc) [991392]
- [net] ipv6: add support of peer address (Jiri Benc) [991392]
- [net] rtm_to_ifaddr: free ifa if ifa_cacheinfo processing fails (Daniel Borkmann) [992908]
- [net] net_sched: restore "linklayer atm" handling (Jesper Brouer) [998588]
- [net] net_sched: psched_ratecfg_precompute() improvements (Jesper Brouer) [998588]
- [net] ip_tunnel: Do not use inner ip-header-id for tunnel ip-header-id (Amerigo Wang) [989522]
- [net] openvswitch: Add vxlan tunneling support (Amerigo Wang) [989522]
- [net] vxlan: Add tx-vlan offload support (Amerigo Wang) [989522]
- [net] vxlan: Improve vxlan headroom calculation (Amerigo Wang) [989522]
- [net] vxlan: Factor out vxlan send api (Amerigo Wang) [989522]
- [net] vxlan: Extend vxlan handlers for openvswitch (Amerigo Wang) [989522]
- [net] vxlan: Add vxlan recv demux (Amerigo Wang) [989522]
- [net] vxlan: Restructure vxlan receive (Amerigo Wang) [989522]
- [net] vxlan: Restructure vxlan socket apis (Amerigo Wang) [989522]
- [net] openvswitch: Reset tunnel key between input and output (Amerigo Wang) [989522]
- [net] openvswitch: Use correct type while allocating flex array (Amerigo Wang) [989522]
- [net] openvswitch: Fix bad merge resolution (Amerigo Wang) [989522]
- [net] rtnetlink: Fix inverted check in ndo_dflt_fdb_del() (Amerigo Wang) [989522]
- [net] rtnetlink: allow using zero MAC address in rtnl_fdb_{add, del} (Amerigo Wang) [989522]
- [net] vxlan: fix a soft lockup in vxlan module removal (Amerigo Wang) [989522]
- [net] vxlan: fix a regression of igmp join (Amerigo Wang) [989522]
- [net] vxlan: fix rcu related warning (Amerigo Wang) [989522]
- [net] vxlan: fdb: replace an existing entry (Amerigo Wang) [989522]
- [net] vxlan: fix igmp races (Amerigo Wang) [989522]
- [net] vxlan: unregister on namespace exit (Amerigo Wang) [989522]
- [net] vxlan: add necessary locking on device removal (Amerigo Wang) [989522]
- [net] vxlan: Fix kernel crash on rmmod (Amerigo Wang) [989522]
- [net] vxlan: fix function name spelling (Amerigo Wang) [989522]
- [net] vxlan: fdb: allow specifying multiple destinations for zero MAC (Amerigo Wang) [989522]
- [net] vxlan: allow removal of single destination from fdb entry (Amerigo Wang) [989522]
- [net] vxlan: introduce vxlan_fdb_parse (Amerigo Wang) [989522]
- [net] vxlan: introduce vxlan_fdb_find_rdst (Amerigo Wang) [989522]
- [net] vxlan: add implicit fdb entry for default destination (Amerigo Wang) [989522]
- [net] vxlan: Fix sparse warnings (Amerigo Wang) [989522]
- [net] vxlan: cosmetic cleanup's (Amerigo Wang) [989522]
- [net] vxlan: Use initializer for dummy structures (Amerigo Wang) [989522]
- [net] vxlan: port module param should be ushort (Amerigo Wang) [989522]
- [net] vxlan: convert remotes list to list_rcu (Amerigo Wang) [989522]
- [net] vxlan: make vxlan_xmit_one void (Amerigo Wang) [989522]
- [net] vxlan: move cleanup to uninit (Amerigo Wang) [989522]
- [net] vxlan: fix race caused by dropping rtnl_unlock (Amerigo Wang) [989522]
- [net] vxlan: send notification when MAC migrates (Amerigo Wang) [989522]
- [net] vxlan: move IGMP join/leave to work queue (Amerigo Wang) [989522]
- [net] vxlan: fix crash from work pending on module removal (Amerigo Wang) [989522]
- [net] vxlan: fix out of order operation on module removal (Amerigo Wang) [989522]
- [net] vxlan: defer vxlan init as late as possible (Amerigo Wang) [989522]
- [net] vxlan: use unsigned int instead of unsigned (Amerigo Wang) [989522]
- [net] vxlan: remove the unused rcu head from struct vxlan_rdst (Amerigo Wang) [989522]
- [net] vxlan: listen on multiple ports (Amerigo Wang) [989522]
- [rhel] Kconfig: enable CONFIG_OPENVSWITCH_GRE (Amerigo Wang) [992917]
- [net] ip_tunnel: embed hash list head (Amerigo Wang) [992917]
- [net] sit: fix tunnel update via netlink (Amerigo Wang) [992917]
- [net] ipv6: only apply anti-spoofing checks to not-pointopoint tunnels (Amerigo Wang) [992917]
- [net] gre: Fix MTU sizing check for gretap tunnels (Amerigo Wang) [992917]
- [net] ip_tunnels: Use skb-len to PMTU check (Amerigo Wang) [992917]
- [net] gso: Update tunnel segmentation to support Tx checksum offload (Amerigo Wang) [992917]
- [net] gre: move GSO functions to gre_offload (Amerigo Wang) [992917]
- [net] gre: fix a regression in ioctl (Amerigo Wang) [992917]
- [net] sit: add support of x-netns (Amerigo Wang) [992917]
- [net] dev: introduce skb_scrub_packet() (Amerigo Wang) [992917]
- [net] dev: remove duplicate 'skb->dev = dev' in dev_forward_skb() (Amerigo Wang) [992917]
- [net] sit: fix an oops when IFLA_IPTUN_PROTO is not set (Amerigo Wang) [992917]
- [net] sit: fix 4in4 + IPsec scenario (Amerigo Wang) [992917]
- [net] openvswitch: Add Kconfig dependency on GRE-DEMUX (Amerigo Wang) [992917]
- [net] ip_tunnel: Protect tunnel functions with CONFIG_INET guard (Amerigo Wang) [992917]
- [net] openvswitch: Use correct config guard (Amerigo Wang) [992917]
- [net] openvswitch: Add gre tunnel support (Amerigo Wang) [992917]
- [net] openvswitch: Optimize flow key match for non tunnel flows (Amerigo Wang) [992917]
- [net] openvswitch: Expand action buffer size (Amerigo Wang) [992917]
- [net] openvswitch: Add tunneling interface (Amerigo Wang) [992917]
- [net] openvswitch: Copy individual actions (Amerigo Wang) [992917]
- [net] ip_tunnel: Add dont fragment flag (Amerigo Wang) [992917]
- [net] ip_tunnel: push generic protocol handling to ip_tunnel module (Amerigo Wang) [992917]
- [net] ip_tunnel: extend iptunnel_xmit() (Amerigo Wang) [992917]
- [net] gre: export gre_handle_offloads() function (Amerigo Wang) [992917]
- [net] gre: export gre_build_header() function (Amerigo Wang) [992917]
- [net] gre: Allow multiple protocol listener for gre protocol (Amerigo Wang) [992917]
- [net] gre: Simplify gre protocol registration locking (Amerigo Wang) [992917]
- [net] openvswitch: make skb->csum consistent with rest of networking stack (Amerigo Wang) [992917]
- [net] openvswitch: Simplify interface ovs_flow_metadata_from_nlattrs() (Amerigo Wang) [992917]
- [net] openvswitch: Fix misspellings in comments and docs (Amerigo Wang) [992917]
- [net] openvswitch: Unify vport error stats handling (Amerigo Wang) [992917]
- [net] openvswitch: fix variable names in comment (Amerigo Wang) [992917]
- [net] openvswitch: Immediately exit on error in ovs_vport_cmd_set() (Amerigo Wang) [992917]
- [net] openvswitch: Remove unused get_config vport op (Amerigo Wang) [992917]
- [net] iptunnel: specify protocol outside IP header (Amerigo Wang) [992917]
- [net] sit: add IPv4 over IPv4 support (Amerigo Wang) [992917]
- [net] export physical port id via sysfs (Jiri Pirko) [991026]
- [net] rtnl: export physical port id via RT netlink (Jiri Pirko) [991026]
- [net] add ndo to get id of physical port of the device (Jiri Pirko) [991026]
- [net] busy_poll: revert unsupported bits from creation of BUSY_POLL socket option (Neil Horman) [958330]
- [net] busy_poll: rename busy poll socket op and globals (Neil Horman) [958330]
- [net] busy_poll: rename ll methods to busy-poll (Neil Horman) [958330]
- [net] busy_poll: rename include/net/ll_poll.h to include/net/busy_poll.h (Neil Horman) [958330]
- [net] busy_poll: change busy poll time accounting (Neil Horman) [958330]
- [net] busy_poll: rename low latency sockets functions to busy poll (Neil Horman) [958330]
- [net] busy_poll: lls fix build with allnoconfig (Neil Horman) [958330]
- [net] busy_poll: convert lls to use time_in_range() (Neil Horman) [958330]
- [net] busy_poll: avoid calling sched_clock when LLS is off (Neil Horman) [958330]
- [net] busy_poll: fix LLS debug_smp_processor_id() warning (Neil Horman) [958330]
- [net] busy_poll: poll/select low latency socket support (Neil Horman) [958330]
- [net] busy_poll: add socket option for low latency polling (Neil Horman) [958330]
- [net] busy_poll: remove NET_LL_RX_POLL config menu (Neil Horman) [958330]
- [net] busy_poll: convert low latency sockets to sched_clock() (Neil Horman) [958330]
- [net] busy_poll: change sysctl_net_ll_poll into an unsigned int (Neil Horman) [958330]
- [netdrv] ixgbe: add extra stats for ndo_ll_poll (Neil Horman) [958330]
- [netdrv] ixgbe: add support for ndo_ll_poll (Neil Horman) [958330]
- [net] tcp: add low latency socket poll support (Neil Horman) [958330]
- [net] udp: add low latency socket poll support (Neil Horman) [958330]
- [net] busy_poll: add low latency socket poll (Neil Horman) [958330]
- [net] add napi_id and hash (Neil Horman) [958330]

* Wed Aug 28 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-13.el7]
- [powerpc] pseries: Drop "select HOTPLUG" (Myron Stowe) [999178]
- [misc] Finally eradicate CONFIG_HOTPLUG (Myron Stowe) [999178]
- [vfio] vfio-pci: Avoid deadlock on remove (Alex Williamson) [912293]
- [vfio] Ignore sprurious notifies (Alex Williamson) [912293]
- [vfio] Don't overreact to DEL_DEVICE (Alex Williamson) [912293]
- [s390] qeth: Fix crash on initial MTU size change (Hendrik Brueckner) [997607]
- [s390] qeth: change default standard blkt settings for OSA (Hendrik Brueckner) [997635]
- [s390] dasd: fix hanging devices after path events (Hendrik Brueckner) [996178]
- [s390] zcrypt: Alias for new zcrypt device driver base module (Hendrik Brueckner) [996731]
- [s390] zfcp: status read buffers on first adapter open with link down (Hendrik Brueckner) [976636]
- [s390] zfcp: fix adapter (re)open recovery while link to SAN is down (Hendrik Brueckner) [889079]
- [netdrv] be2net: Fix to avoid hardware workaround when not needed (Ivan Vecera) [982900]
- [fs] gfs2: Take glock reference in examine_bucket() (Steven Whitehouse) [999897]
- [fs] gfs2: Check for glock already held in gfs2_getxattr (Steven Whitehouse) [997604]
- [crypto] nx: fix nx-aes-gcm verification (Steve Best) [997057]
- [s390] zfcp: remove access control tables interface (Hendrik Brueckner) [994519]
- [s390] zfcp: cfdc fops add owner (Hendrik Brueckner) [994519]
- [scsi] fcoe: cleanup return codes from fcoe_rcv (Neil Horman) [984876]
- [scsi] fcoe: make sure fcoe frames are unshared prior to manipulating them (Neil Horman) [984876]
- [scsi] fcoe: ensure that skb placed on the fip_recv_list are unshared (Neil Horman) [984876]
- [mm] zswap: add documentation (Steve Best) [731499]
- [mm] zswap: add to mm (Steve Best) [731499]
- [mm] zbud: add to mm (Steve Best) [731499]
- [misc] MAINTAINERS: add zswap and zbud maintainer (Steve Best) [731499]
- [fs] debugfs: add get/set for atomic types (Steve Best) [731499]

* Mon Aug 26 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-12.el7]
- [acpi] memhotplug: Fix a stale pointer in error path (Lenny Szubowicz) [995322]
- [powerpc] Add second POWER8 PVR entry (Steve Best) [995355]
- [acpi] power: add missing newline to debug messages (Myron Stowe) [998633]
- [tools] cpupower: Add Haswell family 0x45 specific idle monitor to show PC8, 9, 10 states (Myron Stowe) [998633]
- [tools] cpupower: Haswell also supports the C-states introduced with SandyBridge (Myron Stowe) [998633]
- [tools] cpupower: Introduce idle-set subcommand and C-state enabling/disabling (Myron Stowe) [998633]
- [tools] cpupower: Implement disabling of cstate interface (Myron Stowe) [998633]
- [tools] cpupower: Make idlestate usage unsigned (Myron Stowe) [998633]
- [acpi] fan: Initialize acpi_state variable (Myron Stowe) [998633]
- [acpi] scan: remove unused LIST_HEAD(acpi_device_list) (Myron Stowe) [998633]
- [acpi] dock: Actually define acpi_dock_init() as void (Myron Stowe) [998633]
- [acpi] pm: Fix corner case in acpi_bus_update_power() (Myron Stowe) [998633]
- [cpufreq] Fix serialization of frequency transitions (Myron Stowe) [998633]
- [cpufreq] Fix cpufreq regression after suspend/resume (Myron Stowe) [991615]
- [acpi] pm: Fix possible NULL pointer deref in acpi_pm_device_sleep_state() (Myron Stowe) [991615]
- [kernel] power: Warn about system time after resume with pm_trace (Myron Stowe) [991615]
- [cpufreq] don't leave stale policy pointer in cdbs->cur_policy (Myron Stowe) [991615]
- [cpufreq] acpi-cpufreq: Add new sysfs attribute freqdomain_cpus (Myron Stowe) [991615]
- [cpufreq] make sure frequency transitions are serialized (Myron Stowe) [991615]
- [acpi] implement acpi_os_get_timer() according the spec (Myron Stowe) [991615]
- [acpi] ec: Add HP Folio 13 to ec_dmi_table in order to skip DSDT scan (Myron Stowe) [991615]
- [acpi] Add CMOS RTC Operation Region handler support (Myron Stowe) [991615]
- [acpi] processor: Drop unused variable from processor_perflib.c (Myron Stowe) [991615]
- [cpufreq] powernow-k8: call CPUFREQ_POSTCHANGE notfier in error cases (Myron Stowe) [991615]
- [cpufreq] pcc: call CPUFREQ_POSTCHANGE notfier in error cases (Myron Stowe) [991615]
- [cpufreq] acpi-cpufreq: call CPUFREQ_POSTCHANGE notfier in error cases (Myron Stowe) [991615]
- [Documentation] power: Add pm_qos and dev_pm_qos to events-power.txt (Myron Stowe) [991615]
- [base] power/qos: Add dev_pm_qos_request tracepoints (Myron Stowe) [991615]
- [kernel] power/qos: Add pm_qos_request tracepoints (Myron Stowe) [991615]
- [kernel] power/qos: Add pm_qos_update_target/flags tracepoints (Myron Stowe) [991615]
- [acpi] processor: Remove unused macros in processor_driver.c (Myron Stowe) [991615]
- [Documentation] power: Update Documentation/power/pm_qos_interface.txt (Myron Stowe) [991615]
- [Documentation] cpu-hotplug: Rephrase the outdated description for MADT entries (Myron Stowe) [991615]
- [cpufreq] make __cpufreq_notify_transition() static (Myron Stowe) [991615]
- [cpufreq] Fix minor formatting issues (Myron Stowe) [991615]
- [cpufreq] Fix governor start/stop race condition (Myron Stowe) [991615]
- [kernel] power: Print last wakeup source on failed wakeup_count write (Myron Stowe) [991615]
- [kernel] power/qos: correct the valid range of pm_qos_class (Myron Stowe) [991615]
- [Documentation] video: update video_extension.txt for backlight control (Myron Stowe) [991615]
- [Documentation] video: move video_extension.txt to Documentation/acpi (Myron Stowe) [991615]
- [Documentation] video: add description for brightness_switch_enabled (Myron Stowe) [991615]
- [Documentation] Add ACPI namespace documentation (Myron Stowe) [991615]
- [Documentation] Add sysfs ABI documentation (Myron Stowe) [991615]
- [Documentation] MAINTAINERS: include Documentation/acpi (Myron Stowe) [991615]
- [acpi] acpica: Update version to 20130517 (Myron Stowe) [991615]
- [acpi] acpica: _CST repair, handle null package entries (Myron Stowe) [991615]
- [acpi] acpica: Add several repairs for _CST predefined name (Myron Stowe) [991615]
- [acpi] acpica: Move _PRT repair into the standard complex repair module (Myron Stowe) [991615]
- [acpi] scan: Do not bind ACPI drivers to objects with scan handlers (Myron Stowe) [991615]
- [acpi] pm: Rework and clean up acpi_dev_pm_get_state() (Myron Stowe) [991615]
- [acpi] pm: Replace ACPI_STATE_D3 with ACPI_STATE_D3_COLD in device_pm.c (Myron Stowe) [991615]
- [acpi] pm: Rename function acpi_device_power_state() and make it static (Myron Stowe) [991615]
- [acpi] pm: acpi_processor_suspend() can be static (Myron Stowe) [991615]
- [virt] xen/acpi: Register an acpi_suspend_lowlevel callback (Myron Stowe) [991615]
- [x86] acpi/sleep: Provide registration for acpi_suspend_lowlevel (Myron Stowe) [991615]
- [acpi] Remove unused flags in acpi_device_flags (Myron Stowe) [991615]
- [acpi] Remove useless initializers (Myron Stowe) [991615]
- [acpi] battery: Make sure all spaces are in correct places (Myron Stowe) [991615]
- [acpi] add _STA evaluation at do_acpi_find_child() (Myron Stowe) [991615]
- [acpi] ec: access user space with get_user()/put_user() (Myron Stowe) [991615]
- [cpufreq] Simplify userspace governor (Myron Stowe) [991615]
- [acpi] lpss: override SDIO private register space size from ACPI tables (Myron Stowe) [991615]
- [acpi] lpss: mask the UART TX completion interrupt (Myron Stowe) [991615]
- [acpi] lpss: add support for Intel BayTrail (Myron Stowe) [991615]
- [acpi] Do not use CONFIG_ACPI_HOTPLUG_MEMORY_MODULE (Myron Stowe) [991615]
- [cpufreq] x86: make X86_AMD_FREQ_SENSITIVITY select CPU_FREQ_TABLE (Myron Stowe) [991615]
- [cpufreq] powerpc: make CBE_RAS select CPU_FREQ_TABLE (Myron Stowe) [991615]
- [cpufreq] blackfin: enable driver for CONFIG_BFIN_CPU_FREQ (Myron Stowe) [991615]
- [acpi] acpica: Clear events initialized flag upon event component termination (Myron Stowe) [991615]
- [acpi] acpica: Fix possible memory leak in GPE init error path (Myron Stowe) [991615]
- [acpi] acpica: on termination, delete global lock pending lock (Myron Stowe) [991615]
- [acpi] acpica: Update interface to acpi_ut_valid_acpi_name() (Myron Stowe) [991615]
- [acpi] acpica: Do not use extended sleep registers unless HW-reduced bit is set (Myron Stowe) [991615]
- [acpi] acpica: Split table print utilities to a new a separate file (Myron Stowe) [991615]
- [acpi] acpica: Add option to disable loading of SSDTs from the RSDT/XSDT (Myron Stowe) [991615]
- [acpi] acpica: Standardize all switch() blocks (Myron Stowe) [991615]
- [acpi] acpica: Split internal error msg routines to a separate file (Myron Stowe) [991615]
- [acpi] acpica: Split buffer dump routines into separate file (Myron Stowe) [991615]
- [acpi] scan: Simplify ACPI driver probing (Myron Stowe) [991615]
- [base] power/wakeup: Adjust messaging for wake events during suspend (Myron Stowe) [991615]
- [cpuidle] Fix ARCH_NEEDS_CPU_IDLE_COUPLED dependency warning (Myron Stowe) [991615]
- [cpuidle] Comment the driver's framework code (Myron Stowe) [991615]
- [cpuidle] simplify multiple driver support (Myron Stowe) [991615]
- [cpufreq] powerpc: move cpufreq driver to drivers/cpufreq (Myron Stowe) [991615]
- [cpufreq] acpi-cpufreq: Add ACPI processor device IDs to acpi-cpufreq (Myron Stowe) [991615]
- [cpufreq] remove unnecessary cpufreq_cpu_{get,put}() calls (Myron Stowe) [991615]
- [Documentation] MAINTAINERS: Add git tree path for ARM specific updates to cpufreq (Myron Stowe) [991615]
- [cpufreq] rename index as driver_data in cpufreq_frequency_table (Myron Stowe) [991615]
- [Documentation] power: Update .runtime_idle() callback documentation (Myron Stowe) [991615]
- [kernel] power: Rework the "runtime idle" helper routine (Myron Stowe) [991615]
- [kernel] power: print physical addresses consistently with other parts of kernel (Myron Stowe) [991615]
- [cpuidle] improve governor Kconfig options (Myron Stowe) [991615]
- [Documentation] MAINTAINERS: update mailing list for devfreq(DVFS) (Myron Stowe) [991615]
- [devfreq] fix typo "CPU_EXYNOS4.12" twice (Myron Stowe) [991615]
- [devfreq] add comments and Documentation (Myron Stowe) [991615]
- [devfreq] account suspend/resume for stats (Myron Stowe) [991615]
- [mm] memory_hotplug: Move alternative function definitions to header (Myron Stowe) [991615]
- [acpi] processor: Fix potential NULL pointer dereference in acpi_processor_add() (Myron Stowe) [991615]
- [acpi] acpica: Update version to 20130418 (Myron Stowe) [991615]
- [acpi] acpica: Update for "orphan" embedded controller _REG method support (Myron Stowe) [991615]
- [acpi] acpica: Remove unused macros, no functional change (Myron Stowe) [991615]
- [acpi] acpica: Predefined name support, remove unused local variable (Myron Stowe) [991615]
- [acpi] acpica: Add argument typechecking for all predefined ACPI names (Myron Stowe) [991615]
- [acpi] acpica: Add BIOS error interface for predefined name validation support (Myron Stowe) [991615]
- [acpi] acpica: Change an exception code for the ASL UnLoad() operator (Myron Stowe) [991615]
- [acpi] memhotplug: Simplify memory removal (Myron Stowe) [991615]
- [acpi] scan: Add second pass of companion offlining to hot-remove code (Myron Stowe) [991615]
- [base] memory: Drop offline_memory_block() (Myron Stowe) [991615]
- [acpi] processor: Pass processor object handle to acpi_bind_one() (Myron Stowe) [991615]
- [acpi] Drop removal_type field from struct acpi_device (Myron Stowe) [991615]
- [base] memory: Simplify __memory_block_change_state() (Myron Stowe) [991615]
- [acpi] processor: Initialize per_cpu(processors, pr->id) properly (Myron Stowe) [991615]
- [base] cpu: Fix sysfs cpu/online of offlined CPUs (Myron Stowe) [991615]
- [cpufreq] Don't create empty /sys/devices/system/cpu/cpufreq directory (Myron Stowe) [991615]
- [cpufreq] Move get_cpu_idle_time() to cpufreq.c (Myron Stowe) [991615]
- [cpufreq] governors: Move get_governor_parent_kobj() to cpufreq.c (Myron Stowe) [991615]
- [cpufreq] Add EXPORT_SYMBOL_GPL for have_governor_per_policy (Myron Stowe) [991615]
- [pnp] restore automatic resolution of DMA conflicts (Myron Stowe) [991615]
- [net] af_unix: use freezable blocking calls in read (Myron Stowe) [991615]
- [kernel] sigtimedwait: use freezable blocking call (Myron Stowe) [991615]
- [kernel] nanosleep: use freezable blocking call (Myron Stowe) [991615]
- [kernel] futex: use freezable blocking call (Myron Stowe) [991615]
- [fs] select: use freezable blocking call (Myron Stowe) [991615]
- [fs] epoll: use freezable blocking call (Myron Stowe) [991615]
- [kernel] freezer: add new freezable helpers using freezer_do_not_count() (Myron Stowe) [991615]
- [kernel] freezer: convert freezable helpers to static inline where possible (Myron Stowe) [991615]
- [kernel] freezer: convert freezable helpers to freezer_do_not_count() (Myron Stowe) [991615]
- [kernel] freezer: skip waking up tasks with PF_FREEZER_SKIP set (Myron Stowe) [991615]
- [kernel] power: shorten freezer sleep time using exponential backoff (Myron Stowe) [991615]
- [kernel] lockdep: check that no locks held at freeze time (Myron Stowe) [991615]
- [kernel] lockdep: remove task argument from debug_check_no_locks_held (Myron Stowe) [991615]
- [fs] cifs: add unsafe versions of freezable helpers for CIFS (Myron Stowe) [991615]
- [fs] nfs: add unsafe versions of freezable helpers for NFS (Myron Stowe) [991615]
- [base] memory: Introduce offline/online callbacks for memory blocks (Myron Stowe) [991615]
- [acpi] memhotplug: Bind removable memory blocks to ACPI device nodes (Myron Stowe) [991615]
- [acpi] processor: Use common hotplug infrastructure (Myron Stowe) [991615]
- [acpi] hotplug: Use device offline/online for graceful hot-removal (Myron Stowe) [991615]
- [base] cpu: Use generic offline/online for CPU offline/online (Myron Stowe) [991615]
- [base] core: Add offline/online device operations (Myron Stowe) [991615]
- [scsi] bnx2i: Fix bug on some bnx2x devices that don't support iSCSI (Tomas Henzl) [957024]
- [x86] tracing: Add irq_enter/exit() in smp_trace_reschedule_interrupt() (Seiji Aguchi) [741673]
- [x86] trace: Add config option checking to the definitions of mce handlers (Seiji Aguchi) [741673]
- [x86] trace: Do not call local_irq_save() in load_current_idt() (Seiji Aguchi) [741673]
- [x86] trace: Move creation of irq tracepoints from apic.c to irq.c (Seiji Aguchi) [741673]
- [x86] trace: Add irq vector tracepoints (Seiji Aguchi) [741673]
- [x86] trace: Rename variables for debugging (Seiji Aguchi) [741673]
- [x86] trace: Introduce entering/exiting_irq() (Seiji Aguchi) [741673]
- [tracing] Add DEFINE_EVENT_FN() macro (Seiji Aguchi) [741673]
- [fs] pstore: Fail to unlink if a driver has not defined pstore_erase (Steve Best) [996930]
- [powerpc] pseries: Inform the hypervisor we are using EBB regs (Steve Best) [997646]
- [powerpc] perf: Export PERF_EVENT_CONFIG_EBB_SHIFT to userspace (Steve Best) [997646]
- [powerpc] perf: Set PPC_FEATURE2_EBB when we register the power8 PMU (Steve Best) [997646]
- [powerpc] Fix hypervisor facility unavaliable vector number (Steve Best) [995354]
- [powerpc] Fix context switch DSCR on POWER8 (Steve Best) [995354]
- [powerpc] Rework setting up H/FSCR bit definitions (Steve Best) [995354]
- [powerpc] Wire up the HV facility unavailable exception (Steve Best) [995354]
- [powerpc] Rename and flesh out the facility unavailable exception handler (Steve Best) [995354]
- [powerpc] Remove KVMTEST from RELON exception handlers (Steve Best) [995354]
- [powerpc] tm: Fix context switching TAR, PPR and DSCR SPRs (Steve Best) [988340]
- [powerpc] Save the TAR register earlier (Steve Best) [988340]

* Wed Aug 21 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-11.el7]
- [security] Revert: Secure Boot related kernel enforcements (Jarod Wilson) [903815]

* Tue Aug 20 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-10.el7]
- [block] blk-mq: blk-mq should free bios in pass through case (Mike Snitzer) [960150]
- [block] blk-mq: add missing percpu_counter_destroy for mq_usage_counter (Mike Snitzer) [960150]
- [fs] direct-io: only inc_dec inode->i_dio_count for file systems (Mike Snitzer) [960150]
- [lib] percpu_counter: make APIs irq safe (Mike Snitzer) [960150]
- [block] null_blk: multi queue aware block test driver (Mike Snitzer) [960150]
- [kernel] smp: Export __smp_call_function_single() (Mike Snitzer) [960150]
- [block] blk-mq: change sw <-> hw queue mappings on hotplug events (Mike Snitzer) [960150]
- [block] blk-mq: re-initialize queue data structure after CPU hotplug (Mike Snitzer) [960150]
- [block] blk-mq: add queue freeze/unfreeze support (Mike Snitzer) [960150]
- [block] blk-mq: fix timer infinite loop after first timeout event (Mike Snitzer) [960150]
- [block] blk-mq: timeout fixes (Mike Snitzer) [960150]
- [block] blk-mq: cpu hot plug_unplug fixes (Mike Snitzer) [960150]
- [block] blk-mq: flush handling (Mike Snitzer) [960150]
- [block] blk-mq: new multi-queue block IO queueing mechanism (Mike Snitzer) [960150]
- [block] make rq->cmd_flags be 64-bit (Mike Snitzer) [960150]
- [kernel] smp: don't warn about csd->flags having CSD_FLAG_LOCK cleared for !wait (Mike Snitzer) [960150]
- [mm] sched: Allow uaccess in atomic with pagefault_disable() (Michael S. Tsirkin) [988029]
- [mm] sched: Drop voluntary schedule from might_fault() (Michael S. Tsirkin) [988029]
- [x86] uaccess s/might_sleep/might_fault/ (Michael S. Tsirkin) [988029]
- [powerpc] uaccess s/might_sleep/might_fault/ (Michael S. Tsirkin) [988029]
- [misc] asm-generic: uaccess s/might_sleep/might_fault/ (Michael S. Tsirkin) [988029]
- [x86] efi: Disable secure boot if shim is in insecure mode (Lenny Szubowicz) [903815]
- [kernel] modsign: Import certificates from UEFI Secure Boot (Lenny Szubowicz) [903815]
- [kernel] keys: Add a system blacklist keyring (Lenny Szubowicz) [903815]
- [crypto] asymmetric_keys: Add an EFI signature blob parser and key loader (Lenny Szubowicz) [903815]
- [kernel] modsign: Fix including certificate twice when the signing_key.x509 already exists (Lenny Szubowicz) [903815]
- [kernel] keys: Add a 'trusted' flag and a 'trusted only' flag (Lenny Szubowicz) [903815]
- [kernel] modsign: Separate the kernel signature checking keyring from module signing (Lenny Szubowicz) [903815]
- [kernel] modsign: Load *.x509 files into kernel keyring (Lenny Szubowicz) [903815]
- [efi] Add EFI signature data types (Lenny Szubowicz) [903815]
- [kernel] modsign: Always enforce module signing in a Secure Boot environment (Lenny Szubowicz) [903815]
- [kernel] hibernate: Disable in a Secure Boot environment (Lenny Szubowicz) [903815]
- [kernel] kexec: Disable in a secure boot environment (Lenny Szubowicz) [903815]
- [x86] Lock down MSR writing in secure boot (Lenny Szubowicz) [903815]
- [acpi] Ignore acpi_rsdp kernel parameter in a secure boot environment (Lenny Szubowicz) [903815]
- [char] mem: Restrict /dev/mem and /dev/kmem in secure boot setups (Lenny Szubowicz) [903815]
- [platform] asus-wmi: Restrict debugfs interface (Lenny Szubowicz) [903815]
- [acpi] Limit access to custom_method (Lenny Szubowicz) [903815]
- [x86] Lock down IO port access in secure boot environments (Lenny Szubowicz) [903815]
- [pci] Lock down BAR access in secure boot environments (Lenny Szubowicz) [903815]
- [x86] efi: Enable secure boot lockdown automatically when enabled in firmware (Lenny Szubowicz) [903815]
- [kernel] Add a kernel parameter that will force on Secure Boot mode (Lenny Szubowicz) [903815]
- [security] selinux: define mapping for new Secure Boot capability (Lenny Szubowicz) [903815]
- [uapi] Add new secure boot capability (Lenny Szubowicz) [903815]
- [kernel] audit: fix mq_open and mq_unlink to add the MQ root as a hidden parent audit_names record (Jeff Layton) [908885 953186]
- [kernel] audit: log the audit_names record type (Jeff Layton) [908885 953186]
- [kernel] audit: add child record before the create to handle case where create fails (Jeff Layton) [908885 953186]
- [md] dm-raid: silence compiler warning on rebuilds_per_group (Jonathan E Brassow) [970782]
- [md] dm-raid: Fix raid_resume not reviving failed devices in all cases (Jonathan E Brassow) [970782]
- [md] dm-raid: Break-up untidy function (Jonathan E Brassow) [970782]
- [s390] zfcp: block queue limits with data router (Hendrik Brueckner) [976657]
- [scsi] scsi_lib: Fix race between starved list and device removal (Ewan Milne) [986037]
- [md] dm-switch: add switch target (Mike Snitzer) [983188]
- [wireless] disable WiMAX support (John Linville) [915650]
- [fs] gfs2: don't overrun reserved revokes (Benjamin Marzinski) [950622]
- [fs] gfs2: Reserve journal space for quota change in do_grow (Robert S Peterson) [979131]
- [x86] setup: Add cpu_has_hypervisor check to rh_check_supported() (Prarit Bhargava) [986048]
- [x86] sched: Optimize switch_mm() for multi-threaded workloads (Rik van Riel) [990747]
- [crypto] nx: fix concurrency issue (Steve Best) [996565]
- [powerpc] mm: Fix fallthrough bug in hpte_decode (Steve Best) [993326]
- [misc] Kconfig: enable building user namespace with xfs (Dave Chinner) [987255]
- [fs] xfs: add capability check to free eofblocks ioctl (Dave Chinner) [987255]
- [fs] xfs: create internal eofblocks structure with kuid_t types (Dave Chinner) [987255]
- [fs] xfs: convert kuid_t to/from uid_t for internal structures (Dave Chinner) [987255]
- [fs] xfs: ioctl check for capabilities in the current user namespace (Dave Chinner) [987255]
- [fs] xfs: convert kuid_t to/from uid_t in ACLs (Dave Chinner) [987255]
- [fs] xfs: create wrappers for converting kuid_t to/from uid_t (Dave Chinner) [987255]
- [md] raid5: fix interaction of 'replace' and 'recovery' (Jes Sorensen) [978055]
- [md] raid10: remove use-after-free bug (Jes Sorensen) [978055]
- [md] raid1: fix bio handling problems in process_checks() (Jes Sorensen) [978055]
- [md] Remove recent change which allows devices to skip recovery (Jes Sorensen) [978055]
- [md] raid10: fix two problems with RAID10 resync (Jes Sorensen) [978055]
- [md] raid10: fix bug which causes all RAID10 reshapes to move no data (Jes Sorensen) [978055]
- [md] raid5: allow 5-device RAID6 to be reshaped to 4-device (Jes Sorensen) [978055]
- [md] raid10: fix two bugs affecting RAID10 reshape (Jes Sorensen) [978055]
- [md] Remember the last sync operation that was performed (Jes Sorensen) [978055]
- [md] raid0: fix buglet in RAID5 -> RAID0 conversion (Jes Sorensen) [978055]
- [md] raid10: check In_sync flag in 'enough()' (Jes Sorensen) [978055]
- [md] raid10: locking changes for 'enough()' (Jes Sorensen) [978055]
- [md] replace strict_strto*() with kstrto*() (Jes Sorensen) [978055]
- [md] Wait for md_check_recovery before attempting device removal (Jes Sorensen) [978055]
- [md] dm-raid: Add ability to restore transiently failed devices on resume (Jes Sorensen) [978055]
- [net] ipv6: resend MLD report if a link-local address completes DAD (Flavio Leitner) [889455]
- [net] ipv6: introduce per-interface counter for dad-completed ipv6 addresses (Flavio Leitner) [889455]
- [net] ipv6: split duplicate address detection and router solicitation timer (Flavio Leitner) [889455]
- [net] tcp: introduce a per-route knob for quick ack (Amerigo Wang) [984504]
- [net] nlmon: use standard rtnetlink link api for add/del devices (Daniel Borkmann) [957721]
- [net] nlmon: fix comparison in nlmon_is_valid_mtu (Daniel Borkmann) [957721]
- [net] packet: nlmon: virtual netlink monitoring device for packet sockets (Daniel Borkmann) [957721]
- [net] netlink: virtual tap device management (Daniel Borkmann) [957721]
- [net] if_arp: add ARPHRD_NETLINK type (Daniel Borkmann) [957721]

* Tue Aug 13 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-9.el7]
- [kernel] sched: disable autogroups by default (Josh Poimboeuf) [989741]
- [powerpc] pseries: Add backward compatibilty to read old kernel oops-log (Steve Best) [991831]
- [powerpc] pseries: Fix buffer overflow when reading from pstore (Steve Best) [991831]
- [crypto] nx: saves chaining value from co-processor (Steve Best) [972656]
- [crypto] nx: fix limits to sg lists for SHA-2 (Steve Best) [972656]
- [crypto] nx: fix physical addresses added to sg lists (Steve Best) [972656]

* Mon Aug 12 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-8.el7]
- [net] ipv6: ip6_append_data_mtu did not care about pmtudisc and frag_size (Francesco Fusco) [994346] {CVE-2013-4163}
- [net] ipv6: call udp_push_pending_frames when uncorking a socket with AF_INET pending data (Francesco Fusco) [988355] {CVE-2013-4162}
- [kernel] sysctl: range checking in do_proc_dointvec_ms_jiffies_conv (Francesco Fusco) [972393]
- [net] neigh: prevent overflowing params in /proc/sys/net/ipv4/neigh/ (Francesco Fusco) [972393]
- [net] vhost-net: fix use-after-free in vhost_net_flush (Thomas Graf) [984723] {CVE-2013-4127}
- [powerpc] tm: Fix return of active 64bit signals (Steve Best) [731886]
- [powerpc] tm: Fix return of 32bit rt signals to active transactions (Steve Best) [731886]
- [powerpc] tm: Fix restoration of MSR on 32bit signal return (Steve Best) [731886]
- [powerpc] tm: Fix 32 bit non-rt signals (Steve Best) [731886]
- [powerpc] tm: Fix writing top half of MSR on 32 bit signals (Steve Best) [731886]
- [fs] nfs: verify open flags before allowing an atomic open (Jeff Layton) [984823]
- [s390] zfcp: module parameter dbflevel for early debugging (Hendrik Brueckner) [994597]
- [virt] virtio_net: fix the race between channels setting and refill (Jason Wang) [978153]
- [kernel] audit: restore order of tty and ses fields in log output (Richard Guy Briggs) [983157]
- [kernel] time/tick: Make oneshot broadcast robust vs. CPU offlining (Prarit Bhargava) [967464]
- [virt] virtio_net: fix race in RX VQ processing (Jason Wang) [989409]
- [virt] virtio: support unlocked queue poll (Jason Wang) [989409]
- [powerpc] mm: Use the correct SLB(LLP) encoding in tlbie instruction (Steve Best) [993448]
- [net] tuntap: do not zerocopy if iov needs more pages than MAX_SKB_FRAGS (Jason Wang) [982513]
- [net] tuntap: correctly linearize skb when zerocopy is used (Jason Wang) [982513]
- [virt] macvtap: do not zerocopy if iov needs more pages than MAX_SKB_FRAGS (Jason Wang) [990786]
- [virt] macvtap: do not assume 802.1Q when send vlan packets (Jason Wang) [990786]
- [virt] macvtap: fix the missing ret value of TUNSETQUEUE (Jason Wang) [990786]
- [virt] macvtap: correctly linearize skb when zerocopy is used (Jason Wang) [982513]
- [virt] macvtap: Perform GSO on forwarding path (Jason Wang) [895484]
- [virt] macvtap: Let TUNSETOFFLOAD actually controll offload features (Jason Wang) [895484]
- [virt] macvtap: Consistently use rcu functions (Jason Wang) [895484]
- [virt] macvtap: Convert to using rtnl lock (Jason Wang) [895484]
- [virt] macvtap: fix uninitialized return value macvtap_ioctl_set_queue() (Jason Wang) [731550]
- [virt] macvtap: slient sparse warnings (Jason Wang) [731550]
- [virt] macvtap: enable multiqueue flag (Jason Wang) [731550]
- [virt] macvtap: add TUNSETQUEUE ioctl (Jason Wang) [731550]
- [virt] macvtap: eliminate linear search (Jason Wang) [731550]
- [virt] macvtap: introduce macvtap_get_vlan() (Jason Wang) [731550]
- [virt] macvtap: do not add self to waitqueue if doing a nonblock read (Jason Wang) [731550]
- [virt] macvtap: fix a possible race between queue selection and changing queues (Jason Wang) [731550]

* Thu Aug 08 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-7.el7]
- [vfio] type1: Fix leak on error path (Alex Williamson) [984081]
- [vfio] Limit group opens (Alex Williamson) [984081]
- [vfio] type1: Fix missed frees and zero sized removes (Alex Williamson) [984081]
- [vfio] Provide module option to disable vfio_iommu_type1 hugepage support (Alex Williamson) [984081]
- [vfio] hugepage support for vfio_iommu_type1 (Alex Williamson) [984081]
- [vfio] Convert type1 iommu to use rbtree (Alex Williamson) [984081]
- [iommu] Use pa and zx instead of casting (Alex Williamson) [984081]
- [iommu] amd: Only unmap large pages from the first pte (Alex Williamson) [984081]
- [iommu] Fix compiler warning on pr_debug (Alex Williamson) [984081]
- [iommu] amd: Fix memory leak in free_pagetable (Alex Williamson) [984081]
- [iommu] Split iommu_unmaps (Alex Williamson) [984081]
- [iommu] intel, amd: Remove multifunction assumption around grouping (Alex Williamson) [984081]
- [x86] spinlock: make ticket lock increment 2, unconditionally (Rik van Riel) [970737]
- [virt] pvticketlock: When paravirtualizing ticket locks, increment by 2 (Rik van Riel) [970737]
- [scsi] isci: Fix a race condition in the SSP task management path (David Milburn) [990201]
- [netdrv] bnx2x: Wait for MCP validity during AER (Michal Schmidt) [797460]
- [virt] virtio_scsi: Fix virtqueue affinity setup (Asias He) [971826]
- [fs] nfs: fix open(O_RDONLY|O_TRUNC) in NFS4.0 (Jeff Layton) [987615]
- [watchdog] hpwdt: Add check for UEFI bits (Linda Knippers) [985195]
- [powerpc] mm/numa: VPHN topology change updates all siblings (Steve Best) [973594]
- [powerpc] powernv: Fix iommu initialization again (Steve Best) [979523]
- [firmware] efivars: If pstore_register fails, free unneeded pstore buffer (Lenny Szubowicz) [983597]
- [acpi] Eliminate console msg if pstore.backend excludes ERST (Lenny Szubowicz) [983597]
- [fs] pstore: Return unique error if backend registration excluded by kernel param (Lenny Szubowicz) [983597]

* Tue Aug 06 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-6.el7]
- [fs] locks: move file_lock_list to a set of percpu hlist_heads and convert file_lock_lock to an lglock (Jeff Layton) [976876]
- [fs] seq_file: add seq_list_*_percpu helpers (Jeff Layton) [976876]
- [fs] locks: give the blocked_hash its own spinlock (Jeff Layton) [976876]
- [fs] locks: add a new "lm_owner_key" lock operation (Jeff Layton) [976876]
- [fs] locks: turn the blocked_list into a hashtable (Jeff Layton) [976876]
- [fs] locks: convert fl_link to a hlist_node (Jeff Layton) [976876]
- [fs] locks: avoid taking global lock if possible when waking up blocked waiters (Jeff Layton) [976876]
- [fs] locks: protect most of the file_lock handling with i_lock (Jeff Layton) [976876]
- [fs] locks: encapsulate the fl_link list handling (Jeff Layton) [976876]
- [fs] locks: make "added" in __posix_lock_file a bool (Jeff Layton) [976876]
- [fs] locks: comment cleanups and clarifications (Jeff Layton) [976876]
- [fs] locks: make generic_add_lease and generic_delete_lease static (Jeff Layton) [976876]
- [fs] cifs: use posix_unblock_lock instead of locks_delete_block (Jeff Layton) [976876]
- [fs] locks: drop the unused filp argument to posix_unblock_lock (Jeff Layton) [976876]
- [scsi] ipr: IOA Status Code(IOASC) update (Steve Best) [731129]
- [scsi] ipr: qc_fill_rtf() method should not store alternate status register (Steve Best) [731129]
- [scsi] ipr: possible irq lock inversion dependency detected (Steve Best) [731129]
- [fs] nfsd: when dentry_open returns an error do not propagate as struct file (Steve Dickson) [987090]
- [net] sunrpc: underflow issue in decode_write_list() (Steve Dickson) [987090]
- [fs] nfsd: fix minorversion support interface (Steve Dickson) [987090]
- [fs] lockd: protect nlm_blocked access in nlmsvc_retry_blocked (Steve Dickson) [987090]
- [fs] nfsd: support minorversion 1 by default (Steve Dickson) [987090]
- [fs] nfsd: allow destroy_session over destroyed session (Steve Dickson) [987090]
- [net] sunrpc: fix failures to handle -1 uid's (Steve Dickson) [987090]
- [net] sunrpc: Don't schedule an upcall on a replaced cache entry (Steve Dickson) [987090]
- [net] sunrpc: xpt_auth_cache should be ignored when expired (Steve Dickson) [987090]
- [net] sunrpc/cache: ensure items removed from cache do not have pending upcalls (Steve Dickson) [987090]
- [net] sunrpc/cache: use cache_fresh_unlocked consistently and correctly (Steve Dickson) [987090]
- [net] sunrpc/cache: remove races with queuing an upcall (Steve Dickson) [987090]
- [fs] nfsd: return delegation immediately if lease fails (Steve Dickson) [987090]
- [fs] nfsd: do not throw away 4.1 lock state on last unlock (Steve Dickson) [987090]
- [fs] nfsd: delegation-based open reclaims should bypass permissions (Steve Dickson) [987090]
- [net] sunrpc: don't error out on small tcp fragment (Steve Dickson) [987090]
- [net] sunrpc: fix handling of too-short rpc's (Steve Dickson) [987090]
- [fs] nfsd: minor read_buf cleanup (Steve Dickson) [987090]
- [fs] nfsd: fix decoding of compounds across page boundaries (Steve Dickson) [987090]
- [fs] nfsd: clean up nfs4_open_delegation (Steve Dickson) [987090]
- [fs] nfsd: Don't give out read delegations on creates (Steve Dickson) [987090]
- [fs] nfsd: allow client to send no cb_sec flavors (Steve Dickson) [987090]
- [fs] nfsd: fail attempts to request gss on the backchannel (Steve Dickson) [987090]
- [fs] nfsd: implement minimal SP4_MACH_CRED (Steve Dickson) [987090]
- [net] sunrpc: store gss mech in svc_cred (Steve Dickson) [987090]
- [net] sunrpc: introduce init_svc_cred (Steve Dickson) [987090]
- [fs] nfsd: avoid undefined signed overflow (Steve Dickson) [987090]
- [net] sunrpc: the cache_detail in cache_is_valid is unused any more (Steve Dickson) [987090]
- [net] sunrpc: server back channel needs no rpcbind method (Steve Dickson) [987090]
- [fs] nfsd: fix compile in !CONFIG_NFSD_V4_SECURITY_LABEL case (Steve Dickson) [987090]
- [fs] nfsd: Server implementation of MAC Labeling (Steve Dickson) [987090]
- [fs] nfsd: Add NFS v4.2 support to the NFS server (Steve Dickson) [987090]
- [security] fix cap_inode_getsecctx returning garbage (Steve Dickson) [987090]
- [fs] nfsd: store correct client minorversion for >=4.2 (Steve Dickson) [987090]
- [fs] nfsd: get rid of the unused functions in vfs (Steve Dickson) [987090]
- [fs] nfs: Fix brainfart in attribute length calculation (Steve Dickson) [987090]
- [fs] nfs: Fix a regression against the FreeBSD server (Steve Dickson) [987090]
- [net] sunrpc/rpc_pipe: rpc_dir_inode_operations can be static (Steve Dickson) [987090]
- [fs] nfs: Allow nfs_updatepage to extend a write under additional circumstances (Steve Dickson) [987090]
- [fs] nfs: Make nfs_readdir revalidate less often (Steve Dickson) [987090]
- [fs] nfs: Make nfs_attribute_cache_expired() non-static (Steve Dickson) [987090]
- [net] sunrpc/rpc_pipe: set dentry operations at d_alloc time (Steve Dickson) [987090]
- [fs] nfs: set verifier on existing dentries in nfs_prime_dcache (Steve Dickson) [987090]
- [fs] nfs: Set NFS_CS_MIGRATION for NFSv4 mounts (Steve Dickson) [987090]
- [fs] nfs: Refactor nfs4_init_session and nfs4_init_channel_attrs (Steve Dickson) [987090]
- [fs] nfs: use pnfs_device maxcount for the objectlayout gdia_maxcount (Steve Dickson) [987090]
- [fs] nfs: use pnfs_device maxcount for the blocklayout gdia_maxcount (Steve Dickson) [987090]
- [fs] nfs: Fix gdia_maxcount calculation to fit in ca_maxresponsesize (Steve Dickson) [987090]
- [fs] nfs: Improve legacy idmapping fallback (Steve Dickson) [987090]
- [fs] nfs: end back channel session draining (Steve Dickson) [987090]
- [fs] nfs: Apply v4.1 capabilities to v4.2 (Steve Dickson) [987090]
- [fs] nfs: Clean up layout segment comparison helper names (Steve Dickson) [987090]
- [fs] nfs: layout segment comparison helpers should take 'const' parameters (Steve Dickson) [987090]
- [fs] nfs: Move the DNS resolver into the NFSv4 module (Steve Dickson) [987090]
- [net] sunrpc/rpc_pipefs: only set rpc_dentry_ops if d_op isn't already set (Steve Dickson) [987090]
- [fs] nfs: SETCLIENTID add the format string for the NETID (Steve Dickson) [987090]
- [fs] nfs: Add in v4.2 callback operation (Steve Dickson) [987090]
- [fs] nfs: Make callbacks minor version generic (Steve Dickson) [987090]
- [fs] nfs: Add Kconfig entry for Labeled NFS V4 client (Steve Dickson) [987090]
- [fs] nfs: Extend NFS xattr handlers to accept the security namespace (Steve Dickson) [987090]
- [fs] nfs: Client implementation of Labeled-NFS (Steve Dickson) [987090]
- [fs] nfs: Add label lifecycle management (Steve Dickson) [987090]
- [fs] nfs: Add labels to client function prototypes (Steve Dickson) [987090]
- [fs] nfs: Extend fattr bitmaps to support all 3 words (Steve Dickson) [987090]
- [fs] nfs: Introduce new label structure (Steve Dickson) [987090]
- [fs] nfs: Add label recommended attribute and NFSv4 flags (Steve Dickson) [987090]
- [fs] nfs: Added NFS v4.2 support to the NFS client (Steve Dickson) [987090]
- [security] selinux: Add new labeling type native labels (Steve Dickson) [987090]
- [security] lsm: Add flags field to security_sb_set_mnt_opts for in kernel mount data (Steve Dickson) [987090]
- [security] Add Hook to test if the particular xattr is part of a MAC model (Steve Dickson) [987090]
- [security] Add hook to calculate context based on a negative dentry (Steve Dickson) [987090]
- [fs] nfs: Close another NFSv4 recovery race (Steve Dickson) [987090]
- [fs] nfs: Move dentry instantiation into the NFSv4-specific atomic open code (Steve Dickson) [987090]
- [fs] nfs: Refactor _nfs4_open_and_get_state to set ctx->state (Steve Dickson) [987090]
- [fs] nfs: pass the nfs_open_context to nfs4_do_open (Steve Dickson) [987090]
- [fs] nfs: Remove redundant check for FMODE_EXEC in nfs_finish_open (Steve Dickson) [987090]
- [net] sunrpc: Remove redundant call to rpc_set_running() in __rpc_execute() (Steve Dickson) [987090]
- [net] sunrpc: Remove unused functions rpc_task_set/has_priority (Steve Dickson) [987090]
- [net] sunrpc: Remove the unused helpers task_for_each() and task_for_first() (Steve Dickson) [987090]
- [net] sunrpc: Remove unused function rpc_queue_empty (Steve Dickson) [987090]
- [net] sunrpc: Fix a potential race in rpc_execute (Steve Dickson) [987090]
- [fs] nfs: Simplify setting the layout header credential (Steve Dickson) [987090]
- [fs] nfs: Enable state protection (Steve Dickson) [987090]
- [fs] nfs: Use layout credentials for get_deviceinfo calls (Steve Dickson) [987090]
- [fs] nfs: Ensure that test_stateid and free_stateid use correct credentials (Steve Dickson) [987090]
- [fs] nfs: Ensure that reclaim_complete uses the right credential (Steve Dickson) [987090]
- [fs] nfs: Ensure that layoutreturn uses the correct credential (Steve Dickson) [987090]
- [fs] nfs: Ensure that layoutget is called using the layout credential (Steve Dickson) [987090]
- [fs] nfs: Add NFSv4.2 protocol constants (Steve Dickson) [987090]

* Fri Aug 02 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-5.el7]
- [fs] cifs: fix bad error handling in crypto code (Jeff Layton) [988398]
- [fs] cifs: Fix a deadlock when a file is reopened (Sachin Prabhu) [988398]
- [fs] cifs: Reopen the file if reconnect durable handle failed (Sachin Prabhu) [988398]
- [fs] cifs: Fix minor endian error in durable handle patch series (Sachin Prabhu) [988398]
- [fs] cifs: Reconnect durable handles for SMB2 (Sachin Prabhu) [988398]
- [fs] cifs: Make SMB2_open use cifs_open_parms struct (Sachin Prabhu) [988398]
- [fs] cifs: Introduce cifs_open_parms struct (Sachin Prabhu) [988398]
- [fs] cifs: Request durable open for SMB2 opens (Sachin Prabhu) [988398]
- [fs] cifs: Simplify SMB2 create context handling (Sachin Prabhu) [988398]
- [fs] cifs: Simplify SMB2_open code path (Sachin Prabhu) [988398]
- [fs] cifs: Respect create_options in smb2_open_file (Sachin Prabhu) [988398]
- [fs] cifs: Fix lease context buffer parsing (Sachin Prabhu) [988398]
- [fs] cifs: use sensible file nlink values if unprovided (Sachin Prabhu) [988398]
- [fs] cifs: Limit allocation of crypto mechanisms to dialect which requires (Sachin Prabhu) [988398]
- [fs] cifs: Don't pass inode to ->d_hash() and ->d_compare() (Sachin Prabhu) [988398]
- [fs] cifs: fill TRANS2_QUERY_FILE_INFO ByteCount fields (Sachin Prabhu) [988398]
- [fs] cifs: fix SMB2 signing enablement in cifs_enable_signing (Sachin Prabhu) [988398]
- [fs] cifs: Fix build warning (Sachin Prabhu) [988398]
- [fs] cifs: SMB3 Signing enablement (Sachin Prabhu) [988398]
- [fs] cifs: Do not set DFS flag on SMB2 open (Sachin Prabhu) [988398]
- [fs] cifs: fix static checker warning (Sachin Prabhu) [988398]
- [fs] cifs: try to handle the MUST SecurityFlags sanely (Sachin Prabhu) [988398]
- [fs] cifs: When server doesn't provide SecurityBuffer on SMB2Negotiate pick default (Sachin Prabhu) [988398]
- [fs] cifs: Handle big endianness in NTLM (ntlmv2) authentication (Sachin Prabhu) [988398]
- [fs] cifs: revalidate directories instiantiated via FIND_* in order to handle DFS referrals (Sachin Prabhu) [988398]
- [fs] cifs: SMB2 FSCTL and IOCTL worker function (Sachin Prabhu) [988398]
- [fs] cifs: Charge at least one credit, if server says that it supports multicredit (Sachin Prabhu) [988398]
- [fs] cifs: Remove typo (Sachin Prabhu) [988398]
- [fs] cifs: Some missing share flags (Sachin Prabhu) [988398]
- [fs] cifs: using strlcpy instead of strncpy (Sachin Prabhu) [988398]
- [fs] cifs: Update headers to update various SMB3 ioctl definitions (Sachin Prabhu) [988398]
- [fs] cifs: Update cifs version number (Sachin Prabhu) [988398]
- [fs] cifs: Add ability to dipslay SMB3 share flags and capabilities for debugging (Sachin Prabhu) [988398]
- [fs] cifs: Add some missing SMB3 and SMB3.02 flags (Sachin Prabhu) [988398]
- [fs] cifs: Add SMB3.02 dialect support (Sachin Prabhu) [988398]
- [fs] cifs: Fix endian error in SMB2 protocol negotiation (Sachin Prabhu) [988398]
- [fs] cifs: clean up the SecurityFlags write handler (Sachin Prabhu) [988398]
- [fs] cifs: update the default global_secflags to include "raw" NTLMv2 (Sachin Prabhu) [988398]
- [fs] move sectype to the cifs_ses instead of TCP_Server_Info (Sachin Prabhu) [988398]
- [fs] cifs: track the enablement of signing in the TCP_Server_Info (Sachin Prabhu) [988398]
- [fs] add new fields to smb_vol to track the requested security flavor (Sachin Prabhu) [988398]
- [fs] cifs: add new fields to cifs_ses to track requested security flavor (Sachin Prabhu) [988398]
- [fs] cifs: track the flavor of the NEGOTIATE reponse (Sachin Prabhu) [988398]
- [fs] cifs: add new "Unspecified" securityEnum value (Sachin Prabhu) [988398]
- [fs] cifs: factor out check for extended security bit into separate function (Sachin Prabhu) [988398]
- [fs] cifs: move handling of signed connections into separate function (Sachin Prabhu) [988398]
- [fs] cifs: break out lanman NEGOTIATE handling into separate function (Sachin Prabhu) [988398]
- [fs] cifs: break out decoding of security blob into separate function (Sachin Prabhu) [988398]
- [fs] cifs: remove the cifs_ses->flags field (Sachin Prabhu) [988398]
- [fs] cifs: throw a warning if negotiate or sess_setup ops are passed NULL server or session pointers (Sachin Prabhu) [988398]
- [fs] cifs: make decode_ascii_ssetup void return (Sachin Prabhu) [988398]
- [fs] cifs: remove useless memset in LANMAN auth code (Sachin Prabhu) [988398]
- [fs] cifs: remove protocolEnum definition (Sachin Prabhu) [988398]
- [fs] cifs: add a "nosharesock" mount option to force new sockets to server to be created (Sachin Prabhu) [988398]
- [fs] fuse: readdirplus cleanup (Niels de Vos) [988312]
- [fs] fuse: readdirplus change attributes once (Niels de Vos) [988312]
- [fs] fuse: readdirplus fix instantiate (Niels de Vos) [988312]
- [fs] fuse: readdirplus sanity checks (Niels de Vos) [988312]
- [fs] fuse: fix readdirplus dentry leak (Niels de Vos) [988312]
- [powerpc] hw_brk: Fix off by one error when validating DAWR region end (Steve Best) [843485]
- [powerpc] hw_brk: Fix clearing of extraneous IRQ (Steve Best) [843485]
- [powerpc] hw_brk: Fix setting of length for exact mode breakpoints (Steve Best) [843485]
- [powerpc] perf: Add power8 EBB support (Steve Best) [969176]
- [powerpc] perf: Core EBB support for 64-bit book3s (Steve Best) [969176]
- [powerpc] perf: Don't enable if we have zero events (Steve Best) [969176]
- [powerpc] powerpc/perf: Use existing out label in power_pmu_enable() (Steve Best) [969176]
- [powerpc] perf: Freeze PMC5/6 if we're not using them (Steve Best) [969176]
- [powerpc] powerpc/perf: Rework disable logic in pmu_disable() (Steve Best) [969176]
- [powerpc] perf: Check that events only include valid bits on Power8 (Steve Best) [969176]
- [ipc] sem: rename try_atomic_semop() to perform_atomic_semop(), docu update (Rik van Riel) [881820]
- [ipc] sem: replace shared sem_otime with per-semaphore value (Rik van Riel) [881820]
- [ipc] sem: always use only one queue for alter operations (Rik van Riel) [881820]
- [ipc] sem: separate wait-for-zero and alter tasks into seperate queues (Rik van Riel) [881820]
- [ipc] sem: cacheline align the semaphore structures (Rik van Riel) [881820]
- [fs] gfs2: Add atomic_open support (Steven Whitehouse) [983098]
- [fs] gfs2: Only do one directory search on create (Steven Whitehouse) [983098]
- [fs] pstore: Add hsize argument in write_buf call of pstore_ftrace_call (Steve Best) [947161]
- [powerpc] pseries: Support compression of oops text via pstore (Steve Best) [947161]
- [powerpc] pseries: Re-organise the oops compression code (Steve Best) [947161]
- [powerpc] pstore: Pass header size in the pstore write callback (Steve Best) [947161]
- [powerpc] pseries: Read common partition via pstore (Steve Best) [947161]
- [powerpc] pseries: Read of-config partition via pstore (Steve Best) [947161]
- [powerpc] pseries: Distinguish between a os-partition and non-os partition (Steve Best) [947161]
- [powerpc] pseries: Read rtas partition via pstore (Steve Best) [947161]
- [powerpc] pseries: Read/Write oops nvram partition via pstore (Steve Best) [947161]
- [powerpc] pseries: Introduce generic read function to read nvram-partitions (Steve Best) [947161]
- [powerpc] pseries: Add version and timestamp to oops header (Steve Best) [947161]
- [powerpc] pseries: Remove syslog prefix in uncompressed oops text (Steve Best) [947161]

* Wed Jul 31 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-4.el7]
- [x86] signals: Merge EFLAGS bit clearing into a single statement (Jiri Olsa) [986216]
- [x86] signals: Clear RF EFLAGS bit for signal handler (Jiri Olsa) [986216]
- [x86] signals: Propagate RF EFLAGS bit through the signal restore call (Jiri Olsa) [986216]
- [kernel] perf: Fix perf_lock_task_context() vs RCU (Jiri Olsa) [986216]
- [kernel] perf: Remove WARN_ON_ONCE() check in __perf_event_enable() for valid scenario (Jiri Olsa) [986216]
- [kernel] perf: Clone child context from parent context pmu (Jiri Olsa) [986216]
- [kernel] perf: Fix interrupt handler timing harness (Jiri Olsa) [986216]
- [kernel] perf: Drop sample rate when sampling is too slow (Jiri Olsa) [986216]
- [kernel] hw_breakpoint: Introduce "struct bp_cpuinfo" (Jiri Olsa) [986216]
- [kernel] hw_breakpoint: Simplify *register_wide_hw_breakpoint() (Jiri Olsa) [986216]
- [kernel] hw_breakpoint: Introduce cpumask_of_bp() (Jiri Olsa) [986216]
- [kernel] hw_breakpoint: Simplify the "weight" usage in toggle_bp_slot() paths (Jiri Olsa) [986216]
- [kernel] hw_breakpoint: Simplify list/idx mess in toggle_bp_slot() paths (Jiri Olsa) [986216]
- [kernel] perf: Add simple Haswell PMU support (Jiri Olsa) [986216]
- [kernel] perf: Add const qualifier to perf_pmu_register's 'name' arg (Jiri Olsa) [986216]
- [kernel] perf: Fix hypervisor branch sampling permission check (Jiri Olsa) [986216]
- [kernel] perf: Check branch sampling priv level in generic code (Jiri Olsa) [986216]
- [kernel] perf: Add sysfs entry to adjust multiplexing interval per PMU (Jiri Olsa) [986216]
- [kernel] perf: Use hrtimers for event multiplexing (Jiri Olsa) [986216]
- [kernel] perf: Fix hw breakpoints overflow period sampling (Jiri Olsa) [986216]
- [tools] perf/tests: Check proper prev_state size for sched_switch tp (Jiri Olsa) [984998]
- [tools] perf/tests: Omit end of the symbol check failure for test 1 (Jiri Olsa) [984998]
- [tools] perf/script: Fix broken include in Context.xs (Jiri Olsa) [984998]
- [tools] perf: Fix -ldw/-lelf link test when static linking (Jiri Olsa) [984998]
- [tools] perf: Fix perf version generation (Jiri Olsa) [984998]
- [tools] perf/stat: Fix per-socket output bug for uncore events (Jiri Olsa) [984998]
- [tools] perf/symbols: Fix vdso list searching (Jiri Olsa) [984998]
- [tools] perf/evsel: Fix missing increment in sample parsing (Jiri Olsa) [984998]
- [tools] perf: Update symbol_conf.nr_events when processing attribute events (Jiri Olsa) [984998]
- [tools] perf: Fix new_term() missing free on error path (Jiri Olsa) [984998]
- [tools] perf: Fix parse_events_terms() segfault on error path (Jiri Olsa) [984998]
- [tools] perf/evsel: Fix count parameter to read call in event_format__new (Jiri Olsa) [984998]
- [tools] perf: Fix -x/--exclude-other option for report command (Jiri Olsa) [984998]
- [tools] perf/evlist: Enhance perf_evlist__start_workload() (Jiri Olsa) [984998]
- [tools] perf/record: Remove -f/--force option (Jiri Olsa) [984998]
- [tools] perf/record: Remove -A/--append option (Jiri Olsa) [984998]
- [tools] perf/stat: Avoid sending SIGTERM to random processes (Jiri Olsa) [984998]
- [tools] perf: Include termios.h explicitly (Jiri Olsa) [984998]
- [tools] perf/bench: Fix memory allocation fail check in mem{set, cpy} workloads (Jiri Olsa) [984998]
- [tools] perf: Fix build errors with O and DESTDIR make vars set (Jiri Olsa) [984998]
- [tools] perf: Fix output directory of Documentation/ (Jiri Olsa) [984998]
- [tools] perf: Get only verbose output with V=1 (Jiri Olsa) [984998]
- [tools] perf: Add missing liblk.a dependency for python/perf.so (Jiri Olsa) [984998]
- [tools] perf: Remove '?=' Makefile STRIP assignment (Jiri Olsa) [984998]
- [tools] perf: Replace multiple line assignment with multiple statements (Jiri Olsa) [984998]
- [tools] perf: Replace tabs with spaces for all non-commands statements (Jiri Olsa) [984998]
- [tools] perf: Add NO_BIONIC variable to confiure bionic setup (Jiri Olsa) [984998]
- [tools] perf: Switch to full path C include directories (Jiri Olsa) [984998]
- [tools] perf: Merge all *LDFLAGS* make variable into LDFLAGS (Jiri Olsa) [984998]
- [tools] perf: Merge all *CFLAGS* make variable into CFLAGS (Jiri Olsa) [984998]
- [tools] perf/evlist: Reset SIGTERM handler in workload child process (Jiri Olsa) [984998]
- [tools] perf: Remove cwdlen from struct perf_session (Jiri Olsa) [984998]
- [tools] perf: Remove frozen from perf_header struct (Jiri Olsa) [984998]
- [tools] perf/tests: Fix exclude_guest|exclude_host checking for attr tests (Jiri Olsa) [984998]
- [tools] perf/tests: Fix attr test for record -d option (Jiri Olsa) [984998]
- [tools] perf: Final touches for CHK config move (Jiri Olsa) [984998]
- [tools] perf: Move paths config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libnuma check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move stdlib check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libbfd check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libpython check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libperl check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move gtk2 check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move slang check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libaudit check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libunwind check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libdw check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move libelf check config into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move compiler and linker flags check into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move programs check into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Move arch check into config/Makefile (Jiri Olsa) [984998]
- [tools] perf: Add automated make test suite (Jiri Olsa) [984998]
- [tools] perf: Save parent pid in thread struct (Jiri Olsa) [984998]
- [tools] perf/stats: Fix divide by 0 in variance (Jiri Olsa) [984998]
- [tools] perf/kvm: Handle realloc failures (Jiri Olsa) [984998]
- [tools] perf/evsel: Fix printing of perf_event_paranoid message (Jiri Olsa) [984998]
- [tools] perf/test: Fix typo (Jiri Olsa) [984998]
- [tools] perf/hists: Rename hist_entry__add_pair arguments (Jiri Olsa) [984998]
- [tools] perf/diff: Use internal rb tree for hists__precompute (Jiri Olsa) [984998]
- [tools] perf/report: Add report.percent-limit config variable (Jiri Olsa) [984998]
- [tools] perf/top: Add --percent-limit option (Jiri Olsa) [984998]
- [tools] perf/report: Add --percent-limit option (Jiri Olsa) [984998]
- [tools] perf/report: Don't bother locking when adding hist entries (Jiri Olsa) [984998]
- [tools] perf/hists: Move locking to its call-sites (Jiri Olsa) [984998]
- [tools] perf/top: Get rid of *_threaded() functions (Jiri Olsa) [984998]
- [tools] perf/top: Fix percent output when no samples collected (Jiri Olsa) [984998]
- [tools] perf/top: Fix -E option behavior (Jiri Olsa) [984998]
- [tools] perf/record: handle death by SIGTERM (Jiri Olsa) [984998]
- [tools] perf: Handle JITed code in shared memory (Jiri Olsa) [984998]
- [tools] perf/tests: Fix compile errors in bp_signal files (Jiri Olsa) [984998]
- [tools] perf: Fix tab vs spaces issue in Makefile ifdef/endif (Jiri Olsa) [984998]
- [tools] perf/hists browser: Use sort__has_sym (Jiri Olsa) [984998]
- [tools] perf/top: Use sort__has_sym (Jiri Olsa) [984998]
- [tools] perf/sort: Cleanup sort__has_sym setting (Jiri Olsa) [984998]
- [tools] perf/sort: Reorder HISTC_SRCLINE index (Jiri Olsa) [984998]
- [tools] perf/archive: Fix typo on Documentation (Jiri Olsa) [984998]
- [tools] perf/sort: Consolidate sort_entry__setup_elide() (Jiri Olsa) [984998]
- [tools] perf/sort: Separate out memory-specific sort keys (Jiri Olsa) [984998]
- [tools] perf/sort: Factor out common code in sort_dimension__add() (Jiri Olsa) [984998]
- [tools] perf/sort: Introduce sort__mode variable (Jiri Olsa) [984998]
- [tools] perf/report: Fix alignment of symbol column when -v is given (Jiri Olsa) [984998]
- [tools] perf/hists: Free unused mem info of a matched hist entry (Jiri Olsa) [984998]
- [tools] perf/hists: Fix an invalid memory free on he->branch_info (Jiri Olsa) [984998]
- [tools] perf: Fix bug in isupper() and islower() (Jiri Olsa) [984998]
- [mm] thp: define HPAGE_PMD_* constants as BUILD_BUG() if !THP (Steve Best) [947166]
- [powerpc] mm: Fix build warnings with CONFIG_TRANSPARENT_HUGEPAGE disabled (Steve Best) [947166]
- [powerpc] mm: Optimize hugepage invalidate (Steve Best) [947166]
- [powerpc] thp: Enable THP on PPC64 (Steve Best) [947166]
- [powerpc] mm: split hugepage when using subpage protection (Steve Best) [947166]
- [powerpc] mm: disable assert_pte_locked for collapse_huge_page (Steve Best) [947166]
- [powerpc] mm: Prevent gcc to re-read the pagetables (Steve Best) [947166]
- [powerpc] mm: Make linux pagetable walk safe with THP enabled (Steve Best) [947166]
- [powerpc] thp: Add code to handle HPTE faults for hugepages (Steve Best) [947166]
- [powerpc] mm: Update gup_pmd_range to handle transparent hugepages (Steve Best) [947166]
- [powerpc] kvm: Handle transparent hugepage in KVM (Steve Best) [947166]
- [powerpc] mm: Replace find_linux_pte with find_linux_pte_or_hugepte (Steve Best) [947166]
- [powerpc] mm: Update find_linux_pte_or_hugepte to handle transparent hugepages (Steve Best) [947166]
- [powerpc] mm: move find_linux_pte_or_hugepte and gup_hugepte to common code (Steve Best) [947166]
- [powerpc] thp: Implement transparent hugepages for ppc64 (Steve Best) [947166]
- [powerpc] thp: Double the PMD table size for THP (Steve Best) [947166]
- [powerpc] mm: handle hugepage size correctly when invalidating hpte entries (Steve Best) [947166]
- [mm] thp: deposit the transpare huge pgtable before set_pmd (Steve Best) [947166]
- [mm] thp: don't use HPAGE_SHIFT in transparent hugepage code (Steve Best) [947166]
- [mm] thp: withdraw the pgtable after pmdp related operations (Steve Best) [947166]
- [mm] thp: add pmd args to pgtable deposit and withdraw APIs (Steve Best) [947166]
- [mm] thp: use the correct function when updating access flags (Steve Best) [947166]

* Fri Jul 26 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-3.el7]
- [powerpc] mm/numa: Do not update sysfs cpu registration from invalid context (Steve Best) [967447]
- [misc] MAINTAINERS: Add ACPI folks for ACPI-related things under drivers/pci (Myron Stowe) [984759]
- [pci] Add CircuitCo vendor ID and subsystem ID (Myron Stowe) [984759]
- [pci] Use pdev->pm_cap instead of pci_find_capability(.., PCI_CAP_ID_PM) (Myron Stowe) [984759]
- [pci] Return early on allocation failures to unindent mainline code (Myron Stowe) [984759]
- [pci] Simplify IOV implementation and fix reference count races (Myron Stowe) [984759]
- [pci] Drop redundant setting of bus->is_added in virtfn_add_bus() (Myron Stowe) [984759]
- [pci] pci-acpi: Use correct power state strings in messages (Myron Stowe) [984759]
- [pci] Fix comment typo for pcie_pme_remove() (Myron Stowe) [984759]
- [pci] Rename pci_release_bus_bridge_dev() to pci_release_host_bridge_dev() (Myron Stowe) [984759]
- [pci] Fix refcount issue in pci_create_root_bus() error recovery path (Myron Stowe) [984759]
- [pci] Convert alloc_pci_dev(void) to pci_alloc_dev(bus) (Myron Stowe) [984759]
- [pci] Hide remove and rescan sysfs interfaces for SR-IOV virtual functions (Myron Stowe) [984759]
- [pci] Add pcibios_release_device() (Myron Stowe) [984759]
- [iommu] irq_remapping: Conserve interrupt resources when using multiple-MSIs (Myron Stowe) [984759]
- [i2c] i2c-piix4: Add AMD CZ SMBus device ID (Myron Stowe) [984759]
- [ata] ahci: Add AMD CZ SATA device ID (Myron Stowe) [984759]
- [pci] Put Hudson-2 device IDs together (Myron Stowe) [984759]
- [pci] Replace strict_strtoul() with kstrtoul() (Myron Stowe) [984759]
- [pci] Finish SR-IOV VF setup before adding the device (Myron Stowe) [984759]
- [pci] Fix comment typo for PCI_EXP_LNKCAP_CLKPM (Myron Stowe) [984759]
- [acpi] pci_root: Use dev_printk(), acpi_handle_print(), pr_xxx() when possible (Myron Stowe) [984759]
- [acpi] pci_root: Remove unused global list acpi_pci_roots (Myron Stowe) [984759]
- [acpi] pci_root: Introduce "handle" local for economy of expression (Myron Stowe) [984759]
- [acpi] pci_root: Combine duplicate adjacent "if" tests (Myron Stowe) [984759]
- [pci] Allocate only as many MSI vectors as requested by driver (Myron Stowe) [984759]
- [pci] Replace printks with appropriate pr_*() (Myron Stowe) [984759]
- [pci] Fix kerneldoc for pci_disable_link_state() (Myron Stowe) [984759]
- [x86] pci: Increase info->res_num before checking pci_use_crs (Myron Stowe) [984759]
- [pci] Fix INTC comment typo for pci_swizzle_interrupt_pin() (Myron Stowe) [984759]
- [pci] Convert ioapic.c to module_pci_driver (Myron Stowe) [984759]
- [pci] Introduce pci_alloc_dev(struct pci_bus*) to replace alloc_pci_dev() (Myron Stowe) [984759]
- [pci] Introduce pci_bus_{get|put}() to manage PCI bus reference count (Myron Stowe) [984759]
- [pci] Unset resource if initial BAR value is invalid (Myron Stowe) [984759]
- [pci] Consolidate calls to pcibios_bus_to_resource() in __pci_read_base() (Myron Stowe) [984759]
- [pci] Add 0x prefix to BAR register position in __pci_read_base() (Myron Stowe) [984759]
- [pci] aspm: Warn when driver asks to disable ASPM, but we can't do it (Myron Stowe) [984759]
- [powerpc] pci: Use PCI_UNKNOWN for unknown power state (Myron Stowe) [984759]
- [acpi] pci_root: Check acpi_resource_to_address64() return value (Myron Stowe) [984759]
- [pci] Work around Ivytown NTB BAR size issue (Myron Stowe) [984759]
- [net] sunrpc: Fix another issue with rpc_client_register() (Jeff Layton) [924649]
- [net] sunrpc: Fix a deadlock in rpc_client_register() (Jeff Layton) [924649]
- [net] sunrpc: PipeFS MOUNT notification optimization for dying clients (Jeff Layton) [924649]
- [net] sunrpc: split client creation routine into setup and registration (Jeff Layton) [924649]
- [net] sunrpc: fix races on PipeFS UMOUNT notifications (Jeff Layton) [924649]
- [net] sunrpc: fix races on PipeFS MOUNT notifications (Jeff Layton) [924649]

* Fri Jul 19 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-2.el7]
- [scsi] sd: fix crash when UA received on DIF enabled device (Ewan Milne) [979440]
- [md] dm-cache: add call to mark_tech_preview (Mike Snitzer) [982752]
- [fs] nfs: have NFSv3 try server-specified auth flavors in turn (Jeff Layton) [977649]
- [fs] nfs: have nfs_mount fake up a auth_flavs list when the server didn't provide it (Jeff Layton) [977649]
- [fs] nfs: move server_authlist into nfs_try_mount_request (Jeff Layton) [977649]
- [fs] nfs: refactor "need_mount" code out of nfs_try_mount (Jeff Layton) [977649]
- [pci] ear: Reset link for devices below Root Port or Downstream Port (Myron Stowe) [797485]
- [acpi] apei: Force fatal AER severity when component has been reset (Myron Stowe) [797485]
- [pci] aer: Remove "extern" from function declarations (Myron Stowe) [797485]
- [pci] aer: Move AER severity defines to aer.h (Myron Stowe) [797485]
- [pci] aer: Set dev->__aer_firmware_first only for matching devices (Myron Stowe) [797485]
- [pci] aer: Factor out HEST device type matching (Myron Stowe) [797485]
- [pci] aer: Don't parse HEST table for non-PCIe devices (Myron Stowe) [797485]

* Tue Jul 09 2013 Jarod Wilson <jarod@redhat.com> [3.10.0-1.el7]
- [x86] fix !CONFIG_HYPERVISOR_GUEST compile (Andrew Jones)
- [s390x] crash: Fuzzy live dump for Linux on System z (Hendrik Brueckner) [805120]
- [xen] xenfv: fix hangs when kdumping (Andrew Jones) [845471]
- [libata] export ata_port port_no attribute via /sys (David Milburn) [951181]
- [s390x] kdump: Use 4 GiB for KEXEC_AUTO_THRESHOLD (Hendrik Brueckner) [953044]
- [x86] hpet: allow user controlled mmap for user processes (Prarit Bhargava) [788727]
- [mm] add memory tracking hooks (James Paradis) [725860]
- [kernel] clocksource, fix !CONFIG_CLOCKSOURCE_WATCHDOG compile (Prarit Bhargava) [914709]
- [x86] disable clocksource watchdog (Prarit Bhargava) [914709]
- [kdump] x86, fix kdump and unsupported HW check (Prarit Bhargava) [923256]
- [x86] support single cpu on guests only (Prarit Bhargava) [873806]
- [kernel] Mark power5, power6, !Intel, and !AMD systems as unsupported (Prarit Bhargava) [870129]
- [kernel] Backport RH specific TAINT flags (Prarit Bhargava) [870129]
- [s390x] zfcpdump: Add user space tool (Hendrik Brueckner) [825189]
- [kdump] crashkernel=auto fixes and cleanup (Dave Young) [804077]
- [fedora] /dev/crash driver (Kyle McMartin) [808839]
- [kdump] forward port crashkernel auto reservation code (Dave Young) [804077]
- [block] Change scheduler to CFQ for ATA/SATA (Vivek Goyal) [811016]
- [kernel] kbuild: AFTER_LINK (Roland McGrath)
- [ppc64] disable INFINIBAND_EHCA temporarily, it ftbfs (Kyle McMartin)
- [kernel] Add RHEL_{MAJOR,MINOR,RELEASE} to top level Makefile (Kyle McMartin)

* Mon Jun 03 2013 Kyle McMartin <kyle@redhat.com>
- Trimmed changelog for rhel7.git, see rhpkg git for earlier history.

###
# The following Emacs magic makes C-c C-e use UTC dates.
# Local Variables:
# rpm-change-log-uses-utc: t
# End:
###
